@@ -40,6 +40,7 @@ use OCA\DAV\Connector\Sabre\Exception\EntityTooLarge;
 use OCA\DAV\Connector\Sabre\Exception\FileLocked;
 use OCA\DAV\Connector\Sabre\Exception\Forbidden as DAVForbiddenException;
 use OCA\DAV\Connector\Sabre\Exception\UnsupportedMediaType;
+use OCA\DAV\Files\IFileNode;
 use OCP\Encryption\Exceptions\GenericEncryptionException;
 use OCP\Events\EventEmitterTrait;
 use OCP\Files\EntityTooLargeException;
@@ -61,11 +62,10 @@ use Sabre\DAV\Exception\ServiceUnavailable;
 use Sabre\DAV\IFile;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
-class File extends Node implements IFile {
-
+class File extends Node implements IFile, IFileNode {
 	use EventEmitterTrait;
 	protected $request;
-	
+
 	/**
 	 * Sets up the node, expects a full path name
 	 *
@@ -81,7 +81,30 @@ class File extends Node implements IFile {
 		}
 		parent::__construct($view, $info, $shareManager);
 	}
-	
+
+	/**
+	 * Handles metadata updates for the target storage (mtime, propagation)
+	 *
+	 * @param Storage $targetStorage
+	 * @param $targetInternalPath
+	 */
+	private function handleMetadataUpdate(\OC\Files\Storage\Storage $targetStorage, $targetInternalPath) {
+		// since we skipped the view we need to scan and emit the hooks ourselves
+
+		// allow sync clients to send the mtime along in a header
+		if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
+			$mtime = $this->sanitizeMtime(
+				$this->request->server ['HTTP_X_OC_MTIME']
+			);
+			if ($targetStorage->touch($targetInternalPath, $mtime)) {
+				$this->header('X-OC-MTime: accepted');
+			}
+			$targetStorage->getUpdater()->update($targetInternalPath, $mtime);
+		} else {
+			$targetStorage->getUpdater()->update($targetInternalPath);
+		}
+	}
+
 	/**
 	 * Updates the data
 	 *
@@ -143,11 +166,11 @@ class File extends Node implements IFile {
 		}
 
 		list($partStorage) = $this->fileView->resolvePath($this->path);
-		$needsPartFile = $this->needsPartFile($partStorage) && (strlen($this->path) > 1);
+		$usePartFile = $this->usePartFile($partStorage) && (\strlen($this->path) > 1);
 
-		if ($needsPartFile) {
+		if ($usePartFile) {
 			// mark file as partial while uploading (ignored by the scanner)
-			$partFilePath = $this->getPartFileBasePath($this->path) . '.ocTransferId' . rand() . '.part';
+			$partFilePath = $this->getPartFileBasePath($this->path) . '.ocTransferId' . \rand() . '.part';
 		} else {
 			// upload file directly as the final path
 			$partFilePath = $this->path;
@@ -159,16 +182,33 @@ class File extends Node implements IFile {
 		/** @var \OC\Files\Storage\Storage $storage */
 		list($storage, $internalPath) = $this->fileView->resolvePath($this->path);
 		try {
+			try {
+				$this->changeLock(ILockingProvider::LOCK_EXCLUSIVE);
+			} catch (LockedException $e) {
+				if ($usePartFile) {
+					$partStorage->unlink($internalPartPath);
+				}
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
+			}
+
 			$target = $partStorage->fopen($internalPartPath, 'wb');
-			if ($target === false) {
+			if (!\is_resource($target)) {
 				\OCP\Util::writeLog('webdav', '\OC\Files\Filesystem::fopen() failed', \OCP\Util::ERROR);
 				// because we have no clue about the cause we can only throw back a 500/Internal Server Error
 				throw new Exception('Could not write file contents');
 			}
-			list($count, $result) = \OC_Helper::streamCopy($data, $target);
-			fclose($target);
 
-			if (!self::isChecksumValid($partStorage, $internalPartPath)) {
+			list($count, $result) = \OC_Helper::streamCopy($data, $target);
+			\fclose($target);
+
+			try {
+				$this->changeLock(ILockingProvider::LOCK_SHARED);
+			} catch (LockedException $e) {
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
+			}
+
+			if (!self::isChecksumValid($this->request, $partStorage, $internalPartPath)) {
+				$partStorage->unlink($internalPartPath);  // remove the uploaded file on checksum error
 				throw new BadRequest('The computed checksum does not match the one received from the client.');
 			}
 
@@ -189,9 +229,8 @@ class File extends Node implements IFile {
 					throw new BadRequest('expected filesize ' . $expected . ' got ' . $count);
 				}
 			}
-
 		} catch (\Exception $e) {
-			if ($needsPartFile) {
+			if ($usePartFile) {
 				$partStorage->unlink($internalPartPath);
 			}
 			$this->convertToSabreException($e);
@@ -201,6 +240,10 @@ class File extends Node implements IFile {
 			$view = \OC\Files\Filesystem::getView();
 			if ($view) {
 				$run = $this->emitPreHooks($exists);
+				if ($run === false) {
+					$view->unlockFile($this->path, ILockingProvider::LOCK_SHARED);
+					return null;
+				}
 			} else {
 				$run = true;
 			}
@@ -208,13 +251,13 @@ class File extends Node implements IFile {
 			try {
 				$this->changeLock(ILockingProvider::LOCK_EXCLUSIVE);
 			} catch (LockedException $e) {
-				if ($needsPartFile) {
+				if ($usePartFile) {
 					$partStorage->unlink($internalPartPath);
 				}
 				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
 			}
 
-			if ($needsPartFile) {
+			if ($usePartFile) {
 				// rename to correct path
 				try {
 					if ($run) {
@@ -233,8 +276,7 @@ class File extends Node implements IFile {
 				}
 			}
 
-			// since we skipped the view we need to scan and emit the hooks ourselves
-			$storage->getUpdater()->update($internalPath);
+			$this->handleMetadataUpdate($storage, $internalPath);
 
 			try {
 				$this->changeLock(ILockingProvider::LOCK_SHARED);
@@ -242,31 +284,11 @@ class File extends Node implements IFile {
 				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
 			}
 
-			// allow sync clients to send the mtime along in a header
-			if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
-				$mtime = $this->sanitizeMtime($this->request->server ['HTTP_X_OC_MTIME']);
-				if ($this->fileView->touch($this->path, $mtime)) {
-					$this->header('X-OC-MTime: accepted');
-				}
-			}
-
 			if ($view) {
 				$this->emitPostHooks($exists);
 			}
 
 			$this->refreshInfo();
-
-			$meta = $partStorage->getMetaData($internalPartPath);
-
-			if (isset($meta['checksum'])) {
-				$this->fileView->putFileInfo(
-					$this->path,
-					['checksum' => $meta['checksum']]
-				);
-			}
-
-			$this->refreshInfo();
-
 		} catch (StorageNotAvailableException $e) {
 			throw new ServiceUnavailable("Failed to check file size: " . $e->getMessage());
 		}
@@ -285,7 +307,7 @@ class File extends Node implements IFile {
 		if ($partFileInStorage) {
 			return $path;
 		} else {
-			return md5($path); // will place it in the root of the view with a unique name
+			return \md5($path); // will place it in the root of the view with a unique name
 		}
 	}
 
@@ -293,7 +315,7 @@ class File extends Node implements IFile {
 	 * @param string $path
 	 */
 	private function emitPreHooks($exists, $path = null) {
-		if (is_null($path)) {
+		if ($path === null) {
 			$path = $this->path;
 		}
 		$hookPath = Filesystem::getView()->getRelativePath($this->fileView->getAbsolutePath($path));
@@ -337,7 +359,7 @@ class File extends Node implements IFile {
 	 * @param string $path
 	 */
 	private function emitPostHooks($exists, $path = null) {
-		if (is_null($path)) {
+		if ($path === null) {
 			$path = $this->path;
 		}
 		$hookPath = Filesystem::getView()->getRelativePath($this->fileView->getAbsolutePath($path));
@@ -365,7 +387,7 @@ class File extends Node implements IFile {
 	public function get() {
 		//throw exception if encryption is disabled but files are still encrypted
 		try {
-			$viewPath = ltrim($this->path, '/');
+			$viewPath = \ltrim($this->path, '/');
 			if (!$this->info->isReadable() || !$this->fileView->file_exists($viewPath)) {
 				// do a if the file did not exist
 				throw new NotFound();
@@ -438,7 +460,7 @@ class File extends Node implements IFile {
 		}
 		/** @var \OCP\Files\Storage $storage */
 		list($storage, $internalPath) = $this->fileView->resolvePath($this->path);
-		if (is_null($storage)) {
+		if ($storage === null) {
 			return [];
 		}
 
@@ -454,7 +476,7 @@ class File extends Node implements IFile {
 	 * @throws ServiceUnavailable
 	 */
 	private function createFileChunked($data) {
-		list($path, $name) = \Sabre\HTTP\URLUtil::splitPath($this->path);
+		list($path, $name) = \Sabre\Uri\split($this->path);
 
 		$info = \OC_FileChunking::decodeName($name);
 		if (empty($info)) {
@@ -465,7 +487,7 @@ class File extends Node implements IFile {
 		$bytesWritten = $chunk_handler->store($info['index'], $data);
 
 		//detect aborted upload
-		if (isset ($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
+		if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
 			if (isset($_SERVER['CONTENT_LENGTH'])) {
 				$expected = $_SERVER['CONTENT_LENGTH'];
 				if ($bytesWritten != $expected) {
@@ -477,8 +499,8 @@ class File extends Node implements IFile {
 		}
 
 		if ($chunk_handler->isComplete()) {
-			list($storage,) = $this->fileView->resolvePath($path);
-			$needsPartFile = $this->needsPartFile($storage);
+			list($storage, ) = $this->fileView->resolvePath($path);
+			$usePartFile = $this->usePartFile($storage);
 			$partFile = null;
 
 			$targetPath = $path . '/' . $info['name'];
@@ -505,16 +527,16 @@ class File extends Node implements IFile {
 				/** @var \OC\Files\Storage\Storage $targetStorage */
 				list($targetStorage, $targetInternalPath) = $this->fileView->resolvePath($targetPath);
 
-				if ($needsPartFile) {
+				if ($usePartFile) {
 					// we first assembly the target file as a part file
 					$partFile = $this->getPartFileBasePath($path . '/' . $info['name']) . '.ocTransferId' . $info['transferid'] . '.part';
 					/** @var \OC\Files\Storage\Storage $targetStorage */
 					list($partStorage, $partInternalPath) = $this->fileView->resolvePath($partFile);
 
-
 					$chunk_handler->file_assemble($partStorage, $partInternalPath);
 
-					if (!self::isChecksumValid($partStorage, $partInternalPath)) {
+					if (!self::isChecksumValid($this->request, $partStorage, $partInternalPath)) {
+						$partStorage->unlink($partInternalPath);  // remove the uploaded file on checksum error
 						throw new BadRequest('The computed checksum does not match the one received from the client.');
 					}
 
@@ -538,18 +560,7 @@ class File extends Node implements IFile {
 					$chunk_handler->file_assemble($targetStorage, $targetInternalPath);
 				}
 
-				// allow sync clients to send the mtime along in a header
-				if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
-					$mtime = $this->sanitizeMtime(
-						$this->request->server ['HTTP_X_OC_MTIME']
-					);
-					if ($targetStorage->touch($targetInternalPath, $mtime)) {
-						$this->header('X-OC-MTime: accepted');
-					}
-				}
-
-				// since we skipped the view we need to scan and emit the hooks ourselves
-				$targetStorage->getUpdater()->update($targetInternalPath);
+				$this->handleMetadataUpdate($targetStorage, $targetInternalPath);
 
 				$this->fileView->changeLock($targetPath, ILockingProvider::LOCK_SHARED);
 
@@ -558,12 +569,12 @@ class File extends Node implements IFile {
 				// FIXME: should call refreshInfo but can't because $this->path is not the of the final file
 				$info = $this->fileView->getFileInfo($targetPath);
 
-
-				if (isset($partStorage) && isset($partInternalPath)) {
-					$checksums = $partStorage->getMetaData($partInternalPath)['checksum'];
+				if (isset($partStorage, $partInternalPath)) {
+					$metadata = $partStorage->getMetaData($partInternalPath);
 				} else {
-					$checksums = $targetStorage->getMetaData($targetInternalPath)['checksum'];
+					$metadata = $targetStorage->getMetaData($targetInternalPath);
 				}
+				$checksums = (isset($metadata['checksum'])) ? $metadata['checksum'] : null;
 
 				$this->fileView->putFileInfo(
 					$targetPath,
@@ -602,20 +613,18 @@ class File extends Node implements IFile {
 	 * @param $path
 	 * @return bool
 	 */
-	private static function isChecksumValid(Storage $storage, $path) {
+	private static function isChecksumValid(Request $request, Storage $storage, $path) {
 		$meta = $storage->getMetaData($path);
-		$request = \OC::$server->getRequest();
 
 		if (!isset($request->server['HTTP_OC_CHECKSUM']) || !isset($meta['checksum'])) {
 			// No comparison possible, skip the check
 			return true;
 		}
 
-		$expectedChecksum = trim($request->server['HTTP_OC_CHECKSUM']);
+		$expectedChecksum = \trim($request->server['HTTP_OC_CHECKSUM']);
 		$computedChecksums = $meta['checksum'];
 
-		return strpos($computedChecksums, $expectedChecksum) !== false;
-
+		return \strpos($computedChecksums, $expectedChecksum) !== false;
 	}
 
 	/**
@@ -624,14 +633,11 @@ class File extends Node implements IFile {
 	 * target storage.
 	 *
 	 * @param \OCP\Files\Storage $storage
-	 * @return bool true if the storage needs part file handling
+	 * @return bool true if the storage uses part file handling
 	 */
-	private function needsPartFile($storage) {
+	private function usePartFile($storage) {
 		// TODO: in the future use ChunkHandler provided by storage
-		// and/or add method on Storage called "needsPartFile()"
-		return !$storage->instanceOfStorage('OCA\Files_Sharing\External\Storage') &&
-			!$storage->instanceOfStorage('OCA\Files_external\Lib\Storage\OwnCloud') &&
-			!$storage->instanceOfStorage('OC\Files\ObjectStore\ObjectStoreStorage');
+		return $storage->usePartFile();
 	}
 
 	/**
@@ -644,7 +650,7 @@ class File extends Node implements IFile {
 	private function convertToSabreException(\Exception $e) {
 		if ($e instanceof FileContentNotAllowedException) {
 			// the file content is not permitted
-			throw new FileContentNotAllowedException($e->getMessage(), $e->getRetry(), $e);
+			throw new DAVForbiddenException($e->getMessage(), $e->getRetry(), $e);
 		}
 		if ($e instanceof \Sabre\DAV\Exception) {
 			throw $e;
@@ -698,12 +704,12 @@ class File extends Node implements IFile {
 			return $allChecksums;
 		}
 
-		$checksums = explode(' ', $allChecksums);
-		$algoPrefix = strtoupper($algo) . ':';
+		$checksums = \explode(' ', $allChecksums);
+		$algoPrefix = \strtoupper($algo) . ':';
 
 		foreach ($checksums as $checksum) {
 			// starts with $algoPrefix
-			if (substr($checksum, 0, strlen($algoPrefix)) === $algoPrefix) {
+			if (\substr($checksum, 0, \strlen($algoPrefix)) === $algoPrefix) {
 				return $checksum;
 			}
 		}
@@ -714,4 +720,11 @@ class File extends Node implements IFile {
 	protected function header($string) {
 		\header($string);
 	}
+
+	/**
+	 * @return \OCP\Files\Node
+	 */
+	public function getNode() {
+		return \OC::$server->getRootFolder()->get($this->getFileInfo()->getPath());
+	}
 }
