@@ -38,6 +38,8 @@ use OCP\IUserManager;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IShare;
 use OCP\Share\IShareProvider;
+use Symfony\Component\EventDispatcher\EventDispatcherInterface;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * Class FederatedShareProvider
@@ -45,12 +47,14 @@ use OCP\Share\IShareProvider;
  * @package OCA\FederatedFileSharing
  */
 class FederatedShareProvider implements IShareProvider {
-
 	const SHARE_TYPE_REMOTE = 6;
 
 	/** @var IDBConnection */
 	private $dbConnection;
 
+	/** @var EventDispatcherInterface */
+	private $eventDispatcher;
+
 	/** @var AddressHandler */
 	private $addressHandler;
 
@@ -75,6 +79,9 @@ class FederatedShareProvider implements IShareProvider {
 	/** @var string */
 	private $externalShareTable = 'share_external';
 
+	/** @var string */
+	private $shareTable = 'share';
+
 	/** @var IUserManager */
 	private $userManager;
 
@@ -82,6 +89,7 @@ class FederatedShareProvider implements IShareProvider {
 	 * DefaultShareProvider constructor.
 	 *
 	 * @param IDBConnection $connection
+	 * @param EventDispatcherInterface $eventDispatcher
 	 * @param AddressHandler $addressHandler
 	 * @param Notifications $notifications
 	 * @param TokenHandler $tokenHandler
@@ -93,6 +101,7 @@ class FederatedShareProvider implements IShareProvider {
 	 */
 	public function __construct(
 			IDBConnection $connection,
+			EventDispatcherInterface $eventDispatcher,
 			AddressHandler $addressHandler,
 			Notifications $notifications,
 			TokenHandler $tokenHandler,
@@ -103,6 +112,7 @@ class FederatedShareProvider implements IShareProvider {
 			IUserManager $userManager
 	) {
 		$this->dbConnection = $connection;
+		$this->eventDispatcher = $eventDispatcher;
 		$this->addressHandler = $addressHandler;
 		$this->notifications = $notifications;
 		$this->tokenHandler = $tokenHandler;
@@ -131,13 +141,13 @@ class FederatedShareProvider implements IShareProvider {
 	 * @throws \Exception
 	 */
 	public function create(IShare $share) {
-
 		$shareWith = $share->getSharedWith();
 		$itemSource = $share->getNodeId();
 		$itemType = $share->getNodeType();
 		$permissions = $share->getPermissions();
+		$expiration = $share->getExpirationDate();
 		$sharedBy = $share->getSharedBy();
-		
+
 		/*
 		 * Check if file is not already shared with the remote user
 		 */
@@ -145,23 +155,23 @@ class FederatedShareProvider implements IShareProvider {
 		if (!empty($alreadyShared)) {
 			$message = 'Sharing %s failed, because this item is already shared with %s';
 			$message_t = $this->l->t('Sharing %s failed, because this item is already shared with %s', [$share->getNode()->getName(), $shareWith]);
-			$this->logger->debug(sprintf($message, $share->getNode()->getName(), $shareWith), ['app' => 'Federated File Sharing']);
+			$this->logger->debug(\sprintf($message, $share->getNode()->getName(), $shareWith), ['app' => 'Federated File Sharing']);
 			throw new \Exception($message_t);
 		}
 
-
 		// don't allow federated shares if source and target server are the same
-		list($user, $remote) = $this->addressHandler->splitUserRemote($shareWith);
-		$currentServer = $this->addressHandler->generateRemoteURL();
 		$currentUser = $sharedBy;
-		if ($this->addressHandler->compareAddresses($user, $remote, $currentUser, $currentServer)) {
+		$ownerAddress =  $this->addressHandler->getLocalUserFederatedAddress($currentUser);
+		$shareWithAddress = new Address($shareWith);
+
+		if ($ownerAddress->equalTo($shareWithAddress)) {
 			$message = 'Not allowed to create a federated share with the same user.';
 			$message_t = $this->l->t('Not allowed to create a federated share with the same user');
 			$this->logger->debug($message, ['app' => 'Federated File Sharing']);
 			throw new \Exception($message_t);
 		}
 
-		$share->setSharedWith($user . '@' . $remote);
+		$share->setSharedWith($shareWithAddress->getCloudId());
 
 		try {
 			$remoteShare = $this->getShareFromExternalShareTable($share);
@@ -172,11 +182,11 @@ class FederatedShareProvider implements IShareProvider {
 		if ($remoteShare) {
 			try {
 				$uidOwner = $remoteShare['owner'] . '@' . $remoteShare['remote'];
-				$shareId = $this->addShareToDB($itemSource, $itemType, $shareWith, $sharedBy, $uidOwner, $permissions, 'tmp_token_' . time());
+				$shareId = $this->addShareToDB($itemSource, $itemType, $shareWith, $sharedBy, $uidOwner, $permissions, $expiration, 'tmp_token_' . \time());
 				$share->setId($shareId);
 				list($token, $remoteId) = $this->askOwnerToReShare($shareWith, $share, $shareId);
 				// remote share was create successfully if we get a valid token as return
-				$send = is_string($token) && $token !== '';
+				$send = \is_string($token) && $token !== '';
 			} catch (\Exception $e) {
 				// fall back to old re-share behavior if the remote server
 				// doesn't support flat re-shares (was introduced with ownCloud 9.1)
@@ -184,14 +194,13 @@ class FederatedShareProvider implements IShareProvider {
 				$shareId = $this->createFederatedShare($share);
 			}
 			if ($send) {
-				$this->updateSuccessfulReshare($shareId, $token);
+				$this->updateSuccessfulReShare($shareId, $token);
 				$this->storeRemoteId($shareId, $remoteId);
 			} else {
 				$this->removeShareFromTable($share);
 				$message_t = $this->l->t('File is already shared with %s', [$shareWith]);
 				throw new \Exception($message_t);
 			}
-
 		} else {
 			$shareId = $this->createFederatedShare($share);
 		}
@@ -217,28 +226,50 @@ class FederatedShareProvider implements IShareProvider {
 			$share->getSharedBy(),
 			$share->getShareOwner(),
 			$share->getPermissions(),
+			$share->getExpirationDate(),
 			$token
 		);
 
 		try {
-			$sharedByFederatedId = $share->getSharedBy();
-			if ($this->userManager->userExists($sharedByFederatedId)) {
-				$sharedByFederatedId = $sharedByFederatedId . '@' . $this->addressHandler->generateRemoteURL();
+			$sharedBy = $share->getSharedBy();
+			if ($this->userManager->userExists($sharedBy)) {
+				$sharedByAddress = $this->addressHandler->getLocalUserFederatedAddress($sharedBy);
+			} else {
+				$sharedByAddress = new Address($sharedBy);
 			}
-			$send = $this->notifications->sendRemoteShare(
+
+			$owner = $share->getShareOwner();
+			$ownerAddress = $this->addressHandler->getLocalUserFederatedAddress($owner);
+			$sharedWith = $share->getSharedWith();
+			$shareWithAddress = new Address($sharedWith);
+			$result = $this->notifications->sendRemoteShare(
+				$shareWithAddress,
+				$ownerAddress,
+				$sharedByAddress,
 				$token,
-				$share->getSharedWith(),
 				$share->getNode()->getName(),
-				$shareId,
-				$share->getShareOwner(),
-				$share->getShareOwner() . '@' . $this->addressHandler->generateRemoteURL(),
-				$share->getSharedBy(),
-				$sharedByFederatedId
+				$shareId
 			);
 
-			if ($send === false) {
-				$message_t = $this->l->t('Sharing %s failed, could not find %s, maybe the server is currently unreachable.',
-					[$share->getNode()->getName(), $share->getSharedWith()]);
+			/* Check for failure or null return from sending and pick up an error message
+			 * if there is one coming from the remote server, otherwise use a generic one.
+			 */
+			if (\is_bool($result)) {
+				$status = $result;
+			} elseif (isset($result['ocs']['meta']['status'])) {
+				$status = $result['ocs']['meta']['status'];
+			} else {
+				$status = false;
+			}
+
+			if ($status === false) {
+				$msg = $result['ocs']['meta']['message'] ?? false;
+				if (!$msg) {
+					$message_t = $this->l->t('Sharing %s failed, could not find %s, maybe the server is currently unreachable.',
+						[$share->getNode()->getName(), $share->getSharedWith()]);
+				} else {
+					$message_t = $this->l->t("Federated Sharing failed: %s", [$msg]);
+				}
 				throw new \Exception($message_t);
 			}
 		} catch (\Exception $e) {
@@ -258,7 +289,6 @@ class FederatedShareProvider implements IShareProvider {
 	 * @throws \Exception
 	 */
 	protected function askOwnerToReShare($shareWith, IShare $share, $shareId) {
-
 		$remoteShare = $this->getShareFromExternalShareTable($share);
 		$token = $remoteShare['share_token'];
 		$remoteId = $remoteShare['remote_id'];
@@ -290,7 +320,7 @@ class FederatedShareProvider implements IShareProvider {
 			->andWhere($query->expr()->eq('mountpoint', $query->createNamedParameter($share->getTarget())));
 		$result = $query->execute()->fetchAll();
 
-		if (isset($result[0]) && (int)$result[0]['remote_id'] > 0) {
+		if (isset($result[0]) && $result[0]['remote_id'] !== "") {
 			return $result[0];
 		}
 
@@ -309,9 +339,9 @@ class FederatedShareProvider implements IShareProvider {
 	 * @param string $token
 	 * @return int
 	 */
-	private function addShareToDB($itemSource, $itemType, $shareWith, $sharedBy, $uidOwner, $permissions, $token) {
+	private function addShareToDB($itemSource, $itemType, $shareWith, $sharedBy, $uidOwner, $permissions, $expiration, $token) {
 		$qb = $this->dbConnection->getQueryBuilder();
-		$qb->insert('share')
+		$qb->insert($this->shareTable)
 			->setValue('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE))
 			->setValue('item_type', $qb->createNamedParameter($itemType))
 			->setValue('item_source', $qb->createNamedParameter($itemSource))
@@ -320,8 +350,9 @@ class FederatedShareProvider implements IShareProvider {
 			->setValue('uid_owner', $qb->createNamedParameter($uidOwner))
 			->setValue('uid_initiator', $qb->createNamedParameter($sharedBy))
 			->setValue('permissions', $qb->createNamedParameter($permissions))
+			->setValue('expiration', $qb->createNamedParameter($expiration, IQueryBuilder::PARAM_DATE))
 			->setValue('token', $qb->createNamedParameter($token))
-			->setValue('stime', $qb->createNamedParameter(time()));
+			->setValue('stime', $qb->createNamedParameter(\time()));
 
 		/*
 		 * Added to fix https://github.com/owncloud/core/issues/22215
@@ -346,21 +377,36 @@ class FederatedShareProvider implements IShareProvider {
 		 * We allow updating the permissions of federated shares
 		 */
 		$qb = $this->dbConnection->getQueryBuilder();
-			$qb->update('share')
+		$qb->update($this->shareTable)
 				->where($qb->expr()->eq('id', $qb->createNamedParameter($share->getId())))
 				->set('permissions', $qb->createNamedParameter($share->getPermissions()))
+				->set('expiration', $qb->createNamedParameter($share->getExpirationDate(), IQueryBuilder::PARAM_DATE))
 				->set('uid_owner', $qb->createNamedParameter($share->getShareOwner()))
 				->set('uid_initiator', $qb->createNamedParameter($share->getSharedBy()))
 				->execute();
 
-		// send the updated permission to the owner/initiator, if they are not the same
-		if ($share->getShareOwner() !== $share->getSharedBy()) {
+		// send the updated permission to the owner/initiator
+		if ($this->shouldNotifyRemote($share)) {
 			$this->sendPermissionUpdate($share);
 		}
 
 		return $share;
 	}
 
+	/**
+	 * User based check
+	 *
+	 * @param IShare $share
+	 * @return bool
+	 */
+	protected function shouldNotifyRemote($share) {
+		// We notify owner/initiator, if they are not the same user and ANY of them is NOT a local user
+		// they could be both local e.g. if recipient of local share shared it via federation
+		$isRemoteUserInvolved =  $this->userManager->userExists($share->getShareOwner()) == false
+			|| $this->userManager->userExists($share->getSharedBy()) == false;
+		return $isRemoteUserInvolved && $share->getShareOwner() !== $share->getSharedBy();
+	}
+
 	/**
 	 * send the updated permission to the owner/initiator, if they are not the same
 	 *
@@ -379,7 +425,6 @@ class FederatedShareProvider implements IShareProvider {
 		$this->notifications->sendPermissionChange($remote, $remoteId, $share->getToken(), $share->getPermissions());
 	}
 
-
 	/**
 	 * update successful reShare with the correct token
 	 *
@@ -388,7 +433,7 @@ class FederatedShareProvider implements IShareProvider {
 	 */
 	protected function updateSuccessfulReShare($shareId, $token) {
 		$query = $this->dbConnection->getQueryBuilder();
-		$query->update('share')
+		$query->update($this->shareTable)
 			->where($query->expr()->eq('id', $query->createNamedParameter($shareId)))
 			->set('token', $query->createNamedParameter($token))
 			->execute();
@@ -416,7 +461,7 @@ class FederatedShareProvider implements IShareProvider {
 	 * get share ID on remote server for federated re-shares
 	 *
 	 * @param IShare $share
-	 * @return int
+	 * @return string
 	 * @throws ShareNotFound
 	 */
 	public function getRemoteId(IShare $share) {
@@ -425,11 +470,11 @@ class FederatedShareProvider implements IShareProvider {
 			->where($query->expr()->eq('share_id', $query->createNamedParameter((int)$share->getId())));
 		$data = $query->execute()->fetch();
 
-		if (!is_array($data) || !isset($data['remote_id'])) {
+		if (!\is_array($data) || !isset($data['remote_id'])) {
 			throw new ShareNotFound();
 		}
 
-		return (int)$data['remote_id'];
+		return $data['remote_id'];
 	}
 
 	/**
@@ -454,13 +499,13 @@ class FederatedShareProvider implements IShareProvider {
 
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('*')
-			->from('share')
+			->from($this->shareTable)
 			->where($qb->expr()->eq('parent', $qb->createNamedParameter($parent->getId())))
 			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)))
 			->orderBy('id');
 
 		$cursor = $qb->execute();
-		while($data = $cursor->fetch()) {
+		while ($data = $cursor->fetch()) {
 			$children[] = $this->createShareObject($data);
 		}
 		$cursor->closeCursor();
@@ -474,13 +519,10 @@ class FederatedShareProvider implements IShareProvider {
 	 * @param IShare $share
 	 */
 	public function delete(IShare $share) {
-
 		list(, $remote) = $this->addressHandler->splitUserRemote($share->getSharedWith());
 
 		$isOwner = false;
 
-		$this->removeShareFromTable($share);
-
 		// if the local user is the owner we can send the unShare request directly...
 		if ($this->userManager->userExists($share->getShareOwner())) {
 			$this->notifications->sendRemoteUnShare($remote, $share->getId(), $share->getToken());
@@ -492,8 +534,8 @@ class FederatedShareProvider implements IShareProvider {
 			$this->revokeShare($share, false);
 		}
 
-		// send revoke notification to the other user, if initiator and owner are not the same user
-		if ($share->getShareOwner() !== $share->getSharedBy()) {
+		// send revoke notification to the other user
+		if ($this->shouldNotifyRemote($share)) {
 			$remoteId = $this->getRemoteId($share);
 			if ($isOwner) {
 				list(, $remote) = $this->addressHandler->splitUserRemote($share->getSharedBy());
@@ -502,6 +544,7 @@ class FederatedShareProvider implements IShareProvider {
 			}
 			$this->notifications->sendRevokeShare($remote, $remoteId, $share->getToken());
 		}
+		$this->removeShareFromTable($share);
 	}
 
 	/**
@@ -514,8 +557,8 @@ class FederatedShareProvider implements IShareProvider {
 	 * @throws \OC\HintException
 	 */
 	protected function revokeShare($share, $isOwner) {
-		// also send a unShare request to the initiator, if this is a different user than the owner
-		if ($share->getShareOwner() !== $share->getSharedBy()) {
+		// also send a unShare request to the initiator
+		if ($this->shouldNotifyRemote($share)) {
 			if ($isOwner) {
 				list(, $remote) = $this->addressHandler->splitUserRemote($share->getSharedBy());
 			} else {
@@ -542,7 +585,7 @@ class FederatedShareProvider implements IShareProvider {
 	 */
 	private function removeShareFromTableById($shareId) {
 		$qb = $this->dbConnection->getQueryBuilder();
-		$qb->delete('share')
+		$qb->delete($this->shareTable)
 			->where($qb->expr()->eq('id', $qb->createNamedParameter($shareId)));
 		$qb->execute();
 
@@ -567,63 +610,64 @@ class FederatedShareProvider implements IShareProvider {
 	 */
 	public function getAllSharesBy($userId, $shareTypes, $nodeIDs, $reshares) {
 		$shares = [];
+
 		$qb = $this->dbConnection->getQueryBuilder();
+		$qb->select('*')
+			->from($this->shareTable);
 
-		$nodeIdsChunks = array_chunk($nodeIDs, 100);
-		foreach ($nodeIdsChunks as $nodeIdsChunk) {
-			// In federates sharing currently we have only one share_type_remote
-			$qb->select('*')
-				->from('share');
+		// In federated sharing currently we have only one share_type_remote
+		$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)));
 
-			$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)));
+		$qb->andWhere($qb->expr()->in('file_source', $qb->createParameter('file_source_ids')));
 
-			/**
-			 * Reshares for this user are shares where they are the owner.
-			 */
-			if ($reshares === false) {
-				//Special case for old shares created via the web UI
-				$or1 = $qb->expr()->andX(
+		/**
+		 * Reshares for this user are shares where they are the owner.
+		 */
+		if ($reshares === false) {
+			//Special case for old shares created via the web UI
+			$or1 = $qb->expr()->andX(
+				$qb->expr()->eq('uid_owner', $qb->createNamedParameter($userId)),
+				$qb->expr()->isNull('uid_initiator')
+			);
+
+			$qb->andWhere(
+				$qb->expr()->orX(
+					$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId)),
+					$or1
+				)
+			);
+		} else {
+			$qb->andWhere(
+				$qb->expr()->orX(
 					$qb->expr()->eq('uid_owner', $qb->createNamedParameter($userId)),
-					$qb->expr()->isNull('uid_initiator')
-				);
+					$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId))
+				)
+			);
+		}
 
-				$qb->andWhere(
-					$qb->expr()->orX(
-						$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId)),
-						$or1
-					)
-				);
-			} else {
-				$qb->andWhere(
-					$qb->expr()->orX(
-						$qb->expr()->eq('uid_owner', $qb->createNamedParameter($userId)),
-						$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId))
-					)
-				);
-			}
+		$qb->orderBy('id');
 
-			$qb->andWhere($qb->expr()->in('file_source', $qb->createParameter('file_source_ids')));
+		$nodeIdsChunks = \array_chunk($nodeIDs, 900);
+		foreach ($nodeIdsChunks as $nodeIdsChunk) {
 			$qb->setParameter('file_source_ids', $nodeIdsChunk, IQueryBuilder::PARAM_INT_ARRAY);
 
-			$qb->orderBy('id');
-
 			$cursor = $qb->execute();
-			while($data = $cursor->fetch()) {
+			while ($data = $cursor->fetch()) {
 				$shares[] = $this->createShareObject($data);
 			}
 			$cursor->closeCursor();
 		}
-		
+
 		return $shares;
 	}
-	
+
 	/**
 	 * @inheritdoc
 	 */
 	public function getSharesBy($userId, $shareType, $node, $reshares, $limit, $offset) {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('*')
-			->from('share');
+			->from($this->shareTable);
 
 		$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)));
 
@@ -665,7 +709,7 @@ class FederatedShareProvider implements IShareProvider {
 
 		$cursor = $qb->execute();
 		$shares = [];
-		while($data = $cursor->fetch()) {
+		while ($data = $cursor->fetch()) {
 			$shares[] = $this->createShareObject($data);
 		}
 		$cursor->closeCursor();
@@ -680,10 +724,10 @@ class FederatedShareProvider implements IShareProvider {
 		$qb = $this->dbConnection->getQueryBuilder();
 
 		$qb->select('*')
-			->from('share')
+			->from($this->shareTable)
 			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)))
 			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)));
-		
+
 		$cursor = $qb->execute();
 		$data = $cursor->fetch();
 		$cursor->closeCursor();
@@ -711,13 +755,13 @@ class FederatedShareProvider implements IShareProvider {
 		$qb = $this->dbConnection->getQueryBuilder();
 
 		$cursor = $qb->select('*')
-			->from('share')
+			->from($this->shareTable)
 			->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($path->getId())))
 			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)))
 			->execute();
 
 		$shares = [];
-		while($data = $cursor->fetch()) {
+		while ($data = $cursor->fetch()) {
 			$shares[] = $this->createShareObject($data);
 		}
 		$cursor->closeCursor();
@@ -725,7 +769,6 @@ class FederatedShareProvider implements IShareProvider {
 		return $shares;
 	}
 
-
 	/**
 	 * @inheritdoc
 	 */
@@ -743,7 +786,7 @@ class FederatedShareProvider implements IShareProvider {
 		//Get shares directly with this user
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('*')
-			->from('share');
+			->from($this->shareTable);
 
 		// Order by id
 		$qb->orderBy('id');
@@ -764,12 +807,11 @@ class FederatedShareProvider implements IShareProvider {
 
 		$cursor = $qb->execute();
 
-		while($data = $cursor->fetch()) {
+		while ($data = $cursor->fetch()) {
 			$shares[] = $this->createShareObject($data);
 		}
 		$cursor->closeCursor();
 
-
 		return $shares;
 	}
 
@@ -784,7 +826,7 @@ class FederatedShareProvider implements IShareProvider {
 		$qb = $this->dbConnection->getQueryBuilder();
 
 		$cursor = $qb->select('*')
-			->from('share')
+			->from($this->shareTable)
 			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_REMOTE)))
 			->andWhere($qb->expr()->eq('token', $qb->createNamedParameter($token)))
 			->execute();
@@ -804,6 +846,44 @@ class FederatedShareProvider implements IShareProvider {
 		return $share;
 	}
 
+	/**
+	 * @inheritDoc
+	 */
+	public function getSharesWithInvalidFileid(int $limit) {
+		// mimic the implementation for the default share provider in core
+		$validShareTypes = [
+			\OCP\Share::SHARE_TYPE_REMOTE,
+		];
+		// other share types aren't handled by this provider
+
+		$qb = $this->dbConnection->getQueryBuilder();
+
+		$qb = $qb->select('s.*')
+			->from('share', 's')
+			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+			->where($qb->expr()->isNull('f.fileid'))
+			->andWhere(
+				$qb->expr()->in(
+					'share_type',
+					$qb->createNamedParameter($validShareTypes, IQueryBuilder::PARAM_INT_ARRAY)
+				)
+			)
+			->orderBy('s.id');
+
+		if ($limit >= 0) {
+			$qb->setMaxResults($limit);
+		}
+		$cursor = $qb->execute();
+
+		$shares = [];
+		while ($data = $cursor->fetch()) {
+			$shares[] = $this->createShareObject($data);
+		}
+		$cursor->closeCursor();
+
+		return $shares;
+	}
+
 	/**
 	 * get database row of a give share
 	 *
@@ -816,7 +896,7 @@ class FederatedShareProvider implements IShareProvider {
 		// Now fetch the inserted share and create a complete share object
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('*')
-			->from('share')
+			->from($this->shareTable)
 			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)));
 
 		$cursor = $qb->execute();
@@ -839,9 +919,8 @@ class FederatedShareProvider implements IShareProvider {
 	 * @throws ShareNotFound
 	 */
 	private function createShareObject($data) {
-
 		$share = new Share($this->rootFolder, $this->userManager);
-		$share->setId((int)$data['id'])
+		$share->setId($data['id'])
 			->setShareType((int)$data['share_type'])
 			->setPermissions((int)$data['permissions'])
 			->setTarget($data['file_target'])
@@ -865,6 +944,11 @@ class FederatedShareProvider implements IShareProvider {
 			$share->setShareOwner($owner->getUID());
 		}
 
+		if ($data['expiration'] !== null) {
+			$expiration = \DateTime::createFromFormat('Y-m-d H:i:s', $data['expiration']);
+			$share->setExpirationDate($expiration);
+		}
+
 		$share->setNodeId((int)$data['file_source']);
 		$share->setNodeType($data['item_type']);
 
@@ -888,7 +972,7 @@ class FederatedShareProvider implements IShareProvider {
 			throw new InvalidShare();
 		}
 
-		$nodes = $userFolder->getById($id);
+		$nodes = $userFolder->getById($id, true);
 
 		if (empty($nodes)) {
 			throw new InvalidShare();
@@ -909,7 +993,7 @@ class FederatedShareProvider implements IShareProvider {
 
 		$qb = $this->dbConnection->getQueryBuilder();
 
-		$qb->delete('share')
+		$qb->delete($this->shareTable)
 			->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_REMOTE)))
 			->andWhere($qb->expr()->eq('uid_owner', $qb->createNamedParameter($uid)))
 			->execute();
@@ -936,6 +1020,16 @@ class FederatedShareProvider implements IShareProvider {
 		return;
 	}
 
+	/**
+	 * check if scan of federated shares from other ownCloud instances should be performed
+	 *
+	 * @return bool
+	 */
+	public function isCronjobScanExternalEnabled() {
+		$result = $this->config->getAppValue('files_sharing', 'cronjob_scan_external_enabled', 'no');
+		return ($result === 'yes') ? true : false;
+	}
+
 	/**
 	 * check if users from other ownCloud instances are allowed to mount public links share by this instance
 	 *
@@ -955,4 +1049,135 @@ class FederatedShareProvider implements IShareProvider {
 		$result = $this->config->getAppValue('files_sharing', 'incoming_server2server_share_enabled', 'yes');
 		return ($result === 'yes') ? true : false;
 	}
+
+	/**
+	 * @inheritdoc
+	 */
+	public function updateForRecipient(IShare $share, $recipient) {
+		/*
+		 * This function does nothing yet as it is just for outgoing
+		 * federated shares.
+		 */
+		return $share;
+	}
+
+	/**
+	 * @param string $remoteId
+	 * @param string $shareToken
+	 * @return mixed
+	 */
+	public function unshare($remoteId, $shareToken) {
+		$query = $this->dbConnection->getQueryBuilder();
+		$query->select('*')->from($this->externalShareTable)
+			->where(
+				$query->expr()->eq(
+					'remote_id', $query->createNamedParameter($remoteId)
+				)
+			)
+			->andWhere(
+				$query->expr()->eq(
+					'share_token',
+					$query->createNamedParameter($shareToken)
+				)
+			);
+		$shareRow = $query->execute()->fetch();
+		if ($shareRow !== false) {
+			$query = $this->dbConnection->getQueryBuilder();
+			$query->delete($this->externalShareTable)
+				->where(
+					$query->expr()->eq(
+						'remote_id',
+						$query->createNamedParameter($shareRow['remote_id'])
+					)
+				)
+				->andWhere(
+					$query->expr()->eq(
+						'share_token',
+						$query->createNamedParameter($shareRow['share_token'])
+					)
+				);
+			$query->execute();
+		}
+		return $shareRow;
+	}
+
+	/**
+	 * @param $remote
+	 * @param $token
+	 * @param $name
+	 * @param $owner
+	 * @param $shareWith
+	 * @param $remoteId
+	 *
+	 * @return int
+	 */
+	public function addShare($remote, $token, $name, $owner, $shareWith, $remoteId) {
+		\OC_Util::setupFS($shareWith);
+		$externalManager = new \OCA\Files_Sharing\External\Manager(
+			$this->dbConnection,
+			\OC\Files\Filesystem::getMountManager(),
+			\OC\Files\Filesystem::getLoader(),
+			\OC::$server->getNotificationManager(),
+			\OC::$server->getEventDispatcher(),
+			$shareWith
+		);
+		$externalManager->addShare(
+			$remote,
+			$token,
+			'',
+			$name,
+			$owner,
+			$this->getAccepted($remote, $shareWith),
+			$shareWith,
+			$remoteId
+		);
+		return $this->dbConnection->lastInsertId("*PREFIX*{$this->externalShareTable}");
+	}
+
+	/**
+	 * @param string $remote
+	 * @param string $shareWith
+	 *
+	 * @return bool
+	 */
+	public function getAccepted($remote, $shareWith) {
+		$event = $this->eventDispatcher->dispatch(
+			'remoteshare.received',
+			new GenericEvent('', ['remote' => $remote])
+		);
+		'@phan-var GenericEvent $event';
+		if ($event->getArgument('autoAddServers')) {
+			return false;
+		}
+		$globalAutoAcceptValue  = $this->config->getAppValue(
+			'federatedfilesharing',
+			'auto_accept_trusted',
+			'no'
+		);
+		if ($globalAutoAcceptValue !== 'yes') {
+			return false;
+		}
+		$autoAccept = $this->config->getUserValue(
+			$shareWith,
+			'federatedfilesharing',
+			'auto_accept_share_trusted',
+			$globalAutoAcceptValue
+		);
+		if ($autoAccept !== 'yes') {
+			return false;
+		}
+
+		return $event->getArgument('isRemoteTrusted') === true;
+	}
+
+	/**
+	 * @inheritdoc
+	 */
+	public function getProviderCapabilities() {
+		return [
+			\OCP\Share::CONVERT_SHARE_TYPE_TO_STRING[\OCP\Share::SHARE_TYPE_REMOTE] => [
+				IShareProvider::CAPABILITY_STORE_EXPIRATION,
+			],
+		];
+	}
 }
