@@ -4,10 +4,12 @@ OC.L10N.register(
     "Unknown error" : "غیر معروف خرابی",
     "Close" : "بند ",
     "Download" : "ڈاؤن لوڈ،",
+    "Rename" : "نام بدلیں",
     "Delete" : "حذف کریں",
-    "Error" : "ایرر",
+    "Unshare" : "شئیرنگ ختم کریں",
+    "Files" : "فائلیں",
+    "group" : "مجموعہ",
     "Name" : "اسم",
-    "Save" : "حفظ",
     "Settings" : "ترتیبات"
 },
 "nplurals=2; plural=(n != 1);");
