@@ -14,8 +14,9 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Martin Mattel <github@diemattels.at>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,18 +39,17 @@ use GuzzleHttp\Exception\RequestException;
 use Icewind\Streams\IteratorDirectory;
 use Icewind\Streams\RetryWrapper;
 
-set_include_path(get_include_path().PATH_SEPARATOR.
-	\OC_App::getAppPath('files_external').'/3rdparty/google-api-php-client/src');
-require_once 'Google/autoload.php';
-
-class Google extends \OC\Files\Storage\Common {
-
+class Google extends \OCP\Files\Storage\StorageAdapter {
 	private $client;
 	private $id;
+	private $root;
 	private $service;
 	private $driveFiles;
 
-	private static $tempFiles = array();
+	private static $tempFiles = [];
+
+	private $defaultFieldsForFile;
+	private $defaultFieldsForFolderScan;
 
 	// Google Doc mimetypes
 	const FOLDER = 'application/vnd.google-apps.folder';
@@ -61,57 +61,122 @@ class Google extends \OC\Files\Storage\Common {
 
 	public function __construct($params) {
 		if (isset($params['configured']) && $params['configured'] === 'true'
-			&& isset($params['client_id']) && isset($params['client_secret'])
-			&& isset($params['token'])
+			&& isset($params['client_id'], $params['client_secret'], $params['token'])
+
 		) {
-			$this->client = new \Google_Client();
+			$this->client = new \Google_Client([
+				'retry' => [
+					'retries' => 5,
+					// keep other retry params as default
+				]
+			]);
 			$this->client->setClientId($params['client_id']);
 			$this->client->setClientSecret($params['client_secret']);
-			$this->client->setScopes(array('https://www.googleapis.com/auth/drive'));
-			$this->client->setAccessToken($params['token']);
-			// if curl isn't available we're likely to run into
-			// https://github.com/google/google-api-php-client/issues/59
-			// - disable gzip to avoid it.
-			if (!function_exists('curl_version') || !function_exists('curl_exec')) {
-				$this->client->setClassConfig("Google_Http_Request", "disable_gzip", true);
-			}
-			$this->client->setClassConfig('Google_Task_Runner', 'retries', 5);
+			$this->client->setScopes(['https://www.googleapis.com/auth/drive']);
+			$this->client->setAccessToken(\json_decode($params['token'], true));
+
 			// note: API connection is lazy
 			$this->service = new \Google_Service_Drive($this->client);
-			$token = json_decode($params['token'], true);
-			$this->id = 'google::'.substr($params['client_id'], 0, 30).$token['created'];
+			$token = \json_decode($params['token'], true);
+			$this->id = 'google::'.\substr($params['client_id'], 0, 30).$token['created'];
+			$this->root = isset($params['root']) ? $params['root'] : '';
 		} else {
 			throw new \Exception('Creating Google storage failed');
 		}
 	}
 
+	/**
+	 * @return boolean
+	 */
+	public function usePartFile() {
+		return false;
+	}
+
 	public function getId() {
-		return $this->id;
+		if ($this->root === '') {
+			return $this->id;
+		} else {
+			return "{$this->id}/{$this->root}";
+		}
+	}
+
+	private function getDefaultFieldsForFile() {
+		if ($this->defaultFieldsForFile === null) {
+			$this->defaultFieldsForFile = \implode(',', [
+				'id',
+				'name',
+				'mimeType',
+				'parents',
+				'capabilities/canEdit',
+				'size',
+				'viewedByMeTime',
+				'createdTime',
+				'modifiedTime',
+			]);
+		}
+		return $this->defaultFieldsForFile;
+	}
+
+	private function getDefaultFieldsForFolderScan() {
+		if ($this->defaultFieldsForFolderScan === null) {
+			$this->defaultFieldsForFolderScan = \implode(',', [
+				'incompleteSearch',
+				'nextPageToken',
+				"files({$this->getDefaultFieldsForFile()})",  // ask for the same fields to cache info
+			]);
+		}
+		return $this->defaultFieldsForFolderScan;
 	}
 
 	/**
-	 * Get the Google_Service_Drive_DriveFile object for the specified path.
+	 * Transform an external path to one originating from the virtual root.
+	 * @param $path string the path relative to the virtual root directory
+	 * @return string a path starting at the real root of Google Drive
+	 */
+	private function getAbsolutePath($path) {
+		if ($path === '.') {
+			$path = '';
+		}
+		$path = "{$this->root}/{$path}";
+		return \trim($path, '/');
+	}
+
+	/**
+	 * Get elements of the relative path given.
+	 * The path is relative, in case a subfolder is used.
 	 * Returns false on failure.
 	 * @param string $path
 	 * @return \Google_Service_Drive_DriveFile|false
 	 */
 	private function getDriveFile($path) {
+		return $this->getInternalDriveFile($this->getAbsolutePath($path));
+	}
+
+	/**
+	 * Get the elements of the absolute path in case a subfolder is used.
+	 * Returns false on failure.
+	 * @param string $path
+	 * @return \Google_Service_Drive_DriveFile|false
+	 */
+	private function getInternalDriveFile($path) {
 		// Remove leading and trailing slashes
-		$path = trim($path, '/');
+		$path = \trim($path, '/');
 		if ($path === '.') {
 			$path = '';
 		}
 		if (isset($this->driveFiles[$path])) {
 			return $this->driveFiles[$path];
-		} else if ($path === '') {
-			$root = $this->service->files->get('root');
+		} elseif ($path === '') {
+			$root = $this->service->files->get('root', [
+				'fields' => $this->getDefaultFieldsForFile(),
+			]);
 			$this->driveFiles[$path] = $root;
 			return $root;
 		} else {
 			// Google Drive SDK does not have methods for retrieving files by path
 			// Instead we must find the id of the parent folder of the file
-			$parentId = $this->getDriveFile('')->getId();
-			$folderNames = explode('/', $path);
+			$parentId = $this->getInternalDriveFile('')->getId();
+			$folderNames = \explode('/', $path);
 			$path = '';
 			// Loop through each folder of this path to get to the file
 			foreach ($folderNames as $name) {
@@ -124,24 +189,28 @@ class Google extends \OC\Files\Storage\Common {
 				if (isset($this->driveFiles[$path])) {
 					$parentId = $this->driveFiles[$path]->getId();
 				} else {
-					$q = "title='" . str_replace("'","\\'", $name) . "' and '" . str_replace("'","\\'", $parentId) . "' in parents and trashed = false";
-					$result = $this->service->files->listFiles(array('q' => $q))->getItems();
+					$q = "name='" . \str_replace("'", "\\'", $name) . "' and '" . \str_replace("'", "\\'", $parentId) . "' in parents and trashed = false";
+					$result = $this->service->files->listFiles([
+						'q' => $q,
+						'fields' => $this->getDefaultFieldsForFolderScan(),
+					])->getFiles();
+
 					if (!empty($result)) {
 						// Google Drive allows files with the same name, ownCloud doesn't
-						if (count($result) > 1) {
+						if (\count($result) > 1) {
 							$this->onDuplicateFileDetected($path);
 							return false;
 						} else {
-							$file = current($result);
+							$file = \current($result);
 							$this->driveFiles[$path] = $file;
 							$parentId = $file->getId();
 						}
 					} else {
 						// Google Docs have no extension in their title, so try without extension
-						$pos = strrpos($path, '.');
+						$pos = \strrpos($path, '.');
 						if ($pos !== false) {
-							$pathWithoutExt = substr($path, 0, $pos);
-							$file = $this->getDriveFile($pathWithoutExt);
+							$pathWithoutExt = \substr($path, 0, $pos);
+							$file = $this->getInternalDriveFile($pathWithoutExt);
 							if ($file && $this->isGoogleDocFile($file)) {
 								// Switch cached Google_Service_Drive_DriveFile to the correct index
 								unset($this->driveFiles[$pathWithoutExt]);
@@ -166,13 +235,22 @@ class Google extends \OC\Files\Storage\Common {
 	 * @param \Google_Service_Drive_DriveFile|false $file
 	 */
 	private function setDriveFile($path, $file) {
-		$path = trim($path, '/');
+		$this->setDriveFileHelper($this->getAbsolutePath($path), $file);
+	}
+
+	/**
+	 * Set the Google_Service_Drive_DriveFile object in the cache
+	 * @param string $path
+	 * @param \Google_Service_Drive_DriveFile|false $file
+	 */
+	private function setDriveFileHelper($path, $file) {
+		$path = \trim($path, '/');
 		$this->driveFiles[$path] = $file;
 		if ($file === false) {
 			// Remove all children
-			$len = strlen($path);
+			$len = \strlen($path);
 			foreach ($this->driveFiles as $key => $file) {
-				if (substr($key, 0, $len) === $path) {
+				if (\substr($key, 0, $len) === $path) {
 					unset($this->driveFiles[$key]);
 				}
 			}
@@ -184,8 +262,10 @@ class Google extends \OC\Files\Storage\Common {
 	 * @param string $path
 	 */
 	private function onDuplicateFileDetected($path) {
-		$about = $this->service->about->get();
-		$user = $about->getName();
+		$about = $this->service->about->get([
+			'fields' => 'user/displayName',
+		]);
+		$user = $about->getUser()->getDisplayName();
 		\OCP\Util::writeLog('files_external',
 			'Ignoring duplicate file name: '.$path.' on Google Drive for Google user: '.$user,
 			\OCP\Util::INFO
@@ -200,11 +280,11 @@ class Google extends \OC\Files\Storage\Common {
 	private function getGoogleDocExtension($mimetype) {
 		if ($mimetype === self::DOCUMENT) {
 			return 'odt';
-		} else if ($mimetype === self::SPREADSHEET) {
+		} elseif ($mimetype === self::SPREADSHEET) {
 			return 'ods';
-		} else if ($mimetype === self::DRAWING) {
+		} elseif ($mimetype === self::DRAWING) {
 			return 'jpg';
-		} else if ($mimetype === self::PRESENTATION) {
+		} elseif ($mimetype === self::PRESENTATION) {
 			// Download as .odp is not available
 			return 'pdf';
 		} else {
@@ -225,15 +305,13 @@ class Google extends \OC\Files\Storage\Common {
 
 	public function mkdir($path) {
 		if (!$this->is_dir($path)) {
-			$parentFolder = $this->getDriveFile(dirname($path));
+			$parentFolder = $this->getDriveFile(\dirname($path));
 			if ($parentFolder) {
 				$folder = new \Google_Service_Drive_DriveFile();
-				$folder->setTitle(basename($path));
+				$folder->setName(\basename($path));
 				$folder->setMimeType(self::FOLDER);
-				$parent = new \Google_Service_Drive_ParentReference();
-				$parent->setId($parentFolder->getId());
-				$folder->setParents(array($parent));
-				$result = $this->service->files->insert($folder);
+				$folder->setParents([$parentFolder->getId()]);
+				$result = $this->service->files->create($folder, ['fields' => $this->getDefaultFieldsForFile()]);
 				if ($result) {
 					$this->setDriveFile($path, $result);
 				}
@@ -247,19 +325,19 @@ class Google extends \OC\Files\Storage\Common {
 		if (!$this->isDeletable($path)) {
 			return false;
 		}
-		if (trim($path, '/') === '') {
+		if (\trim($path, '/') === '') {
 			$dir = $this->opendir($path);
-			if(is_resource($dir)) {
-				while (($file = readdir($dir)) !== false) {
+			if (\is_resource($dir)) {
+				while (($file = \readdir($dir)) !== false) {
 					if (!\OC\Files\Filesystem::isIgnoredDir($file)) {
 						if (!$this->unlink($path.'/'.$file)) {
 							return false;
 						}
 					}
 				}
-				closedir($dir);
+				\closedir($dir);
 			}
-			$this->driveFiles = array();
+			$this->driveFiles = [];
 			return true;
 		} else {
 			return $this->unlink($path);
@@ -269,25 +347,30 @@ class Google extends \OC\Files\Storage\Common {
 	public function opendir($path) {
 		$folder = $this->getDriveFile($path);
 		if ($folder) {
-			$files = array();
-			$duplicates = array();
+			$files = [];
+			$duplicates = [];
 			$pageToken = true;
 			while ($pageToken) {
-				$params = array();
+				$params = [];
 				if ($pageToken !== true) {
 					$params['pageToken'] = $pageToken;
 				}
-				$params['q'] = "'" . str_replace("'","\\'", $folder->getId()) . "' in parents and trashed = false";
+				$params['q'] = "'" . \str_replace("'", "\\'", $folder->getId()) . "' in parents and trashed = false";
+				$params['fields'] = $this->getDefaultFieldsForFolderScan();
 				$children = $this->service->files->listFiles($params);
-				foreach ($children->getItems() as $child) {
-					$name = $child->getTitle();
+				foreach ($children->getFiles() as $child) {
+					$name = $child->getName();
 					// Check if this is a Google Doc i.e. no extension in name
 					$extension = $child->getFileExtension();
 					if (empty($extension)) {
 						if ($child->getMimeType() === self::MAP) {
 							continue; // No method known to transfer map files, ignore it
-						} else if ($child->getMimeType() !== self::FOLDER) {
-							$name .= '.'.$this->getGoogleDocExtension($child->getMimeType());
+						} elseif ($child->getMimeType() !== self::FOLDER) {
+							$extension = $this->getGoogleDocExtension($child->getMimeType());
+							// don't append an empty extension as they will create broken paths
+							if ($extension !== '') {
+								$name .= ".{$extension}";
+							}
 						}
 					}
 					if ($path === '') {
@@ -297,7 +380,7 @@ class Google extends \OC\Files\Storage\Common {
 					}
 					// Google Drive allows files with the same name, ownCloud doesn't
 					// Prevent opendir() from returning any duplicate files
-					$key = array_search($name, $files);
+					$key = \array_search($name, $files);
 					if ($key !== false || isset($duplicates[$filepath])) {
 						if (!isset($duplicates[$filepath])) {
 							$duplicates[$filepath] = true;
@@ -322,21 +405,15 @@ class Google extends \OC\Files\Storage\Common {
 	public function stat($path) {
 		$file = $this->getDriveFile($path);
 		if ($file) {
-			$stat = array();
+			$stat = [];
 			if ($this->filetype($path) === 'dir') {
 				$stat['size'] = 0;
 			} else {
-				// Check if this is a Google Doc
-				if ($this->isGoogleDocFile($file)) {
-					// Return unknown file size
-					$stat['size'] = \OCP\Files\FileInfo::SPACE_UNKNOWN;
-				} else {
-					$stat['size'] = $file->getFileSize();
-				}
+				$stat['size'] = $file->getSize();
 			}
-			$stat['atime'] = strtotime($file->getLastViewedByMeDate());
-			$stat['mtime'] = strtotime($file->getModifiedDate());
-			$stat['ctime'] = strtotime($file->getCreatedDate());
+			$stat['atime'] = \strtotime($file->getViewedByMeTime());
+			$stat['mtime'] = \strtotime($file->getModifiedTime());
+			$stat['ctime'] = \strtotime($file->getCreatedTime());
 			return $stat;
 		} else {
 			return false;
@@ -344,7 +421,7 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function filetype($path) {
-		if ($path === '') {
+		if ($this->getAbsolutePath($path) === '') {
 			return 'dir';
 		} else {
 			$file = $this->getDriveFile($path);
@@ -363,7 +440,7 @@ class Google extends \OC\Files\Storage\Common {
 	public function isUpdatable($path) {
 		$file = $this->getDriveFile($path);
 		if ($file) {
-			return $file->getEditable();
+			return $file->getCapabilities()->getCanEdit();
 		} else {
 			return false;
 		}
@@ -376,7 +453,10 @@ class Google extends \OC\Files\Storage\Common {
 	public function unlink($path) {
 		$file = $this->getDriveFile($path);
 		if ($file) {
-			$result = $this->service->files->trash($file->getId());
+			$toUpdate = new \Google_Service_Drive_DriveFile();
+			$toUpdate->setTrashed(true);
+			// not interested in the 'fields' returned by the response
+			$result = $this->service->files->update($file->getId(), $toUpdate);
 			if ($result) {
 				$this->setDriveFile($path, false);
 			}
@@ -390,20 +470,21 @@ class Google extends \OC\Files\Storage\Common {
 		$file = $this->getDriveFile($path1);
 		if ($file) {
 			$newFile = $this->getDriveFile($path2);
-			if (dirname($path1) === dirname($path2)) {
+			$toUpdate = new \Google_Service_Drive_DriveFile();
+			if (\dirname($path1) === \dirname($path2)) {
 				if ($newFile) {
 					// rename to the name of the target file, could be an office file without extension
-					$file->setTitle($newFile->getTitle());
+					$toUpdate->setName($newFile->getName());
 				} else {
-					$file->setTitle(basename(($path2)));
+					$toUpdate->setName(\basename(($path2)));
 				}
 			} else {
 				// Change file parent
-				$parentFolder2 = $this->getDriveFile(dirname($path2));
+				$parentFolder1 = $this->getDriveFile(\dirname($path1));
+				$parentFolder2 = $this->getDriveFile(\dirname($path2));
 				if ($parentFolder2) {
-					$parent = new \Google_Service_Drive_ParentReference();
-					$parent->setId($parentFolder2->getId());
-					$file->setParents(array($parent));
+					$removedParent = $parentFolder1->getId();
+					$addedParent = $parentFolder2->getId();
 				} else {
 					return false;
 				}
@@ -417,7 +498,11 @@ class Google extends \OC\Files\Storage\Common {
 				$this->rmdir($path2);
 				$oldfile = false;
 			}
-			$result = $this->service->files->patch($file->getId(), $file);
+			$result = $this->service->files->update($file->getId(), $toUpdate, [
+				'fields' => $this->getDefaultFieldsForFile(),
+				'addParents' => $addedParent,
+				'removeParents' => $removedParent
+			]);
 			if ($result) {
 				$this->setDriveFile($path1, false);
 				$this->setDriveFile($path2, $result);
@@ -435,9 +520,9 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function fopen($path, $mode) {
-		$pos = strrpos($path, '.');
+		$pos = \strrpos($path, '.');
 		if ($pos !== false) {
-			$ext = substr($path, $pos);
+			$ext = \substr($path, $pos);
 		} else {
 			$ext = '';
 		}
@@ -446,39 +531,25 @@ class Google extends \OC\Files\Storage\Common {
 			case 'rb':
 				$file = $this->getDriveFile($path);
 				if ($file) {
-					$exportLinks = $file->getExportLinks();
-					$mimetype = $this->getMimeType($path);
-					$downloadUrl = null;
-					if ($exportLinks && isset($exportLinks[$mimetype])) {
-						$downloadUrl = $exportLinks[$mimetype];
-					} else {
-						$downloadUrl = $file->getDownloadUrl();
-					}
-					if (isset($downloadUrl)) {
-						$request = new \Google_Http_Request($downloadUrl, 'GET', null, null);
-						$httpRequest = $this->client->getAuth()->sign($request);
-						// the library's service doesn't support streaming, so we use Guzzle instead
-						$client = \OC::$server->getHTTPClientService()->newClient();
-						try {
-							$response = $client->get($downloadUrl, [
-								'headers' => $httpRequest->getRequestHeaders(),
-								'stream' => true,
-								'verify' => realpath(__DIR__ . '/../../../3rdparty/google-api-php-client/src/Google/IO/cacerts.pem'),
-							]);
-						} catch (RequestException $e) {
-							if(!is_null($e->getResponse())) {
-								if ($e->getResponse()->getStatusCode() === 404) {
-									return false;
-								} else {
-									throw $e;
-								}
+					try {
+						if (!$this->isGoogleDocFile($file)) {
+							$content = $this->service->files->get($file->getId(), ['alt' => 'media']);
+						} else {
+							$content = $this->service->files->export($file->getId(), $this->getMimeType($path));
+						}
+						$contentBody = $content->getBody();
+						$contentBody->seek(0);
+						return RetryWrapper::wrap($contentBody->detach());
+					} catch (RequestException $e) {
+						if ($e->getResponse() !== null) {
+							if ($e->getResponse()->getStatusCode() === 404) {
+								return false;
 							} else {
 								throw $e;
 							}
+						} else {
+							throw $e;
 						}
-
-						$handle = $response->getBody();
-						return RetryWrapper::wrap($handle);
 					}
 				}
 				return false;
@@ -495,51 +566,54 @@ class Google extends \OC\Files\Storage\Common {
 			case 'c':
 			case 'c+':
 				$tmpFile = \OCP\Files::tmpFile($ext);
-				\OC\Files\Stream\Close::registerCallback($tmpFile, array($this, 'writeBack'));
+				\OC\Files\Stream\Close::registerCallback($tmpFile, [$this, 'writeBack']);
 				if ($this->file_exists($path)) {
 					$source = $this->fopen($path, 'rb');
-					file_put_contents($tmpFile, $source);
+					\file_put_contents($tmpFile, $source);
 				}
 				self::$tempFiles[$tmpFile] = $path;
-				return fopen('close://'.$tmpFile, $mode);
+				return \fopen('close://'.$tmpFile, $mode);
 		}
 	}
 
 	public function writeBack($tmpFile) {
 		if (isset(self::$tempFiles[$tmpFile])) {
 			$path = self::$tempFiles[$tmpFile];
-			$parentFolder = $this->getDriveFile(dirname($path));
+			$parentFolder = $this->getDriveFile(\dirname($path));
 			if ($parentFolder) {
 				$mimetype = \OC::$server->getMimeTypeDetector()->detect($tmpFile);
-				$params = array(
+				$params = [
 					'mimeType' => $mimetype,
-					'uploadType' => 'media'
-				);
+					'uploadType' => 'media',
+					'fields' => $this->getDefaultFieldsForFile(),
+				];
 				$result = false;
 
 				$chunkSizeBytes = 10 * 1024 * 1024;
 
 				$useChunking = false;
-				$size = filesize($tmpFile);
+				$size = \filesize($tmpFile);
 				if ($size > $chunkSizeBytes) {
 					$useChunking = true;
 				} else {
-					$params['data'] = file_get_contents($tmpFile);
+					$params['data'] = \file_get_contents($tmpFile);
 				}
 
 				if ($this->file_exists($path)) {
 					$file = $this->getDriveFile($path);
 					$this->client->setDefer($useChunking);
-					$request = $this->service->files->update($file->getId(), $file, $params);
+					$request = $this->service->files->update(
+						$file->getId(),
+						new \Google_Service_Drive_DriveFile(),
+						$params
+					);
 				} else {
 					$file = new \Google_Service_Drive_DriveFile();
-					$file->setTitle(basename($path));
+					$file->setName(\basename($path));
 					$file->setMimeType($mimetype);
-					$parent = new \Google_Service_Drive_ParentReference();
-					$parent->setId($parentFolder->getId());
-					$file->setParents(array($parent));
+					$file->setParents([$parentFolder->getId()]);
 					$this->client->setDefer($useChunking);
-					$request = $this->service->files->insert($file, $params);
+					$request = $this->service->files->create($file, $params);
 				}
 
 				if ($useChunking) {
@@ -557,9 +631,9 @@ class Google extends \OC\Files\Storage\Common {
 					// Upload the various chunks. $status will be false until the process is
 					// complete.
 					$status = false;
-					$handle = fopen($tmpFile, 'rb');
-					while (!$status && !feof($handle)) {
-						$chunk = fread($handle, $chunkSizeBytes);
+					$handle = \fopen($tmpFile, 'rb');
+					while (!$status && !\feof($handle)) {
+						$chunk = \fread($handle, $chunkSizeBytes);
 						$status = $media->nextChunk($chunk);
 					}
 
@@ -570,7 +644,7 @@ class Google extends \OC\Files\Storage\Common {
 						$result = $status;
 					}
 
-					fclose($handle);
+					\fclose($handle);
 				} else {
 					$result = $request;
 				}
@@ -582,7 +656,7 @@ class Google extends \OC\Files\Storage\Common {
 					$this->setDriveFile($path, $result);
 				}
 			}
-			unlink($tmpFile);
+			\unlink($tmpFile);
 		}
 	}
 
@@ -593,13 +667,13 @@ class Google extends \OC\Files\Storage\Common {
 			// Convert Google Doc mimetypes, choosing Open Document formats for download
 			if ($mimetype === self::FOLDER) {
 				return 'httpd/unix-directory';
-			} else if ($mimetype === self::DOCUMENT) {
+			} elseif ($mimetype === self::DOCUMENT) {
 				return 'application/vnd.oasis.opendocument.text';
-			} else if ($mimetype === self::SPREADSHEET) {
+			} elseif ($mimetype === self::SPREADSHEET) {
 				return 'application/x-vnd.oasis.opendocument.spreadsheet';
-			} else if ($mimetype === self::DRAWING) {
+			} elseif ($mimetype === self::DRAWING) {
 				return 'image/jpeg';
-			} else if ($mimetype === self::PRESENTATION) {
+			} elseif ($mimetype === self::PRESENTATION) {
 				// Download as .odp is not available
 				return 'application/pdf';
 			} else {
@@ -612,34 +686,40 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function free_space($path) {
-		$about = $this->service->about->get();
-		return $about->getQuotaBytesTotal() - $about->getQuotaBytesUsed();
+		$about = $this->service->about->get([
+			'fields' => 'storageQuota(limit,usage)',
+		]);
+		$quotas = $about->getStorageQuota();
+		return $quotas->getLimit() - $quotas->getUsage();
 	}
 
 	public function touch($path, $mtime = null) {
 		$file = $this->getDriveFile($path);
+		$toUpdate = new \Google_Service_Drive_DriveFile();
 		$result = false;
 		if ($file) {
 			if (isset($mtime)) {
 				// This is just RFC3339, but frustratingly, GDrive's API *requires*
 				// the fractions portion be present, while no handy PHP constant
 				// for RFC3339 or ISO8601 includes it. So we do it ourselves.
-				$file->setModifiedDate(date('Y-m-d\TH:i:s.uP', $mtime));
-				$result = $this->service->files->patch($file->getId(), $file, array(
-					'setModifiedDate' => true,
-				));
+				$toUpdate->setModifiedTime(\date('Y-m-d\TH:i:s.uP', $mtime));
 			} else {
-				$result = $this->service->files->touch($file->getId());
+				$toUpdate->setModifiedTime(\date('Y-m-d\TH:i:s.uP'));
 			}
+			$result = $this->service->files->update(
+				$file->getId(),
+				$toUpdate,
+				['fields' => $this->getDefaultFieldsForFile()]
+			);
 		} else {
-			$parentFolder = $this->getDriveFile(dirname($path));
+			$parentFolder = $this->getDriveFile(\dirname($path));
 			if ($parentFolder) {
-				$file = new \Google_Service_Drive_DriveFile();
-				$file->setTitle(basename($path));
-				$parent = new \Google_Service_Drive_ParentReference();
-				$parent->setId($parentFolder->getId());
-				$file->setParents(array($parent));
-				$result = $this->service->files->insert($file);
+				$toUpdate->setName(\basename($path));
+				$toUpdate->setParents([$parentFolder->getId()]);
+				$result = $this->service->files->create(
+					$toUpdate,
+					['fields' => $this->getDefaultFieldsForFile()]
+				);
 			}
 		}
 		if ($result) {
@@ -656,64 +736,41 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function hasUpdated($path, $time) {
-		$appConfig = \OC::$server->getAppConfig();
 		if ($this->is_file($path)) {
 			return parent::hasUpdated($path, $time);
-		} else {
-			// Google Drive doesn't change modified times of folders when files inside are updated
-			// Instead we use the Changes API to see if folders have been updated, and it's a pain
-			$folder = $this->getDriveFile($path);
-			if ($folder) {
-				$result = false;
-				$folderId = $folder->getId();
-				$startChangeId = $appConfig->getValue('files_external', $this->getId().'cId');
-				$params = array(
-					'includeDeleted' => true,
-					'includeSubscribed' => true,
-				);
-				if (isset($startChangeId)) {
-					$startChangeId = (int)$startChangeId;
-					$largestChangeId = $startChangeId;
-					$params['startChangeId'] = $startChangeId + 1;
-				} else {
-					$largestChangeId = 0;
-				}
-				$pageToken = true;
-				while ($pageToken) {
-					if ($pageToken !== true) {
-						$params['pageToken'] = $pageToken;
-					}
-					$changes = $this->service->changes->listChanges($params);
-					if ($largestChangeId === 0 || $largestChangeId === $startChangeId) {
-						$largestChangeId = $changes->getLargestChangeId();
-					}
-					if (isset($startChangeId)) {
-						// Check if a file in this folder has been updated
-						// There is no way to filter by folder at the API level...
-						foreach ($changes->getItems() as $change) {
-							$file = $change->getFile();
-							if ($file) {
-								foreach ($file->getParents() as $parent) {
-									if ($parent->getId() === $folderId) {
-										$result = true;
-									// Check if there are changes in different folders
-									} else if ($change->getId() <= $largestChangeId) {
-										// Decrement id so this change is fetched when called again
-										$largestChangeId = $change->getId();
-										$largestChangeId--;
-									}
-								}
-							}
-						}
-						$pageToken = $changes->getNextPageToken();
-					} else {
-						// Assuming the initial scan just occurred and changes are negligible
-						break;
-					}
-				}
-				$appConfig->setValue('files_external', $this->getId().'cId', $largestChangeId);
-				return $result;
+		}
+
+		// follow similar approach than opendir
+		// assume there won't be changes (common case), so optimize the request
+		// although data won't be cached.
+		$folder = $this->getDriveFile($path);
+		if (!$folder) {
+			// missing folder implies it changed
+			return true;
+		}
+
+		$pageToken = true;
+		while ($pageToken) {
+			$params = [];
+			if ($pageToken !== true) {
+				$params['pageToken'] = $pageToken;
 			}
+			$params['q'] = "'" . \str_replace("'", "\\'", $folder->getId()) . "' in parents and trashed = false";
+			$params['fields'] = 'incompleteSearch,nextPageToken,files(modifiedTime)';  // just need the mtime
+			$children = $this->service->files->listFiles($params);
+			if ($children->getIncompleteSearch()) {
+				// if the search is incomplete, assume there is a change
+				return true;
+			}
+
+			foreach ($children->getFiles() as $child) {
+				$childMTime = \strtotime($child->getModifiedTime());
+				if ($childMTime > $time) {
+					// a child has changed since that time, no need to keep on going
+					return true;
+				}
+			}
+			$pageToken = $children->getNextPageToken();
 		}
 		return false;
 	}
@@ -724,5 +781,4 @@ class Google extends \OC\Files\Storage\Common {
 	public static function checkDependencies() {
 		return true;
 	}
-
 }
