@@ -36,25 +36,31 @@ use Icewind\SMB\Exception\ConnectException;
 use Icewind\SMB\Exception\Exception;
 use Icewind\SMB\Exception\ForbiddenException;
 use Icewind\SMB\Exception\NotFoundException;
-use Icewind\SMB\FileInfo;
-use Icewind\SMB\NativeServer;
-use Icewind\SMB\Server;
-use Icewind\SMB\Share;
+use Icewind\SMB\BasicAuth;
+use Icewind\SMB\IFileInfo;
+use Icewind\SMB\IServer;
+use Icewind\SMB\Native\NativeServer;
+use Icewind\SMB\Wrapped\FileInfo;
+use Icewind\SMB\ServerFactory;
+use Icewind\SMB\System;
+use Icewind\SMB\IShare;
 use Icewind\Streams\CallbackWrapper;
 use Icewind\Streams\IteratorDirectory;
 use OC\Cache\CappedMemoryCache;
 use OC\Files\Filesystem;
+use OCA\Files_External\Lib\Cache\SmbCacheWrapper;
+use OCP\Files\Storage\StorageAdapter;
 use OCP\Files\StorageNotAvailableException;
 use OCP\Util;
 
-class SMB extends \OCP\Files\Storage\StorageAdapter {
+class SMB extends StorageAdapter {
 	/**
-	 * @var \Icewind\SMB\Server
+	 * @var IServer
 	 */
 	protected $server;
 
 	/**
-	 * @var \Icewind\SMB\Share
+	 * @var IShare
 	 */
 	protected $share;
 
@@ -64,7 +70,7 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 	protected $root;
 
 	/**
-	 * @var \Icewind\SMB\FileInfo[]
+	 * @var CappedMemoryCache
 	 */
 	protected $statCache;
 
@@ -74,27 +80,28 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		if (!empty($loggedParams['password'])) {
 			$loggedParams['password'] = '***removed***';
 		}
-		$this->log('enter: '.__FUNCTION__.'('.json_encode($loggedParams).')');
+		$this->log('enter: '.__FUNCTION__.'('.\json_encode($loggedParams).')');
 
-		if (isset($params['host']) && isset($params['user']) && isset($params['password']) && isset($params['share'])) {
-			if (Server::NativeAvailable()) {
-				$this->log('using native libsmbclient');
-				$this->server = new NativeServer($params['host'], $params['user'], $params['password']);
-			} else {
-				$this->log('falling back to smbclient');
-				$this->server = new Server($params['host'], $params['user'], $params['password']);
-			}
-			$this->share = $this->server->getShare(trim($params['share'], '/'));
+		if (isset($params['host'], $params['user'], $params['password'], $params['share'])) {
+			$domain = $params['domain'] ?? '';
+
+			$auth = new BasicAuth($params['user'], $domain, $params['password']);
+			$serverFactory = new ServerFactory();
+			$this->server = $serverFactory->createServer($params['host'], $auth);
+			$this->share = $this->server->getShare(\trim($params['share'], '/'));
+
+			$shareClass = \get_class($this->share);
+			$this->log("using $shareClass for the connection");
 
 			$this->root = isset($params['root']) ? $params['root'] : '/';
 			if (!$this->root || $this->root[0] != '/') {
 				$this->root = '/' . $this->root;
 			}
-			if (substr($this->root, -1, 1) != '/') {
+			if (\substr($this->root, -1, 1) !== '/') {
 				$this->root .= '/';
 			}
 		} else {
-			$ex = new \Exception('Invalid configuration');
+			$ex = new \Exception('Invalid configuration: '.\json_encode($loggedParams));
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
 		}
@@ -102,14 +109,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		$this->log('leave: '.__FUNCTION__.', getId:'.$this->getId());
 	}
 
-	/**
-	 * @return string
-	 */
-	public function getId() {
+	public function getId(): string {
 		// FIXME: double slash to keep compatible with the old storage ids,
 		// failure to do so will lead to creation of a new storage id and
 		// loss of shares from the storage
-		return 'smb::' . $this->server->getUser() . '@' . $this->server->getHost() . '//' . $this->share->getName() . '/' . $this->root;
+		return 'smb::' . $this->server->getAuth()->getUsername() . '@' . $this->server->getHost() . '//' . $this->share->getName() . '/' . $this->root;
 	}
 
 	/**
@@ -131,61 +135,79 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 	 */
 	protected function getFileInfo($path) {
 		$this->log('enter: '.__FUNCTION__."($path)");
-			$path = $this->buildPath($path);
-			if (!isset($this->statCache[$path])) {
+		$path = $this->buildPath($path);
+		if (!isset($this->statCache[$path])) {
+			try {
+				$this->log("stat fetching '$path'");
 				try {
-					$this->log("stat fetching '$path'");
-					try {
-						$this->statCache[$path] = $this->share->stat($path);
-					} catch (NotFoundException $e) {
-						if ($this->share instanceof Share) {
-							// smbclient may have problems with the allinfo cmd
-							$this->log("stat for '$path' failed, trying to read parent dir");
-							$infos = $this->share->dir(dirname($path));
-							foreach ($infos as $fileInfo) {
-								if ($fileInfo->getName() === basename($path)) {
-									$this->statCache[$path] = $fileInfo;
-									break;
-								}
+					$this->statCache[$path] = $this->share->stat($path);
+				} catch (NotFoundException $e) {
+					if ($this->share instanceof IShare) {
+						// smbclient may have problems with the allinfo cmd
+						$this->log("stat for '$path' failed, trying to read parent dir");
+						$infos = $this->share->dir(\dirname($path));
+						foreach ($infos as $fileInfo) {
+							if ($fileInfo->getName() === \basename($path)) {
+								$this->statCache[$path] = $fileInfo;
+								break;
 							}
-							if (empty($this->statCache[$path])) {
-								$this->leave(__FUNCTION__, $e);
-								throw $e;
-							}
-						} else {
-							// trust the results of libsmb
+						}
+						if (empty($this->statCache[$path])) {
 							$this->leave(__FUNCTION__, $e);
 							throw $e;
 						}
-					}
-					if ($this->isRootDir($path) && $this->statCache[$path]->isHidden()) {
-						$this->log("unhiding stat for '$path'");
-						// make root never hidden, may happen when accessing a shared drive (mode is 22, archived and readonly - neither is true ... whatever)
-						if ($this->statCache[$path]->isReadOnly()) {
-							$mode = FileInfo::MODE_DIRECTORY & FileInfo::MODE_READONLY;
-						} else {
-							$mode = FileInfo::MODE_DIRECTORY;
-						}
-						$this->statCache[$path] = new FileInfo($path, '', 0, $this->statCache[$path]->getMTime(), $mode);
-					}
-				} catch (ConnectException $e) {
-					$ex = new StorageNotAvailableException(
-						$e->getMessage(), $e->getCode(), $e);
-					$this->leave(__FUNCTION__, $ex);
-					throw $ex;
-				} catch (ForbiddenException $e) {
-					if ($this->remoteIsShare() && $this->isRootDir($path)) { //mtime may not work for share root
-						$this->log("faking stat for forbidden '$path'");
-						$this->statCache[$path] = new FileInfo($path, '', 0, $this->shareMTime(), FileInfo::MODE_DIRECTORY);
 					} else {
+						// trust the results of libsmb
 						$this->leave(__FUNCTION__, $e);
 						throw $e;
 					}
 				}
-			} else {
-				$this->log("stat cache hit for '$path'");
+				if ($this->isRootDir($path) && $this->statCache[$path]->isHidden()) {
+					$this->log("unhiding stat for '$path'");
+					// make root never hidden, may happen when accessing a shared drive (mode is 22, archived and readonly - neither is true ... whatever)
+					if ($this->statCache[$path]->isReadOnly()) {
+						$mode = IFileInfo::MODE_DIRECTORY & IFileInfo::MODE_READONLY;
+					} else {
+						$mode = IFileInfo::MODE_DIRECTORY;
+					}
+					$this->statCache[$path] = new FileInfo(
+						$path,
+						'',
+						0,
+						$this->statCache[$path]->getMTime(),
+						$mode,
+						function () {
+							return [];
+						}
+					);
+				}
+			} catch (ConnectException $e) {
+				$ex = new StorageNotAvailableException(
+					$e->getMessage(), $e->getCode(), $e);
+				$this->leave(__FUNCTION__, $ex);
+				throw $ex;
+			} catch (ForbiddenException $e) {
+				if ($this->remoteIsShare() && $this->isRootDir($path)) { //mtime may not work for share root
+					$this->log("faking stat for forbidden '$path'");
+					$this->statCache[$path] = new FileInfo(
+						$path,
+						'',
+						0,
+						$this->shareMTime(),
+						IFileInfo::MODE_DIRECTORY,
+						function () {
+							return [];
+						}
+					);
+				} else {
+					$this->leave(__FUNCTION__, $e);
+					throw $e;
+				}
 			}
-			$result = $this->statCache[$path];
+		} else {
+			$this->log("stat cache hit for '$path'");
+		}
+		$result = $this->statCache[$path];
 		return $this->leave(__FUNCTION__, $result);
 	}
 
@@ -201,6 +223,12 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 			$result = [];
 			$children = $this->share->dir($path);
 			foreach ($children as $fileInfo) {
+				$fullPath = "{$path}/{$fileInfo->getName()}";
+				if (isset($this->statCache[$fullPath])) {
+					// reference in the cache might have its fileinfo's mode
+					// already resolved, so use that
+					$fileInfo = $this->statCache[$fullPath];
+				}
 				// check if the file is readable before adding it to the list
 				// can't use "isReadable" function here, use smb internals instead
 				try {
@@ -209,10 +237,12 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 					} else {
 						$result[] = $fileInfo;
 						//remember entry so we can answer file_exists and filetype without a full stat
-						$this->statCache[$path . '/' . $fileInfo->getName()] = $fileInfo;
+						$this->statCache[$fullPath] = $fileInfo;
 					}
 				} catch (NotFoundException $e) {
 					$this->swallow(__FUNCTION__, $e);
+				} catch (ForbiddenException $e) {
+					$this->swallow(__FUNCTION__, $e);
 				}
 			}
 		} catch (ConnectException $e) {
@@ -258,22 +288,39 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 
 		try {
 			$result = $this->share->rename($this->root . $source, $this->root . $target);
-			$this->removeFromCache($this->root . $source);
-			$this->removeFromCache($this->root . $target);
+			if ($result) {
+				$this->removeFromCache($this->root . $source);
+				$this->removeFromCache($this->root . $target);
+			}
 		} catch (AlreadyExistsException $e) {
 			$this->swallow(__FUNCTION__, $e);
-			$this->unlink($target);
-			$result = $this->share->rename($this->root . $source, $this->root . $target);
-			$this->removeFromCache($this->root . $source);
-			$this->removeFromCache($this->root . $target);
+			if ($this->unlink($target)) {
+				$result = $this->share->rename($this->root . $source, $this->root . $target);
+				if ($result) {
+					$this->removeFromCache($this->root . $source);
+					$this->removeFromCache($this->root . $target);
+				}
+			} else {
+				$result = false;
+			}
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
 		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 			// Icewind\SMB\Exception\Exception, not a plain exception
 			if ($e->getCode() === 22) {
-				$this->unlink($target);
-				$result = $this->share->rename($this->root . $source, $this->root . $target);
-				$this->removeFromCache($this->root . $source);
-				$this->removeFromCache($this->root . $target);
+				// some servers seem to return an error code 22 instead of the expected AlreadyExistException
+				if ($this->unlink($target)) {
+					$result = $this->share->rename($this->root . $source, $this->root . $target);
+					if ($result) {
+						$this->removeFromCache($this->root . $source);
+						$this->removeFromCache($this->root . $target);
+					}
+				} else {
+					$result = false;
+				}
 			} else {
 				$result = false;
 			}
@@ -285,11 +332,10 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 	}
 
 	private function removeFromCache($path) {
-		$path = trim($path, '/');
+		$path = \trim($path, '/');
 		// TODO The CappedCache does not really clear by prefix. It just clears all.
-		//$this->dirCache->clear($path);
+		'@phan-var \OC\Cache\CappedMemoryCache $this->statCache';
 		$this->statCache->clear($path);
-		//$this->xattrCache->clear($path);
 	}
 	/**
 	 * @param string $path
@@ -299,7 +345,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		$this->log('enter: '.__FUNCTION__."($path)");
 		try {
 			$result = $this->formatInfo($this->getFileInfo($path));
-		} catch (NotFoundException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 			$result = false;
 		}
@@ -364,19 +414,16 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 				$result = $this->rmdir($path);
 			} else {
 				$path = $this->buildPath($path);
-				unset($this->statCache[$path]);
 				$this->share->del($path);
+				unset($this->statCache[$path]);
 				$result = true;
 			}
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
-			$this->swallow(__FUNCTION__, $e);
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
+		} catch (Exception $e) {
+			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
 	}
@@ -431,8 +478,8 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 				case 'c':
 				case 'c+':
 					//emulate these
-					if (strrpos($path, '.') !== false) {
-						$ext = substr($path, strrpos($path, '.'));
+					if (\strrpos($path, '.') !== false) {
+						$ext = \substr($path, \strrpos($path, '.'));
 					} else {
 						$ext = '';
 					}
@@ -442,28 +489,25 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 						}
 						$tmpFile = $this->getCachedFile($path);
 					} else {
-						if (!$this->isCreatable(dirname($path))) {
+						if (!$this->isCreatable(\dirname($path))) {
 							break;
 						}
 						$tmpFile = \OC::$server->getTempManager()->getTemporaryFile($ext);
 					}
-					$source = fopen($tmpFile, $mode);
+					$source = \fopen($tmpFile, $mode);
 					$share = $this->share;
 					$result = CallbackWrapper::wrap($source, null, null, function () use ($tmpFile, $fullPath, $share) {
 						unset($this->statCache[$fullPath]);
 						$share->put($tmpFile, $fullPath);
-						unlink($tmpFile);
+						\unlink($tmpFile);
 					});
 			}
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
-			$this->swallow(__FUNCTION__, $e);
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
+		} catch (Exception $e) {
+			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
 	}
@@ -489,34 +533,31 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 			}
 			$this->share->rmdir($this->buildPath($path));
 			$result = true;
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
-			$this->swallow(__FUNCTION__, $e);
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
+		} catch (Exception $e) {
+			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
 	}
 
 	public function touch($path, $time = null) {
 		$this->log('enter: '.__FUNCTION__."($path, $time)");
+		$result = false;
 		try {
 			if (!$this->file_exists($path)) {
 				$fh = $this->share->write($this->buildPath($path));
-				fclose($fh);
+				\fclose($fh);
 				$result = true;
-			} else {
-				$result = false;
 			}
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
+		} catch (Exception $e) {
+			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
 	}
@@ -526,14 +567,16 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		$result = false;
 		try {
 			$files = $this->getFolderContents($path);
-			$names = array_map(function ($info) {
+			$names = \array_map(function ($info) {
 				/** @var \Icewind\SMB\IFileInfo $info */
 				return $info->getName();
 			}, $files);
 			$result = IteratorDirectory::wrap($names);
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
@@ -544,9 +587,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		$result = false;
 		try {
 			$result = $this->getFileInfo($path)->isDirectory() ? 'dir' : 'file';
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
@@ -559,8 +604,7 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		try {
 			$result = $this->share->mkdir($path);
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
 		} catch (Exception $e) {
@@ -575,15 +619,12 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		try {
 			$this->getFileInfo($path);
 			$result = true;
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
-			$this->swallow(__FUNCTION__, $e);
 		} catch (ConnectException $e) {
-			$ex = new StorageNotAvailableException(
-				$e->getMessage(), $e->getCode(), $e);
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 			$this->leave(__FUNCTION__, $ex);
 			throw $ex;
+		} catch (Exception $e) {
+			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
 	}
@@ -594,9 +635,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		try {
 			$info = $this->getFileInfo($path);
 			$result = !$info->isHidden();
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
@@ -610,9 +653,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 			// following windows behaviour for read-only folders: they can be written into
 			// (https://support.microsoft.com/en-us/kb/326549 - "cause" section)
 			$result = !$info->isHidden() && (!$info->isReadOnly() || $this->is_dir($path));
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
@@ -624,9 +669,11 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		try {
 			$info = $this->getFileInfo($path);
 			$result = !$info->isHidden() && !$info->isReadOnly();
-		} catch (NotFoundException $e) {
-			$this->swallow(__FUNCTION__, $e);
-		} catch (ForbiddenException $e) {
+		} catch (ConnectException $e) {
+			$ex = new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+			$this->leave(__FUNCTION__, $ex);
+			throw $ex;
+		} catch (Exception $e) {
 			$this->swallow(__FUNCTION__, $e);
 		}
 		return $this->leave(__FUNCTION__, $result);
@@ -638,7 +685,7 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 	public static function checkDependencies() {
 		return (
 			(bool)\OC_Helper::findBinaryPath('smbclient')
-			|| Server::NativeAvailable()
+			|| NativeServer::available(new System())
 		) ? true : ['smbclient'];
 	}
 
@@ -681,28 +728,28 @@ class SMB extends \OCP\Files\Storage\StorageAdapter {
 		if (\OC::$server->getConfig()->getSystemValue('smb.logging.enable', false) === false) {
 			//don't bother building log strings
 			return $result;
-		} else if ($result === true) {
+		} elseif ($result === true) {
 			Util::writeLog('smb', "leave: $function, return true", Util::DEBUG);
-		} else if ($result === false) {
+		} elseif ($result === false) {
 			Util::writeLog('smb', "leave: $function, return false", Util::DEBUG);
-		} else if (is_string($result)) {
+		} elseif (\is_string($result)) {
 			Util::writeLog('smb', "leave: $function, return '$result'", Util::DEBUG);
-		} else if (is_resource($result)) {
+		} elseif (\is_resource($result)) {
 			Util::writeLog('smb', "leave: $function, return resource", Util::DEBUG);
-		} else if ($result instanceof \Exception) {
-			Util::writeLog('smb', "leave: $function, throw ".get_class($result)
+		} elseif ($result instanceof \Exception) {
+			Util::writeLog('smb', "leave: $function, throw ".\get_class($result)
 				.' - code: '.$result->getCode()
 				.' message: '.$result->getMessage()
 				.' trace: '.$result->getTraceAsString(), Util::DEBUG);
 		} else {
-			Util::writeLog('smb', "leave: $function, return ".json_encode($result, true), Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return ".\json_encode($result, true), Util::DEBUG);
 		}
 		return $result;
 	}
 
 	private function swallow($function, \Exception $exception) {
 		if (\OC::$server->getConfig()->getSystemValue('smb.logging.enable', false) === true) {
-			Util::writeLog('smb', "$function swallowing ".get_class($exception)
+			Util::writeLog('smb', "$function swallowing ".\get_class($exception)
 				.' - code: '.$exception->getCode()
 				.' message: '.$exception->getMessage()
 				.' trace: '.$exception->getTraceAsString(), Util::DEBUG);
