@@ -4,7 +4,6 @@ OC.L10N.register(
     "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
     "The mountpoint name contains invalid characters." : "El punto de montaje contiene caracteres inválidos.",
     "Not allowed to create a federated share with the same user server" : "No se permite crear un recurso compartido federado con el mismo servidor de usuario",
-    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
     "Could not authenticate to remote share, password might be wrong" : "No se ha podido autenticar para compartir remotamente, quizás esté mal la contraseña",
     "Storage not valid" : "Almacenamiento inválido",
     "Couldn't add remote share" : "No se puede añadir un compartido remoto",
@@ -21,6 +20,9 @@ OC.L10N.register(
     "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
     "No shared links" : "No hay enlaces compartidos",
     "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
+    "An error occurred while updating share state: {message}" : "Un error ha ocurrido mientras se trataba de actualizar el estado: {message}",
+    "Accept Share" : "Aceptar compartido",
+    "Decline Share" : "No aceptar compartido",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea añadir el recurso compartido remoto {name} de {owner}@{remote}?",
     "Remote share" : "Recurso compartido remoto",
     "Remote share password" : "Contraseña del compartido remoto",
@@ -31,28 +33,10 @@ OC.L10N.register(
     "Invalid ownCloud url" : "URL de ownCloud inválida",
     "Share" : "Compartir",
     "No expiration date set" : "No se ha establecido fecha de caducidad",
+    "Declined" : "Denegado",
+    "Pending" : "Pendiente",
     "Shared by" : "Compartido por",
     "Sharing" : "Compartiendo",
-    "Share API is disabled" : "El API de compartir está deshabilitado",
-    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
-    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
-    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
-    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
-    "Cannot remove all permissions" : "No puedo eliminar todos los permisos",
-    "Please specify a valid user" : "Por favor, especifica un usuario válido",
-    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
-    "Please specify a valid group" : "Por favor, especifica un grupo válido",
-    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
-    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
-    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
-    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
-    "Unknown share type" : "Tipo desconocido de recurso compartido",
-    "Not a directory" : "No es un directorio",
-    "Could not lock path" : "No se ha podido bloquear la ruta",
-    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
-    "Wrong or no update parameter given" : "No se ha suministrado un parametro correcto",
-    "Cannot increase permissions" : "No es posible aumentar permisos",
     "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
     "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Se ha <strong>descargado</strong> un archivo o carpeta compartido públicamente",
@@ -67,6 +51,7 @@ OC.L10N.register(
     "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
     "You removed the share of %2$s for %1$s" : "Ha cambiado el compartido %2$s por %1$s",
     "%2$s removed the share of %3$s for %1$s" : "%2$s eliminó la compartición de %3$s con %1$s",
+    "You unshared %1$s shared by %2$s from self" : "Tú dejaste de compartir %1$s compartido por %2$s de sí mismo",
     "You shared %1$s with group %2$s" : "Usted ha compartido %1$s con el grupo %2$s",
     "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s con el grupo %3$s",
     "You removed the share of group %2$s for %1$s" : "Ha cambiado el compartido del grupo %2$s por %1$s",
@@ -84,6 +69,7 @@ OC.L10N.register(
     "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
     "Removed share for %2$s" : "Borrado el compartido %2$s",
     "%2$s removed share for %3$s" : "%2$s ha borrado el compartido %3$s",
+    "Unshared %1$s from self" : "Dejó de compartirse  %1$s por ti",
     "Shared with group %2$s" : "Compartido con el grupo %2$s",
     "Shared with group %3$s by %2$s" : "Compartido con el grupo %3$s por %2$s",
     "Removed share of group %2$s" : "Borrado el compartido del grupo %2$s",
@@ -96,11 +82,44 @@ OC.L10N.register(
     "Public link of %2$s expired" : "El enlace público %2$s ha expirado",
     "Shared by %2$s" : "Compartido por %2$s",
     "Shares" : "Compartidos",
+    "File sharing" : "Compartir Archivos",
+    "Public link" : "Enlace Publico",
+    "Couldn't send mail to following recipient(s): %s " : "No se puede enviar un correo electrónico a los siguientes receptores: %s ",
+    "Share API is disabled" : "El API de compartir está deshabilitado",
+    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
+    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
+    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
+    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
+    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
+    "Please specify a valid user" : "Por favor, especifica un usuario válido",
+    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
+    "Please specify a valid group" : "Por favor, especifica un grupo válido",
+    "The group is blacklisted for sharing" : "El grupo está en la lista negra de compartir",
+    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
+    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
+    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
+    "shareWith parameter must be a string" : "El parametro shareWith debe ser una cadena de texto",
+    "Unknown share type" : "Tipo desconocido de recurso compartido",
+    "Could not lock path" : "No se ha podido bloquear la ruta",
+    "Not a directory" : "No es un directorio",
+    "Could not update share" : "No se pudo actualizar la compartición",
+    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
+    "Only recipient can change accepted state" : "Solo el receptor puede cambiar el cambio de estado.",
+    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" ha compartido \"%3$s\" contigo (en nombre de \"%2$s\")",
+    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" ha compartido \"%3$s\" contigo",
+    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" te ha invitado a ver \"%3$s\" (en nombre de \"%2$s\")",
+    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" te ha invitado a ver \"%3$s\"",
+    "Accept" : "Aceptar",
+    "Decline" : "Denegar",
+    "Automatically accept new incoming local user shares" : "Aceptar automáticamente nuevos compartidos de los usuarios locales.",
+    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "Permite que lo encuentren a través del completado automático en un diálogo de compartición. Si esta opción está deshabilitada es necesario introducir el nombre de usuario completo.",
     "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
     "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
     "Password" : "Contraseña",
     "No entries found in this folder" : "No hay entradas en esta carpeta",
     "Name" : "Nombre",
+    "State" : "Estado",
     "Share time" : "Compartido hace",
     "Expiration date" : "Fecha de caducidad",
     "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
@@ -110,10 +129,12 @@ OC.L10N.register(
     "sharing is disabled" : "compartir está desactivado",
     "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
     "%s is publicly shared" : "%s esta compartido publicamente",
-    "Add to your ownCloud" : "Agregue a su ownCloud",
     "Download" : "Descargar",
     "Download %s" : "Descargar %s",
     "Direct link" : "Enlace directo",
-    "No permission to create share" : "Permisos insuficientes para crear un compartido"
+    "Nothing to configure." : "Nada que configurar",
+    "Group Sharing Blacklist" : "Lista negra Grupo compartidos",
+    "Exclude groups from receiving shares" : "Excluir grupos de recibir compartidos",
+    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Estos grupos no estarán disponibles para compartir. Los miembros de este grupo no están restringidos para compartir y pueden recibir compartidos respecto de otros grupos que sí son miembros."
 },
 "nplurals=2; plural=(n != 1);");
