@@ -4,13 +4,15 @@ OC.L10N.register(
     "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
     "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères non valides.",
     "Not allowed to create a federated share with the same user server" : "Non autorisé à créer un partage fédéré avec un utilisateur du même serveur",
-    "Invalid or untrusted SSL certificate" : "Certificat SSL non valable ou non fiable",
     "Could not authenticate to remote share, password might be wrong" : "Impossible de s'authentifier au partage distant : le mot de passe en probablement incorrect",
     "Storage not valid" : "Support de stockage non valide",
     "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
     "Shared with you" : "Partagés avec vous",
     "Shared with others" : "Partagés avec d'autres",
     "Shared by link" : "Partagés par lien",
+    "Anonymous upload" : "Téléversement anonyme",
+    "Click to select files or use drag & drop to upload" : "Cliquez pour sélectionner les fichiers ou utilisez le cliquer-glisser pour téléverser",
+    "Uploaded files" : "Fichiers téléversés",
     "Uploading..." : "Téléversement en cours…",
     "Nothing shared with you yet" : "Aucun fichier n'est partagé avec vous pour l'instant",
     "Files and folders others share with you will show up here" : "Les fichiers et dossiers partagés avec vous apparaîtront ici",
@@ -18,6 +20,8 @@ OC.L10N.register(
     "Files and folders you share will show up here" : "Les fichiers et dossiers que vous partagez apparaîtront ici",
     "No shared links" : "Aucun partage par lien",
     "Files and folders you share by link will show up here" : "Les fichiers et dossiers que vous partagez par lien apparaîtront ici",
+    "Accept Share" : "accepter le partage",
+    "Decline Share" : "Decliner le partager",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} de {owner}@{remote} ?",
     "Remote share" : "Partage distant",
     "Remote share password" : "Mot de passe du partage distant",
@@ -28,27 +32,10 @@ OC.L10N.register(
     "Invalid ownCloud url" : "URL ownCloud non valide",
     "Share" : "Partager",
     "No expiration date set" : "Aucune date d'expiration spécifiée",
+    "Declined" : "Refusé",
+    "Pending" : "En attente",
     "Shared by" : "Partagé par",
     "Sharing" : "Partage",
-    "Share API is disabled" : "l'API de partage est désactivée",
-    "Wrong share ID, share doesn't exist" : "Mauvais ID de partage, le partage n'existe pas",
-    "Could not delete share" : "Impossible de supprimer le partage",
-    "Please specify a file or folder path" : "Veuillez spécifier un fichier ou dossier",
-    "Wrong path, file/folder doesn't exist" : "Mauvais chemin, Le fichier/dossier n'existe pas",
-    "Please specify a valid user" : "Veuillez entrer un utilisateur valide",
-    "Group sharing is disabled by the administrator" : "Le partage de groupe a été désactivé par l'administrateur",
-    "Please specify a valid group" : "Veuillez entrer un groupe valide",
-    "Public link sharing is disabled by the administrator" : "Le partage de lien public a été désactivé par l'administrateur",
-    "Public upload disabled by the administrator" : "Téléversement public désactivé par l'administrateur",
-    "Public upload is only possible for publicly shared folders" : "Le téléversement public est possible uniquement pour les dossiers partagés publiquement",
-    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format doit être YYYY-MM-DD",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "Le partage %s a échoué parce que l'infrastructure n'autorise pas les partages du type %s",
-    "Unknown share type" : "Type de partage inconnu",
-    "Not a directory" : "N'est pas un répertoire",
-    "Could not lock path" : "Impossible de verrouiller le chemin",
-    "Can't change permissions for public share links" : "Impossible de changer les permissions pour les liens de partage public",
-    "Wrong or no update parameter given" : "Mauvais ou aucun paramètre donné ",
-    "Cannot increase permissions" : "Impossible d'augmenter les permissions",
     "A file or folder has been <strong>shared</strong>" : "Un fichier ou un répertoire a été <strong>partagé</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Un fichier ou un répertoire a été partagé depuis <strong>un autre serveur</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Un fichier ou un répertoire partagé publiquement a été <strong>téléchargé</strong>",
@@ -92,6 +79,32 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Le lien public de %2$s a expiré",
     "Shared by %2$s" : "Partagé par %2$s",
     "Shares" : "Partages",
+    "File sharing" : "partage de fichier",
+    "Public link" : "Lien public",
+    "Couldn't send mail to following recipient(s): %s " : "Impossible d'envoyer de mail au(x) destinataire(s) suivant(s) : %s",
+    "Share API is disabled" : "l'API de partage est désactivée",
+    "Wrong share ID, share doesn't exist" : "Mauvais ID de partage, le partage n'existe pas",
+    "Could not delete share" : "Impossible de supprimer le partage",
+    "Please specify a file or folder path" : "Veuillez spécifier un fichier ou dossier",
+    "Wrong path, file/folder doesn't exist" : "Mauvais chemin, Le fichier/dossier n'existe pas",
+    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format doit être YYYY-MM-DD",
+    "Please specify a valid user" : "Veuillez entrer un utilisateur valide",
+    "Group sharing is disabled by the administrator" : "Le partage de groupe a été désactivé par l'administrateur",
+    "Please specify a valid group" : "Veuillez entrer un groupe valide",
+    "Public link sharing is disabled by the administrator" : "Le partage de lien public a été désactivé par l'administrateur",
+    "Public upload disabled by the administrator" : "Téléversement public désactivé par l'administrateur",
+    "Public upload is only possible for publicly shared folders" : "Le téléversement public est possible uniquement pour les dossiers partagés publiquement",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Le partage %s a échoué parce que l'infrastructure n'autorise pas les partages du type %s",
+    "Unknown share type" : "Type de partage inconnu",
+    "Could not lock path" : "Impossible de verrouiller le chemin",
+    "Not a directory" : "N'est pas un répertoire",
+    "Can't change permissions for public share links" : "Impossible de changer les permissions pour les liens de partage public",
+    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" Partage \"%3$s\" avec vous (de la part de \"%2$s\")",
+    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" a partagé \"%3$s\" avec vous",
+    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" vous a invité à voir \"%3$s\" (de la part de \"%2$s\")'",
+    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" vous a invité à voir \"%3$s\"",
+    "Accept" : "Accepter",
+    "Decline" : "Refuser",
     "This share is password-protected" : "Ce partage est protégé par un mot de passe",
     "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
     "Password" : "Mot de passe",
@@ -106,14 +119,10 @@ OC.L10N.register(
     "sharing is disabled" : "le partage est désactivé",
     "For more info, please ask the person who sent this link." : "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
     "%s is publicly shared" : "%s est partagé publiquement",
-    "Add to your ownCloud" : "Ajouter à votre ownCloud",
     "Download" : "Télécharger",
     "Download %s" : "Télécharger %s",
     "Direct link" : "Lien direct",
-    "Anonymous upload" : "Téléversement anonyme",
-    "Uploaded files" : "Fichiers téléversés",
-    "Click to select files or use drag & drop to upload" : "Cliquez pour sélectionner les fichiers ou utilisez le cliquer-glisser pour téléverser",
-    "Cannot remove all permissions" : "Il n'est pas possible d'enlever toutes les permissions",
-    "No permission to create share" : "Interdit de créer le partage"
+    "Nothing to configure." : "Rien à configurer.",
+    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Ces groupes ne seront pas disponibles pour le partage. Les membres du groupe ne sont pas exclus du partage et peuvent recevoir le partage en tant que membres d'autres groupes."
 },
 "nplurals=2; plural=(n > 1);");
