@@ -3,13 +3,15 @@ OC.L10N.register(
     {
     "Server to server sharing is not enabled on this server" : "Współdzielenie między serwerami nie jest uruchomione na tym serwerze",
     "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
-    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
     "Could not authenticate to remote share, password might be wrong" : "Nie można zalogować do zdalnego zasobu, hasło może być niepoprawne",
     "Storage not valid" : "Zasób nie jest prawidłowy",
     "Couldn't add remote share" : "Nie można dodać zdalnego folderu",
     "Shared with you" : "Współdzielony z Tobą",
     "Shared with others" : "Współdzielony z innymi",
     "Shared by link" : "Współdzielony linkiem",
+    "Anonymous upload" : "Wgrywanie anonimowe",
+    "Click to select files or use drag & drop to upload" : "Naciśnij aby wybrać pliki lub przeciągnij tutaj aby wgrać",
+    "Uploaded files" : "Wysłane pliki",
     "Uploading..." : "Wgrywanie....",
     "Nothing shared with you yet" : "Nie masz jeszcze nic udostępnionego",
     "Files and folders others share with you will show up here" : "Pliki i foldery udostępnione Tobie przez innych wyświetlą się tutaj",
@@ -17,6 +19,9 @@ OC.L10N.register(
     "Files and folders you share will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
     "No shared links" : "Brak udostępnionych odnośników",
     "Files and folders you share by link will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
+    "An error occurred while updating share state: {message}" : "Błąd podczas aktualizacji stanu udziału: {message}",
+    "Accept Share" : "Akceptuj współdzielenie",
+    "Decline Share" : "Odrzuć współdzielenie",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać udział zdalny {name} od {owner}@{remote}?",
     "Remote share" : "Zdalny zasób",
     "Remote share password" : "Hasło do zdalnego zasobu",
@@ -27,42 +32,67 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Błędny adres URL",
     "Share" : "Udostępnij",
     "No expiration date set" : "Data wygaśnięcia nie została ustawiona",
+    "Declined" : "Nie zaakceptowane",
+    "Pending" : "Oczekujące",
     "Shared by" : "Udostępniane przez",
     "Sharing" : "Udostępnianie",
+    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
+    "A file or folder was shared from <strong>another server</strong>" : "Plik lub folder został udostępniony z <strong>innego serwera</strong>",
+    "A public shared file or folder was <strong>downloaded</strong>" : "Udostępniony publicznie plik lub folder został <strong>pobrany</strong>",
+    "You received a new remote share %2$s from %1$s" : "Otrzymałeś nowy zdalny dostęp do %2$s od %1$s",
+    "You received a new remote share from %s" : "Otrzymałeś nowy dostęp zdalny od %s",
+    "%1$s accepted remote share %2$s" : "%1$s zaakceptował zdalny dostęp do %2$s",
+    "%1$s declined remote share %2$s" : "%1$s odmówił zdalnego dostępu do %2$s",
+    "Public shared folder %1$s was downloaded" : "Publicznie udostępniony katalog %1$s został pobrany",
+    "Public shared file %1$s was downloaded" : "Publicznie udostępniony plik %1$s  został pobrany",
+    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
+    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
+    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
+    "Your public link for %1$s expired" : "Twój publiczny link do %1$s wygasł",
+    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
+    "%2$s removed the share for %1$s" : "%2$s usunął udział dla %1$s",
+    "Downloaded via public link" : "Pobrano poprzez odnośnik publiczny",
+    "%2$s removed share of group %3$s" : "%2$susunął udział grupy %3$s",
+    "Shared via link by %2$s" : "Udostępnione za pomocą odnośnika przez %2$s",
+    "Shared via public link" : "Udostępniono poprzez publiczny odnośnik",
+    "Removed public link" : "Usunięto publiczny odnośnik",
+    "%2$s removed public link" : "%2$susunął odnośnik publiczny",
+    "Public link expired" : "Publiczny odnośnik wygasł",
+    "Public link of %2$s expired" : "Odnośnik publiczny do %2$s wygasł",
+    "Shared by %2$s" : "Udostępnione przez %2$s",
+    "Shares" : "Udziały",
+    "File sharing" : "Udostępnianie pliku",
+    "Public link" : "Link publiczny",
+    "Couldn't send mail to following recipient(s): %s " : "Nie udało się wysłać wiadomości do odbiorcy(ów): %s ",
     "Share API is disabled" : "API udostępniania jest wyłączone",
     "Wrong share ID, share doesn't exist" : "Nieprawidłowe ID zasobu, zasób nie istnieje",
     "Could not delete share" : "Nie można usunąć zasobu",
     "Please specify a file or folder path" : "Wskaż ścieżkę pliku lub folderu",
     "Wrong path, file/folder doesn't exist" : "Nieprawidłowa ścieżka, plik/folder nie istnieje",
-    "Cannot remove all permissions" : "Nie można usunąć wszystkich uprawnień",
+    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, właściwy format daty: RRRR-MM-DD",
     "Please specify a valid user" : "Proszę określ prawidłowego użytkownika ",
     "Group sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
     "Please specify a valid group" : "Określ prawidłową grupę",
+    "The group is blacklisted for sharing" : "Grupa jest na czarnej liście współdzielenia",
     "Public link sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
     "Public upload disabled by the administrator" : "Publiczne wczytywanie zostało zablokowane przez twojego administratora",
     "Public upload is only possible for publicly shared folders" : "Publiczne wczytywanie jest możliwe wyłącznie do katalogów publicznych",
-    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, właściwy format daty: RRRR-MM-DD",
     "Unknown share type" : "Nieznany typ udziału",
-    "Not a directory" : "To nie jest katalog",
     "Could not lock path" : "Nie można zablokować ścieżki ",
+    "Not a directory" : "To nie jest katalog",
     "Can't change permissions for public share links" : "Nie można zmienić uprawnień dla publicznych linków",
-    "Wrong or no update parameter given" : "Przekazano pusty lub nieprawidłowy parametr",
-    "Cannot increase permissions" : "Nie można podnieść uprawnień",
-    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
-    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
-    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
-    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
-    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
-    "%2$s removed the share for %1$s" : "%2$s usunął udział dla %1$s",
-    "Shared via public link" : "Udostępniono poprzez publiczny odnośnik",
-    "Removed public link" : "Usunięto publiczny odnośnik",
-    "Public link expired" : "Publiczny odnośnik wygasł",
-    "Shares" : "Udziały",
+    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" udostępnił Tobie \"%3$s\" (z upoważnienia \"%2$s\")",
+    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" udostępnił Tobie \"%3$s\"",
+    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" zaprosił cię do podglądu \"%3$s\"",
+    "Accept" : "Akceptuj",
+    "Decline" : "Odmów",
+    "Automatically accept new incoming local user shares" : "Automatyczna akceptacja nowych, przychodzących udziałów użytkowników lokalnych",
     "This share is password-protected" : "Udział ten jest chroniony hasłem",
     "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
     "Password" : "Hasło",
     "No entries found in this folder" : "Brak wpisów w tym folderze",
     "Name" : "Nazwa",
+    "State" : "Stan",
     "Share time" : "Czas współdzielenia",
     "Expiration date" : "Data wygaśnięcia",
     "Sorry, this link doesn’t seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
@@ -71,10 +101,9 @@ OC.L10N.register(
     "the link expired" : "link wygasł",
     "sharing is disabled" : "udostępnianie jest wyłączone",
     "For more info, please ask the person who sent this link." : "Aby uzyskać więcej informacji proszę poprosić osobę, która wysłał ten link.",
-    "Add to your ownCloud" : "Dodaj do twojego ownCloud",
+    "%s is publicly shared" : "%sjest publicznie udostępniony",
     "Download" : "Pobierz",
     "Download %s" : "Pobierz %s",
-    "Direct link" : "Bezpośredni link",
-    "Downloaded via public link" : "Pobrano poprzez odnośnik publiczny"
+    "Direct link" : "Bezpośredni link"
 },
-"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
+"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
