@@ -12,11 +12,10 @@ OC.L10N.register(
     "No crop data provided" : "Ingen beskæringsdata give",
     "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
     "Crop is not square" : "Beskæringen er ikke kvadratisk",
-    "Couldn't reset password because the token is invalid" : "Kunne ikke nulstille kodeordet, fordi symboludtrykket er ugyldigt",
-    "Couldn't reset password because the token is expired" : "Kunne ikke nulstille kodeord, da tokenet er udløbet",
+    "%s password changed successfully" : "App %s succesfuldt opdateret",
     "%s password reset" : "%s adgangskode nulstillet",
     "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
-    "Couldn't send mail to following users: %s " : "Kunne ikke sende mail til følgende brugere: %s",
+    "Upload only" : "Upload kun",
     "Preparing update" : "Forbereder opdatering",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Reparationsadvarsel:",
@@ -140,36 +139,44 @@ OC.L10N.register(
     "Error while sharing" : "Fejl under deling",
     "Error while unsharing" : "Fejl under annullering af deling",
     "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
-    "Set expiration date" : "Vælg udløbsdato",
     "Expiration" : "Udløb",
-    "Expiration date" : "Udløbsdato",
+    "Expiration date is required" : "Udløbsdato er påkrævet",
+    "Delete {link}" : "Slet {link}",
+    "Remove link" : "Fjern link",
     "Link" : "Link",
+    "Create public link" : "opret offentligt link",
     "Edit" : "Redigér",
     "Remove" : "Fjern",
+    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Social share" : "Social deling",
+    "There are currently no link shares, you can create one" : "Der er på nuværende tidspunkt ingen liks delt med dig, du kan oprettet et",
+    "Anyone with the link has access to the file/folder" : "Alle med linket har adgang til filen/mappen",
     "Copied!" : "Kopieret!",
     "Not supported!" : "Ikke understøttet!",
     "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
     "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
-    "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
+    "Choose a password" : "Vælg et kodeord",
+    "Password required" : "Kodeord påkrævet",
+    "Link name" : "Linknavn",
+    "Name" : "Navn",
     "Filename" : "Filnavn",
     "Password" : "Adgangskode",
-    "Name" : "Navn",
-    "Allow editing" : "Tillad redigering",
+    "Edit link share: {name}" : "Rediger linkdeling: {name}",
+    "Create link share: {name}" : "Opret linkdeling: {name}",
+    "Share" : "Del",
     "Save" : "Gem",
+    "Remove password" : "Fjern kodeord",
     "Share to Twitter. Opens in a new window." : "Del med Twitter. Åbner i et nyt vindue.",
     "Share to Facebook. Opens in a new window." : "Del med Facebook. Åbner i et nyt vindue.",
     "Share to Diaspora. Opens in a new window." : "Del med Diaspora Åbner i et nyt vindue.",
     "Share to Google+. Opens in a new window." : "Del med Google+. Åbner i et nyt vindue.",
     "Share via email. Opens your mail client." : "Del via email. Åbner din mail klient.",
-    "Error while sending notification" : "Fejl ved afsendelse af notifikation",
-    "Sending ..." : "Sender ...",
-    "Email sent" : "E-mail afsendt",
     "Email link to person" : "E-mail link til person",
     "Send link via email" : "Send link via e-mail",
+    "Sending" : "Sender",
     "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
     "Shared with you by {owner}" : "Delt med dig af {owner}",
     "group" : "gruppe",
-    "remote" : "ekstern",
     "notify by email" : "Giv besked med mail",
     "Unshare" : "Fjern deling",
     "can share" : "kan dele",
@@ -183,18 +190,16 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Ingen brugere eller grupper fundet for {search}",
     "No users found for {search}" : "Ingen brugere fundet for {search}",
     "An error occurred. Please try again" : "Der opstor den fejl. Prøv igen",
-    "{sharee} (group)" : "{sharee} (gruppe)",
-    "{sharee} (at {server})" : "{sharee} (på {server})",
-    "{sharee} (remote)" : "{sharee} (ekstern)",
-    "Share" : "Del",
-    "Resharing is not allowed" : "Videredeling ikke tilladt",
+    "User" : "Bruger",
+    "Group" : "Gruppe",
+    "User and Groups" : "Bruger og Grupper",
+    "Public Links" : "Offentlige links",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med andre på ownCloud ved hjælp af syntaxen username@example.com/owncloud",
     "Share with users…" : "Del med brugere...",
     "Share with users, groups or remote users…" : "Del med brugere, grupper eller eksterne brugere...",
     "Share with users or groups…" : "Del med brugere eller grupper...",
     "Share with users or remote users…" : "Del med brugere eller eksterne brugere...",
     "Error removing share" : "Fejl ved fjernelse af deling",
-    "Warning" : "Advarsel",
     "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
     "restricted" : "begrænset",
     "invisible" : "usynlig",
@@ -240,8 +245,6 @@ OC.L10N.register(
     "Cheers!" : "Hav en fortsat god dag.",
     "Internal Server Error" : "Intern serverfejl",
     "The server encountered an internal error and was unable to complete your request." : "Servern stødte på en intern fejl og var ikke i stand til at fuldføre din forespørgsel.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Kontakt venligst serveradministratoren, hvis denne fejl gentager sig flere gange - medtag venligst de tekniske detaljer nedenfor i din rapport.",
-    "More details can be found in the server log." : "Flere detaljer kan fås i serverloggen.",
     "Technical details" : "Tekniske detaljer",
     "Remote Address: %s" : "Fjernadresse: %s",
     "Request ID: %s" : "Forespørgsels-ID: %s",
@@ -251,6 +254,7 @@ OC.L10N.register(
     "File: %s" : "Fil: %s",
     "Line: %s" : "Linje: %s",
     "Trace" : "Sporing",
+    "Imprint" : "Aftryk",
     "Create an <strong>admin account</strong>" : "Opret en <strong>administratorkonto</strong>",
     "Username" : "Brugernavn",
     "Storage & database" : "Lager & database",
@@ -275,19 +279,21 @@ OC.L10N.register(
     "See the documentation" : "Se dokumentationen",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej med dig,<br><br>Dette er blot for at informere dig om, at %s har delt <strong>%s</strong> med dig.<br><a href=\"%s\">Se det her!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden. ",
+    "Menu" : "Menu",
     "Log out" : "Log ud",
     "Search" : "Søg",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
     "Please contact your administrator." : "Kontakt venligst din administrator",
     "An internal error occurred." : "Der opstod en intern fejl.",
     "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
+    "Login" : "Login",
     "Username or email" : "Brugernavn eller email",
-    "Log in" : "Log ind",
     "Wrong password. Reset it?" : "Forkert kodeord. Skal det nulstilles?",
     "Wrong password." : "Forkert kodeord.",
     "Stay logged in" : "Forbliv logget ind",
     "Alternative Logins" : "Alternative logins",
     "Use the following link to reset your password: {link}" : "Anvend følgende link til at nulstille din adgangskode: {link}",
+    "Password changed successfully" : "Kodeord succesfuldt ændret.",
     "New password" : "Ny adgangskode",
     "New Password" : "Ny adgangskode",
     "Reset password" : "Nulstil kodeord",
@@ -301,9 +307,6 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Bekræft venligst ved brug af den valgte faktor.",
     "An error occurred while verifying the token" : "Der opstod en fejl under kontrollen af token",
     "You are accessing the server from an untrusted domain." : "Du tilgår serveren fra et utroværdigt domæne",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontakt din administrator. Hvis du er administrator for denne instans, konfigurer indstillingen \"trusted_domains\" i config / config.php. En eksempel-konfiguration findes i config / config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Afhænger af din konfiguration, da du som administrator eventuelt også er i stand til at gøre brug af knappen nedenfor til at tildele tillid til dette domæne.",
-    "Add \"%s\" as trusted domain" : "Tilføj \"%s\" som et troværdigt domæne",
     "App update required" : "Opdatering af app påkræves",
     "%s will be updated to version %s" : "%s vil blive opdateret til version %s",
     "These apps will be updated:" : "Følgende apps vil blive opdateret:",
@@ -313,31 +316,8 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
     "Detailed logs" : "Detaljerede logge",
     "Update needed" : "Opdatering nødvendigt",
-    "Please use the command line updater because you have a big instance." : "Brug venligst kommandolinje-opdateringsprogrammet, fordi du har en stor opsætning.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For at få hjælp, se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> dokumentationen </a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
-    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen.",
-    "Expiration date is required" : "Udløbsdato er påkrævet",
-    "Remove link" : "Fjern link",
-    "Create public link" : "opret offentligt link",
-    "Copy to clipboard" : "Kopier til udklipsholder",
-    "There are currently no link shares, you can create one" : "Der er på nuværende tidspunkt ingen liks delt med dig, du kan oprettet et",
-    "Anyone with the link has access to the file/folder" : "Alle med linket har adgang til filen/mappen",
-    "Choose a password" : "Vælg et kodeord",
-    "Password required" : "Kodeord påkrævet",
-    "Upload only" : "Upload kun",
-    "Remove password" : "Fjern kodeord",
-    "Sending" : "Sender",
-    "User and Groups" : "Bruger og Grupper",
-    "Public Links" : "Offentlige links",
-    "Delete {link}" : "Slet {link}",
-    "Menu" : "Menu",
-    "Password changed successfully" : "Kodeord succesfuldt ændret.",
-    "Social share" : "Social deling",
-    "Link name" : "Linknavn",
-    "%s password changed successfully" : "App %s succesfuldt opdateret",
-    "{fileName} link" : "{fileName} link",
-    "Edit link share: {name}" : "Rediger linkdeling: {name}",
-    "Create link share: {name}" : "Opret linkdeling: {name}"
+    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen."
 },
 "nplurals=2; plural=(n != 1);");
