@@ -12,11 +12,10 @@ OC.L10N.register(
     "No crop data provided" : "No se proporcionó datos del recorte",
     "No valid crop data provided" : "No hay datos de recorte válidos",
     "Crop is not square" : "Recorte no es cuadrado",
-    "Couldn't reset password because the token is invalid" : "No se pudo restablecer la contraseña por que el token es inválido",
-    "Couldn't reset password because the token is expired" : "No se pudo restablecer la contraseña por que el token ha expirado",
     "%s password reset" : "%s restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No se pudo enviar correo de restauración de contraseña. Por favor contacta a tu administrador.",
-    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
+    "Download / View / Upload" : "Descargar / Ver / Subir",
+    "Upload only" : "Solo subir",
     "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Alerta de reparación:",
@@ -80,6 +79,7 @@ OC.L10N.register(
     "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
     "Ok" : "Aceptar",
     "Error loading message template: {error}" : "Error cargando plantilla del mensaje: {error}",
+    "read-only" : "solo-lectura",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
     "One file conflict" : "Un conflicto de archivo",
     "Which files do you want to keep?" : "¿Que archivos deseas mantener?",
@@ -93,26 +93,24 @@ OC.L10N.register(
     "Error" : "Error",
     "Error while sharing" : "Error al compartir",
     "Error while unsharing" : "Error al dejar de compartir",
-    "Set expiration date" : "Establecer fecha de caducidad",
     "Expiration" : "Caducidad",
-    "Expiration date" : "Fecha de caducidad",
     "Remove link" : "Eliminar enlace",
     "Link" : "Enlace",
     "Edit" : "Editar",
     "Remove" : "Borrar",
-    "Choose a password for the public link" : "Establece una contraseña para el enlace público",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Anyone with the link has access to the file/folder" : "Cualquier persona con el enlace tiene acceso al archivo/carpeta",
+    "Link name" : "Nombre del enlace",
+    "Name" : "Nombre",
     "Filename" : "Nombre de archivo",
     "Password" : "Contraseña",
-    "Name" : "Nombre",
-    "Allow editing" : "Permitir edición",
+    "Share" : "Compartir",
     "Save" : "Guardar",
-    "Sending ..." : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Email link to person" : "Enviar enlace por correo electrónico a una persona",
+    "Sending" : "Enviando",
     "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartido contigo por {owner}",
     "group" : "grupo",
-    "remote" : "remoto",
     "notify by email" : "notificar al usuario por correo electrónico",
     "Unshare" : "Dejar de compartir",
     "can share" : "puede compartir",
@@ -121,9 +119,8 @@ OC.L10N.register(
     "change" : "cambio",
     "delete" : "eliminar",
     "access control" : "control de acceso",
-    "Share" : "Compartir",
-    "Resharing is not allowed" : "No se permite compartir de nuevo",
-    "Warning" : "Precaución",
+    "User" : "Usuario",
+    "Group" : "Grupo",
     "restricted" : "restringido",
     "invisible" : "invisible",
     "({scope})" : "({scope})",
@@ -156,6 +153,7 @@ OC.L10N.register(
     "Message: %s" : "Mensaje: %s",
     "File: %s" : "Archivo: %s",
     "Line: %s" : "Línea: %s",
+    "Imprint" : "pie de imprenta",
     "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
     "Username" : "Nombre de usuario",
     "Data folder" : "Directorio de datos",
@@ -171,17 +169,17 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
     "Please contact your administrator." : "Por favor, contacte con el administrador.",
-    "Log in" : "Entrar",
+    "Login" : "Iniciar sesión",
+    "Wrong password." : "Contraseña incorrecta.",
     "Alternative Logins" : "Accesos Alternativos",
     "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
     "New password" : "Nueva contraseña",
+    "New Password" : "Nueva contraseña",
+    "Confirm Password" : "Confirmar contraseña",
     "Reset password" : "Restablecer contraseña",
     "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
     "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
-    "Thank you for your patience." : "Gracias por su paciencia.",
-    "Copy to clipboard" : "Copiar al portapapeles",
-    "Anyone with the link has access to the file/folder" : "Cualquier persona con el enlace tiene acceso al archivo/carpeta",
-    "Link name" : "Nombre del enlace"
+    "Thank you for your patience." : "Gracias por su paciencia."
 },
 "nplurals=2; plural=(n != 1);");
