@@ -12,11 +12,13 @@ OC.L10N.register(
     "No crop data provided" : "Lõikeandmeid ei leitud",
     "No valid crop data provided" : "Korrektseid lõikeandmeid ei leitud",
     "Crop is not square" : "Lõikamine pole ruudukujuline",
-    "Couldn't reset password because the token is invalid" : "Ei saanud parooli taastada, kuna märgend on vigane",
     "%s password changed successfully" : "%s parool on muudetud",
     "%s password reset" : "%s parooli lähtestus",
     "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
-    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
+    "Download / View" : "Laadi alla / Vaata",
+    "Download / View / Upload" : "Laadi alla / Vaata / Laadi üles",
+    "Download / View / Edit" : "Laadi alla / Vaata / Muuda",
+    "Upload only" : "Ainult üleslaadimine",
     "Preparing update" : "Uuendamise ettevalmistamine",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Paranda hoiatus:",
@@ -89,6 +91,8 @@ OC.L10N.register(
     "Saving..." : "Salvestamine...",
     "Dismiss" : "Jäta vahele",
     "seconds ago" : "sekundit tagasi",
+    "Enter license key" : "Sisesta litsentsivõti",
+    "Set new key" : "Määra uus litsentsivõti",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. <br />Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. <br />Oled sa kindel, et sa soovid jätkata?",
     "I know what I'm doing" : "Ma tean mida teen",
@@ -124,44 +128,42 @@ OC.L10N.register(
     "Error while sharing" : "Viga jagamisel",
     "Error while unsharing" : "Viga jagamise lõpetamisel",
     "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
-    "Set expiration date" : "Määra aegumise kuupäev",
     "Expiration" : "Aegumine",
-    "Expiration date" : "Aegumise kuupäev",
+    "Choose an expiration date" : "Vali aegumise kuupäev",
     "Expiration date is required" : "Aegumise kuupäev on nõutud",
     "Delete {link}" : "Kustuta {link}",
     "Remove link" : "Eemalda link",
-    "{fileName} link" : "{fileName} link",
     "Link" : "Link",
     "Create public link" : "Loo avalik link",
     "Edit" : "Muuda",
     "Remove" : "Eemalda",
-    "Click to copy to clipboard" : "Kliki, et link lõikelauale kopeerida",
+    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Social share" : "Sotsiaalvõrgustikus jagamine",
     "Copied!" : "Kopeeritud!",
     "Not supported!" : "Pole toetatud!",
     "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘-C.",
     "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl-C.",
-    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
+    "Choose a password" : "Vali parool",
     "Password required" : "Parool on nõutud",
+    "Link name" : "Lingi nimi",
+    "Name" : "Nimi",
     "Filename" : "Failinimi",
     "Password" : "Parool",
-    "Name" : "Nimi",
-    "Allow editing" : "Luba muutmine",
-    "Show file listing" : "Näita failide nimekirja",
     "Edit link share: {name}" : "Muuda jagamise link: {name}",
-    "Save" : "Salvesta",
     "Create link share: {name}" : "Loo lingiga jagamine: {name}",
+    "Share" : "Jaga",
+    "Save" : "Salvesta",
     "Remove password" : "Eemalda parool",
     "Share to Twitter. Opens in a new window." : "Jaga Twitteris. Avaneb uues aknas.",
     "Share to Facebook. Opens in a new window." : "Jaga Facebookis. Avaneb uues aknas.",
     "Share to Diaspora. Opens in a new window." : "Jaga Diasporas. Avaneb uues aknas.",
     "Share to Google+. Opens in a new window." : "Jaga Google plusis. Avaneb uues aknas.",
     "Share via email. Opens your mail client." : "Jaga e-postiga. Avab sinu meilikliendi",
-    "Error while sending notification" : "Tõrge teavituse saatmisel",
-    "Sending ..." : "Saatmine ...",
-    "Email sent" : "E-kiri on saadetud",
     "Email link to person" : "Saada link isikule e-postiga",
+    "Send copy to self" : "Saada koopia ka endale",
     "Send link via email" : "Jaga linki e-postiga",
+    "Add personal message" : "Lisa isiklik sõnum",
+    "Sending" : "Saatmine",
     "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
     "Shared with you by {owner}" : "Sinuga jagas {owner}",
     "group" : "grupp",
@@ -176,22 +178,22 @@ OC.L10N.register(
     "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
     "No users found for {search}" : "Otsinguga {search} ei leitud ühtegi kasutajat",
     "An error occurred. Please try again" : "Tekkis tõrge. Palu proovi uuesti",
-    "{sharee} (group)" : "{sharee} (group)",
-    "{sharee} (at {server})" : "{sharee} (serveris {server})",
-    "{sharee} (remote)" : "{sharee} (mujal serveris)",
-    "Share" : "Jaga",
+    "User" : "Kasutaja",
+    "Group" : "Grupp",
+    "Guest" : "Külaline",
     "User and Groups" : "Kasutajad ja grupid",
     "Public Links" : "Avalikud lingid",
-    "Resharing is not allowed" : "Edasijagamine pole lubatud",
+    "Sharing is not allowed" : "Jagamine pole lubatud",
     "Share with users…" : "Jaga kasutajatega...",
     "Share with users, groups or remote users…" : "Jaga kasutajate, gruppide või kaugkasutajatega...",
     "Share with users or groups…" : "Jaga kasutajate või gruppidega...",
     "Share with users or remote users…" : "Jaga kasutajate või kaugkasutajatega...",
     "Error removing share" : "Jagamise eemaldamisel tekkis tõrge",
-    "Warning" : "Hoiatus",
+    "Unknown Share" : "Tundmatu jagamine",
     "Non-existing tag #{tag}" : "Silti #{tag} pole olemas",
     "restricted" : "piiratud",
     "invisible" : "nähtamatu",
+    "Static" : "Staatiline",
     "({scope})" : "({scope})",
     "Delete" : "Kustuta",
     "Rename" : "Nimeta ümber",
@@ -230,8 +232,6 @@ OC.L10N.register(
     "Cheers!" : "Terekest!",
     "Internal Server Error" : "Serveri sisemine viga",
     "The server encountered an internal error and was unable to complete your request." : "Serveris tekkis sisemine tõrge ja sinu päringu täitmine ebaõnnestus.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Kui seda veateadet näidatakse mitu korda, siis palun võta ühendust serveri administraatoriga. Palun lisa alla aruandesse tehnilised üksikasjad.",
-    "More details can be found in the server log." : "Lisainfot võib leida serveri logist.",
     "Technical details" : "Tehnilised andmed",
     "Remote Address: %s" : "Kaugaadress: %s",
     "Request ID: %s" : "Päringu ID: %s",
@@ -241,6 +241,8 @@ OC.L10N.register(
     "File: %s" : "Fail: %s",
     "Line: %s" : "Rida: %s",
     "Trace" : "Jälita",
+    "Imprint" : "Impressum",
+    "Privacy Policy" : "Privaatsus",
     "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
     "Username" : "Kasutajanimi",
     "Storage & database" : "Andmehoidla ja andmebaas",
@@ -261,14 +263,15 @@ OC.L10N.register(
     "See the documentation" : "Vaata dokumentatsiooni",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
+    "Menu" : "Menüü",
     "Log out" : "Logi välja",
     "Search" : "Otsi",
     "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
     "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
     "An internal error occurred." : "Tekkis sisemine tõrge",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
+    "Login" : "Logi sisse",
     "Username or email" : "Kasutajanimi või e-posti aadress",
-    "Log in" : "Logi sisse",
     "Wrong password. Reset it?" : "Vale parool. Kas vajad parooli taastamist?",
     "Wrong password." : "Vale parool.",
     "Stay logged in" : "Püsi sisselogituna",
@@ -277,6 +280,7 @@ OC.L10N.register(
     "Password changed successfully" : "Parool on muudetud",
     "New password" : "Uus parool",
     "New Password" : "Uus parool",
+    "Confirm Password" : "Kinnita parool",
     "Reset password" : "Nulli parool",
     "This ownCloud instance is currently in single user mode." : "See ownCloud on momendil seadistatud ühe kasutaja jaoks.",
     "This means only administrators can use the instance." : "See tähendab, et seda saavad kasutada ainult administraatorid.",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Two-step verification" : "Kahe-etapiline kinnitamine",
     "Cancel login" : "Tühista sisselogimine",
     "You are accessing the server from an untrusted domain." : "Sa kasutad serverit usalduseta asukohast",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Sõltuvalt sinu seadetest võib ka administraator kasutada allolevat nuppu, et seda domeeni usaldusväärseks märkida.",
-    "Add \"%s\" as trusted domain" : "Lisa \"%s\" usaldusväärse domeenina",
     "App update required" : "Rakenduse uuendus on nõutud",
     "These apps will be updated:" : "Neid rakendusi uuendatakse:",
     "The theme %s has been disabled." : "Teema %s on keelatud.",
@@ -295,8 +297,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
     "Detailed logs" : "Üksikasjalikud logid",
     "Update needed" : "On vaja uuendada",
-    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval.",
-    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
-    "Menu" : "Menüü"
+    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval."
 },
 "nplurals=2; plural=(n != 1);");
