@@ -1,21 +1,54 @@
 OC.L10N.register(
     "core",
     {
+    "Please select a file." : "Mesedez, hautatu fitxategia.",
+    "File is too big" : "Fitxategia handiegia da",
+    "Invalid file provided" : "Baliogabeko fitxategia",
     "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "Invalid image" : "Baliogabeko irudia",
+    "An error occurred. Please contact your admin." : "Errore bat gertatu da. Mesedez jarri harremanetan zure administratzailearekin.",
     "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
     "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
-    "Couldn't reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
+    "No valid crop data provided" : "Ebaketarako datu baliogabea",
+    "Crop is not square" : "Ebaketa ez da karratua",
+    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
+    "Could not reset password because the token expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
+    "Could not reset password because the token does not match" : "Ezin izan da pasahitza berrezarri tokena ez datorrelako bat",
+    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
     "%s password reset" : "%s pasahitza berrezarri",
     "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
-    "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
+    "Download / View" : "Deskargatu / Ikusi",
+    "Recipients can view or download contents." : "Hartzaileek edukiak ikusi edo jaitsi ditzakete.",
+    "Download / View / Upload" : "Deskargatu / Ikusi / Kargatu",
+    "Recipients can view, download, edit, delete and upload contents." : "Hartzaileek edukiak jaitsi, editatu, ezabatu eta igo ditzakete.",
+    "Upload only" : "Kargatu bakarrik",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Hainbat hartzaileengandik fitxategiak jaso karpeten edukiak erakutsi gabe.",
+    "Preparing update" : "Eguneraketa prestatzen",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Konponketa abisua:",
+    "Repair error: " : "Konponketa errorea:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mesedez, erabili komando lerroko eguneraketa, modu automatikoa desgaitua dago config.php fitxategian",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: %s Taula baieztatzen",
     "Turned on maintenance mode" : "Mantenu modua gaitu da",
     "Turned off maintenance mode" : "Mantenu modua desgaitu da",
+    "Maintenance mode is kept active" : "Mantentze-modua aktibo dago",
+    "Updating database schema" : "Datu-base eskema eguneratzen",
     "Updated database" : "Datu basea eguneratu da",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Datu-base eskema eguneratu daiteken baieztatzen (dabu-base tamainaren arabera denbora luzea eraman dezake honek)",
     "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
+    "Checking updates of apps" : "Aplikazioentzat eguneraketak baieztatzen",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s-en datubase eskema eguneratu daitekeen baieztatzen (datubasearen tamainaren arabera denbora luzea eman dezake honek)",
     "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
     "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
+    "Set log level to debug" : "Log maila arazketa gisa jarri",
+    "Reset log level" : "Log maila berrezarri",
+    "Starting code integrity check" : "Kode osotasun baieztapena hasten",
+    "Finished code integrity check" : "Kode osotasun baieztapena amaituta",
+    "%s (3rdparty)" : "%s (3garrena)",
+    "%s (incompatible)" : "%s (bateraezina)",
+    "Following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
+    "Already up to date" : "Dagoeneko martxan",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
     "Tuesday" : "Asteartea",
@@ -31,6 +64,11 @@ OC.L10N.register(
     "Fri." : "ol.",
     "Sat." : "lr.",
     "Su" : "Ig",
+    "Mo" : "Al",
+    "Tu" : "Ar",
+    "We" : "Az",
+    "Th" : "Og",
+    "Fr" : "Ol",
     "Sa" : "La",
     "January" : "Urtarrila",
     "February" : "Otsaila",
@@ -56,13 +94,17 @@ OC.L10N.register(
     "Oct." : "urr.",
     "Nov." : "aza.",
     "Dec." : "abe.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Arazoak egon dira kodearen osotasun egiaztatzearekin. Xehetasun gehiago...</a>",
     "Settings" : "Ezarpenak",
+    "Problem loading page, reloading in 5 seconds" : "Arazoa orria kargatzen, 5 segundo barru birkargatuko da",
     "Saving..." : "Gordetzen...",
+    "Dismiss" : "Baztertu",
     "seconds ago" : "segundu",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Zure pasahitza berrezartzeko lotura zure postara bidalia izan da.<br>Ez baduzu arrazoizko denbora epe batean jasotzen begiratu zure zabor-posta karpetan.<br>Hor ere ez badago kudeatzailearekin harremanetan jarri.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Zure fitxategiak enkriptaturik daude. Ez baduzu berreskuratze gakoa gaitzen pasahitza berrabiaraztean ez da zure fitxategiak berreskuratzeko modurik egongo. <br />Zer egin ziur ez bazaude kudeatzailearekin harremanetan ipini jarraitu aurretik.<br /> Ziur zaude aurrera jarraitu nahi duzula?",
-    "I know what I'm doing" : "Badakit zer ari naizen egiten",
+    "I know what I'm doing" : "Badakit zertan nabilen",
     "Password can not be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Mesedez jarri harremetan zure administradorearekin.",
+    "Error adding {addItem}: {addItem} already exists" : "{addItem} gehitzean errorea: {addItem} dagoeneko bada",
     "No" : "Ez",
     "Yes" : "Bai",
     "Choose" : "Aukeratu",
@@ -86,6 +128,8 @@ OC.L10N.register(
     "So-so password" : "Halamoduzko pasahitza",
     "Good password" : "Pasahitz ona",
     "Strong password" : "Pasahitz sendoa",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Zure web zerbitzaria ez dago ondo ezarrita WebDAV interfazea apurtuta dagoela dirudielako.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Zure web zerbitzaria ez dago ondo ezarrita \"{url}\" ebazteko. Xehetasun gehiago aurkitu daiteke gure <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentazioan</a>.",
     "Error occurred while checking server setup" : "Errore bat gertatu da zerbitzariaren konfigurazioa egiaztatzerakoan.",
     "Shared" : "Elkarbanatuta",
     "Shared with {recipients}" : "{recipients}-rekin partekatua.",
@@ -93,24 +137,31 @@ OC.L10N.register(
     "Error while sharing" : "Errore bat egon da elkarbanatzean",
     "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
     "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
-    "Set expiration date" : "Ezarri muga data",
     "Expiration" : "Iraungitzea",
-    "Expiration date" : "Muga data",
+    "Remove link" : "Esteka ezabatu",
     "Link" : "Esteka",
+    "Create public link" : "Esteka publikoa sortu",
     "Edit" : "Editatu",
     "Remove" : "Ezabatu",
-    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
-    "Password" : "Pasahitza",
+    "Copy to clipboard" : "Kopiatu arbelera",
+    "Anyone with the link has access to the file/folder" : "Esteka duen edonork atzitu dezake fitxategi/karpeta",
+    "Copied!" : "Kopiatua!",
+    "Not supported!" : "Euskarririk ez!",
+    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
+    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
+    "Choose a password" : "Aukeratu pasahitza",
+    "Password required" : "Pasahitza beharrezkoa",
+    "Link name" : "Estekaren izena",
     "Name" : "Izena",
-    "Allow editing" : "Baimendu editatzea",
+    "Filename" : "Fitxategiaren izena",
+    "Password" : "Pasahitza",
+    "Share" : "Elkarbanatu",
     "Save" : "Gorde",
-    "Sending ..." : "Bidaltzen ...",
-    "Email sent" : "Eposta bidalia",
+    "Remove password" : "Pasahitza ezabatu",
     "Email link to person" : "Postaz bidali lotura ",
     "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
     "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
     "group" : "taldea",
-    "remote" : "urrunekoa",
     "notify by email" : "jakinarazi eposta bidez",
     "Unshare" : "Ez elkarbanatu",
     "can share" : "elkarbana dezake",
@@ -119,12 +170,16 @@ OC.L10N.register(
     "change" : "aldatu",
     "delete" : "ezabatu",
     "access control" : "sarrera kontrola",
-    "Share" : "Elkarbanatu",
-    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
+    "No users found for {search}" : "Ez da erabiltzailerik aurkitu {search} bilaketan",
+    "An error occurred. Please try again" : "Errorea eman da. Saiatu berriz mesedez",
+    "User" : "Erabiltzailea",
+    "Group" : "Taldea",
+    "User and Groups" : "Erabiltzaile eta Taldeak",
+    "Public Links" : "Esteka Publikoak",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partekatu beste ownClud-en jendearekin sintaxi honekin erabiltzaleizena@adibidea.com/owncloud",
-    "Warning" : "Abisua",
     "Delete" : "Ezabatu",
     "Rename" : "Berrizendatu",
+    "Collaborative tags" : "Kolaboraziorako etiketak",
     "The object type is not specified." : "Objetu mota ez dago zehaztuta.",
     "Enter new" : "Sartu berria",
     "Add" : "Gehitu",
@@ -152,13 +207,11 @@ OC.L10N.register(
     "File not found" : "Ez da fitxategia aurkitu",
     "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
     "You can click here to return to %s." : "Hemen klika dezakezu %sra itzultzeko.",
-    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Kaixo\n\n%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s\n\n",
+    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Kaixo,\n\n%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s\n\n",
     "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
     "Cheers!" : "Ongi izan!",
     "Internal Server Error" : "Zerbitzariaren Barne Errorea",
     "The server encountered an internal error and was unable to complete your request." : "Zerbitzariak barne errore bat izan du eta ez da gai izan zure eskaria osatzeko.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Mesedez harremanetan jarri zerbitzariaren kudeatzailearekin errore hau aldi askotan agertzekotan, mesedez gehitu beheko zehaztapen teknikoak zure txostenean.",
-    "More details can be found in the server log." : "Zehaztapen gehiago zerbitzariaren egunerokoan aurki daitezke.",
     "Technical details" : "Arazo teknikoak",
     "Remote Address: %s" : "Urruneko Helbidea: %s",
     "Request ID: %s" : "Eskariaren IDa: %s",
@@ -167,6 +220,8 @@ OC.L10N.register(
     "File: %s" : "Fitxategia: %s",
     "Line: %s" : "Lerroa: %s",
     "Trace" : "Arrastoa",
+    "Imprint" : "Imprint",
+    "Privacy Policy" : "Pribatasun Politika",
     "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
     "Username" : "Erabiltzaile izena",
     "Storage & database" : "Biltegia & datubasea",
@@ -181,68 +236,28 @@ OC.L10N.register(
     "Finish setup" : "Bukatu konfigurazioa",
     "Finishing …" : "Bukatzen...",
     "Need help?" : "Laguntza behar al duzu?",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo<br><br>%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo,<br><br>%s-ek <strong>%s</strong> zurekin partekatu duela jakin dezazun.<br><a href=\"%s\">Ikusi ezazu!</a><br><br>",
+    "Menu" : "Menua",
     "Log out" : "Saioa bukatu",
     "Search" : "Bilatu",
     "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
     "Please contact your administrator." : "Mesedez jarri harremetan zure administradorearekin.",
-    "Log in" : "Hasi saioa",
+    "Login" : "Saio hasiera",
     "Alternative Logins" : "Beste erabiltzaile izenak",
     "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
     "New password" : "Pasahitz berria",
     "New Password" : "Pasahitz Berria",
+    "Confirm Password" : "Pasahitza baieztatu",
     "Reset password" : "Berrezarri pasahitza",
     "This ownCloud instance is currently in single user mode." : "ownCloud instantzia hau erabiltzaile bakar moduan dago.",
     "This means only administrators can use the instance." : "Honek administradoreak bakarrik erabili dezakeela esan nahi du.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu hau irauten badu edo bat-batean agertu bada.",
     "Thank you for your patience." : "Milesker zure patzientziagatik.",
     "You are accessing the server from an untrusted domain." : "Zerbitzaria domeinu ez fidagarri batetik eskuratzen ari zara.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Zure ezarpenen gorabehera, administratzaile bezala posible duzu ere azpiko botoia erabiltzea fidatzeko domeinu horrekin.",
-    "Add \"%s\" as trusted domain" : "Gehitu \"%s\" domeinu fidagarri gisa",
     "The theme %s has been disabled." : "%s gaia desgaitu da.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
     "Start update" : "Hasi eguneraketa",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
-    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean.",
-    "No valid crop data provided" : "Ebaketarako datu baliogabea",
-    "Crop is not square" : "Ebaketa ez da karratua",
-    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
-    "Could not reset password because the token expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
-    "Could not reset password because the token does not match" : "Ezin izan da pasahitza berrezarri tokena ez datorrelako bat",
-    "Preparing update" : "Eguneraketa prestatzen",
-    "Create public link" : "Esteka publikoa sortu",
-    "Copy to clipboard" : "Kopiatu arbelera",
-    "Anyone with the link has access to the file/folder" : "Esteka duen edonork atzitu dezake fitxategi/karpeta",
-    "Filename" : "Fitxategiaren izena",
-    "User and Groups" : "Erabiltzaile eta Taldeak",
-    "Menu" : "Menua",
-    "Invalid file provided" : "Baliogabeko fitxategia",
-    "File is too big" : "Fitxategia handiegia da",
-    "Collaborative tags" : "Kolaboraziorako etiketak",
-    "Please select a file." : "Mesedez, hautatu fitxategia.",
-    "An error occurred. Please contact your admin." : "Errore bat gertatu da. Mesedez jarri harremanetan zure administratzailearekin.",
-    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair warning: " : "Konponketa abisua:",
-    "Repair error: " : "Konponketa errorea:",
-    "Checking updates of apps" : "Aplikazioentzat eguneraketak baieztatzen",
-    "%s (3rdparty)" : "%s (3garrena)",
-    "%s (incompatible)" : "%s (bateraezina)",
-    "Following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
-    "Already up to date" : "Dagoeneko martxan",
-    "Mo" : "Al",
-    "Tu" : "Ar",
-    "We" : "Az",
-    "Th" : "Og",
-    "Fr" : "Ol",
-    "Dismiss" : "Baztertu",
-    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
-    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
-    "Updating database schema" : "Datu-base eskema eguneratzen",
-    "Error adding {addItem}: {addItem} already exists" : "{addItem} gehitzean errorea: {addItem} dagoeneko bada",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Datu-base eskema eguneratu daiteken baieztatzen (dabu-base tamainaren arabera denbora luzea eraman dezake honek)",
-    "Reset log level" : "Log maila berrezarri",
-    "Starting code integrity check" : "Kode osotasun baieztapena hasten",
-    "Finished code integrity check" : "Kode osotasun baieztapena amaituta"
+    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean."
 },
 "nplurals=2; plural=(n != 1);");
