@@ -12,11 +12,17 @@ OC.L10N.register(
     "No crop data provided" : "Puutteellinen tieto",
     "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
     "Crop is not square" : "Leikkaus ei ole neliö",
-    "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutus on virheellinen",
-    "Couldn't reset password because the token is expired" : "Salasanan palauttaminen ei onnistunut, koska valtuutus on vanhentunut",
+    "Could not reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutuslinkki on virheellinen",
+    "Could not reset password because the token expired" : "Salasanaa ei voitu nollata koska valtuutuslinkki on vanhentunut",
+    "Could not reset password because the token does not match" : "Salasanaa ei voitu nollata koska valtuutuslinkki ei täsmää",
+    "%s password changed successfully" : "%s salasana vaihdettiin onnistuneesti",
     "%s password reset" : "%s salasanan palautus",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Couldn't send mail to following users: %s " : "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
+    "Download / View" : "Lataa / Näytä",
+    "Recipients can view or download contents." : "Vastaanottaja voi katsoa tai ladata sisältöä.",
+    "Download / View / Upload" : "Lataa / Näytä / Lähetä",
+    "Recipients can view, download, edit, delete and upload contents." : "Vastaanottaja voi katsoa, ladata, muokata, poistaa ja lähettää sisältöä.",
+    "Upload only" : "Vain lähetys",
     "Preparing update" : "Valmistellaan päivitystä",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Korjausvaroitus:",
@@ -122,6 +128,7 @@ OC.L10N.register(
     "Strong password" : "Vahva salasana",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "HTTP-palvelinta ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liittymä vaikuttaa olevan rikki.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tällä palvelimella ei ole toimivaa internetyhteyttä. Sen seurauksena jotkin ominaisuudet, kuten erillinen tallennustila, ilmoitukset päivityksistä ja kolmansien osapuolten sovellusten asennus eivät toimi. Tiedostojen käyttö etänä tai ilmoitusten lähetys sähköpostitse eivät välttämättä toimi myöskään. Suosittelemme kytkemään palvelimen internetyhteyteen, jos haluat käyttää kaikkia ownCloudin ominaisuuksia.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Sinulla on käytässä PHP {version}. Kannustamme sinua päivättämään PHP versiosi hyödyntääksesi <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">tehokkuus ja tietoturva päivityksiä jotka PHP Group tarjoaa </a> heti kun jakelusi tukee sitä.",
     "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datahakemistosi ja tiedostosi ovat luultavasti käytettävissä suoraan internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään http-palvelimen asetukset siten, ettei datahakemisto ole suoraan käytettävissä internetistä, tai siirtämään datahakemiston http-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-otsaketta \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten suosittelemme muuttamaan asetuksen arvoa.",
@@ -132,36 +139,48 @@ OC.L10N.register(
     "Error while sharing" : "Virhe jaettaessa",
     "Error while unsharing" : "Virhe jakoa peruttaessa",
     "The public link will expire no later than {days} days after it is created" : "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
-    "Set expiration date" : "Aseta päättymispäivä",
     "Expiration" : "Erääntyminen",
-    "Expiration date" : "Päättymispäivä",
+    "Choose an expiration date" : "Valitse vanhenemispäivä",
+    "Expiration date is required" : "Vanhenemispäivä vaaditaan",
+    "Delete {link}" : "Poista {link}",
+    "Remove link" : "Poista linkki",
     "Link" : "Linkki",
+    "Create public link" : "Luo julkinen linkki",
     "Edit" : "Muokkaa",
     "Remove" : "Poista",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Social share" : "Sosiaalinen jako",
+    "There are currently no link shares, you can create one" : "Jakolinkkejä ei nyt ole. Voit luoda uuden.",
+    "Anyone with the link has access to the file/folder" : "Kenellä tahansa linkin omaavalla on pääsy tiedostoon/kansioon",
     "Copied!" : "Kopioitu!",
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
+    "Choose a password" : "Valitse salasana",
+    "Password required" : "Salasana vaaditaan",
+    "Link name" : "Linkin nimi",
+    "Name" : "Nimi",
     "Filename" : "Tiedostonimi",
     "Password" : "Salasana",
-    "Name" : "Nimi",
-    "Allow editing" : "Salli muokkaus",
+    "Edit link share: {name}" : "Muokkaa jakolinkkiä: {name}",
+    "Create link share: {name}" : "Luo jakolinkki: {name}",
+    "Share" : "Jaa",
     "Save" : "Tallenna",
+    "Remove password" : "Poista salasana",
     "Share to Twitter. Opens in a new window." : "Jaa Twitteriin. Avautuu uuteen ikkunaan.",
     "Share to Facebook. Opens in a new window." : "Jaa Facebookiin. Avautuu uuteen ikkunaan.",
     "Share to Diaspora. Opens in a new window." : "Jaa Diasporaan. Avautuu uuteen ikkunaan.",
     "Share to Google+. Opens in a new window." : "Jaa Google+:aan. Avautuu uuteen ikkunaan.",
     "Share via email. Opens your mail client." : "Jaa sähköpostitse. Avautuu sähköpostisovellukseen.",
-    "Error while sending notification" : "Virhe ilmoitusta lähettäessä",
-    "Sending ..." : "Lähetetään...",
-    "Email sent" : "Sähköposti lähetetty",
     "Email link to person" : "Lähetä linkki sähköpostitse",
+    "Send copy to self" : "Lähetä kopio itsellesi",
     "Send link via email" : "Lähetä linkki sähköpostitse",
+    "Add personal message" : "Lisää henkilökohtainen viesti",
+    "Sending" : "Lähetetään",
+    "E-Mail sent" : "Sähköposti lähetetty",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
     "Shared with you by {owner}" : "Jaettu kanssasi käyttäjän {owner} toimesta",
     "group" : "ryhmä",
-    "remote" : "etä",
     "notify by email" : "ilmoita sähköpostitse",
     "Unshare" : "Peru jakaminen",
     "can share" : "jaa",
@@ -171,22 +190,22 @@ OC.L10N.register(
     "delete" : "poista",
     "access control" : "Pääsyn hallinta",
     "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
+    "Email notification was sent!" : "Sähköposti-ilmoitus lähetetty!",
+    "Email notification not sent" : "Sähköposti-ilmoitusta ei lähetetty",
     "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
     "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
     "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
     "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
-    "{sharee} (group)" : "{sharee} (ryhmä)",
-    "{sharee} (at {server})" : "{sharee} (palvelimella {server})",
-    "{sharee} (remote)" : "{sharee} (etä)",
-    "Share" : "Jaa",
-    "Resharing is not allowed" : "Jakaminen uudelleen ei ole salittu",
+    "User" : "Käyttäjä",
+    "Group" : "Ryhmä",
+    "User and Groups" : "Käyttäjät ja ryhmät",
+    "Public Links" : "Julkiset linkit",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Jaa toisia ownCloud-järjestelmiä käyttävien kesken käyttäen syntaksia käyttäjätunnus@esimerkki.fi/owncloud",
     "Share with users…" : "Jaa käyttäjien kanssa…",
     "Share with users, groups or remote users…" : "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
     "Share with users or groups…" : "Jaa käyttäjien tai ryhmien kanssa…",
     "Share with users or remote users…" : "Jaa käyttäjien tai etäkäyttäjien kanssa…",
     "Error removing share" : "Virhe jakoa poistaessa",
-    "Warning" : "Varoitus",
     "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
     "restricted" : "rajoitettu",
     "invisible" : "näkymätön",
@@ -232,8 +251,7 @@ OC.L10N.register(
     "Cheers!" : "Kiitos!",
     "Internal Server Error" : "Sisäinen palvelinvirhe",
     "The server encountered an internal error and was unable to complete your request." : "Palvelin kohtasi sisäisen virheen, eikä pystynyt viimeistelmään pyyntöäsi.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Ota yhteys palvelimen ylläpitäjään, jos tämä virhe ilmenee useita kertoja. Lisää yhteydenottoosi alla olevat tekniset tiedot.",
-    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Lisätietoja on saatavilla <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">palvelinlokista</a>.",
     "Technical details" : "Tekniset tiedot",
     "Remote Address: %s" : "Etäosoite: %s",
     "Request ID: %s" : "Pyynnön tunniste: %s",
@@ -243,6 +261,8 @@ OC.L10N.register(
     "File: %s" : "Tiedosto: %s",
     "Line: %s" : "Rivi: %s",
     "Trace" : "Jälki",
+    "Imprint" : "Tiedot",
+    "Privacy Policy" : "Tietosuojalauseke",
     "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
     "Username" : "Käyttäjätunnus",
     "Storage & database" : "Tallennus ja tietokanta",
@@ -267,22 +287,26 @@ OC.L10N.register(
     "See the documentation" : "Tutustu dokumentaatioon",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
+    "Menu" : "Valikko",
     "Log out" : "Kirjaudu ulos",
     "Search" : "Etsi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
     "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
     "An internal error occurred." : "Tapahtui sisäinen virhe",
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
+    "Login" : "Kirjaudu",
     "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
-    "Log in" : "Kirjaudu sisään",
     "Wrong password. Reset it?" : "Väärä salasana. Haluatko palauttaa salasanan?",
     "Wrong password." : "Väärä salasana.",
+    "You are trying to access a private link. Please log in first." : "Yrität käyttää yksityistä linkkiä. Kirjaudu sisään ensin.",
     "Stay logged in" : "Pysy sisäänkirjautuneena",
     "Alternative Logins" : "Vaihtoehtoiset kirjautumiset",
     "Use the following link to reset your password: {link}" : "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
+    "Password changed successfully" : "Salasana vaihdettu onnistuneesti",
     "New password" : "Uusi salasana",
     "New Password" : "Uusi salasana",
     "Reset password" : "Palauta salasana",
+    "Personal note from the sender: <br> %s." : "Henkilökohtainen viesti lähettäjältä: <br> %s.",
     "This ownCloud instance is currently in single user mode." : "Tämä ownCloud-asennus on parhaillaan single user -tilassa.",
     "This means only administrators can use the instance." : "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
@@ -292,9 +316,6 @@ OC.L10N.register(
     "Cancel login" : "Peru kirjautuminen",
     "Please authenticate using the selected factor." : "Tunnistaudu käyttäen valittua vahvistusta.",
     "You are accessing the server from an untrusted domain." : "Olet yhteydessä palvelimeen epäluotettavasta verkko-osoitteesta.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ota yhteys ylläpitoon. Jos olet tämän asennuksen ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tarjolla tiedostossa config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Riippuen määrityksistä, ylläpitäjänä saatat kyetä käyttämään alla olevaa painiketta luodaksesi luottamussuhteen tähän toimialueeseen.",
-    "Add \"%s\" as trusted domain" : "Lisää \"%s\" luotetuksi toimialueeksi",
     "App update required" : "Sovelluksen päivittäminen vaaditaan",
     "%s will be updated to version %s" : "%s päivitetään versioon %s",
     "These apps will be updated:" : "Nämä sovellukset päivitetään:",
@@ -304,30 +325,9 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
     "Detailed logs" : "Yksityiskohtainen loki",
     "Update needed" : "Päivitys vaaditaan",
-    "Please use the command line updater because you have a big instance." : "Käytä komentorivipäivitintä, koska käyttämäsi ownCloud on sen verran suuri.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automaattiset päivitykset on poistettu käytöstä config.php:ssä. Päivittääksesi asennuksesi, ole hyvä ja käytä päivittäjää komentoriviltä (occ upgrade)",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Apua saat <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaatiosta</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
-    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä.",
-    "Expiration date is required" : "Vanhenemispäivä vaaditaan",
-    "Remove link" : "Poista linkki",
-    "Create public link" : "Luo julkinen linkki",
-    "Copy to clipboard" : "Kopioi leikepöydälle",
-    "Anyone with the link has access to the file/folder" : "Kenellä tahansa linkin omaavalla on pääsy tiedostoon/kansioon",
-    "Password required" : "Salasana vaaditaan",
-    "Remove password" : "Poista salasana",
-    "User and Groups" : "Käyttäjät ja ryhmät",
-    "Public Links" : "Julkiset linkit",
-    "Delete {link}" : "Poista {link}",
-    "Menu" : "Valikko",
-    "Read only" : "Vain luku",
-    "Read & Write" : "Luku ja kirjoitus",
-    "Email notification not sent" : "Sähköposti-ilmoitusta ei lähetetty",
-    "You took too long to login, please try again now" : "Kirjautumisessa kesti liian kauan. Yritä uudelleen nyt",
-    "Password changed successfully" : "Salasana vaihdettu onnistuneesti",
-    "Social share" : "Sosiaalinen jako",
-    "Link name" : "Linkin nimi",
-    "Owner: {owner}" : "Omistaja: {owner}",
-    "Email notification was sent!" : "Sähköposti-ilmoitus lähetetty!",
-    "You are trying to access a private link. Please log in first." : "Yrität käyttää yksityistä linkkiä. Kirjaudu sisään ensin."
+    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä."
 },
 "nplurals=2; plural=(n != 1);");
