@@ -12,12 +12,20 @@ OC.L10N.register(
     "No crop data provided" : "Aucune donnée de recadrage fournie",
     "No valid crop data provided" : "Données de recadrage non valides",
     "Crop is not square" : "Le recadrage n'est pas carré",
-    "Couldn't reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton n'est pas valable.",
-    "Couldn't reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
+    "Could not reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton est non valable",
+    "Could not reset password because the token expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
+    "Could not reset password because the token does not match" : "Impossible de réinitialiser le mot de passe car le jeton ne correspond pas.",
     "%s password changed successfully" : "Le mot de passe %s a été correctement changé",
     "%s password reset" : "Réinitialisation de votre mot de passe %s",
     "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
-    "Couldn't send mail to following users: %s " : "Impossible d'envoyer un courriel aux utilisateurs suivants : %s",
+    "Download / View" : "Télécharger / Voir",
+    "Recipients can view or download contents." : "Les bénéficiaires peuvent voir ou télécharger le contenu.",
+    "Download / View / Upload" : "Télécharger / Voir / Téléverser",
+    "Recipients can view, download and upload contents." : "Les bénéficiaires peuvent voir, télécharger, modifier et téléverser le contenu.",
+    "Download / View / Edit" : "Télécharger / Voir / Modifier",
+    "Recipients can view, download, edit, delete and upload contents." : "Les bénéficiaires peuvent voir, télécharger, modifier, supprimer et téléverser le contenu.",
+    "Upload only" : "Téléverser seulement",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Recevoir des fichiers de plusieurs bénéficiaires sans révéler le contenu du dossier.",
     "Preparing update" : "Préparation de la mise à jour",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair warning: " : "Avertissement de réparation :",
@@ -94,10 +102,20 @@ OC.L10N.register(
     "Saving..." : "Enregistrement…",
     "Dismiss" : "Ignorer",
     "seconds ago" : "à l'instant",
+    "You have enabled one or more ownCloud Enterprise apps but your installation does not have a valid license yet." : "Vous avez activé une ou plusieurs applications ownCloud Enterprise mais votre installation ne possède aucune licence valide.",
+    "A grace period of 24 hours has started to allow you to get going right away. Once the grace period ends, all Enterprise apps will become disabled unless you supply a valid license key." : "Une période de grâce de 24 heures a commencé pour vous permettre de démarrer. Une fois la période de grâce terminée, toutes les applications d'entreprise seront désactivées à moins que vous ne fournissiez une clé de licence valide.",
+    "To try ownCloud Enterprise, just start a 30-day demo and enter the provided license key below." : "Pour essayer ownCloud Enterprise,  lancez une démo de 30 jours et d'entrer la clé de licence fournie ci-dessous.",
+    "Upgrade to ownCloud Enterprise" : "Passer à ownCloud Enterprise",
+    "Remaining time: {rtime}" : "Temps restant: {rtime}",
+    "Get your demo key" : "Obtenez votre clé de démonstration",
+    "Enter license key" : "Entrez la clé de licence",
+    "Set new key" : "Définir une nouvelle clé",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Un lien permettant de réinitialiser votre mot de passe vient de vous être envoyé par courriel.<br>Si vous ne le recevez pas dans un délai raisonnable, contactez votre administrateur.<br>N'oubliez pas de vérifier dans votre dossier pourriel / spam!",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura aucun moyen de récupérer vos données une fois le mot de passe réinitialisé.<br />Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. <br />Voulez-vous vraiment continuer ?",
     "I know what I'm doing" : "Je sais ce que je fais",
     "Password can not be changed. Please contact your administrator." : "Le mot de passe ne peut être modifié. Veuillez contacter votre administrateur.",
+    "Passwords do not match" : "Les mots de passe ne correspondent pas",
+    "Error adding {addItem}: {addItem} already exists" : "Erreur en ajoutant {addItem}: {addItem} existe déjà",
     "No" : "Non",
     "Yes" : "Oui",
     "Choose" : "Choisir",
@@ -109,7 +127,7 @@ OC.L10N.register(
     "One file conflict" : "Un conflit de fichier",
     "New Files" : "Nouveaux fichiers",
     "Already existing files" : "Fichiers déjà existants",
-    "Which files do you want to keep?" : "Quels fichiers désirez-vous garder ?",
+    "Which files do you want to keep?" : "Quels fichiers désirez-vous conserver ?",
     "If you select both versions, the copied file will have a number added to its name." : "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
     "Cancel" : "Annuler",
     "Continue" : "Continuer",
@@ -130,6 +148,7 @@ OC.L10N.register(
     "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configuration des entêtes du proxy inverse est incorrecte, ou vous accédez à ownCloud depuis un proxy de confiance. Si vous n'êtes pas en train d’accéder à ownCloud depuis un proxy de confiance, ceci est un problème de sécurité qui peut permettre à un attaquant de masquer sa véritable adresse IP. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a> pour avoir plus d'informations à ce sujet.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "\"memcached\" est configuré comme cache distribué, mais le module installé est \"memcache\".  \\OC\\Memcache\\Memcached ne prend en charge que \"memcached\" et non \"memcache\". <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">Consulter le wiki de memcached à propos de ces deux modules.</a>",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Des fichiers n'ont pas réussi à passer la vérification d’intégrité. Plus d'information sur comment résoudre ce problème dans notre <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste des fichiers invalides…</a> / <a href=\"{rescanEndpoint}\">Relancer…</a>)",
+    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Vous êtes en mode DÉBOGAGE , cela peut causer des effets non voulus, Veuillez supprimer le drapeau \"debug\" du fichier \"config.php\".",
     "Error occurred while checking server setup" : "Une erreur s'est produite lors de la vérification de la configuration du serveur",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou de le déplacer hors de la racine du serveur web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'en-tête HTTP \"{header}\" n'est pas configurée pour être égale à \"{expected}\" créant potentiellement un risque relié à la sécurité et à la vie privée. Il est donc recommandé d'ajuster ce paramètre.",
@@ -141,18 +160,16 @@ OC.L10N.register(
     "Error while sharing" : "Erreur lors de la mise en partage",
     "Error while unsharing" : "Erreur lors de l'annulation du partage",
     "The public link will expire no later than {days} days after it is created" : "Ce lien public expirera au plus tard {days} jours après sa création.",
-    "Set expiration date" : "Spécifier une date d'expiration",
     "Expiration" : "Expiration",
-    "Expiration date" : "Date d'expiration",
+    "Choose an expiration date" : "Sélectionner une date d'expiration",
     "Expiration date is required" : "Une date d'expiration est requise",
     "Delete {link}" : "Supprimer {link}",
     "Remove link" : "Supprimer le lien",
-    "{fileName} link" : "Lien vers {fileName}",
     "Link" : "Lien",
     "Create public link" : "Créer un lien public",
     "Edit" : "Éditer",
     "Remove" : "Supprimer",
-    "Click to copy to clipboard" : "Cliquez pour copier dans le presse-papier",
+    "Copy to clipboard" : "Copier dans le presse papiers",
     "Social share" : "Partage social",
     "There are currently no link shares, you can create one" : "Il n'y a pour le moment aucun lien de partage. Vous pouvez en créer un",
     "Anyone with the link has access to the file/folder" : "Quiconque dispose du lien a accès aux fichiers/dossiers",
@@ -160,31 +177,34 @@ OC.L10N.register(
     "Not supported!" : "Non supporté !",
     "Press ⌘-C to copy." : "Appuyer sur ⌘-C pour copier.",
     "Press Ctrl-C to copy." : "Appuyer sur Ctrl-C pour copier.",
-    "Choose a password for the public link" : "Choisissez un mot de passe pour le lien public",
+    "Choose a password" : "Choisissez un mot de passe",
     "Password required" : "Mot de passe requis",
+    "Link name" : "Nom du lien",
+    "Name" : "Nom",
     "Filename" : "Nom du fichier",
     "Password" : "Mot de passe",
-    "Name" : "Nom",
-    "Allow editing" : "Permettre la modification",
-    "Show file listing" : "Montrer la liste des fichiers",
+    "Can not remove required password" : "Impossible de supprimer le mot de passe obligatoire",
     "Edit link share: {name}" : "Editer le lien de partage : {name}",
-    "Save" : "Enregistrer",
     "Create link share: {name}" : "Créer le lien de partage : {name}",
+    "Share" : "Partager",
+    "Save" : "Enregistrer",
     "Remove password" : "Effacer le mot de passe",
     "Share to Twitter. Opens in a new window." : "Partager sur Twitter. Ouvre une nouvelle fenêtre.",
     "Share to Facebook. Opens in a new window." : "Partager sur Facebook. Ouvre une nouvelle fenêtre.",
     "Share to Diaspora. Opens in a new window." : "Partager sur Diaspora. Ouvre une nouvelle fenêtre.",
     "Share to Google+. Opens in a new window." : "Partager sur Google+. Ouvre une nouvelle fenêtre.",
     "Share via email. Opens your mail client." : "Partager par courriel. Ouvre une nouvelle fenêtre.",
-    "Error while sending notification" : "Erreur lors de l'envoi de la notification",
-    "Sending ..." : "Envoi…",
-    "Email sent" : "Courriel envoyé",
+    "An error occurred while sending email" : "Une erreur s'est produite lors de l'envoi d'un e-mail",
     "Email link to person" : "Envoyer le lien par courriel",
+    "Send copy to self" : "M'envoyer une copie",
     "Send link via email" : "Envoyer le lien par mail",
+    "Add personal message" : "Ajouter un message personnel",
+    "Sending" : "En cours d'envoi",
+    "E-Mail sent" : "Courriel envoyé",
     "Shared with you and the group {group} by {owner}" : "Partagé avec vous et le groupe {group} par {owner}",
     "Shared with you by {owner}" : "Partagé avec vous par {owner}",
     "group" : "groupe",
-    "remote" : "distant",
+    "federated" : "fédéré",
     "notify by email" : "notifier par courriel",
     "Unshare" : "Ne plus partager",
     "can share" : "peut partager",
@@ -194,27 +214,32 @@ OC.L10N.register(
     "delete" : "suppression",
     "access control" : "contrôle d'accès",
     "Could not unshare" : "Impossible d'arrêter de partager",
+    "Email notification was sent!" : "La notification via email a été envoyée !",
+    "Email notification not sent" : "La notification via email n'a pas été envoyée",
     "Share details could not be loaded for this item." : "Les informations de partage n'ont pu être chargées pour cet élément.",
     "No users or groups found for {search}" : "Pas d'utilisateur ou de groupe trouvé pour {search}",
     "No users found for {search}" : "Aucun utilisateur trouvé pour {search}",
+    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Veuillez saisir au moins {chars} caractère pour les suggestions","Veuillez saisir au moins {chars} caractères pour les suggestions"],
     "An error occurred. Please try again" : "Une erreur est survenue. Merci de réessayer",
-    "{sharee} (group)" : "{sharee} (groupe)",
-    "{sharee} (at {server})" : "{sharee} (sur {server})",
-    "{sharee} (remote)" : "{sharee} (distant)",
-    "Share" : "Partager",
+    "User" : "Utilisateur",
+    "Group" : "Groupe",
+    "Guest" : "Invité",
+    "At {server}" : "Sur {server}",
+    "Federated" : "Fédéré",
     "User and Groups" : "Utilisateurs et groupes",
     "Public Links" : "Liens publics",
-    "Resharing is not allowed" : "Le repartage n'est pas autorisé",
+    "Sharing is not allowed" : "Le partage n’est pas autorisé",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partagez avec des personnes sur d'autres ownClouds en utilisant la syntaxe utilisateur@exemple.com/owncloud",
     "Share with users…" : "Partager avec des utilisateurs...",
     "Share with users, groups or remote users…" : "Partager avec des utilisateurs, groupes ou utilisateurs distants...",
     "Share with users or groups…" : "Partager avec des utilisateurs ou des groupes...",
     "Share with users or remote users…" : "Partager avec des utilisateurs ou des utilisateurs distants...",
     "Error removing share" : "Erreur lors de l'arrêt du partage",
-    "Warning" : "Attention",
+    "Unknown Share" : "Partage inconnue",
     "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
     "restricted" : "Restreint",
     "invisible" : "invisible",
+    "Static" : "Statique",
     "({scope})" : "({scope})",
     "Delete" : "Supprimer",
     "Rename" : "Renommer",
@@ -254,11 +279,12 @@ OC.L10N.register(
     "You can click here to return to %s." : "Vous pouvez cliquer ici pour retourner à %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Bonjour,\n\nNous vous informons que %s a partagé \"%s\" avec vous.\nVous pouvez y accéder à l'adresse suivante : %s\n",
     "The share will expire on %s." : "Le partage expirera le %s.",
+    "Personal note from the sender: \n %s." : "Note personnelle de l'expéditeur:\n%s.",
     "Cheers!" : "À bientôt !",
     "Internal Server Error" : "Erreur interne du serveur",
     "The server encountered an internal error and was unable to complete your request." : "Le serveur a rencontré une erreur interne et est incapable d'exécuter votre requête.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Veuillez contacter l'administrateur du serveur si cette erreur apparaît plusieurs fois. Veuillez joindre les détails techniques à votre rapport.",
-    "More details can be found in the server log." : "Le fichier journal du serveur peut fournir plus de renseignements.",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Veuillez contacter l'administrateur du serveur si cette erreur est rencontrée plusieurs fois et incluez les détails techniques ci-dessous dans votre rapport.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Plus de détails peuvent être trouvés dans le <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">log du serveur</a>.",
     "Technical details" : "Renseignements techniques",
     "Remote Address: %s" : "Adresse distante : %s",
     "Request ID: %s" : "ID de la demande : %s",
@@ -268,6 +294,8 @@ OC.L10N.register(
     "File: %s" : "Fichier : %s",
     "Line: %s" : "Ligne : %s",
     "Trace" : "Trace",
+    "Imprint" : "Mentions légales",
+    "Privacy Policy" : "Politique de confidentialité",
     "Create an <strong>admin account</strong>" : "Créer un <strong>compte administrateur</strong>",
     "Username" : "Nom d'utilisateur",
     "Storage & database" : "Stockage & base de données",
@@ -292,23 +320,28 @@ OC.L10N.register(
     "See the documentation" : "Lire la documentation",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjour,<br><br>Nous vous informons que %s a partagé <strong>%s</strong> avec vous.<br><a href=\"%s\">Cliquez ici pour y accéder !</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
+    "Menu" : "Menu",
     "Log out" : "Se déconnecter",
     "Search" : "Rechercher",
     "Server side authentication failed!" : "L'authentification sur le serveur a échoué !",
     "Please contact your administrator." : "Veuillez contacter votre administrateur.",
     "An internal error occurred." : "Une erreur interne est survenue.",
     "Please try again or contact your administrator." : "Veuillez réessayer ou contacter votre administrateur.",
+    "Login" : "Identifiant",
     "Username or email" : "Nom d'utilisateur ou e-mail",
-    "Log in" : "Se connecter",
+    "You took too long to log in, please try again now" : "Vous avez mis trop de temps à vous connecter, veuillez réessayer maintenant",
     "Wrong password. Reset it?" : "Mot de passe incorrect. Réinitialiser ?",
     "Wrong password." : "Mot de passe incorrect.",
+    "You are trying to access a private link. Please log in first." : "Vous essayez d'accéder à un lien privé. Veuillez d'abord vous connecter.",
     "Stay logged in" : "Rester connecté",
     "Alternative Logins" : "Identifiants alternatifs",
     "Use the following link to reset your password: {link}" : "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
     "Password changed successfully" : "Mot de passe correctement modifié",
     "New password" : "Nouveau mot de passe",
     "New Password" : "Nouveau mot de passe",
+    "Confirm Password" : "Confirmer le mot de passe",
     "Reset password" : "Réinitialiser le mot de passe",
+    "Personal note from the sender: <br> %s." : "Note personnelle de l'expéditeur: <br>%s.",
     "This ownCloud instance is currently in single user mode." : "Cette instance de ownCloud est actuellement en mode utilisateur unique.",
     "This means only administrators can use the instance." : "Cela signifie que seuls les administrateurs peuvent utiliser l'instance.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
@@ -319,9 +352,8 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Veuillez vous identifier en utilisant le facteur sélectionné.",
     "An error occurred while verifying the token" : "Une erreur est survenue lors de la vérification du token",
     "You are accessing the server from an untrusted domain." : "Vous accédez au serveur à partir d'un domaine non approuvé.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Veuillez contacter votre administrateur. Si vous être l'administrateur de cette instance, configurez la variable \"trusted_domains\" dans le fichier config/config.php. Un exemple de configuration est fournit dans le fichier config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En fonction de votre configuration, en tant qu'administrateur vous pouvez également utiliser le bouton ci-dessous pour approuver ce domaine.",
-    "Add \"%s\" as trusted domain" : "Ajouter \"%s\" à la liste des domaines approuvés",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "Veuillez contacter votre administrateur. Si vous êtes l'administrateur, configurez les \"trusted_domains\" dans config/config.php.",
+    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Un exemple de configuration est fourni dans config/config.sample.php ou sur la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>.",
     "App update required" : "Mise à jour de l'application nécessaire",
     "%s will be updated to version %s" : "%s sera mis à jour vers la version %s.",
     "These apps will be updated:" : "Les applications suivantes seront mises à jour:",
@@ -331,35 +363,10 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les timeouts avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
     "Detailed logs" : "Journaux détaillés",
     "Update needed" : "Mise à jour nécessaire",
-    "Please use the command line updater because you have a big instance." : "Veuillez utiliser la mise à jour en ligne de commande, votre instance est trop volumineuse.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Il semble que votre instance héberge de nombreux fichiers et/ou utilisateurs. Pour faciliter la mise à niveau, veuillez réaliser la mise à jour en ligne de commande (occ upgrade).",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "La mise à jour uatomatique est désactivé dans le config.php. Pour mettre à jour votre instance , veuillez utiliser l'outil de mise à jour via l'interface en ligne de commande (occ upgrade).",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
-    "This page will refresh itself when the %s instance is available again." : "Cette page se rafraîchira d'elle-même lorsque l'instance %s sera à nouveau disponible.",
-    "Could not reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton est non valable",
-    "Could not reset password because the token expired" : "Impossible de réinitialiser le mot de passe car le jeton a expiré.",
-    "Could not reset password because the token does not match" : "Impossible de réinitialiser le mot de passe car le jeton ne correspond pas.",
-    "Copy to clipboard" : "Copier dans le presse papiers",
-    "Choose a password" : "Choisissez un mot de passe",
-    "Upload only" : "Téléverser seulement",
-    "Sending" : "En cours d'envoi",
-    "Menu" : "Menu",
-    "Read only" : "Lecture seule",
-    "Read & Write" : "Lire et Ecrire",
-    "Email notification not sent" : "La notification via email n'a pas été envoyée",
-    "You took too long to login, please try again now" : "Vous avez mis trop longtemps pour vous connecter, veuillez réessayer maintenant",
-    "Choose an expiration date" : "Sélectionner une date d'expiration",
-    "An error occured" : "Une erreur est survenue",
-    "Send copy to self" : "M'envoyer une copie",
-    "Add personal message" : "Ajouter un message personnel",
-    "Error adding {addItem}: {addItem} already exists" : "Erreur en ajoutant {addItem}: {addItem} existe déjà",
-    "federated" : "fédéré",
-    "Link name" : "Nom du lien",
-    "Owner: {owner}" : "Propriétaire: {owner}",
-    "Email notification was sent!" : "La notification via email a été envoyée !",
-    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Veuillez contacter l'administrateur du serveur si cette erreur est rencontrée plusieurs fois et incluez les détails techniques ci-dessous dans votre rapport.",
-    "You are trying to access a private link. Please log in first." : "Vous essayez d'accéder à un lien privé. Veuillez d'abord vous connecter.",
-    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Il semble que votre instance héberge de nombreux fichiers et/ou utilisateurs. Pour faciliter la mise à niveau, veuillez réaliser la mise à jour en ligne de commande (occ upgrade).",
-    "Couldn't send mail to following recipient(s): %s " : "Impossible d'envoyer de mail au(x) destinataire(s) suivant(s) : %s",
-    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "La mise à jour uatomatique est désactivé dans le config.php. Pour mettre à jour votre instance , veuillez utiliser l'outil de mise à jour via l'interface en ligne de commande (occ upgrade)."
+    "This page will refresh itself when the %s instance is available again." : "Cette page se rafraîchira d'elle-même lorsque l'instance %s sera à nouveau disponible."
 },
 "nplurals=2; plural=(n > 1);");
