@@ -12,12 +12,20 @@ OC.L10N.register(
     "No crop data provided" : "Non sono stati forniti dati di ritaglio",
     "No valid crop data provided" : "Non sono stati forniti dati di ritaglio validi",
     "Crop is not square" : "Il ritaglio non è quadrato",
-    "Couldn't reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
-    "Couldn't reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
+    "Could not reset password because the token is invalid" : "Reimpostazione della password fallita perchè il token non è valido",
+    "Could not reset password because the token expired" : "Reimpostazione della password fallita perchè il token è scaduto",
+    "Could not reset password because the token does not match" : "Reimpostazione della password fallita perchè il token non corrisponde",
     "%s password changed successfully" : "Password di %s modificata correttamente",
     "%s password reset" : "Ripristino password di %s",
     "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
-    "Couldn't send mail to following users: %s " : "Impossibile inviare email ai seguenti utenti: %s",
+    "Download / View" : "Scarica / visiona",
+    "Recipients can view or download contents." : "I destinatari possono vedere o scaricare contenuti",
+    "Download / View / Upload" : "Scarica / Visiona / Carica",
+    "Recipients can view, download and upload contents." : "I destinatari possono vedere,scaricare e inviare contenuti.",
+    "Download / View / Edit" : "Scarica / Visiona / Modifica",
+    "Recipients can view, download, edit, delete and upload contents." : "I destinatari possono vedere, scaricare, modificare, cancellare ed inviare contenuti",
+    "Upload only" : "Carica solo",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Ricevi file da più destinatari senza rivelare il contenuto della cartella.",
     "Preparing update" : "Preparazione aggiornamento",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Avviso di riparazione",
@@ -94,10 +102,16 @@ OC.L10N.register(
     "Saving..." : "Salvataggio in corso...",
     "Dismiss" : "Annulla",
     "seconds ago" : "secondi fa",
+    "You have enabled one or more ownCloud Enterprise apps but your installation does not have a valid license yet." : "Hai abilitato una o più app ownCloud Enterprise ma la tua installazione non ha ancora una licenza valida.",
+    "Upgrade to ownCloud Enterprise" : "Aggiorna a ownCloud Enterprise",
+    "Remaining time: {rtime}" : "Tempo rimanente: {rtime}",
+    "Get your demo key" : "Ottieni la tua chiave demo",
+    "Set new key" : "Imposta nuova chiave",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Il collegamento per reimpostare la password è stato inviato al tuo indirizzo di posta. Se non lo ricevi in tempi ragionevoli, controlla le cartelle della posta indesiderata.<br>Se non dovesse essere nemmeno lì, contatta il tuo amministratore locale.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "I tuoi file sono cifrati. Se non hai precedentemente abilitato la chiave di ripristino, non sarà più possibile ritrovare i tuoi dati una volta che la password sarà reimpostata.<br />Se non sei sicuro, contatta l'amministratore prima di proseguire.<br />Vuoi davvero continuare?",
     "I know what I'm doing" : "So cosa sto facendo",
     "Password can not be changed. Please contact your administrator." : "La password non può essere cambiata. Contatta il tuo amministratore.",
+    "Error adding {addItem}: {addItem} already exists" : "Errore nell'aggiunta di {addItem}: {addItem} esiste già",
     "No" : "No",
     "Yes" : "Sì",
     "Choose" : "Scegli",
@@ -130,6 +144,7 @@ OC.L10N.register(
     "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a ownCloud da un proxy affidabile. Se non stai effettuando l'accesso da un proxy affidabile, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendolo visibile a ownCloud. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached è configurato come cache distribuita, ma è installato il modulo \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki di memcached per informazioni su entrambi i moduli</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alcuni file non hanno superato il controllo di integrità. Ulteriori informazioni su come risolvere questo problema sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Elenco dei file non validi…</a> / <a href=\"{rescanEndpoint}\">Nuova scansione…</a>)",
+    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Stai utilizzando la modalità DEBUG, la quale potrebbe causare effetti indesiderati. Rimuovi il flag \"debug\" da \"config.php\".",
     "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet.\nIl file .htaccess non funziona. Ti consigliamo vivamente di configurare il server web in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'intestazione HTTP \"{header}\" non è configurata come \"{expected}\". \nQuesto è un potenziale rischio di sicurezza o di riservatezza dei dati e noi consigliamo di modificare questa impostazione.",
@@ -141,48 +156,50 @@ OC.L10N.register(
     "Error while sharing" : "Errore durante la condivisione",
     "Error while unsharing" : "Errore durante la rimozione della condivisione",
     "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
-    "Set expiration date" : "Imposta data di scadenza",
     "Expiration" : "Scadenza",
-    "Expiration date" : "Data di scadenza",
+    "Choose an expiration date" : "Scegli una data di scadenza",
     "Expiration date is required" : "La data di scadenza è richiesta",
     "Delete {link}" : "Elimina {link}",
     "Remove link" : "Rimuovi collegamento",
-    "{fileName} link" : "{fileName} collegamento",
     "Link" : "Collegamento",
     "Create public link" : "Crea collegamento pubblico",
     "Edit" : "Modifica",
     "Remove" : "Rimuovi",
-    "Click to copy to clipboard" : "Fai clic per copiare negli appunti",
+    "Copy to clipboard" : "Copia negli appunti",
     "Social share" : "Condivisione sociale",
     "There are currently no link shares, you can create one" : "Al momento non ci sono collegamenti a condivisioni, puoi crearne uno",
+    "Anyone with the link has access to the file/folder" : "Chiunque sia in possesso del collegamento ha accesso al file/cartella",
     "Copied!" : "Copiato!",
     "Not supported!" : "Non supportato!",
     "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
     "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
-    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
+    "Choose a password" : "Scegli una password",
     "Password required" : "Password richiesta",
+    "Link name" : "Nome collegamento",
+    "Name" : "Nome",
     "Filename" : "Nome del file",
     "Password" : "Password",
-    "Name" : "Nome",
-    "Allow editing" : "Consenti la modifica",
+    "Can not remove required password" : "Impossibile rimuovere la password",
     "Edit link share: {name}" : "Modifica collegamento a condivisione: {name}",
-    "Save" : "Salva",
     "Create link share: {name}" : "Creare collegamento a condivisione: {name}",
+    "Share" : "Condividi",
+    "Save" : "Salva",
     "Remove password" : "Rimuovi password",
     "Share to Twitter. Opens in a new window." : "Condividi su Twitter. Apre una nuova finestra.",
     "Share to Facebook. Opens in a new window." : "Condividi su Facebook. Apre una nuova finestra.",
     "Share to Diaspora. Opens in a new window." : "Condividi su Diaspora. Apre una nuova finestra.",
     "Share to Google+. Opens in a new window." : "Condividi su Google+. Apre una nuova finestra.",
     "Share via email. Opens your mail client." : "Condividi tramite email. Apre una nuova finestra.",
-    "Error while sending notification" : "Errore durante l'invio della notifica",
-    "Sending ..." : "Invio in corso...",
-    "Email sent" : "Messaggio inviato",
     "Email link to person" : "Invia collegamento via email",
+    "Send copy to self" : "Invia una copia a me stesso",
     "Send link via email" : "Invia collegamento tramite email",
+    "Add personal message" : "Aggiungi messaggio personale",
+    "Sending" : "Invio in corso",
+    "E-Mail sent" : "Email inviata",
     "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
     "Shared with you by {owner}" : "Condiviso con te da {owner}",
     "group" : "gruppo",
-    "remote" : "remota",
+    "federated" : "federato",
     "notify by email" : "notifica tramite email",
     "Unshare" : "Rimuovi condivisione",
     "can share" : "può condividere",
@@ -192,27 +209,32 @@ OC.L10N.register(
     "delete" : "elimina",
     "access control" : "controllo d'accesso",
     "Could not unshare" : "Impossibile rimuovere la condivisione",
+    "Email notification was sent!" : "Notifica email inviata!",
+    "Email notification not sent" : "Notifica email non inviata",
     "Share details could not be loaded for this item." : "I dettagli della condivisione non possono essere caricati per questo elemento.",
     "No users or groups found for {search}" : "Nessun utente o gruppo trovato per {search}",
     "No users found for {search}" : "Nessun utente trovato per {search}",
+    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Inserisci almeno {chars} carattere per i suggerimenti","Inserisci almeno {chars} caratteri per i suggerimenti"],
     "An error occurred. Please try again" : "Si è verificato un errore. Prova ancora",
-    "{sharee} (group)" : "{sharee} (group)",
-    "{sharee} (at {server})" : "{sharee} (su {server})",
-    "{sharee} (remote)" : "{sharee} (remote)",
-    "Share" : "Condividi",
+    "User" : "Utente",
+    "Group" : "Gruppo",
+    "Guest" : "Ospite",
+    "At {server}" : "Su {server}",
+    "Federated" : "Federato",
     "User and Groups" : "Utenti e gruppi",
     "Public Links" : "Collegamenti pubblici",
-    "Resharing is not allowed" : "La ri-condivisione non è consentita",
+    "Sharing is not allowed" : "Condivisione non consentita",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Condividi con persone su altri ownCloud utilizzando la sintassi nomeutente@esempio.com/owncloud",
     "Share with users…" : "Condividi con utenti...",
     "Share with users, groups or remote users…" : "Condividi con utenti, gruppi o utenti remoti...",
     "Share with users or groups…" : "Condividi con utenti o gruppi...",
     "Share with users or remote users…" : "Condividi con utenti o utenti remoti...",
     "Error removing share" : "Errore durante la rimozione della condivisione",
-    "Warning" : "Avviso",
+    "Unknown Share" : "Condivisione sconosciuta",
     "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
     "restricted" : "limitato",
     "invisible" : "invisibile",
+    "Static" : "Statico",
     "({scope})" : "({scope})",
     "Delete" : "Elimina",
     "Rename" : "Rinomina",
@@ -252,11 +274,12 @@ OC.L10N.register(
     "You can click here to return to %s." : "Puoi fare clic qui per tornare a %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Ciao,\n\nvolevo informarti che %s ha condiviso %s con te.\nVedi: %s\n\n",
     "The share will expire on %s." : "La condivisione scadrà il %s.",
+    "Personal note from the sender: \n %s." : "Nota personale dal mittente: \n %s.",
     "Cheers!" : "Saluti!",
     "Internal Server Error" : "Errore interno del server",
     "The server encountered an internal error and was unable to complete your request." : "Il server ha riscontrato un errore interno e non è stato in grado di completare la tua richiesta.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Contatta l'amministratore del server se questo errore riappare più volte, includendo i dettagli tecnici sotto riportati nella tua segnalazione.",
-    "More details can be found in the server log." : "Ulteriori dettagli sono disponibili nel log del server.",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Contatta l'amministratore del server se questo errore riappare più volte, includendo i dettagli tecnici sotto nella tua segnalazione.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Possono essere trovati altri dettagli nel <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">log del server</a>.",
     "Technical details" : "Dettagli tecnici",
     "Remote Address: %s" : "Indirizzo remoto: %s",
     "Request ID: %s" : "ID richiesta: %s",
@@ -266,6 +289,8 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Riga: %s",
     "Trace" : "Traccia",
+    "Imprint" : "Imprint",
+    "Privacy Policy" : "Regole sulla riservatezza",
     "Create an <strong>admin account</strong>" : "Crea un <strong>account amministratore</strong>",
     "Username" : "Nome utente",
     "Storage & database" : "Archiviazione e database",
@@ -290,23 +315,27 @@ OC.L10N.register(
     "See the documentation" : "Leggi la documentazione",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ciao,<br><br>volevo informarti che %s ha condiviso <strong>%s</strong> con te.<br><a href=\"%s\">Guarda!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Questa applicazione richiede JavaScript per un corretto funzionamento. {linkstart}Abilita JavaScript{linkend} e ricarica la pagina.",
+    "Menu" : "Menu",
     "Log out" : "Esci",
     "Search" : "Cerca",
     "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
     "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
     "An internal error occurred." : "Si è verificato un errore interno.",
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
+    "Login" : "Accesso",
     "Username or email" : "Nome utente o email",
-    "Log in" : "Accedi",
     "Wrong password. Reset it?" : "Password errata. Vuoi reimpostarla?",
     "Wrong password." : "Password errata.",
+    "You are trying to access a private link. Please log in first." : "Stai tentando di accedere a un collegamento privato. Prima devi accedere.",
     "Stay logged in" : "Rimani collegato",
     "Alternative Logins" : "Accessi alternativi",
     "Use the following link to reset your password: {link}" : "Usa il collegamento seguente per ripristinare la password: {link}",
     "Password changed successfully" : "Password cambiata con successo",
     "New password" : "Nuova password",
     "New Password" : "Nuova password",
+    "Confirm Password" : "Conferma la tua password",
     "Reset password" : "Ripristina la password",
+    "Personal note from the sender: <br> %s." : "Nota personale dal mittente: <br> %s.",
     "This ownCloud instance is currently in single user mode." : "Questa istanza di ownCloud è in modalità utente singolo.",
     "This means only administrators can use the instance." : "Ciò significa che solo gli amministratori possono utilizzare l'istanza.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
@@ -317,9 +346,8 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Autentica utilizzando il fattore selezionato.",
     "An error occurred while verifying the token" : "Si è verificato un errore durante la verifica del token",
     "You are accessing the server from an untrusted domain." : "Stai accedendo al server da un dominio non attendibile.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contatta il tuo amministratore di sistema. Se sei un amministratore di questa istanza, configura l'impostazione \"trusted_domains\" in config/config.php. Una configurazione di esempio è disponibile in config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "In base alla tua configurazione, come amministratore potrai utilizzare anche il pulsante in basso per rendere attendibile questo dominio.",
-    "Add \"%s\" as trusted domain" : "Aggiungi \"%s\" come dominio attendibile",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "Contatta il tuo amministratore di sistema. Se sei un amministratore di questa istanza, configura l'impostazione \"trusted_domains\" in config/config.php.",
+    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Viene fornita una configurazione di esempio in config/config.sample.php o nella <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione</a>.",
     "App update required" : "Aggiornamento dell'applicazione richiesto",
     "%s will be updated to version %s" : "%s sarà aggiornato alla versione %s",
     "These apps will be updated:" : "Queste applicazioni saranno aggiornate:",
@@ -329,20 +357,10 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
     "Detailed logs" : "Log dettagliati",
     "Update needed" : "Aggiornamento necessario",
-    "Please use the command line updater because you have a big instance." : "Utilizza lo strumento da riga di comando per la grandezza della tua istanza.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Pare che la tua istanza stia gestendo molti file e/o utenti. Per assicurare un processo di aggiornamento senza intoppi, usa l'updater da riga di comando (occ upgrade).",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "L'aggiornamento automatico è disattivato in config.php. Per aggiornare la tua istanza, usa l'updater da riga di comando (occ upgrade).",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
-    "This page will refresh itself when the %s instance is available again." : "Questa pagina si aggiornerà quando l'istanza di %s sarà nuovamente disponibile.",
-    "Copy to clipboard" : "Copia negli appunti",
-    "Anyone with the link has access to the file/folder" : "Chiunque sia in possesso del collegamento ha accesso al file/cartella",
-    "Choose a password" : "Scegli una password",
-    "Upload only" : "Carica solo",
-    "Sending" : "Invio in corso",
-    "Menu" : "Menu",
-    "Link name" : "Nome collegamento",
-    "Download / View" : "Scarica / visiona",
-    "Recipients can view or download contents." : "I destinatari possono vedere o scaricare contenuti",
-    "Download / View / Upload" : "Scarica / Visiona / Carica",
-    "Recipients can view, download, edit, delete and upload contents." : "I destinatari possono vedere, scaricare, modificare, cancellare ed inviare contenuti"
+    "This page will refresh itself when the %s instance is available again." : "Questa pagina si aggiornerà quando l'istanza di %s sarà nuovamente disponibile."
 },
 "nplurals=2; plural=(n != 1);");
