@@ -9,11 +9,8 @@ OC.L10N.register(
     "Invalid image" : "Ongültegt Bild",
     "An error occurred. Please contact your admin." : "Et ass e Feeler opgetrueden. W.e.g. kontaktéier däin Administrateur.",
     "No temporary profile picture available, try again" : "Et ass keen temporäert Profilbild verfügbar, versich et nach emol.",
-    "Couldn't reset password because the token is invalid" : "D'Passwuert konnt net zeréck gesat ginn well den Token ongülteg ass",
-    "Couldn't reset password because the token is expired" : "D'Passwuert konnt net zeréck gesat ginn well den Token ofgelaf ass",
     "%s password reset" : "%s Passwuert ass nei gesat",
     "Couldn't send reset email. Please contact your administrator." : "D'Email fir zeréck ze setzen konnt net geschéckt ginn. W.e.g. kontaktéier däin Administrateur.",
-    "Couldn't send mail to following users: %s " : "D'Email fir de folgende Benotzer konnt net geschéckt ginn: %s",
     "Preparing update" : "D'Aktualiséierung gëtt virbereet",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Reparatur Warnung:",
@@ -114,26 +111,19 @@ OC.L10N.register(
     "Error while sharing" : "Feeler beim Deelen",
     "Error while unsharing" : "Feeler beim Annuléiere vum Deelen",
     "The public link will expire no later than {days} days after it is created" : "Den ëffentleche Link wäert net méi spéit wéi {Deeg} Deeg nodeems et erstallt gouf verfalen ",
-    "Set expiration date" : "Verfallsdatum setzen",
     "Expiration" : "Leeft of",
-    "Expiration date" : "Verfallsdatum",
     "Link" : "Link",
     "Edit" : "Änneren",
     "Remove" : "Läschen",
-    "Choose a password for the public link" : "Wiel e Passwuert fir den ëffentleche Link aus",
-    "Password" : "Passwuert",
     "Name" : "Numm",
-    "Allow editing" : "Beaarbechten erlaben",
+    "Password" : "Passwuert",
+    "Share" : "Deelen",
     "Save" : "Späicheren",
-    "Error while sending notification" : "Feeler beim Schécke vun der Notifikatioun",
-    "Sending ..." : "Gëtt geschéckt...",
-    "Email sent" : "Email geschéckt",
     "Email link to person" : "Link enger Persoun mailen",
     "Send link via email" : "De Link iwwer E-Mail schécken",
     "Shared with you and the group {group} by {owner}" : "Gedeelt mat dir an der Grupp {group} vum {owner}",
     "Shared with you by {owner}" : "Gedeelt mat dir vum {owner}",
     "group" : "Grupp",
-    "remote" : "Op Distanz",
     "notify by email" : "via e-mail Bescheed ginn",
     "Unshare" : "Net méi deelen",
     "can share" : "kann deelen",
@@ -147,15 +137,14 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Keng Benotzer oder Gruppe fonnt fir {Sich}",
     "No users found for {search}" : "Keng Benotzer fonnt fir {Sich}",
     "An error occurred. Please try again" : "Et ass e Fehler opgetrueden. W.e.g. probéier nach emol",
-    "Share" : "Deelen",
-    "Resharing is not allowed" : "Weiderdeelen ass net erlaabt",
+    "User" : "Benotzer",
+    "Group" : "Grupp",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mat Leit vun aneren ownCloud deelen, déi d'Syntax username@example.com/owncloud benotzen",
     "Share with users…" : "Mat Benotzer deelen ...",
     "Share with users, groups or remote users…" : "Mat Benotzer, Gruppen oder Benotzer op Distanz deelen ...",
     "Share with users or groups…" : "Mat Benotzer oder Gruppen deelen...",
     "Share with users or remote users…" : "Mat Benotzer oder mat Benotzer op Distanz deelen ...",
     "Error removing share" : "Fehler beim Läschen vum Bäitrag",
-    "Warning" : "Warnung",
     "restricted" : "Ageschränkt",
     "invisible" : "Onsiichtbar",
     "Delete" : "Läschen",
@@ -193,8 +182,6 @@ OC.L10N.register(
     "Cheers!" : "Prost!",
     "Internal Server Error" : "Interne Server Feeler",
     "The server encountered an internal error and was unable to complete your request." : "De Server huet en interne Feeler festgestallt an konnt deng Ufro net ëmsetzen",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "W.e.g. kontaktéier de Server Administrateur wann dëse Feeler e puer Mol optrëtt an sëtz d'technesch Detailer an de Rapport derbäi.",
-    "More details can be found in the server log." : "Méi Detailer kënnen am Server Log fonnt ginn.",
     "Technical details" : "Technesch Detailer",
     "Remote Address: %s" : "D'Adress op Distanz: %s",
     "Request ID: %s" : "ID ufroen: %s",
@@ -204,6 +191,7 @@ OC.L10N.register(
     "File: %s" : "Fichier: %s",
     "Line: %s" : "Zeil: %s",
     "Trace" : "Spuren",
+    "Imprint" : "Impressum",
     "Create an <strong>admin account</strong>" : "En <strong>Admin-Account</strong> uleeën",
     "Username" : "Benotzernumm",
     "Storage & database" : "Speicherplaz & Datebank",
@@ -226,14 +214,15 @@ OC.L10N.register(
     "See the documentation" : "Kuck an der Dokumentatioun",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>ech wëll just Bescheed soen dass den/d' %s <strong>%s</strong> mat dir gedeelt huet.<br><a href=\"%s\">Ukucken!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Dës Applikatioun verlaangt JavaScript fir kënne korrekt auszeféieren. W.e.g {linkstart} schalt JavaScript an {linkend} a luet d'Säit nei.",
+    "Menu" : "Menü",
     "Log out" : "Ofmellen",
     "Search" : "Sichen",
     "Server side authentication failed!" : "D'Autentifikatioun vun der Säit vum Server huet net geklappt!",
     "Please contact your administrator." : "W.e.g. kontaktéier däin Administrateur.",
     "An internal error occurred." : "Et ass en interne Feeler opgetrueden.",
     "Please try again or contact your administrator." : "W.e.g. versich et nach emol oder kontaktéier däin Administrateur.",
+    "Login" : "Login",
     "Username or email" : "Benotzernumm oder Email",
-    "Log in" : "Umellen",
     "Wrong password. Reset it?" : "Falscht Passwuert. Wëlls de et zeréck setzen?",
     "Wrong password." : "Falscht Passwuert.",
     "Stay logged in" : "Bleif ageloggt.",
@@ -249,7 +238,6 @@ OC.L10N.register(
     "Cancel login" : "Login ofbriechen",
     "Please authenticate using the selected factor." : "W.e.g. authentifizéier dech andeems de den ausgewielten Facteur benotz.",
     "You are accessing the server from an untrusted domain." : "Du gräifs vun enger net vertrauensvoller Domän op dëse Server zou.",
-    "Add \"%s\" as trusted domain" : "\"%s\" als zouverlässeg Domän derbäi setzen",
     "App update required" : "App Aktualiséierung néideg",
     "%s will be updated to version %s" : "%s wäert aktualiséiert ginn op d'Versioun %s",
     "These apps will be updated:" : "D!es Apps wäerten aktualiséiert ginn:",
@@ -259,7 +247,6 @@ OC.L10N.register(
     "Detailed logs" : "Detailléiert Loggs",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Fir Hëllef, kuck am <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Documentatioun</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Dës %s Instanz ass am Moment am Maintenance Modus, dat kënnt ee Moment brauche.",
-    "This page will refresh itself when the %s instance is available again." : "Dës Säit luet nees automatesch wann d' %s Instanz nees disponibel ass.",
-    "Menu" : "Menü"
+    "This page will refresh itself when the %s instance is available again." : "Dës Säit luet nees automatesch wann d' %s Instanz nees disponibel ass."
 },
 "nplurals=2; plural=(n != 1);");
