@@ -12,12 +12,19 @@ OC.L10N.register(
     "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
     "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
     "Crop is not square" : "Bijsnijding is niet vierkant",
-    "Couldn't reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is",
-    "Couldn't reset password because the token is expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is",
+    "Could not reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is ",
+    "Could not reset password because the token expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is ",
+    "Could not reset password because the token does not match" : "Kon het wachtwoord niet resetten omdat het token niet overeenkomt",
     "%s password changed successfully" : "%s wachtwoord succesvol gewijzigd.",
     "%s password reset" : "%s wachtwoord reset",
     "Couldn't send reset email. Please contact your administrator." : "Kon herstel e-mail niet versturen. Neem contact op met uw beheerder.",
-    "Couldn't send mail to following users: %s " : "Kon geen e-mail sturen aan de volgende gebruikers: %s",
+    "Download / View" : "Download / Bekijk",
+    "Recipients can view or download contents." : "Ontvangers kunnen de inhoud bekijken of downloaden.",
+    "Download / View / Upload" : "Download / Bekijk / Upload",
+    "Recipients can view, download and upload contents." : "Ontvangers kunnen bestanden bekijken, downloaden en uploaden",
+    "Recipients can view, download, edit, delete and upload contents." : "Ontvangers kunnen de inhoud bekijken, downloaden, bewerken, verwijderen en uploaden.",
+    "Upload only" : "Alleen uploaden",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Ontvang bestanden van meerdere ontvangers zonder de inhoud van de map te weergeven.",
     "Preparing update" : "Update voorbereiden",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Reparatiewaarschuwing:",
@@ -98,6 +105,7 @@ OC.L10N.register(
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Uw bestanden zijn versleuteld. Als u de herstelsleutel niet hebt geactiveerd, is er geen mogelijk om uw gegevens terug te krijgen nadat uw wachtwoord is hersteld. <br>Als u niet weet wat u moet doen, neem dan eerst contact op met uw beheerder. <br>Wilt u echt verder gaan?",
     "I know what I'm doing" : "Ik weet wat ik doe",
     "Password can not be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met uw beheerder.",
+    "Error adding {addItem}: {addItem} already exists" : "Fout bij toevoegen {addItem}: {addItem} bestaat al",
     "No" : "Nee",
     "Yes" : "Ja",
     "Choose" : "Kies",
@@ -141,48 +149,49 @@ OC.L10N.register(
     "Error while sharing" : "Fout tijdens het delen",
     "Error while unsharing" : "Fout tijdens het stoppen met delen",
     "The public link will expire no later than {days} days after it is created" : "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
-    "Set expiration date" : "Stel vervaldatum in",
     "Expiration" : "Vervaltermijn",
-    "Expiration date" : "Vervaldatum",
+    "Choose an expiration date" : "Kies een vervaldatum",
     "Expiration date is required" : "De vervaldatum is vereist",
     "Delete {link}" : "Verwijderen {link}",
     "Remove link" : "Verwijderen link",
-    "{fileName} link" : "{fileName} link",
     "Link" : "Link",
     "Create public link" : "Creëer openbare link",
     "Edit" : "Bewerk",
     "Remove" : "Verwijder",
-    "Click to copy to clipboard" : "Klik om te kopiëren naar klembord",
+    "Copy to clipboard" : "Kopiëren naar klembord",
     "Social share" : "Sociaal delen",
     "There are currently no link shares, you can create one" : "Er zijn momenteel geen gedeelde links, u kunt er een aanmaken",
+    "Anyone with the link has access to the file/folder" : "Iedereen met de link heeft toegang tot het bestand of de map",
     "Copied!" : "Gekopieerd!",
     "Not supported!" : "Niet ondersteund!",
     "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
     "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
-    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
+    "Choose a password" : "Kies een wachtwoord",
     "Password required" : "Wachtwoord vereist",
+    "Link name" : "Naam link",
+    "Name" : "Naam",
     "Filename" : "Bestandsnaam",
     "Password" : "Wachtwoord",
-    "Name" : "Naam",
-    "Allow editing" : "Toestaan bewerken",
     "Edit link share: {name}" : "Bewerk link om te delen: {name}",
-    "Save" : "Opslaan",
     "Create link share: {name}" : "Creëren link om te delen: {name}",
+    "Share" : "Delen",
+    "Save" : "Opslaan",
     "Remove password" : "Verwijder wachtwoord",
     "Share to Twitter. Opens in a new window." : "Delen op Twitter. Opent in een nieuw venster.",
     "Share to Facebook. Opens in a new window." : "Delen op Facebook. Opent in een nieuw venster.",
     "Share to Diaspora. Opens in a new window." : "Delen op diaspora*. Opent in een nieuw venster.",
     "Share to Google+. Opens in a new window." : "Delen op Google+. Opent in een nieuw venster.",
     "Share via email. Opens your mail client." : "Delen via e-mail. Opent uw mailclient.",
-    "Error while sending notification" : "Fout bij versturen melding",
-    "Sending ..." : "Versturen ...",
-    "Email sent" : "E-mail verzonden",
     "Email link to person" : "E-mail link naar persoon",
+    "Send copy to self" : "Stuur een kopie naar uzelf",
     "Send link via email" : "Versturen link via e-mail",
+    "Add personal message" : "Voeg een persoonlijk bericht toe",
+    "Sending" : "Versturen",
+    "E-Mail sent" : "E-mail verzonden",
     "Shared with you and the group {group} by {owner}" : "Gedeeld met u en de groep {group} door {owner}",
     "Shared with you by {owner}" : "Gedeeld met u door {owner}",
     "group" : "groep",
-    "remote" : "extern",
+    "federated" : "gefedereerd",
     "notify by email" : "melden per e-mail",
     "Unshare" : "Stop met delen",
     "can share" : "kan delen",
@@ -192,24 +201,22 @@ OC.L10N.register(
     "delete" : "verwijderen",
     "access control" : "toegangscontrole",
     "Could not unshare" : "Kon delen niet ongedaan maken",
+    "Email notification was sent!" : "E-mailbericht verzonden!",
+    "Email notification not sent" : "E-mailbericht niet verzonden",
     "Share details could not be loaded for this item." : "Details van shares voor dit object konden niet worden geladen.",
     "No users or groups found for {search}" : "Geen gebruikers of groepen gevonden voor {search}",
     "No users found for {search}" : "Geen gebruikers gevonden voor {search}",
     "An error occurred. Please try again" : "Er trad een fout op. Probeer het opnieuw",
-    "{sharee} (group)" : "{sharee} (groep)",
-    "{sharee} (at {server})" : "{sharee} (op {server})",
-    "{sharee} (remote)" : "{sharee} (extern)",
-    "Share" : "Delen",
+    "User" : "Gebruiker",
+    "Group" : "Groep",
     "User and Groups" : "Gebruiker en Groepen",
     "Public Links" : "Openbare Links",
-    "Resharing is not allowed" : "Verder delen is niet toegestaan",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Delen met mensen op andere ownClouds via de syntax gebruikersnaam@voorbeeld.org/owncloud",
     "Share with users…" : "Delen met gebruikers...",
     "Share with users, groups or remote users…" : "Delen met gebruikers, groepen of externe gebruikers...",
     "Share with users or groups…" : "Delen met gebruikers of groepen...",
     "Share with users or remote users…" : "Delen met gebruikers of externe gebruikers...",
     "Error removing share" : "Fout bij verwijderen share",
-    "Warning" : "Waarschuwing",
     "Non-existing tag #{tag}" : "Niet bestaande tag #{tag}",
     "restricted" : "beperkt",
     "invisible" : "onzichtbaar",
@@ -255,8 +262,8 @@ OC.L10N.register(
     "Cheers!" : "Proficiat!",
     "Internal Server Error" : "Interne serverfout",
     "The server encountered an internal error and was unable to complete your request." : "De server ontdekte een interne fout en kon uw aanvraag niet verder uitvoeren.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Neem contact op mer de serverbeheerder als deze fout meerdere keren optreedt en neem de onderstaande technische details op in uw melding.",
-    "More details can be found in the server log." : "Meer details in de serverlogging,",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Neem contact op met de serverbeheerder als deze fout meerdere keren opnieuw optreedt en neem de onderstaande technische details op in uw melding.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Meer details kunnen worden gevonden in het <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>.",
     "Technical details" : "Technische details",
     "Remote Address: %s" : "Extern adres: %s",
     "Request ID: %s" : "Aanvraag ID: %s",
@@ -266,6 +273,8 @@ OC.L10N.register(
     "File: %s" : "Bestand: %s",
     "Line: %s" : "Regel: %s",
     "Trace" : "Trace",
+    "Imprint" : "Colofon",
+    "Privacy Policy" : "Privacybeleid",
     "Create an <strong>admin account</strong>" : "Maak een <strong>beheerdersaccount</strong> aan",
     "Username" : "Gebruikersnaam",
     "Storage & database" : "Opslag & database",
@@ -290,16 +299,18 @@ OC.L10N.register(
     "See the documentation" : "Zie de documentatie",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>%s deelt <strong>%s</strong> met u.<br><a href=\"%s\">Bekijk hier!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
+    "Menu" : "Menu",
     "Log out" : "Afmelden",
     "Search" : "Zoeken",
     "Server side authentication failed!" : "Authenticatie bij de server mislukte!",
     "Please contact your administrator." : "Neem contact op met uw systeembeheerder.",
     "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
     "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met uw beheerder.",
+    "Login" : "Login",
     "Username or email" : "Gebruikersnaam of e-mail",
-    "Log in" : "Meld u aan",
     "Wrong password. Reset it?" : "Onjuist wachtwoord. Resetten?",
     "Wrong password." : "Onjuist wachtwoord.",
+    "You are trying to access a private link. Please log in first." : "U probeert een privé link te benaderen. Meld u zich alstublieft eerst aan.",
     "Stay logged in" : "Ingelogd blijven",
     "Alternative Logins" : "Alternatieve inlogs",
     "Use the following link to reset your password: {link}" : "Gebruik de volgende link om uw wachtwoord te resetten: {link}",
@@ -317,9 +328,6 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Log in met de geselecteerde factor.",
     "An error occurred while verifying the token" : "Er trad een fout op bij het verifiëren van het token",
     "You are accessing the server from an untrusted domain." : "U benadert de server vanaf een niet vertrouwd domein.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Neem contact op met uw beheerder. Als u de beheerder van deze service bent, configureer dan de \"trusted_domains\" instelling in config/config.php. Een voorbeeldconfiguratie is gegeven in config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Afhankelijk van uw configuratie zou u als beheerder ook de onderstaande knop kunnen gebruiken om dit domein te vertrouwen.",
-    "Add \"%s\" as trusted domain" : "\"%s\" toevoegen als vertrouwd domein",
     "App update required" : "Bijwerken App vereist",
     "%s will be updated to version %s" : "%s wordt bijgewerkt naar versie %s",
     "These apps will be updated:" : "Deze apps worden bijgewerkt:",
@@ -329,27 +337,8 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kunt u in plaats hiervan de volgende opdracht geven vanaf uw installatiedirectory:",
     "Detailed logs" : "Gedetailleerde logs",
     "Update needed" : "Update vereist",
-    "Please use the command line updater because you have a big instance." : "Gebruik de commandoregel updater, omdat u een grote ownCloud hebt.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Voor hulp, lees de <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentatie</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
-    "This page will refresh itself when the %s instance is available again." : "Deze pagina wordt ververst als de %s-installatie weer beschikbaar is.",
-    "Could not reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is ",
-    "Could not reset password because the token expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is ",
-    "Could not reset password because the token does not match" : "Kon het wachtwoord niet resetten omdat het token niet overeenkomt",
-    "Copy to clipboard" : "Kopiëren naar klembord",
-    "Anyone with the link has access to the file/folder" : "Iedereen met de link heeft toegang tot het bestand of de map",
-    "Choose a password" : "Kies een wachtwoord",
-    "Upload only" : "Alleen uploaden",
-    "Sending" : "Versturen",
-    "Menu" : "Menu",
-    "Read only" : "Allleen lezen",
-    "Read & Write" : "Lees & Schrijven",
-    "Email notification not sent" : "E-mailbericht niet verzonden",
-    "federated" : "gefedereerd",
-    "Link name" : "Naam link",
-    "Owner: {owner}" : "Eigenaar: {owner}",
-    "Email notification was sent!" : "E-mailbericht verzonden!",
-    "You are trying to access a private link. Please log in first." : "U probeert een privé link te benaderen. Meld u zich alstublieft eerst aan.",
-    "{sharee} (federated)" : "{sharee} (gefedereerd)"
+    "This page will refresh itself when the %s instance is available again." : "Deze pagina wordt ververst als de %s-installatie weer beschikbaar is."
 },
 "nplurals=2; plural=(n != 1);");
