@@ -12,11 +12,8 @@ OC.L10N.register(
     "No crop data provided" : "Cap de donada de requadratge pas provesida",
     "No valid crop data provided" : "Donadas de requadratge invalidas",
     "Crop is not square" : "Lo requadratge es pas carrat",
-    "Couldn't reset password because the token is invalid" : "Impossible de reïnicializar lo senhal perque lo geton es pas valable.",
-    "Couldn't reset password because the token is expired" : "Impossible de reïnicializar lo senhal perque lo geton a expirat.",
     "%s password reset" : "Reïnicializacion de vòstre senhal %s",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
-    "Couldn't send mail to following users: %s " : "Impossible de mandar un corrièl als utilizaires seguents : %s",
     "Preparing update" : "Preparacion de la mesa a jorn",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair warning: " : "Avertiment de reparacion :",
@@ -129,36 +126,30 @@ OC.L10N.register(
     "Error while sharing" : "Error al moment de la mesa en partiment",
     "Error while unsharing" : "Error al moment de l'anullacion del partiment",
     "The public link will expire no later than {days} days after it is created" : "Aqueste ligam public expirarà al mai tard {days} jorns aprèp sa creacion.",
-    "Set expiration date" : "Especificar una data d'expiracion",
     "Expiration" : "Expiracion",
-    "Expiration date" : "Data d'expiracion",
     "Link" : "Ligam",
     "Edit" : "Modificar",
     "Remove" : "Suprimir",
+    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
     "Copied!" : "Copiat !",
     "Not supported!" : "Pas suportat !",
     "Press ⌘-C to copy." : "Quichar sus ⌘-C per copiar.",
     "Press Ctrl-C to copy." : "Quichar sus Ctrl-C per copiar.",
-    "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
+    "Name" : "Nom",
     "Filename" : "Nom del fichièr",
     "Password" : "Senhal",
-    "Name" : "Nom",
-    "Allow editing" : "Permetre la modificacion",
+    "Share" : "Partejar",
     "Save" : "Enregistrar",
     "Share to Twitter. Opens in a new window." : "Partejar sus Twitter. Dobrís una novèla fenèstra.",
     "Share to Facebook. Opens in a new window." : "Partejar sus Facebook. Dobrís una novèla fenèstra.",
     "Share to Diaspora. Opens in a new window." : "Partejar sus Diaspora. Dobrís una novèla fenèstra.",
     "Share to Google+. Opens in a new window." : "Partejar sus Google+. Dobrís una novèla fenèstra.",
     "Share via email. Opens your mail client." : "Partejar per corrièr electronic. Dobrís una novèla fenèstra.",
-    "Error while sending notification" : "Error al moment del mandadís de la notificacion",
-    "Sending ..." : "Mandadís…",
-    "Email sent" : "Corrièl mandat",
     "Email link to person" : "Mandar lo ligam per corrièl",
     "Send link via email" : "Mandar lo ligam per mail",
     "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
     "Shared with you by {owner}" : "Partejat amb vos per {owner}",
     "group" : "grop",
-    "remote" : "distant",
     "notify by email" : "notificar per corrièl",
     "Unshare" : "Partejar pas mai",
     "can share" : "pòt partejar",
@@ -169,15 +160,11 @@ OC.L10N.register(
     "access control" : "contraròtle d'accès",
     "Could not unshare" : "Impossible d'arrestar de partejar",
     "Share details could not be loaded for this item." : "Las informacions de partiment an pas pogut èsser cargadas per aqueste element.",
-    "{sharee} (group)" : "{sharee} (grop)",
-    "{sharee} (at {server})" : "{sharee} (sus {server})",
-    "{sharee} (remote)" : "{sharee} (distant)",
-    "Share" : "Partejar",
-    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
+    "User" : "Utilizaire",
+    "Group" : "Grop",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partejatz amb de personas sus d'autres ownClouds en utilizant la sintaxi utilizaire@exemple.com/owncloud",
     "Share with users…" : "Partejar amb d'utilizaires...",
     "Error removing share" : "Error al moment de l'arrèst del partiment",
-    "Warning" : "Atencion",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} inexistenta",
     "restricted" : "Restrent",
     "invisible" : "invisible",
@@ -221,8 +208,6 @@ OC.L10N.register(
     "Cheers!" : "A lèu !",
     "Internal Server Error" : "Error intèrna del servidor",
     "The server encountered an internal error and was unable to complete your request." : "Lo servidor a rencontrat una error intèrna e es incapable d'executar vòstra requèsta.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Contactatz l'administrator del servidor se aquesta error apareis mantun còp. Jonhètz los detalhs tecnics a vòstre rapòrt.",
-    "More details can be found in the server log." : "Lo fichièr jornal del servidor pòt provesir mai d'entresenhas.",
     "Technical details" : "Enstresenhas tecnicas",
     "Remote Address: %s" : "Adreça distanta : %s",
     "Request ID: %s" : "ID de la demanda : %s",
@@ -232,6 +217,7 @@ OC.L10N.register(
     "File: %s" : "Fichièr : %s",
     "Line: %s" : "Linha : %s",
     "Trace" : "Traça",
+    "Imprint" : "Mencions",
     "Create an <strong>admin account</strong>" : "Crear un <strong>compte administrator</strong>",
     "Username" : "Nom d'utilizaire",
     "Storage & database" : "Emmagazinatge & banca de donadas",
@@ -255,14 +241,15 @@ OC.L10N.register(
     "See the documentation" : "Legir la documentacion",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjorn,<br><br>Vos informam que %s a partejat <strong>%s</strong> amb vos.<br><a href=\"%s\">Clicatz aicí per i accedir !</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar corrèctament. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
+    "Menu" : "Menú",
     "Log out" : "Se desconnectar",
     "Search" : "Recercar",
     "Server side authentication failed!" : "L'autentificacion sul servidor a fracassat !",
     "Please contact your administrator." : "Contactatz vòstre administrator.",
     "An internal error occurred." : "Una error intèrna s'es produita.",
     "Please try again or contact your administrator." : "Reensajatz o contactatz vòstre administrator.",
+    "Login" : "Identificant",
     "Username or email" : "Nom d'utilizaire o e-mail",
-    "Log in" : "Connexion",
     "Wrong password. Reset it?" : "Senhal incorrècte. Reïnicializar ?",
     "Wrong password." : "Senhal incorrècte.",
     "Stay logged in" : "Demorar connectat",
@@ -278,8 +265,6 @@ OC.L10N.register(
     "Two-step verification" : "Verificacion en doas etapas",
     "Cancel login" : "Anullar la connexion",
     "You are accessing the server from an untrusted domain." : "Accedissètz al servidor a partir d'un domeni pas aprovat.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En foncion de vòstra configuracion, en tant qu'administrator podètz tanben utilizar lo boton çaijós per aprovar aqueste domeni.",
-    "Add \"%s\" as trusted domain" : "Apondre \"%s\" a la lista dels domenis aprovats",
     "App update required" : "Mesa a jorn de l'aplicacion necessària",
     "%s will be updated to version %s" : "%s serà mes a jorn cap a la version %s.",
     "These apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
@@ -290,8 +275,6 @@ OC.L10N.register(
     "Detailed logs" : "Jornals detalhats",
     "Update needed" : "Mesa a jorn necessària",
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància de %s es en cors de mantenença, aquò pòt prene de temps.",
-    "This page will refresh itself when the %s instance is available again." : "Aquesta pagina se refrescarà d'ela-meteissa quand l'instància %s serà disponibla tornamai.",
-    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
-    "Menu" : "Menú"
+    "This page will refresh itself when the %s instance is available again." : "Aquesta pagina se refrescarà d'ela-meteissa quand l'instància %s serà disponibla tornamai."
 },
 "nplurals=2; plural=(n > 1);");
