@@ -12,12 +12,14 @@ OC.L10N.register(
     "No crop data provided" : "Não foram fornecidos dados de recorte",
     "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
     "Crop is not square" : "O recorte não é quadrado",
-    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
-    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
+    "Could not reset password because the token is invalid" : "Não foi possível redefinir a palavra-passe porque o código é inválido",
+    "Could not reset password because the token expired" : "Não foi possível redefinir a palavra-passe porque o código expirou",
+    "Could not reset password because the token does not match" : "Não foi possível redefinir a palavra-passe porque o código não corresponde",
     "%s password changed successfully" : "Palavra-passe de %s alterada com sucesso",
     "%s password reset" : "%s reposição da palavra-passe",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
-    "Couldn't send mail to following users: %s " : "Não foi possível enviar a mensagem para os seguintes utilizadores: %s",
+    "Download / View" : "Transferir / Ver\n",
+    "Upload only" : "Apenas envio",
     "Preparing update" : "A preparar atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Aviso de correção:",
@@ -141,18 +143,15 @@ OC.L10N.register(
     "Error while sharing" : "Erro ao partilhar",
     "Error while unsharing" : "Erro ao remover a partilha",
     "The public link will expire no later than {days} days after it is created" : "A hiperligação pública irá expirar, o mais tardar {days} dias depois da sua criação",
-    "Set expiration date" : "Definir a data de expiração",
     "Expiration" : "Expiração",
-    "Expiration date" : "Data de expiração",
     "Expiration date is required" : "A data de expiração é necessária",
     "Delete {link}" : "Apagar {link}",
     "Remove link" : "Remover hiperligação",
-    "{fileName} link" : "Hiperligação de {fileName}",
     "Link" : "Hiperligação",
     "Create public link" : "Criar ligação pública",
     "Edit" : "Editar",
     "Remove" : "Remover",
-    "Click to copy to clipboard" : "Clique para copiar para a área de transferência",
+    "Copy to clipboard" : "Copiar para a área de trânsferencia",
     "Social share" : "Partilha social",
     "There are currently no link shares, you can create one" : "Atualmente não existem partilhas por hiperligação, porém, pode criar uma",
     "Anyone with the link has access to the file/folder" : "Qualquer pessoa com a hiperligação terá acesso ao ficheiro/pasta",
@@ -160,32 +159,29 @@ OC.L10N.register(
     "Not supported!" : "Não suportado!",
     "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
-    "Choose a password for the public link" : "Defina a palavra-passe para a hiperligação pública",
+    "Choose a password" : "Escolha uma palavra-passe",
     "Password required" : "Palavra-passe necessária",
+    "Link name" : "Nome de hiperligação",
+    "Name" : "Nome",
     "Filename" : "Nome do ficheiro",
     "Password" : "Palavra-passe",
-    "Name" : "Nome",
-    "Allow editing" : "Permitir edição",
-    "Show file listing" : "Mostrar listagem de ficheiros",
     "Edit link share: {name}" : "Editar partilha por hiperligação: {name}",
-    "Save" : "Guardar",
     "Create link share: {name}" : "Criar partilha por hiperligação: {name}",
+    "Share" : "Compartilhar",
+    "Save" : "Guardar",
     "Remove password" : "Remover palavra-passe",
     "Share to Twitter. Opens in a new window." : "Partilhar no Twitter. Abre uma janela nova.",
     "Share to Facebook. Opens in a new window." : "Partilhar no Facebook. Abre uma janela nova.",
     "Share to Diaspora. Opens in a new window." : "Partilhar no Diaspora. Abre uma janela nova.",
     "Share to Google+. Opens in a new window." : "Partilhar no Google+. Abre uma janela nova.",
     "Share via email. Opens your mail client." : "Partilhar através de e-mail. Abre o seu cliente de e-mail.",
-    "Error while sending notification" : "Erro enquanto estava a enviar a notificação",
-    "Sending ..." : "A enviar...",
-    "Email sent" : "Mensagem enviada",
     "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
-    "Send link via email" : "Enviar hiperligação por mensagem",
+    "Send link via email" : "Enviar hiperligação via correio eletrónico",
+    "Sending" : "A Enviar",
     "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
     "Shared with you by {owner}" : "Partilhado consigo por {owner}",
     "group" : "grupo",
-    "remote" : "remoto",
-    "notify by email" : "Notificar por mensagem",
+    "notify by email" : "notificar por correio eletrónico",
     "Unshare" : "Cancelar partilha",
     "can share" : "pode partilhar",
     "can edit" : "pode editar",
@@ -198,20 +194,16 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Não foram encontrados nenhuns utilizadores ou grupos para {search}",
     "No users found for {search}" : "Não foram encontrados utilizadores para {search}",
     "An error occurred. Please try again" : "Ocorreu um erro. Por favor, tente de novo.",
-    "{sharee} (group)" : "{sharee} (grupo)",
-    "{sharee} (at {server})" : "{sharee} (em {server})",
-    "{sharee} (remote)" : "{sharee} (remoto)",
-    "Share" : "Compartilhar",
+    "User" : "Utilizador",
+    "Group" : "Grupo",
     "User and Groups" : "Utilizador e Grupos",
     "Public Links" : "Ligações públicas",
-    "Resharing is not allowed" : "Não é permitido voltar a partilhar",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhe com as pessoas nas outras ownClouds utilizando a sintaxe username@example.com/owncloud",
     "Share with users…" : "Compartilhe com os utilizadores...",
     "Share with users, groups or remote users…" : "Compartilhe com os utilizadores, grupos ou utilizadores remotos...",
     "Share with users or groups…" : "Compartilhe com os utilizadores ou grupos...",
     "Share with users or remote users…" : "Compartilhe com os utilizadores ou utilizadores remotos...",
     "Error removing share" : "Erro ao remover partilha",
-    "Warning" : "Aviso",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
     "restricted" : "limitado",
     "invisible" : "invisível",
@@ -257,8 +249,6 @@ OC.L10N.register(
     "Cheers!" : "Parabéns!",
     "Internal Server Error" : "Erro Interno do Servidor",
     "The server encountered an internal error and was unable to complete your request." : "O servidor encontrou um erro interno e não conseguiu concluir o seu pedido.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Entra em contacto com o administrador do servidor se este erro aparecer várias vezes, inclui também os detalhes técnicos abaixo no seu contacto.",
-    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
     "Technical details" : "Detalhes técnicos",
     "Remote Address: %s" : "Endereço remoto: %s",
     "Request ID: %s" : "Id. do pedido: %s",
@@ -268,6 +258,8 @@ OC.L10N.register(
     "File: %s" : "Ficheiro: %s",
     "Line: %s" : "Linha: %s",
     "Trace" : "Rasto",
+    "Imprint" : "Marca",
+    "Privacy Policy" : "Política de Privacidade",
     "Create an <strong>admin account</strong>" : "Criar uma <strong>conta de administrador</strong>",
     "Username" : "Nome de utilizador",
     "Storage & database" : "Armazenamento e base de dados",
@@ -292,14 +284,15 @@ OC.L10N.register(
     "See the documentation" : "Consulte a documentação",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer o JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
+    "Menu" : "Menu",
     "Log out" : "Terminar sessão",
     "Search" : "Procurar",
     "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
     "Please contact your administrator." : "Por favor, contacte o seu administrador.",
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Por favor, tente de novo ou contacte o seu administrador.",
-    "Username or email" : "Nome de utilizador ou e-mail",
-    "Log in" : "Iniciar Sessão",
+    "Login" : "Iniciar Sessão",
+    "Username or email" : "Nome de utilizador ou correio eletrónico",
     "Wrong password. Reset it?" : "Palavra-passe errada. Redefini-la?",
     "Wrong password." : "Palavra-passe errada.",
     "Stay logged in" : "Manter sessão iniciada",
@@ -319,9 +312,6 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Por favor, autentique utilizando um segundo fator.",
     "An error occurred while verifying the token" : "Ocorreu um erro durante a verificação do código",
     "You are accessing the server from an untrusted domain." : "Está a aceder ao servidor a partir de um domínio que não é de confiança.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor, contacte o seu administrador. Se é um administrador desta instância, configure a definição \"trusted_domains\" em config/config.php. É fornecido um exemplo de configuração em config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da sua configuração, como um administrador também pode conseguir utilizar o botão abaixo para confiar neste domínio.",
-    "Add \"%s\" as trusted domain" : "Adicionar \"%s\" como um domínio de confiança",
     "App update required" : "É necessário atualizar a aplicação",
     "%s will be updated to version %s" : "%s será atualizada para a versão %s.",
     "These apps will be updated:" : "Estas aplicações irão ser atualizadas.",
@@ -331,17 +321,8 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos expirados com instalações maiores, em vez disso, pode executar o seguinte comando a partir da diretoria de instalação:",
     "Detailed logs" : "Registos detalhados",
     "Update needed" : "É necessário atualizar",
-    "Please use the command line updater because you have a big instance." : "Por favor, utilize o atualizador de linha de comando porque a sua instância é grande.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
-    "This page will refresh itself when the %s instance is available again." : "Esta página irá ser atualizada quando a instância %s ficar novamente disponível.",
-    "Could not reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque o token é inválido",
-    "Copy to clipboard" : "Copiar para a área de trânsferencia",
-    "Choose a password" : "Escolha uma palavra-passe",
-    "Upload only" : "Apenas envio",
-    "Sending" : "A Enviar",
-    "Menu" : "Menu",
-    "Link name" : "Nome de hiperligação",
-    "Owner: {owner}" : "Proprietário: {owner}"
+    "This page will refresh itself when the %s instance is available again." : "Esta página irá ser atualizada quando a instância %s ficar novamente disponível."
 },
 "nplurals=2; plural=(n != 1);");
