@@ -10,11 +10,11 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "A apărut o eroare. Te rugăm să contactezi administratorul.",
     "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
     "Crop is not square" : "Selecția nu este pătrată",
-    "Couldn't reset password because the token is invalid" : "Parola nu a putut fi resetată deoarece token-ul este invalid",
-    "Couldn't reset password because the token is expired" : "Parola nu a putut fi resetată deoarece token-ul a expirat",
+    "%s password changed successfully" : "parola %s a fost schimbată cu succes",
     "%s password reset" : "%s resetare parola",
     "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
-    "Couldn't send mail to following users: %s " : "Nu s-a putut trimite mesajul către următorii utilizatori: %s",
+    "Download / View" : "Descarcă / Vizualizează",
+    "Download / View / Upload" : "Descarcă / Vizualizează / Încarcă",
     "Preparing update" : "Se pregătește actualizarea",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Alerte reparare:",
@@ -118,27 +118,24 @@ OC.L10N.register(
     "Error while sharing" : "Eroare la partajare",
     "Error while unsharing" : "Eroare la anularea partajării",
     "The public link will expire no later than {days} days after it is created" : "Legătura publică va expira nu mai târziu de {days} zile de la ziua creării",
-    "Set expiration date" : "Specifică data expirării",
     "Expiration" : "Expira",
-    "Expiration date" : "Data expirării",
+    "Remove link" : "Șterge legătura",
     "Link" : "Legătură",
     "Edit" : "Editează",
     "Remove" : "Șterge",
-    "Choose a password for the public link" : "Alege o parolă pentru acest link public",
+    "Copy to clipboard" : "Copiază în clipboard",
+    "Anyone with the link has access to the file/folder" : "Oricine are legătura are acces la fișier/dosar",
+    "Link name" : "Numele legăturii",
+    "Name" : "Nume",
     "Filename" : "Nume fișier",
     "Password" : "Parolă",
-    "Name" : "Nume",
-    "Allow editing" : "Permite editarea",
+    "Share" : "Partajează",
     "Save" : "Salvează",
-    "Error while sending notification" : "Eroare la trimiterea notificării",
-    "Sending ..." : "Se expediază...",
-    "Email sent" : "Mesajul a fost expediat",
     "Email link to person" : "Expediază legătura prin poșta electronică",
     "Send link via email" : "Trimite link via email",
     "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
     "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
     "group" : "grup",
-    "remote" : "de la distanță",
     "notify by email" : "notifică prin email",
     "Unshare" : "Anulare partajare",
     "can share" : "se poate partaja",
@@ -152,13 +149,12 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Nu au fost găsiți utilizatori sau grupuri pentru {search}",
     "No users found for {search}" : "Nu au fost găsiți utilizatori pentru {search}",
     "An error occurred. Please try again" : "A apărut o eroare. Încearcă din nou",
-    "Share" : "Partajează",
-    "Resharing is not allowed" : "Repartajarea nu este permisă",
+    "User" : "Utilizator",
+    "Group" : "Grup",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partajează cu persoane din alte instanțe ownCloud folosind sintaxa nume_utilizator@exemplu.com/owncloud",
     "Share with users…" : "Partajează cu utilizatori...",
     "Share with users or groups…" : "Partajează cu utilizatori sau grupuri...",
     "Error removing share" : "Eroare la înlăturarea elementului partajat",
-    "Warning" : "Atenție",
     "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
     "restricted" : "restricționat",
     "invisible" : "invizibil",
@@ -203,6 +199,7 @@ OC.L10N.register(
     "Code: %s" : "Cod: %s",
     "Message: %s" : "Mesaj: %s",
     "File: %s" : "Fișier: %s",
+    "Imprint" : "Imprint",
     "Create an <strong>admin account</strong>" : "Crează un <strong>cont de administrator</strong>",
     "Username" : "Nume utilizator",
     "Storage & database" : "Stocare și baza de date",
@@ -222,13 +219,14 @@ OC.L10N.register(
     "Finishing …" : "Se finalizează...",
     "Need help?" : "Ai nevoie de ajutor?",
     "See the documentation" : "Vezi documentația",
+    "Menu" : "Meniu",
     "Log out" : "Ieșire",
     "Search" : "Căutare",
     "Please contact your administrator." : "Contactează-ți administratorul.",
     "An internal error occurred." : "A apărut o eroare internă.",
     "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
+    "Login" : "Autentificare",
     "Username or email" : "Nume de utilizator sau adresă email",
-    "Log in" : "Autentificare",
     "Wrong password. Reset it?" : "Parolă greșită. O resetezi?",
     "Wrong password." : "Parolă greșită.",
     "Stay logged in" : "Rămâi autentificat",
@@ -246,7 +244,6 @@ OC.L10N.register(
     "Cancel login" : "Anulează autentificarea",
     "Please authenticate using the selected factor." : "Autentifică-te folosind factorul ales.",
     "You are accessing the server from an untrusted domain." : "Accesezi serverul dintr-un domeniu care nu a fost configurat ca fiind de încredere.",
-    "Add \"%s\" as trusted domain" : "Adaugă \"%s\" ca domeniu de încredere",
     "App update required" : "E necesară o actualizare a aplicației",
     "%s will be updated to version %s" : "%s va fi actualizat la versiunea %s",
     "These apps will be updated:" : "Aceste aplicații vor fi actualizate:",
@@ -254,14 +251,7 @@ OC.L10N.register(
     "Start update" : "Începe actualizarea",
     "Detailed logs" : "Loguri detaliate",
     "Update needed" : "E necesară actualizarea",
-    "Please use the command line updater because you have a big instance." : "Folosește actualizarea din linia de comandă deoarece ai o instanță mare.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
-    "This page will refresh itself when the %s instance is available again." : "Această pagină se va reîmprospăta atunci când %s instance e disponibil din nou.",
-    "Remove link" : "Șterge legătura",
-    "Copy to clipboard" : "Copiază în clipboard",
-    "Anyone with the link has access to the file/folder" : "Oricine are legătura are acces la fișier/dosar",
-    "Menu" : "Meniu",
-    "Link name" : "Numele legăturii",
-    "%s password changed successfully" : "parola %s a fost schimbată cu succes"
+    "This page will refresh itself when the %s instance is available again." : "Această pagină se va reîmprospăta atunci când %s instance e disponibil din nou."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
