@@ -12,12 +12,20 @@ OC.L10N.register(
     "No crop data provided" : "Не указана информация о кадрировании",
     "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
     "Crop is not square" : "Кадр не является квадратом",
-    "Couldn't reset password because the token is invalid" : "Не удалось сбросить пароль из-за неверного токена",
-    "Couldn't reset password because the token is expired" : "Не удалось сбросить пароль, так как срок действия токена истек.",
+    "Could not reset password because the token is invalid" : "Не удалось сбросить пароль, так как токен неправильный",
+    "Could not reset password because the token expired" : "Не удалось сбросить пароль, так как токен устарел",
+    "Could not reset password because the token does not match" : "Не удалось сбросить пароль, так как токен не соответствует",
     "%s password changed successfully" : "Пароль %s изменён успешно",
     "%s password reset" : "Сброс пароля %s",
     "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Пожалуйста, свяжитесь с вашим администратором.",
-    "Couldn't send mail to following users: %s " : "Невозможно отправить письмо следующим пользователям: %s",
+    "Download / View" : "Скачивание / Просмотр",
+    "Recipients can view or download contents." : "Получатели могут просматривать или скачивать содержимое.",
+    "Download / View / Upload" : "Скачивание / Просмотр / Закачка",
+    "Recipients can view, download and upload contents." : "Получатели могут просматривать, скачивать и закачивать содержимое.",
+    "Download / View / Edit" : "Скачивание / Просмотр / Правка",
+    "Recipients can view, download, edit, delete and upload contents." : "Получатели могут просматривать, скачивать, править, удалять и закачивать содержимое.",
+    "Upload only" : "Только закачка",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Получение файлов от многих получателей без раскрытия содержимого каталога.",
     "Preparing update" : "Подготовка к обновлению",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Предупреждение восстановления:",
@@ -94,10 +102,20 @@ OC.L10N.register(
     "Saving..." : "Сохранение...",
     "Dismiss" : "Закрыть",
     "seconds ago" : "несколько секунд назад",
+    "You have enabled one or more ownCloud Enterprise apps but your installation does not have a valid license yet." : "Вы включили одно или несколько приложений ownCloud для Enterprise, но у вашей установки ещё нет допустимого лицензионного ключа.",
+    "A grace period of 24 hours has started to allow you to get going right away. Once the grace period ends, all Enterprise apps will become disabled unless you supply a valid license key." : "Запущен дополнительный период на 24 часа, чтобы вы смогли продвинуться дальше. Как только дополнительный период закончится, все приложения для Enterprise будут отключны, если вы не введёте допустимый лицензионный ключ.",
+    "To try ownCloud Enterprise, just start a 30-day demo and enter the provided license key below." : "Чтобы попробовать ownCloud Enterprise, просто запустите 30-дневную демонстрацию и введите ниже предоставленный лицензионный ключ.",
+    "Upgrade to ownCloud Enterprise" : "Обновление ownCloud до Enterprise",
+    "Remaining time: {rtime}" : "Остающееся время: {rtime}",
+    "Get your demo key" : "Получить демонстрационный ключ",
+    "Enter license key" : "Ввод лицензионного ключа",
+    "Set new key" : "Установить новый ключ",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ссылка для сброса пароля была отправлена на ваш email. Если вы не получили письмо в течении разумного промежутка времени, проверьте папку со спамом.<br>Если его там нет, то обратитесь к вашему администратору.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши файлы зашифрованы. Если вы не включили ключ восстановления, то ваши данные будут недоступны после сброса пароля.<br />Если вы не уверены что делать дальше - обратитесь к вашему администратору.<br />Вы действительно хотите продолжить?",
     "I know what I'm doing" : "Я понимаю, что делаю",
     "Password can not be changed. Please contact your administrator." : "Пароль не может быть изменён. Пожалуйста, свяжитесь с вашим администратором.",
+    "Passwords do not match" : "Пароли не соответствуют друг другу",
+    "Error adding {addItem}: {addItem} already exists" : "Ошибка при добавлении {addItem}: {addItem} уже существует",
     "No" : "Нет",
     "Yes" : "Да",
     "Choose" : "Выбрать",
@@ -130,6 +148,7 @@ OC.L10N.register(
     "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси не верна, либо доступ к ownCloud осуществлён через доверенный прокси. Если ownCloud открыт не через доверенный прокси то это проблема безопасности, которая может позволить атакующему подделать IP адрес, который видит ownCloud. Дополнительная информация доступна в нашей  <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached настроен на распределенный кеш, но установлен не поддерживаемый модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только модуль \"memcached\", но не \"memcache\". Больше информации на <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki странице memcached о обоих модулях</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему доступна в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Список проблемных файлов…</a> / <a href=\"{rescanEndpoint}\">Сканировать ещё раз…</a>)",
+    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Вы работаете в ОТЛАДОЧНОМ режиме, и это может давать нежелательные побочные эффекты. Пожалуйста уберите флаг «debug» из «config.php».",
     "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог данных и ваши файлы возможно доступны из Интернета. Файл .htaccess не работает. Мы настоятельно рекомендуем Вам настроить веб сервер таким образом, чтобы каталог данных не был больше доступен или переместить каталог данных за пределы корня веб сервера.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Заголовок HTTP \"{header}\" не настроен на значение \"{expected}\". Это потенциальная проблема безопасности и мы рекомендуем изменить эти настройки.",
@@ -141,18 +160,16 @@ OC.L10N.register(
     "Error while sharing" : "При попытке поделиться произошла ошибка",
     "Error while unsharing" : "При закрытии доступа произошла ошибка",
     "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
-    "Set expiration date" : "Установить срок действия",
     "Expiration" : "Срок действия",
-    "Expiration date" : "Дата окончания",
+    "Choose an expiration date" : "Выберите срок действия",
     "Expiration date is required" : "Срок действия обязателен",
     "Delete {link}" : "Удалить {link}",
     "Remove link" : "Удалить ссылку",
-    "{fileName} link" : "Ссылка {fileName}",
     "Link" : "Ссылка",
     "Create public link" : "Создать общедоступную ссылку",
     "Edit" : "Редактировать",
     "Remove" : "Удалить",
-    "Click to copy to clipboard" : "Копировать ссылку в буфер обмена",
+    "Copy to clipboard" : "Скопировать в буфер обмена",
     "Social share" : "Поделиться в соцсетях",
     "There are currently no link shares, you can create one" : "Сейчас нет ссылок для доступа, вы можете создать первую",
     "Anyone with the link has access to the file/folder" : "Каждый, у кого есть эта ссылка, имеет доступ к файлу/каталогу",
@@ -160,31 +177,34 @@ OC.L10N.register(
     "Not supported!" : "Не поддерживается!",
     "Press ⌘-C to copy." : "Нажмите ⌘-C чтобы скопировать.",
     "Press Ctrl-C to copy." : "Нажмите Ctrl-C чтобы скопировать.",
-    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
+    "Choose a password" : "Выберите пароль",
     "Password required" : "Требуется пароль",
+    "Link name" : "Имя ссылки",
+    "Name" : "Название",
     "Filename" : "Имя файла",
     "Password" : "Пароль",
-    "Name" : "Название",
-    "Allow editing" : "Разрешить редактирование",
-    "Show file listing" : "Показать список файлов",
+    "Can not remove required password" : "Нельзя удалить обязательный пароль",
     "Edit link share: {name}" : "Изменить доступ по ссылке: {name}",
-    "Save" : "Сохранить",
     "Create link share: {name}" : "Создать доступ по ссылке: {name}",
+    "Share" : "Поделиться",
+    "Save" : "Сохранить",
     "Remove password" : "Удалить пароль",
     "Share to Twitter. Opens in a new window." : "Поделиться в Twitter. Откроется в новом окне",
     "Share to Facebook. Opens in a new window." : "Поделиться в Facebook. Откроется в новом окне",
     "Share to Diaspora. Opens in a new window." : "Поделиться в Diaspora. Откроется в новом окне",
     "Share to Google+. Opens in a new window." : "Поделиться в Google+. Откроется в новом окне",
     "Share via email. Opens your mail client." : "Поделиться через  email. Откроется в вашем почтовом клиенте",
-    "Error while sending notification" : "Ошибка при отправке уведомления",
-    "Sending ..." : "Отправляется ...",
-    "Email sent" : "Письмо отправлено",
+    "An error occurred while sending email" : "При отправке письма произошла ошибка.",
     "Email link to person" : "Отправить ссылку по электронной почте",
+    "Send copy to self" : "Отправить копию себе",
     "Send link via email" : "Отправить ссылку по электронной почте",
+    "Add personal message" : "Добавить личное сообщение",
+    "Sending" : "Отправка",
+    "E-Mail sent" : "Письмо отправлено",
     "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
     "Shared with you by {owner}" : "С вами поделился {owner} ",
     "group" : "группа",
-    "remote" : "удаленный",
+    "federated" : "федеративный",
     "notify by email" : "уведомить по почте",
     "Unshare" : "Закрыть доступ",
     "can share" : "может делиться с другими",
@@ -194,27 +214,32 @@ OC.L10N.register(
     "delete" : "удалить",
     "access control" : "контроль доступа",
     "Could not unshare" : "Не удалось отменить доступ",
+    "Email notification was sent!" : "Уведомление почтой было отправлено!",
+    "Email notification not sent" : "Уведомление почтой не было отправлено",
     "Share details could not be loaded for this item." : "Не удалось загрузить информацию об общем доступе для этого элемента.",
     "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
     "No users found for {search}" : "Не найдено пользователей по запросу {search}",
+    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Пожалуйста введите хотя бы {chars} символ для вывода предложений","Пожалуйста введите хотя бы {chars} символа для вывода предложений","Пожалуйста введите хотя бы {chars} символов для вывода предложений","Пожалуйста введите хотя бы {chars} символов для вывода предложений"],
     "An error occurred. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
-    "{sharee} (group)" : "{sharee} (группа)",
-    "{sharee} (at {server})" : "{sharee} (на {server})",
-    "{sharee} (remote)" : "{sharee} (удалённо)",
-    "Share" : "Поделиться",
+    "User" : "Пользователь",
+    "Group" : "Группа",
+    "Guest" : "Гость",
+    "At {server}" : "На {server}",
+    "Federated" : "Федеративный",
     "User and Groups" : "Пользователь и группы",
     "Public Links" : "Общедоступные ссылки",
-    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
+    "Sharing is not allowed" : "Предоставление доступа не разрешено",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя формат username@example.com/owncloud",
     "Share with users…" : "Поделиться с пользователями...",
     "Share with users, groups or remote users…" : "Поделиться с пользователями, группами или удаленными пользователями...",
     "Share with users or groups…" : "Поделиться с пользователями или группами...",
     "Share with users or remote users…" : "Общий доступ с пользователями или удалеными пользователями",
     "Error removing share" : "Ошибка удаления общего доступа",
-    "Warning" : "Предупреждение",
+    "Unknown Share" : "Неизвестный ресурс общего доступа",
     "Non-existing tag #{tag}" : "Несуществующий тег #{tag}",
     "restricted" : "ограниченный",
     "invisible" : "невидимый",
+    "Static" : "Статично",
     "({scope})" : "({scope})",
     "Delete" : "Удалить",
     "Rename" : "Переименовать",
@@ -254,11 +279,12 @@ OC.L10N.register(
     "You can click here to return to %s." : "Вы можете нажать здесь, чтобы вернуться в %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Здравствуйте,\n\n%s поделился %s с вами.\nПосмотреть: %s\n",
     "The share will expire on %s." : "Доступ будет закрыт %s",
+    "Personal note from the sender: \n %s." : "Личная заметка от отправителя: \n %s.",
     "Cheers!" : "Всего наилучшего!",
     "Internal Server Error" : "Внутренняя ошибка сервера",
     "The server encountered an internal error and was unable to complete your request." : "Запрос не выполнен, на сервере произошла ошибка.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Пожалуйста, свяжитесь с администратором сервера если эта ошибка будет повторяться. Прикрепите указанную ниже информацию к своему сообщению.",
-    "More details can be found in the server log." : "Больше деталей может быть найдено в журнале сервера.",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Если эта ошибка будет повторяться, то пожалуйста свяжитесь с администратором этого сервера, и приложите к сообщению технические подробности, приведённые ниже.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Дополнительные подробности можно найти в <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">журнале сервера</a>.",
     "Technical details" : "Технические детали",
     "Remote Address: %s" : "Удаленный адрес: %s",
     "Request ID: %s" : "ID Запроса: %s",
@@ -268,6 +294,8 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Линия: %s",
     "Trace" : "Трассировка",
+    "Imprint" : "Штамп",
+    "Privacy Policy" : "Политика конфиденциальности",
     "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
     "Username" : "Имя пользователя",
     "Storage & database" : "Хранилище и база данных",
@@ -292,23 +320,28 @@ OC.L10N.register(
     "See the documentation" : "Посмотреть документацию",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здравствуйте,<br><br>%s поделился с вами <strong>%s</strong>.<br>Перейдите по <a href=\"%s\">ссылке</a>, чтобы посмотреть<br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript. Пожалуйста, {linkstart}включите JavaScript{linkend} и обновите страницу.",
+    "Menu" : "Меню",
     "Log out" : "Выйти",
     "Search" : "Найти",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
     "Please contact your administrator." : "Пожалуйста, обратитесь к администратору.",
     "An internal error occurred." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
+    "Login" : "Логин",
     "Username or email" : "Имя пользователя / email",
-    "Log in" : "Войти",
+    "You took too long to log in, please try again now" : "Похоже, вы потратили на вход слишком много времени, пожалуйста попробуйте ещё раз сейчас",
     "Wrong password. Reset it?" : "Неправильный пароль. Сбросить его?",
     "Wrong password." : "Неправильный пароль.",
+    "You are trying to access a private link. Please log in first." : "Вы пытаетесь получить доступ по личной ссылке. Пожалуйста, сначала войдите.",
     "Stay logged in" : "Оставаться в системе",
     "Alternative Logins" : "Альтернативные имена пользователя",
     "Use the following link to reset your password: {link}" : "Используйте следующую ссылку чтобы сбросить пароль: {link}",
     "Password changed successfully" : "Пароль изменён успешно",
     "New password" : "Новый пароль",
     "New Password" : "Новый пароль",
+    "Confirm Password" : "Подтвердите пароль",
     "Reset password" : "Сбросить пароль",
+    "Personal note from the sender: <br> %s." : "Личная заметка от отправителя: <br> %s.",
     "This ownCloud instance is currently in single user mode." : "Сервер ownCloud в настоящее время работает в однопользовательском режиме.",
     "This means only administrators can use the instance." : "Это значит, что только администраторы могут использовать сервер.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
@@ -319,9 +352,8 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Пожалуйста, аутентифицируйтесь выбранным фактором.",
     "An error occurred while verifying the token" : "Произошла ошибка при проверке токена",
     "You are accessing the server from an untrusted domain." : "Вы пытаетесь получить доступ к серверу с недоверенного домена.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Пожалуйста, обратитесь к администратору. Если вы являетесь администратором этого сервера, настройте параметры \"trusted_domains\" в файле config/config.php. Пример настройки можно найти в config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимости от конфигурации, как администратор вы можете также внести домен в доверенные с помощью кнопки, расположенной ниже.",
-    "Add \"%s\" as trusted domain" : "Добавить \"%s\" как доверенный домен",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "Пожалуйста, обратитесь к вашему администратору. Если вы являетесь администратором этого экземпляра, то настройте параметр «trusted_domains» в config/config.php.",
+    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Пример настройки имеется в config/config.sample.php или в <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документации</a>.",
     "App update required" : "Требуется обновление приложения",
     "%s will be updated to version %s" : "%s будет обновлен до версии %s",
     "These apps will be updated:" : "Следующие приложения будут обновлены:",
@@ -331,42 +363,10 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
     "Detailed logs" : "Подбробные логи",
     "Update needed" : "Требуется обновление",
-    "Please use the command line updater because you have a big instance." : "Пожалуйста, используйте обновление через командную строку, так как данная установка имеет большой размер.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Возможно, что ваш экземпляр может содержать много файлов и/или пользователей. Чтобы обеспечить плавный процесс обновления, используйте обновление через командную строку(occ upgrade).",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Автоматическое обновление отключается в config.php. Для обновления вашего экземпляра, пожалуйста, используйте командную строку(occ upgrade).",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Для помощи, ознакомьтесь с  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацией</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
-    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен.",
-    "Could not reset password because the token is invalid" : "Не удалось сбросить пароль, так как токен неправильный",
-    "Could not reset password because the token expired" : "Не удалось сбросить пароль, так как токен устарел",
-    "Could not reset password because the token does not match" : "Не удалось сбросить пароль, так как токен не соответствует",
-    "Copy to clipboard" : "Скопировать в буфер обмена",
-    "Choose a password" : "Выберите пароль",
-    "Upload only" : "Только закачка",
-    "Sending" : "Отправка",
-    "Menu" : "Меню",
-    "Read only" : "Только чтение",
-    "Read & Write" : "Чтение и запись",
-    "Email notification not sent" : "Уведомление почтой не было отправлено",
-    "You took too long to login, please try again now" : "Ваш вход занял слишком много времени, пожалуйста попробуйте ещё раз сейчас",
-    "Choose an expiration date" : "Выберите срок действия",
-    "An error occured" : "Произошла ошибка",
-    "Send copy to self" : "Отправить копию себе",
-    "Add personal message" : "Добавить личное сообщение",
-    "Error adding {addItem}: {addItem} already exists" : "Ошибка при добавлении {addItem}: {addItem} уже существует",
-    "federated" : "федеративный",
-    "Link name" : "Имя ссылки",
-    "Recipients can view, download, edit, delete and upload contents." : "Получатели могут просматривать, скачивать, править, удалять и закачивать содержимое.",
-    "Download / View" : "Скачивание / Просмотр",
-    "Download / View / Upload" : "Скачивание / Просмотр / Закачка",
-    "Owner: {owner}" : "Владелец: {owner}",
-    "Email notification was sent!" : "Уведомление почтой было отправлено!",
-    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Если эта ошибка будет повторяться, то пожалуйста свяжитесь с администратором этого сервера, и приложите к сообщению технические подробности, приведённые ниже.",
-    "You are trying to access a private link. Please log in first." : "Вы пытаетесь получить доступ по личной ссылке. Пожалуйста, сначала войдите.",
-    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Возможно, что ваш экземпляр может содержать много файлов и/или пользователей. Чтобы обеспечить плавный процесс обновления, используйте обновление через командную строку(occ upgrade).",
-    "Couldn't send mail to following recipient(s): %s " : "Не удалось отправить почту следующим получателям: %s ",
-    "Receive files from multiple recipients without revealing the contents of the folder." : "Получение файлов от многих получателей без раскрытия содержимого каталога.",
-    "Recipients can view or download contents." : "Получатели могут просматривать или скачивать содержимое.",
-    "{sharee} (federated)" : "{sharee} (федеративный)",
-    "Personal note from the sender: %s." : "Личное замечание от отправителя: %s.",
-    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Автоматическое обновление отключается в config.php. Для обновления вашего экземпляра, пожалуйста, используйте командную строку(occ upgrade)."
+    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
