@@ -12,12 +12,13 @@ OC.L10N.register(
     "No crop data provided" : "Ni podanih podatkov obreza",
     "No valid crop data provided" : "Navedeni so neveljavni podatki obrez slike",
     "Crop is not square" : "Obrez ni pravokoten",
-    "Couldn't reset password because the token is invalid" : "Ni mogoče ponastaviti gesla zaradi neustreznega žetona.",
-    "Couldn't reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel.",
+    "Could not reset password because the token is invalid" : "Ni mogoče ponastaviti gesla, ker je žeton neveljaven",
+    "Could not reset password because the token expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel",
+    "Could not reset password because the token does not match" : "Ni mogoče ponastaviti gesla, ker žeton ni skladen",
     "%s password changed successfully" : "Geslo %s je uspešno spremenjeno",
     "%s password reset" : "Ponastavitev gesla %s",
     "Couldn't send reset email. Please contact your administrator." : "Ni mogoče nastaviti elektronskega naslova za ponastavitev. Stopite v stik s skrbnikom sistema.",
-    "Couldn't send mail to following users: %s " : "Ni mogoče poslati sporočila za: %s",
+    "Upload only" : "Le pošiljanje",
     "Preparing update" : "Pripravljanje posodobitve",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Opozorilo popravila:",
@@ -141,46 +142,44 @@ OC.L10N.register(
     "Error while sharing" : "Napaka med souporabo",
     "Error while unsharing" : "Napaka med odstranjevanjem souporabe",
     "The public link will expire no later than {days} days after it is created" : "Javna povezava bo potekla {days} dni po ustvarjanju.",
-    "Set expiration date" : "Nastavi datum preteka",
     "Expiration" : "Datum preteka",
-    "Expiration date" : "Datum preteka",
     "Expiration date is required" : "Zahtevan je datum preteka veljavnosti",
     "Delete {link}" : "Izbriši povezavo {link}",
     "Remove link" : "Odstrani povezavo",
-    "{fileName} link" : "Povezava do {fileName}",
     "Link" : "Povezava",
     "Create public link" : "Ustvari javno povezavo",
     "Edit" : "Uredi",
     "Remove" : "Odstrani",
-    "Click to copy to clipboard" : "Kliknite za kopiranje v odložišče",
+    "Copy to clipboard" : "Kopiraj v odložišče",
+    "Social share" : "Objava prek socialnega omrežja",
+    "There are currently no link shares, you can create one" : "Trenutno ni povezav za souporabo. Morda lahko povezave ustvarite.",
+    "Anyone with the link has access to the file/folder" : "Vsak, ki ima povezavo ima dostop do datoteke ali mape",
     "Copied!" : "Kopirano!",
     "Not supported!" : "Možnost ni podprta!",
     "Press ⌘-C to copy." : "Pritisnite tipki ⌘-C za kopiranje.",
     "Press Ctrl-C to copy." : "Pritisnite tipki Ctrl-C za kopiranje.",
-    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
+    "Choose a password" : "Izbor gesla",
     "Password required" : "Zahtevano je geslo",
+    "Link name" : "Naziv povezave",
+    "Name" : "Ime",
     "Filename" : "Ime datoteke",
     "Password" : "Geslo",
-    "Name" : "Ime",
-    "Allow editing" : "Dovoli urejanje",
     "Edit link share: {name}" : "Uredi povezavo za souporabo: {name}",
-    "Save" : "Shrani",
     "Create link share: {name}" : "Ustvari povezavo za souporabo: {name}",
+    "Share" : "Souporaba",
+    "Save" : "Shrani",
     "Remove password" : "Odstrani geslo",
     "Share to Twitter. Opens in a new window." : "Objavi povezavo na Twitter (odpre v novem oknu).",
     "Share to Facebook. Opens in a new window." : "Objavi povezavo na Facebook (odpre se v novem oknu).",
     "Share to Diaspora. Opens in a new window." : "Objavi povezavo na Diasporo (odpre v novem oknu).",
     "Share to Google+. Opens in a new window." : "Objavi povezavo na Google+ (odpre v novem oknu).",
     "Share via email. Opens your mail client." : "Objavi povezavo prek elektronske pošte (odpre v oknu odjemalca).",
-    "Error while sending notification" : "Napaka med pošiljanjem obvestila",
-    "Sending ..." : "Pošiljanje ...",
-    "Email sent" : "Elektronska pošta je poslana",
     "Email link to person" : "Posreduj povezavo po elektronski pošti",
     "Send link via email" : "Pošlji povezavo prek elektronske pošte",
+    "Sending" : "Pošiljanje",
     "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
     "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
     "group" : "skupina",
-    "remote" : "oddaljeno",
     "notify by email" : "obvesti po elektronski pošti",
     "Unshare" : "Prekliči souporabo",
     "can share" : "lahko omogoči souporabo",
@@ -194,20 +193,16 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
     "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
     "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
-    "{sharee} (group)" : "{sharee} (skupina)",
-    "{sharee} (at {server})" : "{sharee} (na {server})",
-    "{sharee} (remote)" : "{sharee} (oddaljeno)",
-    "Share" : "Souporaba",
+    "User" : "Uporabnik",
+    "Group" : "Skupina",
     "User and Groups" : "Uporabnik in skupine",
     "Public Links" : "Javne povezave",
-    "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Souporaba z uporabniki, ki so na drugih oblakih ownCloud s povezavo uporabnik@domena.si/owncloud",
     "Share with users…" : "Omogoči souporabo z ...",
     "Share with users, groups or remote users…" : "Souporaba z uporabniki, skupinami ali zunanjimi uporabniki ...",
     "Share with users or groups…" : "Souporaba z uporabniki ali skupinami ...",
     "Share with users or remote users…" : "Souporaba z uporabniki ali oddaljenimi uporabniki ...",
     "Error removing share" : "Napaka odstranjevanja souporabe",
-    "Warning" : "Opozorilo",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
     "restricted" : "omejeno",
     "invisible" : "nevidno",
@@ -253,8 +248,6 @@ OC.L10N.register(
     "Cheers!" : "Lep pozdrav!",
     "Internal Server Error" : "Notranja  napaka strežnika",
     "The server encountered an internal error and was unable to complete your request." : "Prišlo je do notranje napake, zato ni mogoče končati zahteve.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Stopite v stik s skrbnikom sistema, če se napaka pojavlja pogosto. V poročilo vključite tudi tehnične podatke v dnevniški datoteki.",
-    "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniku strežnika.",
     "Technical details" : "Tehnične podrobnosti",
     "Remote Address: %s" : "Oddaljen naslov: %s",
     "Request ID: %s" : "ID zahteve: %s",
@@ -264,6 +257,7 @@ OC.L10N.register(
     "File: %s" : "Datoteka: %s",
     "Line: %s" : "Vrstica: %s",
     "Trace" : "Sledenje povezav",
+    "Imprint" : "Natis",
     "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
     "Username" : "Uporabniško ime",
     "Storage & database" : "Shramba in podatkovna zbirka",
@@ -288,16 +282,18 @@ OC.L10N.register(
     "See the documentation" : "Preverite dokumentacijo",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
+    "Menu" : "Meni",
     "Log out" : "Odjava",
     "Search" : "Poišči",
     "Server side authentication failed!" : "Overitev s strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
     "An internal error occurred." : "Prišlo je do notranje napake.",
     "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
+    "Login" : "Prijava",
     "Username or email" : "Uporabniško ime ali elektronski naslov",
-    "Log in" : "Prijava",
     "Wrong password. Reset it?" : "Napačno geslo. Ali ga želite ponastaviti?",
     "Wrong password." : "Napačno geslo!",
+    "You are trying to access a private link. Please log in first." : "Poskušate odpreti zasebno povezavo. Pred nadaljevanjem se je treba prijaviti.",
     "Stay logged in" : "Ohrani prijavo",
     "Alternative Logins" : "Druge prijavne možnosti",
     "Use the following link to reset your password: {link}" : "Za ponastavitev gesla uporabite povezavo: {link}",
@@ -315,9 +311,6 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "Overite z uporabo izbranega faktorja.",
     "An error occurred while verifying the token" : "Prišlo je do napake med preverjanjem žetona",
     "You are accessing the server from an untrusted domain." : "Trenutno je vzpostavljena povezava s strežnikom prek ne-varne domene.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Stopite v stik s skrbnikom ali pa nastavite možnost \"varna_domena\" v datoteki config/config.php. Primer nastavitve je razložen v datoteki config/config.sample.php.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Glede na nastavitve bi lahko kot skrbnik uporabili spodnji gumb in domeno ročno določili kot varno.",
-    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" kot varno domeno",
     "App update required" : "Zahtevana je posodobitev programa",
     "%s will be updated to version %s" : "%s bo posodobljen na različico %s.",
     "These apps will be updated:" : "Posodobljeni bodo naslednji vstavki:",
@@ -327,23 +320,8 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
     "Detailed logs" : "Podrobni dnevniški zapisi",
     "Update needed" : "Zahtevana je posodobitev",
-    "Please use the command line updater because you have a big instance." : "Posodobitev večjih namestitev je priporočljivo izvesti prek ukazne vrstice.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacijo</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko traja.",
-    "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena ko bo %s spet na voljo.",
-    "Could not reset password because the token is invalid" : "Ni mogoče ponastaviti gesla, ker je žeton neveljaven",
-    "Could not reset password because the token expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel",
-    "Could not reset password because the token does not match" : "Ni mogoče ponastaviti gesla, ker žeton ni skladen",
-    "Copy to clipboard" : "Kopiraj v odložišče",
-    "There are currently no link shares, you can create one" : "Trenutno ni povezav za souporabo. Morda lahko povezave ustvarite.",
-    "Anyone with the link has access to the file/folder" : "Vsak, ki ima povezavo ima dostop do datoteke ali mape",
-    "Choose a password" : "Izbor gesla",
-    "Upload only" : "Le pošiljanje",
-    "Sending" : "Pošiljanje",
-    "Menu" : "Meni",
-    "Social share" : "Objava prek socialnega omrežja",
-    "Link name" : "Naziv povezave",
-    "Owner: {owner}" : "Lastnik: {owner}",
-    "You are trying to access a private link. Please log in first." : "Poskušate odpreti zasebno povezavo. Pred nadaljevanjem se je treba prijaviti."
+    "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena ko bo %s spet na voljo."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
