@@ -12,12 +12,20 @@ OC.L10N.register(
     "No crop data provided" : "没有提供相应数据",
     "No valid crop data provided" : "没有提供有效的裁剪数据",
     "Crop is not square" : "裁剪的不是正方形",
-    "Couldn't reset password because the token is invalid" : "令牌无效，无法重置密码",
-    "Couldn't reset password because the token is expired" : "无法重设密码，因为令牌已过期",
+    "Could not reset password because the token is invalid" : "无法重置密码，因为该令牌无效。",
+    "Could not reset password because the token expired" : "无法重置密码，因为该令牌已过期。",
+    "Could not reset password because the token does not match" : "因令牌不符无法重置密码",
     "%s password changed successfully" : "%s 密码修改成功",
     "%s password reset" : "重置 %s 的密码",
     "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
-    "Couldn't send mail to following users: %s " : "无法发送邮件到用户: %s ",
+    "Download / View" : "下载 / 查看",
+    "Recipients can view or download contents." : "接收者可查看或下载内容。",
+    "Download / View / Upload" : "下载 / 查看 / 上传",
+    "Recipients can view, download and upload contents." : "接收者可查看、下载以及上传内容。",
+    "Download / View / Edit" : "下载 / 查看 / 编辑",
+    "Recipients can view, download, edit, delete and upload contents." : "接收者可查看、下载、编辑、删除以及上传内容。",
+    "Upload only" : "仅上传",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "从多个接收者处接收文件而不暴露文件夹中的内容。",
     "Preparing update" : "正在准备更新",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "修复警告：",
@@ -98,6 +106,7 @@ OC.L10N.register(
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已被加密。如果您没有启用恢复密钥，密码重置后您将无法取回您的文件。<br />在继续之前，如果有疑问请联系您的管理员。<br />确认继续？",
     "I know what I'm doing" : "我知道我在做什么",
     "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
+    "Error adding {addItem}: {addItem} already exists" : "添加{addItem}时发生错误：{addItem}已经存在",
     "No" : "否",
     "Yes" : "是",
     "Choose" : "选择",
@@ -130,6 +139,7 @@ OC.L10N.register(
     "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "反向代理头配置不正确，或者您正从一个受信任的代理访问ownCloud。如果你不是通过受信任的代理访问 ownCloud，这将引发一个安全问题，可能由于 ownCloud IP 地址可见导致欺骗攻击。更多信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>。",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached 配置为分布式缓存，但是已经安装的 PHP 模块是 \"memcache\" 。 \\OC\\Memcache\\Memcached 仅支持 \"memcached\" 而不是 \"memcache\"。点击 <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\"> memcached wiki 了解两个模块的不同</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "一些文件没有通过完整性检查。如何解决此问题的详细信息可以查看我们的 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">文档</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">无效文件列表…</a> / <a href=\"{rescanEndpoint}\">重新扫描…</a>)",
+    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "你在以 DEBUG 模式运行，这可能导致意外的副作用。请从 \"config.php\" 文件中移除 \"debug\" 标识。",
     "Error occurred while checking server setup" : "当检查服务器启动时出错",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "你的数据目录和你的文件可能从互联网被访问到。.htaccess 文件不工作。我们强烈建议你配置你的网页服务器，使数据目录不再可访问，或者将数据目录移动到网页服务器根文档目录之外。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 头部没有配置和 \"{expected}\" 的一样。这是一个潜在的安全或者隐私风险，我们调整这项设置。",
@@ -141,48 +151,50 @@ OC.L10N.register(
     "Error while sharing" : "共享时出错",
     "Error while unsharing" : "取消共享时出错",
     "The public link will expire no later than {days} days after it is created" : "这个共享链接将在创建后 {days} 天失效",
-    "Set expiration date" : "设置过期日期",
     "Expiration" : "过期",
-    "Expiration date" : "过期日期",
+    "Choose an expiration date" : "选择过期日期",
     "Expiration date is required" : "到期日期为必填",
     "Delete {link}" : "删除 {link}",
     "Remove link" : "移除链接",
-    "{fileName} link" : "{fileName} 链接",
     "Link" : "链接",
     "Create public link" : "创建公共链接",
     "Edit" : "编辑",
     "Remove" : "移除",
-    "Click to copy to clipboard" : "点击复制到剪贴板 ",
+    "Copy to clipboard" : "复制到剪贴板 ",
     "Social share" : "社交分享",
     "There are currently no link shares, you can create one" : "目前没有共享链接，您可以创建一个",
+    "Anyone with the link has access to the file/folder" : "任何查看此链接的人都可以访问文件、文件夹",
     "Copied!" : "已复制！",
     "Not supported!" : "不支持！",
     "Press ⌘-C to copy." : "按⌘-C复制",
     "Press Ctrl-C to copy." : "按Ctrl-C复制",
-    "Choose a password for the public link" : "为共享链接设置密码",
+    "Choose a password" : "选择一个密码",
     "Password required" : "要求输入密码",
+    "Link name" : "链接名称",
+    "Name" : "名称",
     "Filename" : "文件名",
     "Password" : "密码",
-    "Name" : "名称",
-    "Allow editing" : "允许编辑",
+    "Can not remove required password" : "无法移除要求的密码",
     "Edit link share: {name}" : "编辑共享链接： {name}",
-    "Save" : "保存",
     "Create link share: {name}" : "创建共享链接： {name}",
+    "Share" : "分享",
+    "Save" : "保存",
     "Remove password" : "去除密码",
     "Share to Twitter. Opens in a new window." : "分享到Twitter。在新窗口中打开。",
     "Share to Facebook. Opens in a new window." : "分享到Facebook。在新窗口中打开。",
     "Share to Diaspora. Opens in a new window." : "分享到Diaspora。在新窗口中打开。",
     "Share to Google+. Opens in a new window." : "分享到Google+。在新窗口中打开。",
     "Share via email. Opens your mail client." : "通过邮件分享。打开邮件客户端。",
-    "Error while sending notification" : "发送通知时出现错误",
-    "Sending ..." : "正在发送...",
-    "Email sent" : "邮件已发送",
     "Email link to person" : "发送链接到个人",
+    "Send copy to self" : "发送副本给自己。",
     "Send link via email" : "通过邮件发送链接",
+    "Add personal message" : "增加个人信息",
+    "Sending" : "发送中",
+    "E-Mail sent" : "邮件已发送",
     "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 组",
     "Shared with you by {owner}" : "{owner} 与您共享",
     "group" : "群组",
-    "remote" : "远程",
+    "federated" : "联合",
     "notify by email" : "以邮件通知",
     "Unshare" : "取消共享",
     "can share" : "可共享",
@@ -192,27 +204,31 @@ OC.L10N.register(
     "delete" : "删除",
     "access control" : "访问控制",
     "Could not unshare" : "无法共享",
+    "Email notification was sent!" : "电子邮件通知已发送！",
+    "Email notification not sent" : "电子邮件通知未发送",
     "Share details could not be loaded for this item." : "无法加载这个项目的分享详情",
     "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
     "No users found for {search}" : "没有找到 {search} 用户",
+    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["请输入至少 {chars} 字符作为建议"],
     "An error occurred. Please try again" : "发生错误。请重试。",
-    "{sharee} (group)" : "{sharee} (组)",
-    "{sharee} (at {server})" : "{sharee} (位于 {server})",
-    "{sharee} (remote)" : "{sharee} (远程)",
-    "Share" : "分享",
+    "User" : "用户",
+    "Group" : "群组",
+    "Guest" : "访客",
+    "At {server}" : "位于 {server}",
+    "Federated" : "联合",
     "User and Groups" : "用户和组",
     "Public Links" : "公共链接",
-    "Resharing is not allowed" : "不允许二次共享",
+    "Sharing is not allowed" : "禁止分享",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "使用语法 username@example.com/owncloud 分享给其他 ownCloud 上的用户",
     "Share with users…" : "与用户分享...",
     "Share with users, groups or remote users…" : "与用户，组或远程用户分享...",
     "Share with users or groups…" : "与用户或组分享...",
     "Share with users or remote users…" : "与用户或远程用户分享...",
     "Error removing share" : "移除分享时出错",
-    "Warning" : "警告",
     "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
     "restricted" : "受限",
     "invisible" : "不可见",
+    "Static" : "静态的",
     "({scope})" : "({scope})",
     "Delete" : "删除",
     "Rename" : "重命名",
@@ -252,11 +268,12 @@ OC.L10N.register(
     "You can click here to return to %s." : "你可以点击这里返回 %s。",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "嗨、你好,\n\n只想让你知道 %s 分享了 %s 给你。\n现在查看: %s\n",
     "The share will expire on %s." : "此分享将在 %s 过期。",
+    "Personal note from the sender: \n %s." : "来自发送者的个人留言：\n %s.",
     "Cheers!" : "干杯！",
     "Internal Server Error" : "内部服务器错误",
     "The server encountered an internal error and was unable to complete your request." : "服务器发送一个内部错误并且无法完成你的请求。",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "请联系服务器管理员，如果多次出现这个错误，请把下面的技术细节包含在您的报告里。",
-    "More details can be found in the server log." : "更多细节能在服务器日志中找到。",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "如果此错误多次复现请联系服务器管理员，并在报告中包含以下技术细节。",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "更多细节可在 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">服务器日志</a>找到。",
     "Technical details" : "技术细节",
     "Remote Address: %s" : "远程地址： %s",
     "Request ID: %s" : "请求 ID: %s",
@@ -266,6 +283,8 @@ OC.L10N.register(
     "File: %s" : "文件: %s",
     "Line: %s" : "行: %s",
     "Trace" : "追踪",
+    "Imprint" : "版本说明",
+    "Privacy Policy" : "隐私政策",
     "Create an <strong>admin account</strong>" : "创建<strong>管理员账号</strong>",
     "Username" : "用户名",
     "Storage & database" : "存储 & 数据库",
@@ -290,23 +309,27 @@ OC.L10N.register(
     "See the documentation" : "查看文档",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "嗨、你好,<br><br>只想让你知道 %s 分享了 <strong>%s</strong> 给你。<br><a href=\"%s\">现在查看！</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用要求 JavaScript 。请 {linkstart} 打开 JavaScript {linkend} ，然后重新载入页面。",
+    "Menu" : "菜单",
     "Log out" : "注销",
     "Search" : "搜索",
     "Server side authentication failed!" : "服务端验证失败！",
     "Please contact your administrator." : "请联系你的管理员。",
     "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系管理员。",
+    "Login" : "登录",
     "Username or email" : "用户名或邮箱",
-    "Log in" : "登录",
     "Wrong password. Reset it?" : "密码错误。要重置么？",
     "Wrong password." : "密码错误",
+    "You are trying to access a private link. Please log in first." : "您在尝试访问私有链接，请先登录。",
     "Stay logged in" : "保持登录",
     "Alternative Logins" : "其他登录方式",
     "Use the following link to reset your password: {link}" : "使用以下链接重置您的密码：{link}",
     "Password changed successfully" : "密码已成功修改",
     "New password" : "新密码",
     "New Password" : "新密码",
+    "Confirm Password" : "确认密码",
     "Reset password" : "重置密码",
+    "Personal note from the sender: <br> %s." : "来自发送者的个人留言：<br> %s.",
     "This ownCloud instance is currently in single user mode." : "当前ownCloud实例运行在单用户模式下。",
     "This means only administrators can use the instance." : "这意味着只有管理员才能在实例上操作。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系你的系统管理员。",
@@ -317,9 +340,8 @@ OC.L10N.register(
     "Please authenticate using the selected factor." : "请使用所选择的因素验证。",
     "An error occurred while verifying the token" : "在验证令牌时出错",
     "You are accessing the server from an untrusted domain." : "您正在访问来自不信任域名的服务器。",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "请联系你的系统管理员。如果你是系统管理员，配置 config/config.php 文件中参数 \"trusted_domain\" 设置。可以在 config/config.sample.php 文件中找到例子。",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "基于你的配置，作为系统管理员，你可能还能点击下面的按钮来信任这个域。",
-    "Add \"%s\" as trusted domain" : "添加 \"%s\"为信任域",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "请联系你的系统管理员。如果你是系统管理员，配置 config/config.php 文件中参数 \"trusted_domain\" 设置。",
+    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "一个示例配置在 config/config.sample.php 文件或 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>中有提供。",
     "App update required" : "必须的应用更新",
     "%s will be updated to version %s" : "%s 将会更新至版本 %s",
     "These apps will be updated:" : "以下应用将被更新：",
@@ -329,23 +351,10 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为进行避免较大的安装时超时，你可以在你的安装目录下运行下面的命令：",
     "Detailed logs" : "详细日志",
     "Update needed" : "需要更新",
-    "Please use the command line updater because you have a big instance." : "请使用命令行更新。",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "您的实例可能包含较多文件和/或用户，为保证更新过程流畅，请使用命令行更新工具 (occ upgrade)。",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "自动更新在 config.php 中被禁用，请使用命令行更新工具 (occ upgrade) 升级您的实例。",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "该 %s 实例当前处于维护模式，这将进行一些时间。",
-    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。",
-    "Could not reset password because the token is invalid" : "无法重置密码，因为该令牌无效。",
-    "Could not reset password because the token expired" : "无法重置密码，因为该令牌已过期。",
-    "Could not reset password because the token does not match" : "因令牌不符无法重置密码",
-    "Copy to clipboard" : "复制到剪贴板 ",
-    "Anyone with the link has access to the file/folder" : "任何查看此链接的人都可以访问文件、文件夹",
-    "Upload only" : "仅上传",
-    "Sending" : "发送中",
-    "Menu" : "菜单",
-    "Link name" : "链接名称",
-    "Owner: {owner}" : "所有者：{owner}",
-    "You are trying to access a private link. Please log in first." : "您在尝试访问私有链接，请先登录。",
-    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "您的实例可能包含较多文件和/或用户，为保证更新过程流畅，请使用命令行更新工具 (occ upgrade)。",
-    "Couldn't send mail to following recipient(s): %s " : "无法发送邮件到下列收件人: %s ",
-    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "自动更新在 config.php 中被禁用，请使用命令行更新工具 (occ upgrade) 升级您的实例。"
+    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。"
 },
 "nplurals=1; plural=0;");
