@@ -54,6 +54,7 @@
  *
  */
 
+use OC\Autoloader;
 use OCP\IRequest;
 
 require_once 'public/Constants.php';
@@ -102,7 +103,7 @@ class OC {
 	public static $CLI = false;
 
 	/**
-	 * @var \OC\Autoloader $loader
+	 * @var Autoloader $loader
 	 */
 	public static $loader = null;
 
@@ -124,16 +125,16 @@ class OC {
 	 * the app path list is empty or contains an invalid path
 	 */
 	public static function initPaths() {
-		if(defined('PHPUNIT_CONFIG_DIR')) {
+		if (\defined('PHPUNIT_CONFIG_DIR')) {
 			self::$configDir = OC::$SERVERROOT . '/' . PHPUNIT_CONFIG_DIR . '/';
-		} elseif(defined('PHPUNIT_RUN') and PHPUNIT_RUN and is_dir(OC::$SERVERROOT . '/tests/config/')) {
+		} elseif (\defined('PHPUNIT_RUN') and PHPUNIT_RUN and \is_dir(OC::$SERVERROOT . '/tests/config/')) {
 			self::$configDir = OC::$SERVERROOT . '/tests/config/';
 		} else {
 			self::$configDir = OC::$SERVERROOT . '/config/';
 		}
 		self::$config = new \OC\Config(self::$configDir);
 
-		OC::$SUBURI = str_replace("\\", "/", substr(realpath($_SERVER["SCRIPT_FILENAME"]), strlen(OC::$SERVERROOT)));
+		OC::$SUBURI = \str_replace("\\", "/", \substr(\realpath($_SERVER["SCRIPT_FILENAME"]), \strlen(OC::$SERVERROOT)));
 		/**
 		 * FIXME: The following lines are required because we can't yet instantiiate
 		 *        \OC::$server->getRequest() since \OC::$server does not yet exist.
@@ -144,25 +145,31 @@ class OC {
 				'SCRIPT_FILENAME' => $_SERVER['SCRIPT_FILENAME'],
 			],
 		];
-		$fakeRequest = new \OC\AppFramework\Http\Request($params, null, new \OC\AllConfig(new \OC\SystemConfig(self::$config)));
+		/**
+		 * The event dispatcher added here will not be used to listen any event.
+		 * So if the modifications made in the configuration, by fakeRequest
+		 * will not throw events.
+		 */
+		$fakeRequest = new \OC\AppFramework\Http\Request($params, null,
+			new \OC\AllConfig(new \OC\SystemConfig(self::$config),
+				new \Symfony\Component\EventDispatcher\EventDispatcher()));
 		$scriptName = $fakeRequest->getScriptName();
-		if (substr($scriptName, -1) == '/') {
+		if (\substr($scriptName, -1) == '/') {
 			$scriptName .= 'index.php';
 			//make sure suburi follows the same rules as scriptName
-			if (substr(OC::$SUBURI, -9) != 'index.php') {
-				if (substr(OC::$SUBURI, -1) != '/') {
+			if (\substr(OC::$SUBURI, -9) != 'index.php') {
+				if (\substr(OC::$SUBURI, -1) != '/') {
 					OC::$SUBURI = OC::$SUBURI . '/';
 				}
 				OC::$SUBURI = OC::$SUBURI . 'index.php';
 			}
 		}
 
-
 		if (OC::$CLI) {
 			OC::$WEBROOT = self::$config->getValue('overwritewebroot', '');
 		} else {
-			if (substr($scriptName, 0 - strlen(OC::$SUBURI)) === OC::$SUBURI) {
-				OC::$WEBROOT = substr($scriptName, 0, 0 - strlen(OC::$SUBURI));
+			if (\substr($scriptName, 0 - \strlen(OC::$SUBURI)) === OC::$SUBURI) {
+				OC::$WEBROOT = \substr($scriptName, 0, 0 - \strlen(OC::$SUBURI));
 
 				if (OC::$WEBROOT != '' && OC::$WEBROOT[0] !== '/') {
 					OC::$WEBROOT = '/' . OC::$WEBROOT;
@@ -177,9 +184,9 @@ class OC {
 
 			// Resolve /owncloud to /owncloud/ to ensure to always have a trailing
 			// slash which is required by URL generation.
-			if($_SERVER['REQUEST_URI'] === \OC::$WEBROOT &&
-					substr($_SERVER['REQUEST_URI'], -1) !== '/') {
-				header('Location: '.\OC::$WEBROOT.'/');
+			if ($_SERVER['REQUEST_URI'] === \OC::$WEBROOT &&
+					\substr($_SERVER['REQUEST_URI'], -1) !== '/') {
+				\header('Location: '.\OC::$WEBROOT.'/');
 				exit();
 			}
 		}
@@ -188,17 +195,17 @@ class OC {
 		$config_paths = self::$config->getValue('apps_paths', []);
 		if (!empty($config_paths)) {
 			foreach ($config_paths as $paths) {
-				if (isset($paths['url']) && isset($paths['path'])) {
-					$paths['url'] = rtrim($paths['url'], '/');
-					$paths['path'] = rtrim($paths['path'], '/');
+				if (isset($paths['url'], $paths['path'])) {
+					$paths['url'] = \rtrim($paths['url'], '/');
+					$paths['path'] = \rtrim($paths['path'], '/');
 					OC::$APPSROOTS[] = $paths;
 				}
 			}
-		} elseif (file_exists(OC::$SERVERROOT . '/apps')) {
+		} elseif (\file_exists(OC::$SERVERROOT . '/apps')) {
 			OC::$APPSROOTS[] = ['path' => OC::$SERVERROOT . '/apps', 'url' => '/apps', 'writable' => true];
-		} elseif (file_exists(OC::$SERVERROOT . '/../apps')) {
+		} elseif (\file_exists(OC::$SERVERROOT . '/../apps')) {
 			OC::$APPSROOTS[] = [
-				'path' => rtrim(dirname(OC::$SERVERROOT), '/') . '/apps',
+				'path' => \rtrim(\dirname(OC::$SERVERROOT), '/') . '/apps',
 				'url' => '/apps',
 				'writable' => true
 			];
@@ -211,16 +218,16 @@ class OC {
 		$paths = [];
 		foreach (OC::$APPSROOTS as $path) {
 			$paths[] = $path['path'];
-			if (!is_dir($path['path'])) {
-				throw new \RuntimeException(sprintf('App directory "%s" not found! Please put the ownCloud apps folder in the'
+			if (!\is_dir($path['path'])) {
+				throw new \RuntimeException(\sprintf('App directory "%s" not found! Please put the ownCloud apps folder in the'
 					. ' ownCloud folder or the folder above. You can also configure the location in the'
 					. ' config.php file.', $path['path']));
 			}
 		}
 
 		// set the right include path
-		set_include_path(
-			implode(PATH_SEPARATOR, $paths)
+		\set_include_path(
+			\implode(PATH_SEPARATOR, $paths)
 		);
 	}
 
@@ -229,15 +236,14 @@ class OC {
 
 		// Create config if it does not already exist
 		$configFilePath = self::$configDir .'/config.php';
-		if(!file_exists($configFilePath)) {
-			@touch($configFilePath);
+		if (!\file_exists($configFilePath)) {
+			@\touch($configFilePath);
 		}
 
 		// Check if config is writable
-		$configFileWritable = is_writable($configFilePath);
+		$configFileWritable = \is_writable($configFilePath);
 		if (!$configFileWritable && !\OC::$server->getConfig()->isSystemConfigReadOnly()
 			|| !$configFileWritable && self::checkUpgrade(false)) {
-
 			$urlGenerator = \OC::$server->getURLGenerator();
 
 			if (self::$CLI) {
@@ -245,7 +251,7 @@ class OC {
 				echo $l->t('This can usually be fixed by giving the webserver write access to the config directory')."\n";
 				echo "\n";
 				echo $l->t('See %s', [ $urlGenerator->linkToDocs('admin-dir_permissions') ])."\n";
-				exit;
+				exit(1);
 			} else {
 				OC_Template::printErrorPage(
 					$l->t('Cannot write into "config" directory!'),
@@ -258,7 +264,7 @@ class OC {
 	}
 
 	public static function checkInstalled() {
-		if (defined('OC_CONSOLE')) {
+		if (\defined('OC_CONSOLE')) {
 			return;
 		}
 		// Redirect to installer if not installed
@@ -267,7 +273,7 @@ class OC {
 				throw new Exception('Not installed');
 			} else {
 				$url = OC::$WEBROOT . '/index.php';
-				header('Location: ' . $url);
+				\header('Location: ' . $url);
 			}
 			exit();
 		}
@@ -279,8 +285,8 @@ class OC {
 	 */
 	public static function checkMaintenanceMode(IRequest $request) {
 		// Check if requested URL matches 'index.php/occ'
-		$isOccControllerRequested = preg_match('|/index\.php$|', $request->getScriptName()) === 1
-				&& strpos($request->getPathInfo(), '/occ/') === 0;
+		$isOccControllerRequested = \preg_match('|/index\.php$|', $request->getScriptName()) === 1
+				&& \strpos($request->getPathInfo(), '/occ/') === 0;
 		// Allow ajax update script to execute without being stopped
 		if (
 			\OC::$server->getSystemConfig()->getValue('maintenance', false)
@@ -288,9 +294,9 @@ class OC {
 			&& !$isOccControllerRequested
 		) {
 			// send http status 503
-			header('HTTP/1.1 503 Service Temporarily Unavailable');
-			header('Status: 503 Service Temporarily Unavailable');
-			header('Retry-After: 120');
+			\http_response_code(503);
+			\header('Status: 503 Service Temporarily Unavailable');
+			\header('Retry-After: 120');
 
 			// render error page
 			$template = new OC_Template('', 'update.user', 'guest');
@@ -311,14 +317,14 @@ class OC {
 				return;
 			}
 		} else {
-			if(!$lockIfNoUserLoggedIn) {
+			if (!$lockIfNoUserLoggedIn) {
 				return;
 			}
 		}
 		// send http status 503
-		header('HTTP/1.1 503 Service Temporarily Unavailable');
-		header('Status: 503 Service Temporarily Unavailable');
-		header('Retry-After: 120');
+		\http_response_code(503);
+		\header('Status: 503 Service Temporarily Unavailable');
+		\header('Retry-After: 120');
 
 		// render error page
 		$template = new OC_Template('', 'singleuser.user', 'guest');
@@ -363,9 +369,9 @@ class OC {
 		}
 		if ($disableWebUpdater || $tooBig) {
 			// send http status 503
-			header('HTTP/1.1 503 Service Temporarily Unavailable');
-			header('Status: 503 Service Temporarily Unavailable');
-			header('Retry-After: 120');
+			\http_response_code(503);
+			\header('Status: 503 Service Temporarily Unavailable');
+			\header('Retry-After: 120');
 
 			// render error page
 			$template = new OC_Template('', 'update.use-cli', 'guest');
@@ -379,10 +385,10 @@ class OC {
 
 		// check whether this is a core update or apps update
 		$installedVersion = $systemConfig->getValue('version', '0.0.0');
-		$currentVersion = implode('.', \OCP\Util::getVersion());
+		$currentVersion = \implode('.', \OCP\Util::getVersion());
 
 		// if not a core upgrade, then it's apps upgrade
-		$isAppsOnlyUpgrade = (version_compare($currentVersion, $installedVersion, '='));
+		$isAppsOnlyUpgrade = (\version_compare($currentVersion, $installedVersion, '='));
 
 		$oldTheme = $systemConfig->getValue('theme');
 		$systemConfig->setValue('theme', '');
@@ -392,6 +398,7 @@ class OC {
 
 		/** @var \OC\App\AppManager $appManager */
 		$appManager = \OC::$server->getAppManager();
+		'@phan-var \OC\App\AppManager $appManager';
 
 		$tmpl = new OC_Template('', 'update.admin', 'guest');
 		$tmpl->assign('version', OC_Util::getVersionString());
@@ -406,13 +413,6 @@ class OC {
 	}
 
 	public static function initSession() {
-		// prevents javascript from accessing php session cookies
-		ini_set('session.cookie_httponly', true);
-
-		// set the cookie path to the ownCloud directory
-		$cookie_path = OC::$WEBROOT ? : '/';
-		ini_set('session.cookie_path', $cookie_path);
-
 		// Let the session name be changed in the initSession Hook
 		$sessionName = OC_Util::getInstanceId();
 
@@ -441,22 +441,32 @@ class OC {
 
 		$sessionLifeTime = self::getSessionLifeTime();
 
-		// session timeout
-		if ($session->exists('LAST_ACTIVITY') && (time() - $session->get('LAST_ACTIVITY') > $sessionLifeTime)) {
-			if (isset($_COOKIE[session_name()])) {
-				setcookie(session_name(), null, -1, self::$WEBROOT ? : '/');
+		if (!$session->exists('LAST_ACTIVITY')) {
+			// if this is a new session, invalidate any previously stored auth token.
+			// this could happen if the session disappears / expires in the server but the user
+			// didn't log out explicitly
+			if (\OC::$server->getUserSession() !== null) {
+				// web installer doesn't have a valid userSession at this point
+				\OC::$server->getUserSession()->invalidateSessionToken();
+			}
+		} else {
+			if (\time() - $session->get('LAST_ACTIVITY') > $sessionLifeTime) {
+				// session timeout
+				\OC::$server->getUserSession()->logout();
+				if (isset($_COOKIE[\session_name()])) {
+					\setcookie(\session_name(), null, -1, self::$WEBROOT ? : '/');
+				}
 			}
-			\OC::$server->getUserSession()->logout();
 		}
 
-		$session->set('LAST_ACTIVITY', time());
+		$session->set('LAST_ACTIVITY', \time());
 	}
 
 	/**
 	 * @return string
 	 */
 	private static function getSessionLifeTime() {
-		return \OC::$server->getConfig()->getSystemValue('session_lifetime', 60 * 60 * 24);
+		return \OC::$server->getConfig()->getSystemValue('session_lifetime', 60 * 20);
 	}
 
 	public static function loadAppClassPaths() {
@@ -467,7 +477,7 @@ class OC {
 			}
 
 			$file = $appPath . '/appinfo/classpath.php';
-			if (file_exists($file)) {
+			if (\file_exists($file)) {
 				require_once $file;
 			}
 		}
@@ -477,32 +487,22 @@ class OC {
 	 * Try to set some values to the required ownCloud default
 	 */
 	public static function setRequiredIniValues() {
-		@ini_set('default_charset', 'UTF-8');
-		@ini_set('gd.jpeg_ignore_warning', 1);
+		@\ini_set('default_charset', 'UTF-8');
+		@\ini_set('gd.jpeg_ignore_warning', 1);
 	}
 
 	public static function init() {
 		// calculate the root directories
-		OC::$SERVERROOT = str_replace("\\", '/', substr(__DIR__, 0, -4));
+		OC::$SERVERROOT = \str_replace("\\", '/', \substr(__DIR__, 0, -4));
 
 		// register autoloader
-		$loaderStart = microtime(true);
-		require_once __DIR__ . '/autoloader.php';
-		self::$loader = new \OC\Autoloader([
-			OC::$SERVERROOT . '/lib/private/legacy',
-		]);
-		if (defined('PHPUNIT_RUN')) {
-			self::$loader->addValidRoot(OC::$SERVERROOT . '/tests');
-		}
-		spl_autoload_register([self::$loader, 'load']);
-		$loaderEnd = microtime(true);
-
-		self::$CLI = (in_array(php_sapi_name(), ['cli', 'phpdbg']));
+		$loaderStart = \microtime(true);
+		self::$CLI = (\in_array(\php_sapi_name(), ['cli', 'phpdbg']));
 
 		// setup 3rdparty autoloader
 		$vendorAutoLoad = OC::$SERVERROOT . '/lib/composer/autoload.php';
-		if (!file_exists($vendorAutoLoad)) {
-			printf('Composer autoloader not found, unable to continue. Please run "make".');
+		if (!\file_exists($vendorAutoLoad)) {
+			\printf('Composer autoloader not found, unable to continue. Please run "make".');
 			exit();
 		}
 
@@ -512,6 +512,12 @@ class OC {
 			print('Composer autoloader not found!');
 			exit();
 		}
+		self::$loader = new Autoloader();
+		if (\defined('PHPUNIT_RUN')) {
+			self::$loader->addValidRoot(OC::$SERVERROOT . '/tests');
+		}
+		\spl_autoload_register([self::$loader, 'load']);
+		$loaderEnd = \microtime(true);
 
 		try {
 			self::initPaths();
@@ -519,12 +525,12 @@ class OC {
 			if (!self::$CLI) {
 				// can`t use OC_Response::setStatus because server is not
 				// initialized here
-				http_response_code(OC_Response::STATUS_SERVICE_UNAVAILABLE);
+				\http_response_code(OC_Response::STATUS_SERVICE_UNAVAILABLE);
 			}
 			// we can't use the template error page here, because this needs the
 			// DI container which isn't available yet
 			print($e->getMessage());
-			exit();
+			exit(1);
 		}
 
 		// setup the basic server
@@ -533,11 +539,11 @@ class OC {
 		\OC::$server->getEventLogger()->start('boot', 'Initialize');
 
 		// Don't display errors and log them
-		error_reporting(E_ALL | E_STRICT);
-		@ini_set('display_errors', 0);
-		@ini_set('log_errors', 1);
+		\error_reporting(E_ALL | E_STRICT);
+		@\ini_set('display_errors', 0);
+		@\ini_set('log_errors', 1);
 
-		if(!date_default_timezone_set('UTC')) {
+		if (!\date_default_timezone_set('UTC')) {
 			\OC::$server->getLogger()->error('Could not set timezone to UTC');
 		};
 
@@ -546,41 +552,39 @@ class OC {
 		//Let´s try to overwrite some defaults anyway
 
 		//try to set the maximum execution time to 60min
-		@set_time_limit(3600);
-		@ini_set('max_execution_time', 3600);
-		@ini_set('max_input_time', 3600);
+		@\set_time_limit(3600);
+		@\ini_set('max_execution_time', 3600);
+		@\ini_set('max_input_time', 3600);
 
 		//try to set the maximum filesize to 10G
-		@ini_set('upload_max_filesize', '10G');
-		@ini_set('post_max_size', '10G');
-		@ini_set('file_uploads', '50');
+		@\ini_set('upload_max_filesize', '10G');
+		@\ini_set('post_max_size', '10G');
+		@\ini_set('file_uploads', '50');
 
 		self::setRequiredIniValues();
 		self::handleAuthHeaders();
 		self::registerAutoloaderCache();
 
-		// initialize intl fallback is necessary
-		\Patchwork\Utf8\Bootup::initIntl();
 		OC_Util::isSetLocaleWorking();
 
-		if (!defined('PHPUNIT_RUN')) {
+		if (!\defined('PHPUNIT_RUN')) {
 			OC\Log\ErrorHandler::setLogger(\OC::$server->getLogger());
 			$debug = \OC::$server->getConfig()->getSystemValue('debug', false);
 			OC\Log\ErrorHandler::register($debug);
 		}
 
 		// register the stream wrappers
-		stream_wrapper_register('fakedir', 'OC\Files\Stream\Dir');
-		stream_wrapper_register('static', 'OC\Files\Stream\StaticStream');
-		stream_wrapper_register('close', 'OC\Files\Stream\Close');
-		stream_wrapper_register('quota', 'OC\Files\Stream\Quota');
+		\stream_wrapper_register('fakedir', 'OC\Files\Stream\Dir');
+		\stream_wrapper_register('static', 'OC\Files\Stream\StaticStream');
+		\stream_wrapper_register('close', 'OC\Files\Stream\Close');
+		\stream_wrapper_register('quota', 'OC\Files\Stream\Quota');
 
 		\OC::$server->getEventLogger()->start('init_session', 'Initialize session');
-		OC_App::loadApps(['session']);
+		OC_App::loadApps(['session', 'theme']);
 		if (!self::$CLI) {
-			\OC_App::loadApps(['theme']);
 			self::initSession();
 		}
+		OC_App::loadApps(['license']);
 
 		\OC::$server->getEventLogger()->end('init_session');
 
@@ -592,13 +596,10 @@ class OC {
 		self::checkInstalled();
 
 		OC_Response::addSecurityHeaders();
-		if(self::$server->getRequest()->getServerProtocol() === 'https') {
-			ini_set('session.cookie_secure', true);
-		}
 
-		if (!defined('OC_CONSOLE')) {
+		if (!\defined('OC_CONSOLE')) {
 			$errors = OC_Util::checkServer(\OC::$server->getConfig());
-			if (count($errors) > 0) {
+			if (\count($errors) > 0) {
 				if (self::$CLI) {
 					// Convert l10n string into regular string for usage in database
 					$staticErrors = [];
@@ -612,7 +613,7 @@ class OC {
 					}
 
 					try {
-						\OC::$server->getConfig()->setAppValue('core', 'cronErrors', json_encode($staticErrors));
+						\OC::$server->getConfig()->setAppValue('core', 'cronErrors', \json_encode($staticErrors));
 					} catch (\Exception $e) {
 						echo('Writing to database failed');
 					}
@@ -630,10 +631,6 @@ class OC {
 		// set back user
 		\OC::$server->getSession()->set('user_id', $uid);
 
-		//try to set the session lifetime
-		$sessionLifeTime = self::getSessionLifeTime();
-		@ini_set('gc_maxlifetime', (string)$sessionLifeTime);
-
 		$systemConfig = \OC::$server->getSystemConfig();
 
 		// User and Groups
@@ -673,16 +670,20 @@ class OC {
 		}
 
 		//make sure temporary files are cleaned up
-		$tmpManager = \OC::$server->getTempManager();
-		register_shutdown_function([$tmpManager, 'clean']);
-		$lockProvider = \OC::$server->getLockingProvider();
-		register_shutdown_function([$lockProvider, 'releaseAll']);
+		\OC::$server->getShutdownHandler()->register(function () {
+			$tmpManager = \OC::$server->getTempManager();
+			$tmpManager->clean();
+		});
+		\OC::$server->getShutdownHandler()->register(function () {
+			$lockProvider = \OC::$server->getLockingProvider();
+			$lockProvider->releaseAll();
+		});
 
 		// Check whether the sample configuration has been copied
-		if($systemConfig->getValue('copied_sample_config', false)) {
+		if ($systemConfig->getValue('copied_sample_config', false)) {
 			$l = \OC::$server->getL10N('lib');
-			header('HTTP/1.1 503 Service Temporarily Unavailable');
-			header('Status: 503 Service Temporarily Unavailable');
+			\http_response_code(503);
+			\header('Status: 503 Service Temporarily Unavailable');
 			OC_Template::printErrorPage(
 				$l->t('Sample configuration detected'),
 				$l->t('It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php')
@@ -703,8 +704,8 @@ class OC {
 			&& !\OC::$server->getTrustedDomainHelper()->isTrustedDomain($host)
 			&& self::$server->getConfig()->getSystemValue('installed', false)
 		) {
-			header('HTTP/1.1 400 Bad Request');
-			header('Status: 400 Bad Request');
+			\http_response_code(400);
+			\header('Status: 400 Bad Request');
 
 			\OC::$server->getLogger()->warning(
 					'Trusted domain error. "{remoteAddress}" tried to access using "{host}" as host.',
@@ -756,7 +757,9 @@ class OC {
 
 	private static function registerEncryptionHooks() {
 		$enabled = self::$server->getEncryptionManager()->isEnabled();
-		if ($enabled) {
+		//Call share hooks if they are not masterkey
+		if ($enabled &&
+			(\OC::$server->getConfig()->getAppValue('encryption', 'useMasterKey', '0') === '0')) {
 			\OCP\Util::connectHook('OCP\Share', 'post_shared', 'OC\Encryption\HookManager', 'postShared');
 			\OCP\Util::connectHook('OCP\Share', 'post_unshare', 'OC\Encryption\HookManager', 'postUnshared');
 			\OCP\Util::connectHook('OC_Filesystem', 'post_rename', 'OC\Encryption\HookManager', 'postRename');
@@ -821,6 +824,7 @@ class OC {
 		if ($instanceId) {
 			try {
 				$memcacheFactory = \OC::$server->getMemCacheFactory();
+				'@phan-var \OC\MemCache\Factory $memcacheFactory';
 				self::$loader->setMemoryCache($memcacheFactory->createLocal('Autoloader'));
 			} catch (\Exception $ex) {
 			}
@@ -831,7 +835,6 @@ class OC {
 	 * Handle the request
 	 */
 	public static function handleRequest() {
-
 		\OC::$server->getEventLogger()->start('handle_request', 'Handle request');
 		$systemConfig = \OC::$server->getSystemConfig();
 		// load all the classpaths from the enabled apps so they are available
@@ -852,12 +855,12 @@ class OC {
 
 		$request = \OC::$server->getRequest();
 		// Check if requested URL matches 'index.php/occ'
-		$isOccControllerRequested = preg_match('|/index\.php$|', $request->getScriptName()) === 1
-			&& strpos($request->getPathInfo(), '/occ/') === 0;
+		$isOccControllerRequested = \preg_match('|/index\.php$|', $request->getScriptName()) === 1
+			&& \strpos($request->getPathInfo(), '/occ/') === 0;
 
 		$needUpgrade = false;
 		$requestPath = $request->getRawPathInfo();
-		if (substr($requestPath, -3) !== '.js') { // we need these files during the upgrade
+		if (\substr($requestPath, -3) !== '.js') { // we need these files during the upgrade
 			self::checkMaintenanceMode($request);
 			$needUpgrade = self::checkUpgrade(!$isOccControllerRequested);
 		}
@@ -881,7 +884,7 @@ class OC {
 			// Always load authentication apps
 			OC_App::loadApps(['authentication']);
 		} catch (\OC\NeedsUpdateException $e) {
-			if ($isOccControllerRequested && $needUpgrade){
+			if ($isOccControllerRequested && $needUpgrade) {
 				OC::$server->getRouter()->match(\OC::$server->getRequest()->getRawPathInfo());
 				return;
 			}
@@ -893,7 +896,7 @@ class OC {
 			&& !$systemConfig->getValue('maintenance', false)) {
 			// For logged-in users: Load everything
 			$userSession = \OC::$server->getUserSession();
-			if($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
+			if ($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
 				OC_App::loadApps();
 			} else {
 				// For guests: Load only filesystem and logging
@@ -912,13 +915,13 @@ class OC {
 				OC::$server->getRouter()->match(\OC::$server->getRequest()->getRawPathInfo());
 				return;
 			} catch (\OC\NeedsUpdateException $e) {
-				if ($isOccControllerRequested && $needUpgrade){
+				if ($isOccControllerRequested && $needUpgrade) {
 					OC::$server->getRouter()->match(\OC::$server->getRequest()->getRawPathInfo());
 					return;
 				}
 				throw $e;
 			} catch (Symfony\Component\Routing\Exception\ResourceNotFoundException $e) {
-				//header('HTTP/1.0 404 Not Found');
+				//http_response_code(404);
 			} catch (Symfony\Component\Routing\Exception\MethodNotAllowedException $e) {
 				OC_Response::setStatus(405);
 				return;
@@ -930,13 +933,13 @@ class OC {
 			// not allowed any more to prevent people
 			// mounting this root directly.
 			// Users need to mount remote.php/webdav instead.
-			header('HTTP/1.1 405 Method Not Allowed');
-			header('Status: 405 Method Not Allowed');
+			\http_response_code(405);
+			\header('Status: 405 Method Not Allowed');
 			return;
 		}
 
 		// Someone is logged in
-		if($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
+		if ($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
 			OC_App::loadApps();
 			OC_User::setupBackends();
 			OC_Util::setupFS();
@@ -945,7 +948,7 @@ class OC {
 			OC_Util::redirectToDefaultPage();
 		} else {
 			// Not handled and not logged in
-			header('Location: '.\OC::$server->getURLGenerator()->linkToRouteAbsolute('core.login.showLoginForm'));
+			\header('Location: '.\OC::$server->getURLGenerator()->linkToRouteAbsolute('core.login.showLoginForm'));
 		}
 	}
 
@@ -955,7 +958,7 @@ class OC {
 	 * @param OCP\IRequest $request
 	 * @return boolean
 	 */
-	static function handleLogin(OCP\IRequest $request) {
+	public static function handleLogin(OCP\IRequest $request) {
 		$userSession = self::$server->getUserSession();
 		if (OC_User::handleApacheAuth()) {
 			return true;
@@ -984,14 +987,72 @@ class OC {
 			'REDIRECT_HTTP_AUTHORIZATION', // apache+php-cgi alternative
 		];
 		foreach ($vars as $var) {
-			if (isset($_SERVER[$var]) && preg_match('/Basic\s+(.*)$/i', $_SERVER[$var], $matches)) {
-				list($name, $password) = explode(':', base64_decode($matches[1]), 2);
+			if (isset($_SERVER[$var]) && \preg_match('/Basic\s+(.*)$/i', $_SERVER[$var], $matches)) {
+				list($name, $password) = \explode(':', \base64_decode($matches[1]), 2);
 				$_SERVER['PHP_AUTH_USER'] = $name;
 				$_SERVER['PHP_AUTH_PW'] = $password;
 				break;
 			}
 		}
 	}
+
+	/**
+	 * Log an ownCloud's crash. This means that ownCloud isn't usable and can't log through
+	 * normal ownCloud's logger facilities.
+	 * This crash log can't use the normal "owncloud.log" file because the ownCloud's logger
+	 * requires additional context that can't be easily replicated. We'll use a different file.
+	 * The crash log will create a "crash-Y-m-d.log" file in the ownCloud's data directory, unless
+	 * the "crashdirectory" is set in the config.php file (make sure the "crashdirectory" exists and
+	 * it's writeable for the web server). The filename will be reused for all the crashes that happen
+	 * during the same day, and a new one will be used the next day.
+	 * The crash file will be created only if needed.
+	 *
+	 * Note: This is mainly for internal purposes. You're encouraged to use the ownCloud's logger
+	 * for anything you need to log.
+	 *
+	 * @param Throwable $ex
+	 */
+	public static function crashLog(\Throwable $ex): void {
+		$crashDir = self::$SERVERROOT . '/data';
+		if (self::$config) {
+			$dataDir = self::$config->getValue('datadirectory', self::$SERVERROOT . '/data');
+			$crashDir = self::$config->getValue('crashdirectory', $dataDir);
+		}
+
+		$filename = "${crashDir}/crash-" . \date('Y-m-d') . '.log';
+
+		$date = \date('c');
+		$currentEntryId = \uniqid(\md5($date), true);
+		$entry = [
+			'date' => $date,
+			'parentId' => null,
+			'id' => $currentEntryId,
+			'class' => \get_class($ex),
+			'message' => $ex->getMessage(),
+			'stacktrace' => \array_map(static function ($elem) {
+				unset($elem['args'], $elem['type']);
+				return $elem;
+			}, $ex->getTrace()),
+		];
+		\file_put_contents($filename, \json_encode($entry, JSON_PRETTY_PRINT) . PHP_EOL, FILE_APPEND | LOCK_EX);
+
+		while (($ex = $ex->getPrevious()) !== null) {
+			$previousEntryId = $currentEntryId;
+			$currentEntryId = \uniqid(\md5($date), true);
+			$entry = [
+				'date' => $date,
+				'parentId' => $previousEntryId,
+				'id' => $currentEntryId,
+				'class' => \get_class($ex),
+				'message' => $ex->getMessage(),
+				'stacktrace' => \array_map(static function ($elem) {
+					unset($elem['args'], $elem['type']);
+					return $elem;
+				}, $ex->getTrace()),
+			];
+			\file_put_contents($filename, \json_encode($entry, JSON_PRETTY_PRINT) . PHP_EOL, FILE_APPEND | LOCK_EX);
+		}
+	}
 }
 
 OC::init();
