@@ -44,6 +44,7 @@ OC.L10N.register(
     "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
+    "__language_name__" : "Castellano",
     "App directory already exists" : "El directorio de la aplicación ya existe",
     "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
     "Archive does not contain a directory named %s" : "El archivo no contiene un directorio llamado %s",
@@ -55,10 +56,11 @@ OC.L10N.register(
     "App does not provide an info.xml file" : "La aplicación no suministra un fichero info.xml",
     "App cannot be installed because appinfo file cannot be read." : "La app no puede ser instalada debido a que no se puede leer la información de la app.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma no pudo ser evaluada. Por favor, contacte con el desarrollador de la aplicación y compruebe su pantalla de administración.",
-    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
     "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "La App no se puede instalar debido a que la versión de info.xml no es la misma que la versión reportada por la App Store.",
+    "No license key available." : "La Clave de licencia no está disponible",
+    "Invalid license key!" : "La clave de licencia no es válida",
     "Apps" : "Aplicaciones",
     "General" : "General",
     "Storage" : "Almacenamiento",
@@ -68,13 +70,12 @@ OC.L10N.register(
     "Workflows & Tags" : "Workflows & Tags",
     "Sharing" : "Compartiendo",
     "Search" : "Buscar",
-    "Updates" : "Actualizaciones",
     "Help & Tips" : "Ayuda & Trucos",
     "Additional" : "Adicional",
     "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
     "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
     "%s enter the database name." : "%s ingresar el nombre de la base de datos",
-    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
+    "%s enter the database name or connection string." : "%s introduzca el nombre de la base de datos o cadena de conexión.",
     "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
     "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
     "DB Error: \"%s\"" : "Error BD: \"%s\"",
@@ -82,17 +83,22 @@ OC.L10N.register(
     "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
     "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsela bajo su propio riesgo! ",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s No está soportado y %s no funcionará adecuadamente en esta plataforma . Use bajo su propia responsabilidad.",
     "For the best results, please consider using a GNU/Linux server instead." : "Para resultados óptimos, considere utilizar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con arhivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
     "Set an admin username." : "Configurar un nombre de usuario del administrador",
     "Set an admin password." : "Configurar la contraseña del administrador.",
     "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
+    "Can't create or write into the apps-external directory %s" : "No puedo crear o escribir en la carpeta externa %s",
+    "Can't update %s - it is a directory" : "No es posible actualizar %s -  es una carpeta",
+    "Can't update %s" : "No se puede actualizar %s",
     "Invalid Federated Cloud ID" : "ID Nube federada inválida",
+    "Internal mail notification for shared files is not allowed" : "No se permite la notificación por correo interno para archivos compartidos",
     "%s shared »%s« with you" : "%s ha compartido »%s« contigo",
+    "Public link mail notification is not allowed" : "No se permite la notificación por correo de enlaces públicos",
     "%s via %s" : "%s vía %s",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "No se pudo compartir %s porque el repositorio no permite recursos compartidos del tipo %i",
+    "Sharing %s failed, because the backend does not allow shares from type %d" : "Compartir %s ha fallado porque el mecanismo no permite compartidos del tipo %d",
     "Sharing %s failed, because the file does not exist" : "No se pudo compartir %s porque el archivo no existe",
     "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
     "Sharing %s failed, because you can not share with yourself" : "Se falló al compartir %s, porque no puedes compartir contigo mismo",
@@ -105,7 +111,7 @@ OC.L10N.register(
     "You need to provide a password to create a public link, only protected links are allowed" : "Es necesario definir una contraseña para crear un enlace publico. Solo los enlaces protegidos están permitidos",
     "Sharing %s failed, because sharing with links is not allowed" : "Se falló al compartir %s, ya que no está permitida la compartición con enlaces",
     "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se falló al compartir %s. No se pudo hallar %s, quizás haya un problema de conexión con el servidor.",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Compartir%s ha fallado, no encuentro %s, revise lo escrito y/o que el servidor este disponible..",
     "Share type %s is not valid for %s" : "Compartir tipo %s no es válido para %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "La configuración de permisos para %s ha fallado, ya que los permisos superan los permisos dados a %s",
     "Setting permissions for %s failed, because the item was not found" : "La configuración de permisos para %s ha fallado, ya que no se encontró el elemento ",
@@ -120,34 +126,37 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Fallo al compartir %s, ya que no está permitido volverlo a compartir",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se ha fallado al compartir %s porque el motor compartido para %s podría no encontrar su origen",
     "Sharing %s failed, because the file could not be found in the file cache" : "Se ha fallado al compartir %s, ya que el archivo no pudo ser encontrado en el cache de archivo",
-    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
-    "Files can't be shared with delete permissions" : "Los archivos no pueden ser compartidos con permisos de borrado",
-    "Files can't be shared with create permissions" : "Los arhivos no pueden ser compartidos con permisos de creación",
+    "Invalid permissions" : "Permisos no válidos",
+    "Cannot remove all permissions" : "No puedo eliminar todos los permisos",
+    "Cannot set the requested share permissions for %s" : "No se pudieron establecer los permisos para compartir %s",
+    "Cannot set the requested share attributes for %s" : "No se pudieron establecer los atributos de la compartición para %s",
     "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
     "Cannot set expiration date more than %s days in the future" : "No se puede fijar la fecha de caducidad más de %s días en el futuro.",
     "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "Solo se permiten los siguientes caracteres en el nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"",
     "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
     "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
+    "The username must be at least 3 characters long" : "El nombre de usuario debe tener al menos 3 carácteres",
+    "The username can not be longer than 64 characters" : "El nombre de usuario no puede tener mas de 64 caracteres,",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "The username is already being used" : "El nombre de usuario ya está en uso",
     "Login canceled by app" : "Login cancelado por la app",
     "User disabled" : "Usuario deshabilitado",
-    "Help" : "Ayuda",
     "Settings" : "Ajustes",
     "Users" : "Usuarios",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La app \"%s\" no puede instalarse porque las siguientes dependencias no están cumplimentadas: %s",
-    "web services under your control" : "Servicios web bajo su control",
+    "A safe home for all your data" : "Un lugar seguro para todos sus datos",
+    "Imprint" : "Imprimir",
+    "Privacy Policy" : "Política de privacidad",
     "File is currently busy, please try again later" : "Archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
-    "Can't read file" : "No se puede leer archivo",
+    "Access to this resource or one of its sub-items has been denied." : "El acceso a este recurso o uno de sus sub-elementos ha sido denegado.",
+    "File cannot be downloaded" : "El archivo no puede ser descargado",
     "Application is not enabled" : "La aplicación no está habilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "Token expirado. Por favor, recarge la página.",
     "Unknown user" : "Usuario desconocido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
     "Cannot write into \"config\" directory" : "No se puede escribir el el directorio de configuración",
-    "Cannot write into \"apps\" directory" : "No se puede escribir en el directorio de \"apps\"",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto puede solucionarse fácilmente %sdándole permisos de escritura al servidor en el directorio%s de apps o deshabilitando la tienda de apps en el archivo de configuración.",
     "Cannot create \"data\" directory" : "No puedo crear del directorio \"data\"",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Normalmente esto se puede solucionar  <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dándole al servidor web permisos de escritura en todo el directorio o el directorio 'root'</a>",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Los permisos normalmente puede solucionarse %sdándole al servidor permisos de escritura del directorio raíz%s.",
@@ -173,16 +182,13 @@ OC.L10N.register(
     "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
     "Your Data directory  is invalid" : "El directorio de datos no es válido",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifique que el directorio de datos contiene un archivo \".ocdata\" en su directorio raíz.",
+    "User unknown" : "Usuario desconocido",
     "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
     "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
     "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
     "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamiento no se encuentra disponible temporalmente",
     "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
-    "A safe home for all your data" : "Un lugar seguro para todos sus datos",
-    "The username must be at least 3 characters long" : "El nombre de usuario debe tener al menos 3 carácteres",
-    "File cannot be read" : "El archivo no se puede leer",
-    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s No está soportado y %s no funcionará adecuadamente en esta plataforma . Use bajo su propia responsabilidad.",
-    "Sharing %s failed, could not find %s, check spelling and server availability." : "Compartir%s ha fallado, no encuentro %s, revise lo escrito y/o que el servidor este disponible.."
+    "\"%s\" is locked" : "\"%s\" está bloqueado"
 },
 "nplurals=2; plural=(n != 1);");
