@@ -38,6 +38,7 @@ OC.L10N.register(
     "4-byte characters are not supported in file names" : "Znaki 4-bajtowe są niedozwolone w nazwach plików",
     "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
     "File name is too long" : "Nazwa pliku zbyt długa",
+    "__language_name__" : "polski",
     "App directory already exists" : "Katalog aplikacji już isnieje",
     "Can't create app folder. Please fix permissions. %s" : "Nie mogę utworzyć katalogu aplikacji. Proszę popraw uprawnienia. %s",
     "Archive does not contain a directory named %s" : "Archiwum nie zawiera ścieżki o nazwie %s",
@@ -48,7 +49,6 @@ OC.L10N.register(
     "Failed to open archive when installing app" : "Nie udało się otworzyć archiwum podczas instalacji aplikacji",
     "App does not provide an info.xml file" : "Aplikacja nie posiada pliku info.xml",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Sygnatura nie mogła zostać sprawdzona. Proszę o skontaktownie się z twórcą aplikacji i sprawdzenie panelu administratora.",
-    "App can't be installed because of not allowed code in the App" : "Aplikacja nie może być zainstalowany ponieważ nie dopuszcza kod w aplikacji",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikacja nie może zostać zainstalowana ponieważ jest niekompatybilna z tą wersja ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikacja nie może być zainstalowana ponieważ true tag nie jest <shipped>true</shipped> , co nie jest dozwolone dla aplikacji nie wysłanych",
     "Apps" : "Aplikacje",
@@ -58,10 +58,10 @@ OC.L10N.register(
     "Encryption" : "Szyfrowanie",
     "Sharing" : "Udostępnianie",
     "Search" : "Wyszukaj",
-    "Updates" : "Aktualizacje",
+    "Help & Tips" : "Pomoc & Podpowiedzi",
+    "Additional" : "Dodatki",
     "%s enter the database username." : "%s wpisz nazwę użytkownika do  bazy",
     "%s enter the database name." : "%s wpisz nazwę bazy.",
-    "%s you may not use dots in the database name" : "%s nie można używać kropki w nazwie bazy danych",
     "Oracle connection could not be established" : "Nie można ustanowić połączenia z bazą Oracle",
     "Oracle username and/or password not valid" : "Oracle: Nazwa użytkownika i/lub hasło jest niepoprawne",
     "DB Error: \"%s\"" : "Błąd DB: \"%s\"",
@@ -69,13 +69,13 @@ OC.L10N.register(
     "You need to enter either an existing account or the administrator." : "Należy wprowadzić istniejące konto użytkownika lub  administratora.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Niepoprawne polecania:  \"%s\", nazwa: %s, hasło: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL: Nazwa użytkownika i/lub hasło jest niepoprawne",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz na własne ryzyko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepsze rezultaty, rozważ w to miejsce użycie serwera GNU/Linux.",
     "Set an admin username." : "Ustaw nazwę administratora.",
     "Set an admin password." : "Ustaw hasło administratora.",
     "Can't create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
     "Invalid Federated Cloud ID" : "Niewłaściwe ID stowarzyszonej chmury",
     "%s shared »%s« with you" : "%s Współdzielone »%s« z tobą",
+    "%s via %s" : "%s przez %s",
     "Sharing %s failed, because the file does not exist" : "Wspóldzielenie %s nie powiodło się. ponieważ plik nie istnieje",
     "You are not allowed to share %s" : "Nie masz uprawnień aby udostępnić %s",
     "Sharing %s failed, because the user %s does not exist" : "Współdzielenie %s nie powiodło się, ponieważ użytkownik %s nie istnieje",
@@ -85,7 +85,6 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Współdzielenie %s nie powiodło się, ponieważ %s nie jest członkiem grupy %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Musisz zapewnić hasło aby utworzyć link publiczny, dozwolone są tylko linki chronione",
     "Sharing %s failed, because sharing with links is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ współdzielenie z linkami nie jest dozwolone",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Współdzielenie %s nie powiodło się, nie można odnaleźć %s. Prawdopobnie serwer nie jest teraz osiągalny.",
     "Share type %s is not valid for %s" : "Typ udziału %s nie jest właściwy dla %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ uprawnienia wykraczają poza przydzielone %s",
     "Setting permissions for %s failed, because the item was not found" : "Ustawienie uprawnień dla %s nie powiodło się, ponieważ element nie został znaleziony",
@@ -98,25 +97,24 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Współdzielenie %s nie powiodło się, ponieważ ponowne współdzielenie nie jest dozwolone",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Współdzielenie %s nie powiodło się, ponieważ zaplecze współdzielenia dla %s nie mogło znaleźć jego źródła",
     "Sharing %s failed, because the file could not be found in the file cache" : "Współdzielenie %s nie powiodło się, ponieważ plik nie może zostać odnaleziony w buforze plików",
+    "Cannot remove all permissions" : "Nie można usunąć wszystkich uprawnień",
     "Could not find category \"%s\"" : "Nie można odnaleźć kategorii \"%s\"",
     "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
     "A valid password must be provided" : "Należy podać prawidłowe hasło",
     "The username is already being used" : "Ta nazwa użytkownika jest już używana",
     "User disabled" : "Użytkownik zablokowany",
-    "Help" : "Pomoc",
     "Settings" : "Ustawienia",
     "Users" : "Użytkownicy",
-    "web services under your control" : "Kontrolowane serwisy",
+    "A safe home for all your data" : "Bezpieczne miejsce dla wszystkich Twoich danych",
+    "Imprint" : "Stopka",
+    "Privacy Policy" : "Polityka prywatności",
     "File is currently busy, please try again later" : "Plik jest obecnie niedostępny, proszę spróbować ponownie później",
-    "Can't read file" : "Nie można odczytać pliku.",
     "Application is not enabled" : "Aplikacja nie jest włączona",
     "Authentication error" : "Błąd uwierzytelniania",
     "Token expired. Please reload page." : "Token wygasł. Proszę ponownie załadować stronę.",
     "Unknown user" : "Nieznany użytkownik",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Brak sterowników bazy danych (sqlite, mysql or postgresql).",
     "Cannot write into \"config\" directory" : "Nie można zapisać do katalogu \"config\"",
-    "Cannot write into \"apps\" directory" : "Nie można zapisać do katalogu \"apps\"",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Można to zwykle rozwiązać przez %sdodanie serwerowi www uprawnień zapisu do katalogu apps%s lub wyłączenie appstore w pliku konfiguracyjnym.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Problemy z uprawnieniami można zwykle naprawić  przez %sdodanie serwerowi www uprawnień zapisu do katalogu głównego%s.",
     "Setting locale to %s failed" : "Nie udało się zmienić języka na %s",
     "Please install one of these locales on your system and restart your webserver." : "Proszę zainstalować jedno z poniższych locale w Twoim systemie i uruchomić ponownie serwer www.",
@@ -129,10 +127,8 @@ OC.L10N.register(
     "Please upgrade your database version" : "Uaktualnij wersję bazy danych",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, żeby ukryć zawartość katalogu przed innymi użytkownikami.",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Sprawdź, czy katalog danych zawiera plik \".ocdata\".",
+    "User unknown" : "Nieznany użytkownik",
     "Could not obtain lock type %d on \"%s\"." : "Nie można uzyskać blokady typu %d na \"%s\".",
-    "Storage is temporarily not available" : "Składowisko danych tymczasowo niedostępne",
-    "Help & Tips" : "Pomoc & Podpowiedzi",
-    "Additional" : "Dodatki",
-    "A safe home for all your data" : "Bezpieczne miejsce dla wszystkich Twoich danych"
+    "Storage is temporarily not available" : "Składowisko danych tymczasowo niedostępne"
 },
-"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
+"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
