@@ -44,6 +44,7 @@ OC.L10N.register(
     "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
     "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido",
     "File name is too long" : "O nome do arquivo é muito longo",
+    "__language_name__" : "__language_name__",
     "App directory already exists" : "Diretório App  já existe",
     "Can't create app folder. Please fix permissions. %s" : "Não é possível criar pasta app. Corrija as permissões. %s",
     "Archive does not contain a directory named %s" : "O arquivo não contém um diretório chamado %s",
@@ -55,10 +56,18 @@ OC.L10N.register(
     "App does not provide an info.xml file" : "O aplicativo não fornece um arquivo info.xml",
     "App cannot be installed because appinfo file cannot be read." : "O App não pode ser instalado porque o arquivo appinfo não pode ser lido.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "A assinatura não pode ser verificada. Por favor entre em contato com o desenvolvedor do aplicativo e verificar sua tela de administração.",
-    "App can't be installed because of not allowed code in the App" : "O aplicativo não pode ser instalado por causa do código não permitido no Aplivativo",
     "App can't be installed because it is not compatible with this version of ownCloud" : "O aplicativo não pode ser instalado porque não é compatível com esta versão do ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "O aplicativo não pode ser instalado porque ele contém a marca <shipped>verdadeiro</shipped> que não é permitido para aplicações não embarcadas",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "O aplicativo não pode ser instalado porque a versão em info.xml não é o mesmo que a versão relatada na App Store",
+    "No license key available." : "Nenhuma chave de licença disponível.",
+    "Invalid license key!" : "Chave de licença inválida!",
+    "Please contact your administrator or %s for a new license key." : "Entre em contato com seu administrador %s para uma nova chave de licença.",
+    "Your Enterprise license key has expired." : "Sua chave de licença corporativa expirou.",
+    "Enterprise features have been disabled." : "Os recursos da empresa foram desativados.",
+    "Evaluation - expires in %d days." : "Avaliação - expira em %d dias.",
+    "Your Enterprise license key is about to expire (days remaining: %d)." : "Sua chave de licença Enterprise está prestes a expirar (dias restantes: %d).",
+    "The registered enterprise license key expires in %d days" : "A chave de licença corporativa registrada expira em %d dias",
+    "New Design" : "Novo Design",
     "Apps" : "Aplicações",
     "General" : "Geral",
     "Storage" : "Armazenamento",
@@ -68,13 +77,12 @@ OC.L10N.register(
     "Workflows & Tags" : "Fluxos de Trabalho & Etiquetas",
     "Sharing" : "Compartilhamento",
     "Search" : "Pesquisar",
-    "Updates" : "Atualizações",
     "Help & Tips" : "Ajuda & Dicas",
     "Additional" : "Adicional",
     "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
     "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
     "%s enter the database name." : "%s insira o nome do banco de dados.",
-    "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
+    "%s enter the database name or connection string." : "%s insira o nome do banco de dados ou a string de conexão.",
     "Oracle connection could not be established" : "Conexão Oracle não pode ser estabelecida",
     "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválido(s)",
     "DB Error: \"%s\"" : "Erro no BD: \"%s\"",
@@ -82,17 +90,22 @@ OC.L10N.register(
     "You need to enter either an existing account or the administrator." : "Você precisa inserir uma conta existente ou a do administrador.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Comando ofensivo era: \"%s\", nome: %s, senha: %s",
     "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválido(s)",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco. ",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter os melhores resultados, por favor, considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32bit e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente desencorajado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou altere o PHP para 64bit.",
     "Set an admin username." : "Defina um nome do usuário administrador.",
     "Set an admin password." : "Defina uma senha de administrador.",
     "Can't create or write into the data directory %s" : "Não é possível criar ou gravar no diretório de dados %s",
+    "Can't create or write into the apps-external directory %s" : "Não é possível criar ou gravar no diretório apps-external %s",
+    "Can't update %s - it is a directory" : "Não é possível atualizar %s - isto é um diretório",
+    "Can't update %s" : "Não consigo atualizar %s",
     "Invalid Federated Cloud ID" : "Associação Inválida de Nuvem ID",
+    "Internal mail notification for shared files is not allowed" : "Notificação de correio interno para arquivos compartilhados não é permitida",
     "%s shared »%s« with you" : "%s compartilhou »%s« com você",
+    "Public link mail notification is not allowed" : "Notificação de correio de linque público não é permitida",
     "%s via %s" : "%s via %s",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "O compartilhamento %s falhou, porque o processo interno não permite ações de tipo %i",
+    "Sharing %s failed, because the backend does not allow shares from type %d" : "O compartilhamento de %s falhou porque o back-end não permite compartilhamentos do tipo %d",
     "Sharing %s failed, because the file does not exist" : "Compartilhamento %s falhou, porque o arquivo não existe",
     "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
     "Sharing %s failed, because you can not share with yourself" : "O compartilhamento %s falhou, porque você não pode compartilhar com você mesmo",
@@ -105,7 +118,7 @@ OC.L10N.register(
     "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
     "Sharing %s failed, because sharing with links is not allowed" : "Compartilhamento %s falhou, porque compartilhamento com links não é permitido",
     "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou, porque não foi possível encontrar %s, talvez o servidor esteja inacessível.",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "O compartilhamento  %s falhou, não foi possível encontrar %s, verifique o que foi digitado e a disponibilidade do servidor.",
     "Share type %s is not valid for %s" : "Tipo de compartilhamento %s não é válido para %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Definir permissões para %s falhou, porque as permissões excedem as permissões concedidas a %s",
     "Setting permissions for %s failed, because the item was not found" : "Definir permissões para %s falhou, porque o item não foi encontrado",
@@ -120,34 +133,37 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Compartilhamento %s falhou, porque recompartilhamentos não são permitidos",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartilhamento %s falhou, porque a infra-estrutura de compartilhamento para %s não conseguiu encontrar a sua fonte",
     "Sharing %s failed, because the file could not be found in the file cache" : "Compartilhamento %s falhou, porque o arquivo não pôde ser encontrado no cache de arquivos",
-    "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
-    "Files can't be shared with delete permissions" : "Os arquivos não podem ser compartilhadas com permissões de exclusão",
-    "Files can't be shared with create permissions" : "Os arquivos não podem ser compartilhados com permissões de criação",
+    "Invalid permissions" : "Permissões inválidas",
+    "Cannot remove all permissions" : "Não é possível remover todas as permissões",
+    "Cannot set the requested share permissions for %s" : "Não é possível definir as permissões de compartilhamento solicitadas para %s",
+    "Cannot set the requested share attributes for %s" : "Não é possível definir os atributos de compartilhamento solicitados para %s",
     "Expiration date is in the past" : "Data de validade está ultrapassada",
     "Cannot set expiration date more than %s days in the future" : "Não é possível definir a data de validade mais de %s dias no futuro",
     "Could not find category \"%s\"" : "Impossível localizar categoria \"%s\"",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"",
     "A valid username must be provided" : "Forneça um nome de usuário válido",
     "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
+    "The username must be at least 3 characters long" : "O nome de usuário deve ter pelo menos 3 caracteres",
+    "The username can not be longer than 64 characters" : "O nome de usuário não pode ter mais de 64 caracteres",
     "A valid password must be provided" : "Forneça uma senha válida",
     "The username is already being used" : "Este nome de usuário já está sendo usado",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
     "User disabled" : "Usuário desativado",
-    "Help" : "Ajuda",
     "Settings" : "Configurações",
     "Users" : "Usuários",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" não pode ser instalado porque as seguintes dependências não foram cumpridas: %s",
-    "web services under your control" : "serviços web sob seu controle",
+    "A safe home for all your data" : "Um lugar seguro para todos os seus dados",
+    "Imprint" : "Imprimir",
+    "Privacy Policy" : "Política de Privacidade",
     "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
-    "Can't read file" : "Não é possível ler arquivo",
+    "Access to this resource or one of its sub-items has been denied." : "O acesso a este recurso ou a um dos seus subitens foi negado.",
+    "File cannot be downloaded" : "Não é possível baixar o arquivo",
     "Application is not enabled" : "Aplicação não está habilitada",
     "Authentication error" : "Erro de autenticação",
     "Token expired. Please reload page." : "Token expirou. Por favor recarregue a página.",
     "Unknown user" : "Usuário desconhecido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql, or postgresql) instalado.",
     "Cannot write into \"config\" directory" : "Não é possível gravar no diretório \"config\"",
-    "Cannot write into \"apps\" directory" : "Não é possível gravar no diretório \"apps\"",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Isto pode ser corrigido dando ao webserver permissão de escrita %sgiving para o diretório apps directory%s ou desabilitando o appstore no arquivo de configuração.",
     "Cannot create \"data\" directory" : "Não é possível criar o diretório \"data\"",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Esta geralmente pode ser fixado por <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dando permissão de gravação ao diretório raiz do servidor</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Permissões podem ser corrigidas dando permissão de escita %sgiving ao webserver para o diretório raiz directory%s",
@@ -173,16 +189,13 @@ OC.L10N.register(
     "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"diretóriodedados\" na sua configuração",
     "Your Data directory  is invalid" : "Seu diretório de Dados é inválido",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Por favor, verifique se o diretório de dados contém um arquivo \".ocdata\" em sua raiz.",
+    "User unknown" : "Usuário desconhecido",
     "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
     "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
     "Storage incomplete configuration. %s" : "Incompleta configuração de armazenamento. %s",
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
     "Storage connection timeout. %s" : "Tempo limite de conexão de armazenamento. %s",
-    "A safe home for all your data" : "Um lugar seguro para todos os seus dados",
-    "The username must be at least 3 characters long" : "O nome de usuário deve ter pelo menos 3 caracteres",
-    "File cannot be read" : "O arquivo não pode ser lido",
-    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco. ",
-    "Sharing %s failed, could not find %s, check spelling and server availability." : "O compartilhamento  %s falhou, não foi possível encontrar %s, verifique o que foi digitado e a disponibilidade do servidor."
+    "\"%s\" is locked" : "\"%s\" está bloqueado"
 },
 "nplurals=2; plural=(n > 1);");
