@@ -44,6 +44,7 @@ OC.L10N.register(
     "File name is a reserved word" : "Имя файла является зарезервированным словом",
     "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один некорректный символ",
     "File name is too long" : "Имя файла слишком длинное.",
+    "__language_name__" : "Русский",
     "App directory already exists" : "Каталог приложения уже существует",
     "Can't create app folder. Please fix permissions. %s" : "Не удалось создать каталог приложения. Исправьте права доступа. %s",
     "Archive does not contain a directory named %s" : "Архив не содержит папки с именем %s",
@@ -55,10 +56,18 @@ OC.L10N.register(
     "App does not provide an info.xml file" : "Приложение не имеет файла info.xml",
     "App cannot be installed because appinfo file cannot be read." : "Приложение не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Подпись не может быть проверена. Пожалуйста, свяжитесь с разработчиком приложения и проверьте свою страницу администратора.",
-    "App can't be installed because of not allowed code in the App" : "Приложение невозможно установить. В нем содержится запрещенный код.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Приложение невозможно установить. Не совместимо с текущей версией ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Приложение невозможно установить. Оно содержит параметр <shipped>true</shipped> который не допустим для приложений, не входящих в поставку.",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Приложение невозможно установить. Версия в файле info.xml не совпадает с версией заявленной в магазине приложений",
+    "No license key available." : "Лицензионный ключе недоступен.",
+    "Invalid license key!" : "Неправильный лицензионный ключ!",
+    "Please contact your administrator or %s for a new license key." : "Пожалуйста, свяжитесь с вашим администратором, или %s, чтобы получить новый лицензионный ключ.",
+    "Your Enterprise license key has expired." : "Ваш лицензионный ключ для Enterprise устарел.",
+    "Enterprise features have been disabled." : "Возможности Enterprise были отключены.",
+    "Evaluation - expires in %d days." : "Пробный период истекает через %d дней.",
+    "Your Enterprise license key is about to expire (days remaining: %d)." : "Ваш лицензионный ключ для Enterprise скоро устареет (осталось дней: %d).",
+    "The registered enterprise license key expires in %d days" : "Зарегистрированный лицензионный ключ для Enterprise устареет через %d days",
+    "New Design" : "Новый дизайн",
     "Apps" : "Приложения",
     "General" : "Основные",
     "Storage" : "Хранилище",
@@ -68,13 +77,12 @@ OC.L10N.register(
     "Workflows & Tags" : "Рабочие процессы и метки",
     "Sharing" : "Общий доступ",
     "Search" : "Найти",
-    "Updates" : "Обновления",
     "Help & Tips" : "Помощь и советы",
     "Additional" : "Дополнительно",
     "%s enter the database username and name." : "%s укажите имя пользователя и название для базы данных.",
     "%s enter the database username." : "%s введите имя пользователя базы данных.",
     "%s enter the database name." : "%s введите имя базы данных.",
-    "%s you may not use dots in the database name" : "%s Вы не можете использовать точки в имени базы данных",
+    "%s enter the database name or connection string." : "1%s введите название базы данных или строку подключения",
     "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
     "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
     "DB Error: \"%s\"" : "Ошибка БД: \"%s\"",
@@ -82,17 +90,22 @@ OC.L10N.register(
     "You need to enter either an existing account or the administrator." : "Вы должны войти или в существующий аккаунт или под администратором.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Вызываемая команда была: \"%s\", имя: %s, пароль: %s",
     "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не поддерживается и %s может работать некорректно на данной платформе. Используйте на свой страх и риск!",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s не поддерживается и %s не будет работать правильно на этой платформе. Используйте на свой страх и риск! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Пожалуйста, удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
     "Set an admin username." : "Задать имя пользователя для администратора.",
     "Set an admin password." : "Задать пароль для admin.",
     "Can't create or write into the data directory %s" : "Невозможно создать или записать в каталог данных %s",
+    "Can't create or write into the apps-external directory %s" : "Не удалось создать или записать в каталоге внешних приложений %s",
+    "Can't update %s - it is a directory" : "Невозможно обновить %s - это каталог",
+    "Can't update %s" : "Не получается обновить %s",
     "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
+    "Internal mail notification for shared files is not allowed" : "Внутреннее уведомление почтой для совместного доступа к файлам не разрешено",
     "%s shared »%s« with you" : "%s поделился »%s« с вами",
+    "Public link mail notification is not allowed" : "Почтовые уведомления для общедоступных ссылок не разрешены",
     "%s via %s" : "%s через %s",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не удалось поделиться %s, так как механизм хранения не допускает публикации из элементов типа %i",
+    "Sharing %s failed, because the backend does not allow shares from type %d" : "Не удалось предоставить общий доступ к %s,  так как бэкенд не разрешает общий доступ для типа %d",
     "Sharing %s failed, because the file does not exist" : "Не удалось поделиться %s, файл не существует",
     "You are not allowed to share %s" : "Вам не разрешено делиться %s",
     "Sharing %s failed, because you can not share with yourself" : "Не удалось поделиться %s. Вы не можете поделиться с самим собой.",
@@ -105,7 +118,7 @@ OC.L10N.register(
     "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
     "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
     "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не удалось поделиться %s, не удалось найти %s, возможно, сервер не доступен.",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Не удалось предоставить доступ к %s, не удалось найти %s, проверьте написание и доступность сервера.",
     "Share type %s is not valid for %s" : "Тип общего доступа %s недопустим для %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Не удалось настроить права доступа для %s, указанные права доступа превышают предоставленные для %s",
     "Setting permissions for %s failed, because the item was not found" : "Не удалось настроить права доступа для %s, элемент не найден.",
@@ -120,34 +133,37 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Не удалось поделиться %s, повторное открытие доступа запрещено",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не удалось поделиться %s, бэкенд общего доступа не нашел путь до %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше.",
-    "Cannot increase permissions of %s" : "Невозможно увеличить права доступа для %s",
-    "Files can't be shared with delete permissions" : "Файлы не могут иметь общий доступ с правами на удаление",
-    "Files can't be shared with create permissions" : "Файлы не могут иметь общий доступ с правами на создание",
+    "Invalid permissions" : "Недопустимые права",
+    "Cannot remove all permissions" : "Не могу удалить все права",
+    "Cannot set the requested share permissions for %s" : "Не удалось получить запрошенные права доступа для %s",
+    "Cannot set the requested share attributes for %s" : "Не удалось установить запрошенные атрибуты общего доступа для %s",
     "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
     "Cannot set expiration date more than %s days in the future" : "Невозможно установить дату окончания срока действия более %s дней",
     "Could not find category \"%s\"" : "Категория \"%s\"  не найдена",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "В составе имени пользователя допускаются следующие символы: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "В имени пользователя допустимы только следующие символы: «a—z», «A—Z», «0—9», и «+_.@-'»",
     "A valid username must be provided" : "Укажите допустимое имя пользователя",
     "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
+    "The username must be at least 3 characters long" : "Имя пользователя должно быть не менее 3 символов в длину",
+    "The username can not be longer than 64 characters" : "Имя пользователя не может быть длиннее 64 символов",
     "A valid password must be provided" : "Укажите допустимый пароль",
     "The username is already being used" : "Имя пользователя уже используется",
     "Login canceled by app" : "Вход отменен приложением",
     "User disabled" : "Пользователь отключен",
-    "Help" : "Помощь",
     "Settings" : "Настройки",
     "Users" : "Пользователи",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложение \"%s\" не может быть установлено, так как следующие зависимости не выполнены: %s",
-    "web services under your control" : "веб-сервисы под вашим управлением",
+    "A safe home for all your data" : "Безопасный дом для всех ваших данных",
+    "Imprint" : "Штамп",
+    "Privacy Policy" : "Политика конфиденциальности",
     "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
-    "Can't read file" : "Не удается прочитать файл",
+    "Access to this resource or one of its sub-items has been denied." : "Запрещён доступ к этому ресурсу или к одному из его подчинённых элементов.",
+    "File cannot be downloaded" : "Скачать файл не удалось",
     "Application is not enabled" : "Приложение не разрешено",
     "Authentication error" : "Ошибка аутентификации",
     "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
     "Unknown user" : "Неизвестный пользователь",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
     "Cannot write into \"config\" directory" : "Запись в каталог \"config\" невозможна",
-    "Cannot write into \"apps\" directory" : "Запись в каталог \"app\" невозможна",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в каталог приложений%s или отключив магазин приложений в файле конфигурации.",
     "Cannot create \"data\" directory" : "Не могу создать каталог \"data\"",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Обычно это можно исправить <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">предоставив веб-серверу права на запись в корневом каталоге</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в корневой каталог%s.",
@@ -173,16 +189,13 @@ OC.L10N.register(
     "Check the value of \"datadirectory\" in your configuration" : "Проверьте значение \"datadirectory\" в настройках.",
     "Your Data directory  is invalid" : "Ваш каталог данных неверен",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Убедитесь, что файл \".ocdata\" присутствует в корне каталога данных.",
+    "User unknown" : "Пользователь неизвестен",
     "Could not obtain lock type %d on \"%s\"." : "Не удалось получить блокировку типа %d для \"%s\"",
     "Storage unauthorized. %s" : "Хранилище неавторизовано. %s",
     "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
     "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
     "Storage is temporarily not available" : "Хранилище временно не доступно",
     "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
-    "A safe home for all your data" : "Безопасный дом для всех ваших данных",
-    "The username must be at least 3 characters long" : "Имя пользователя должно быть не менее 3 символов в длину",
-    "File cannot be read" : "Невозможно прочитать файл",
-    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s не поддерживается и %s не будет работать правильно на этой платформе. Используйте на свой страх и риск! ",
-    "Sharing %s failed, could not find %s, check spelling and server availability." : "Не удалось предоставить доступ к %s, не удалось найти %s, проверьте написание и доступность сервера."
+    "\"%s\" is locked" : "«%s» заблокировано"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
