@@ -45,9 +45,9 @@
  *
  */
 use OC\App\DependencyAnalyzer;
-use OC\App\InfoParser;
 use OC\App\Platform;
 use OC\Installer;
+use OC\NeedsUpdateException;
 use OC\Repair;
 
 /**
@@ -56,14 +56,12 @@ use OC\Repair;
  * upgrading and removing apps.
  */
 class OC_App {
-	static private $appVersion = [];
-	static private $adminForms = [];
-	static private $personalForms = [];
-	static private $appInfo = [];
-	static private $appTypes = [];
-	static private $loadedApps = [];
-	static private $loadedTypes = [];
-	static private $altLogin = [];
+	private static $adminForms = [];
+	private static $personalForms = [];
+	private static $appTypes = [];
+	private static $loadedApps = [];
+	private static $loadedTypes = [];
+	private static $altLogin = [];
 	const officialApp = 200;
 	const approvedApp = 100;
 
@@ -74,7 +72,7 @@ class OC_App {
 	 * @return string
 	 */
 	public static function cleanAppId($app) {
-		return str_replace(['\0', '/', '\\', '..'], '', $app);
+		return \str_replace(['\0', '/', '\\', '..'], '', $app);
 	}
 
 	/**
@@ -84,7 +82,7 @@ class OC_App {
 	 * @return bool
 	 */
 	public static function isAppLoaded($app) {
-		return in_array($app, self::$loadedApps, true);
+		return \in_array($app, self::$loadedApps, true);
 	}
 
 	/**
@@ -100,7 +98,7 @@ class OC_App {
 	 * if $types is set, only apps of those types will be loaded
 	 */
 	public static function loadApps($types = null) {
-		if (is_array($types) && !array_diff($types, self::$loadedTypes)) {
+		if (\is_array($types) && !\array_diff($types, self::$loadedTypes)) {
 			return true;
 		}
 		if (\OC::$server->getSystemConfig()->getValue('maintenance', false)) {
@@ -110,32 +108,32 @@ class OC_App {
 		$apps = self::getEnabledApps();
 
 		// Add each apps' folder as allowed class path
-		foreach($apps as $app) {
+		foreach ($apps as $app) {
 			if (self::isAppLoaded($app)) {
 				continue;
 			}
 			$path = self::getAppPath($app);
-			if($path !== false) {
+			if ($path !== false) {
 				self::registerAutoloading($app, $path);
 			}
 		}
 
 		// prevent app.php from printing output
-		ob_start();
+		\ob_start();
 		foreach ($apps as $app) {
-			if ((is_null($types) or self::isType($app, $types)) && !in_array($app, self::$loadedApps)) {
+			if (($types === null or self::isType($app, $types)) && !\in_array($app, self::$loadedApps)) {
 				self::loadApp($app);
 			}
 		}
-		ob_end_clean();
+		\ob_end_clean();
 
 		// once all authentication apps are loaded we can validate the session
-		if (is_null($types) || in_array('authentication', $types)) {
+		if ($types === null || \in_array('authentication', $types)) {
 			if (\OC::$server->getUserSession()) {
 				$request = \OC::$server->getRequest();
 				$session = \OC::$server->getUserSession();
 				$davUser = \OC::$server->getUserSession()->getSession()->get(\OCA\DAV\Connector\Sabre\Auth::DAV_AUTHENTICATED);
-				if (is_null($davUser)) {
+				if ($davUser === null) {
 					$session->validateSession();
 				} else {
 					/** @var \OC\Authentication\Token\DefaultTokenProvider $tokenProvider */
@@ -158,8 +156,8 @@ class OC_App {
 				}
 			}
 		}
-		if (is_array($types)) {
-			self::$loadedTypes = array_merge(self::$loadedTypes, $types);
+		if (\is_array($types)) {
+			self::$loadedTypes = \array_merge(self::$loadedTypes, $types);
 		}
 
 		\OC_Hook::emit('OC_App', 'loadedApps');
@@ -171,12 +169,12 @@ class OC_App {
 	 *
 	 * @param string $app
 	 * @param bool $checkUpgrade whether an upgrade check should be done
-	 * @throws \OC\NeedsUpdateException
+	 * @throws NeedsUpdateException
 	 */
 	public static function loadApp($app, $checkUpgrade = true) {
 		self::$loadedApps[] = $app;
 		$appPath = self::getAppPath($app);
-		if($appPath === false) {
+		if ($appPath === false) {
 			return;
 		}
 
@@ -185,12 +183,26 @@ class OC_App {
 
 		self::enableThemeIfApplicable($app);
 
-		if (is_file($appPath . '/appinfo/app.php')) {
+		if (\is_file($appPath . '/appinfo/app.php')) {
 			\OC::$server->getEventLogger()->start('load_app_' . $app, 'Load app: ' . $app);
-			if ($checkUpgrade and self::shouldUpgrade($app)) {
-				throw new \OC\NeedsUpdateException();
+			if ($checkUpgrade && self::shouldUpgrade($app)) {
+				throw new NeedsUpdateException();
+			}
+			try {
+				self::requireAppFile($app);
+			} catch (Exception $ex) {
+				\OC::$server->getLogger()->logException($ex);
+				$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
+				if (!\in_array($app, $blacklist)) {
+					if (!self::isType($app, ['authentication', 'filesystem'])) {
+						\OC::$server->getLogger()->warning('Could not load app "' . $app . '", it will be disabled', ['app' => 'core']);
+						self::disable($app);
+					} else {
+						\OC::$server->getLogger()->warning('Could not load app "' . $app . '", see exception above', ['app' => 'core']);
+					}
+				}
+				throw $ex;
 			}
-			self::requireAppFile($app);
 			if (self::isType($app, ['authentication'])) {
 				// since authentication apps affect the "is app enabled for group" check,
 				// the enabled apps cache needs to be cleared to make sure that the
@@ -223,7 +235,7 @@ class OC_App {
 		// Register on PSR-4 composer autoloader
 		$appNamespace = \OC\AppFramework\App::buildAppNamespace($app);
 		\OC::$composerAutoloader->addPsr4($appNamespace . '\\', $path . '/lib/', true);
-		if (defined('PHPUNIT_RUN')) {
+		if (\defined('PHPUNIT_RUN')) {
 			\OC::$composerAutoloader->addPsr4($appNamespace . '\\Tests\\', $path . '/tests/', true);
 		}
 
@@ -237,22 +249,8 @@ class OC_App {
 	 * @param string $app app name
 	 */
 	private static function requireAppFile($app) {
-		try {
-			// encapsulated here to avoid variable scope conflicts
-			require_once $app . '/appinfo/app.php';
-		} catch (Exception $ex) {
-			\OC::$server->getLogger()->logException($ex);
-			$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
-			if (!in_array($app, $blacklist)) {
-				if (!self::isType($app, ['authentication', 'filesystem'])) {
-					\OC::$server->getLogger()->warning('Could not load app "' . $app . '", it will be disabled', array('app' => 'core'));
-					self::disable($app);
-				} else {
-					\OC::$server->getLogger()->warning('Could not load app "' . $app . '", see exception above', array('app' => 'core'));
-				}
-			}
-			throw $ex;
-		}
+		// encapsulated here to avoid variable scope conflicts
+		require_once self::getAppPath($app) . '/appinfo/app.php';
 	}
 
 	/**
@@ -263,12 +261,12 @@ class OC_App {
 	 * @return bool
 	 */
 	public static function isType($app, $types) {
-		if (is_string($types)) {
+		if (\is_string($types)) {
 			$types = [$types];
 		}
 		$appTypes = self::getAppTypes($app);
 		foreach ($types as $type) {
-			if (array_search($type, $appTypes) !== false) {
+			if (\array_search($type, $appTypes) !== false) {
 				return true;
 			}
 		}
@@ -283,12 +281,12 @@ class OC_App {
 	 */
 	private static function getAppTypes($app) {
 		//load the cache
-		if (count(self::$appTypes) == 0) {
+		if (\count(self::$appTypes) == 0) {
 			self::$appTypes = \OC::$server->getAppConfig()->getValues(false, 'types');
 		}
 
 		if (isset(self::$appTypes[$app])) {
-			return explode(',', self::$appTypes[$app]);
+			return \explode(',', self::$appTypes[$app]);
 		} else {
 			return [];
 		}
@@ -299,12 +297,12 @@ class OC_App {
 	 */
 	public static function setAppTypes($app) {
 		$appData = self::getAppInfo($app);
-		if(!is_array($appData)) {
+		if (!\is_array($appData)) {
 			return;
 		}
 
 		if (isset($appData['types'])) {
-			$appTypes = implode(',', $appData['types']);
+			$appTypes = \implode(',', $appData['types']);
 		} else {
 			$appTypes = '';
 		}
@@ -350,16 +348,16 @@ class OC_App {
 			$user = \OC::$server->getUserSession()->getUser();
 		}
 
-		if (is_null($user)) {
+		if ($user === null) {
 			$apps = $appManager->getInstalledApps();
 		} else {
 			$apps = $appManager->getEnabledAppsForUser($user);
 		}
-		$apps = array_filter($apps, function ($app) {
+		$apps = \array_filter($apps, function ($app) {
 			return $app !== 'files';//we add this manually
 		});
-		sort($apps);
-		array_unshift($apps, 'files');
+		\sort($apps);
+		\array_unshift($apps, 'files');
 		return $apps;
 	}
 
@@ -386,11 +384,20 @@ class OC_App {
 	 * This function set an app as enabled in appconfig.
 	 */
 	public static function enable($app, $groups = null) {
+		// Since core 10.5.0, enterprise_key app is no longer used
+		// Be sure not to accidentally enable it if it has been
+		// left behind in an apps dir.
+		if ($app === 'enterprise_key') {
+			throw new \Exception(
+				"App $app can't be enabled. It is not used from core 10.5.0 onwards."
+			);
+		}
+
 		self::$enabledAppsCache = []; // flush
 
 		// check for required dependencies
 		$config = \OC::$server->getConfig();
-		$l = \OC::$server->getL10N('core');
+		$l = \OC::$server->getL10N('lib');
 		$info = self::getAppInfo($app);
 		if ($info === null) {
 			throw new \Exception("$app can't be enabled since it is not installed.");
@@ -398,12 +405,8 @@ class OC_App {
 
 		self::checkAppDependencies($config, $l, $info);
 
-		if (!Installer::isInstalled($app)) {
-			Installer::installShippedApp($app);
-		}
-
 		$appManager = \OC::$server->getAppManager();
-		if (!is_null($groups)) {
+		if ($groups !== null) {
 			$groupManager = \OC::$server->getGroupManager();
 			$groupsList = [];
 			foreach ($groups as $group) {
@@ -437,17 +440,12 @@ class OC_App {
 	 * @throws Exception
 	 */
 	public static function disable($app) {
-		// Convert OCS ID to regular application identifier
-		if(self::getInternalAppIdByOcs($app) !== false) {
-			$app = self::getInternalAppIdByOcs($app);
-		}
-
 		// flush
 		self::$enabledAppsCache = [];
 
 		// run uninstall steps
 		$appData = OC_App::getAppInfo($app);
-		if (!is_null($appData)) {
+		if ($appData !== null) {
 			OC_App::executeRepairSteps($app, $appData['repair-steps']['uninstall']);
 		}
 
@@ -472,20 +470,6 @@ class OC_App {
 		$urlGenerator = \OC::$server->getURLGenerator();
 
 		$settings = [];
-		// by default, settings only contain the help menu
-		if (OC_Util::getEditionString() === OC_Util::EDITION_COMMUNITY &&
-			\OC::$server->getSystemConfig()->getValue('knowledgebaseenabled', true) == true
-		) {
-			$settings = [
-				[
-					"id" => "help",
-					"order" => 1000,
-					"href" => $urlGenerator->linkToRoute('settings_help'),
-					"name" => $l->t("Help"),
-					"icon" => $urlGenerator->imagePath("settings", "help.svg")
-				]
-			];
-		}
 
 		// if the user is logged-in
 		if (OC_User::isLoggedIn()) {
@@ -501,7 +485,7 @@ class OC_App {
 			//SubAdmins are also allowed to access user management
 			$userObject = \OC::$server->getUserSession()->getUser();
 			$isSubAdmin = false;
-			if($userObject !== null) {
+			if ($userObject !== null) {
 				$isSubAdmin = \OC::$server->getGroupManager()->getSubAdmin()->isSubAdmin($userObject);
 			}
 			if ($isSubAdmin) {
@@ -514,7 +498,6 @@ class OC_App {
 					"icon" => $urlGenerator->imagePath("settings", "users.svg")
 				];
 			}
-
 		}
 
 		return self::proceedNavigation($settings);
@@ -532,12 +515,12 @@ class OC_App {
 		}
 		unset($navEntry);
 
-		usort($list, function($a, $b) {
+		\usort($list, function ($a, $b) {
 			if ($a["order"] == $b["order"]) {
 				return 0;
 			}
 
-			if($a["order"] < $b["order"]) {
+			if ($a["order"] < $b["order"]) {
 				return -1;
 			}
 
@@ -595,7 +578,21 @@ class OC_App {
 	 */
 	public static function isAppDirWritable($appId) {
 		$path = self::getAppPath($appId);
-		return ($path !== false) ? is_writable($path) : false;
+		// Check if the parent directory is marked as writable in config.php
+		if ($path !== false) {
+			$appDir = \substr($path, 0, -\strlen("/$appId"));
+			foreach (OC::$APPSROOTS as $dir) {
+				if ($dir['path'] !== $appDir) {
+					continue;
+				}
+				if (!isset($dir['writable'])
+					|| $dir['writable'] !== true
+				) {
+					return false;
+				}
+			}
+		}
+		return ($path !== false) ? \is_writable($path) : false;
 	}
 
 	/**
@@ -603,65 +600,33 @@ class OC_App {
 	 *
 	 * @param string $appId
 	 * @return string
+	 * @deprecated use \OC::$server->getAppManager()->getAppInfo($appId)
 	 */
 	public static function getAppVersion($appId) {
-		if (!isset(self::$appVersion[$appId])) {
-			$file = self::getAppPath($appId);
-			self::$appVersion[$appId] = ($file !== false) ? self::getAppVersionByPath($file) : '0';
+		$info = \OC::$server->getAppManager()->getAppInfo($appId);
+		if (isset($info['version'])) {
+			return $info['version'];
 		}
-		return self::$appVersion[$appId];
-	}
-
-	/**
-	 * get app's version based on it's path
-	 *
-	 * @param string $path
-	 * @return string
-	 */
-	public static function getAppVersionByPath($path) {
-		$infoFile = $path . '/appinfo/info.xml';
-		$appData = self::getAppInfo($infoFile, true);
-		return isset($appData['version']) ? $appData['version'] : '';
+		return '0';
 	}
 
 	/**
 	 * Read all app metadata from the info.xml file
 	 *
 	 * @param string $appId id of the app or the path of the info.xml file
-	 * @param boolean $path (optional)
+	 * @param bool $path
 	 * @return array|null
 	 * @note all data is read from info.xml, not just pre-defined fields
+	 * @deprecated use \OC::$server->getAppManager()->getAppInfo($appId)
 	 */
 	public static function getAppInfo($appId, $path = false) {
+		/** @var \OC\App\AppManager $am */
+		$am = \OC::$server->getAppManager();
+		'@phan-var \OC\App\AppManager $am';
 		if ($path) {
-			$file = $appId;
-		} else {
-			if (isset(self::$appInfo[$appId])) {
-				return self::$appInfo[$appId];
-			}
-			$appPath = self::getAppPath($appId);
-			if($appPath === false) {
-				return null;
-			}
-			$file = $appPath . '/appinfo/info.xml';
+			return $am->getAppInfoByPath($appId);
 		}
-
-		$parser = new InfoParser();
-		$data = $parser->parse($file);
-
-		if (is_array($data)) {
-			$data = OC_App::parseAppInfo($data);
-		}
-		if(isset($data['ocsid'])) {
-			$storedId = \OC::$server->getConfig()->getAppValue($appId, 'ocsid');
-			if($storedId !== '' && $storedId !== $data['ocsid']) {
-				$data['ocsid'] = $storedId;
-			}
-		}
-
-		self::$appInfo[$appId] = $data;
-
-		return $data;
+		return $am->getAppInfo($appId);
 	}
 
 	/**
@@ -686,17 +651,17 @@ class OC_App {
 	 */
 	public static function getCurrentApp() {
 		$request = \OC::$server->getRequest();
-		$script = substr($request->getScriptName(), strlen(OC::$WEBROOT) + 1);
-		$topFolder = substr($script, 0, strpos($script, '/'));
+		$script = \substr($request->getScriptName(), \strlen(OC::$WEBROOT) + 1);
+		$topFolder = \substr($script, 0, \strpos($script, '/'));
 		if (empty($topFolder)) {
 			$path_info = $request->getPathInfo();
 			if ($path_info) {
-				$topFolder = substr($path_info, 1, strpos($path_info, '/', 1) - 1);
+				$topFolder = \substr($path_info, 1, \strpos($path_info, '/', 1) - 1);
 			}
 		}
 		if ($topFolder == 'apps') {
-			$length = strlen($topFolder);
-			return substr($script, $length + 1, strpos($script, '/', $length + 1) - $length - 1);
+			$length = \strlen($topFolder);
+			return \substr($script, $length + 1, \strpos($script, '/', $length + 1) - $length - 1);
 		} else {
 			return $topFolder;
 		}
@@ -776,21 +741,18 @@ class OC_App {
 	 * @todo: change the name of this method to getInstalledApps, which is more accurate
 	 */
 	public static function getAllApps() {
-
 		$apps = [];
 
 		foreach (OC::$APPSROOTS as $apps_dir) {
-			if (!is_readable($apps_dir['path'])) {
+			if (!\is_readable($apps_dir['path'])) {
 				\OCP\Util::writeLog('core', 'unable to read app folder : ' . $apps_dir['path'], \OCP\Util::WARN);
 				continue;
 			}
-			$dh = opendir($apps_dir['path']);
-
-			if (is_resource($dh)) {
-				while (($file = readdir($dh)) !== false) {
-
-					if ($file[0] != '.' and is_dir($apps_dir['path'] . '/' . $file) and is_file($apps_dir['path'] . '/' . $file . '/appinfo/info.xml')) {
+			$dh = \opendir($apps_dir['path']);
 
+			if (\is_resource($dh)) {
+				while (($file = \readdir($dh)) !== false) {
+					if ($file[0] != '.' and \is_dir($apps_dir['path'] . '/' . $file) and \is_file($apps_dir['path'] . '/' . $file . '/appinfo/info.xml')) {
 						$apps[] = $file;
 					}
 				}
@@ -803,27 +765,28 @@ class OC_App {
 	/**
 	 * List all apps, this is used in apps.php
 	 *
-	 * @param bool $onlyLocal
-	 * @param bool $includeUpdateInfo Should we check whether there is an update
-	 *                                in the app store?
+	 * @param bool $listEveryApp including always-enabled apps
 	 * @return array
 	 */
-	public static function listAllApps() {
+	public static function listAllApps(bool $listEveryApp = false) {
 		$installedApps = OC_App::getAllApps();
 
 		//TODO which apps do we want to blacklist and how do we integrate
 		// blacklisting with the multi apps folder feature?
 
-		//we don't want to show configuration for these
-		$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
+		if ($listEveryApp) {
+			$blacklist = [];
+		} else {
+			//we don't want to show configuration for these
+			$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
+		}
 		$appList = [];
 		$urlGenerator = \OC::$server->getURLGenerator();
 
 		foreach ($installedApps as $app) {
-			if (array_search($app, $blacklist) === false) {
-
+			if (\array_search($app, $blacklist) === false) {
 				$info = OC_App::getAppInfo($app);
-				if (!is_array($info)) {
+				if (!\is_array($info)) {
 					\OCP\Util::writeLog('core', 'Could not read app info file for app "' . $app . '"', \OCP\Util::ERROR);
 					continue;
 				}
@@ -837,7 +800,7 @@ class OC_App {
 				$info['groups'] = null;
 				if ($enabled === 'yes') {
 					$active = true;
-				} else if ($enabled === 'no') {
+				} elseif ($enabled === 'no') {
 					$active = false;
 				} else {
 					$active = true;
@@ -851,9 +814,8 @@ class OC_App {
 					$info['level'] = self::officialApp;
 					$info['removable'] = false;
 				} else {
-					$result = \OC::$server->getIntegrityCodeChecker()->verifyAppSignature($app, '', true);
+					$result = \OC::$server->getIntegrityCodeChecker()->getVerifiedAppsFromCache($app, '', true);
 					if (empty($result)) {
-						$info['internal'] = false;
 						$info['level'] = self::approvedApp;
 						$info['removable'] = false;
 					}
@@ -863,33 +825,31 @@ class OC_App {
 				}
 
 				$appPath = self::getAppPath($app);
-				if($appPath !== false) {
+				if ($appPath !== false) {
 					$appIcon = $appPath . '/img/' . $app . '.svg';
-					if (file_exists($appIcon)) {
+					if (\file_exists($appIcon)) {
 						$info['preview'] = \OC::$server->getURLGenerator()->imagePath($app, $app . '.svg');
 						$info['previewAsIcon'] = true;
 					} else {
 						$appIcon = $appPath . '/img/app.svg';
-						if (file_exists($appIcon)) {
+						if (\file_exists($appIcon)) {
 							$info['preview'] = \OC::$server->getURLGenerator()->imagePath($app, 'app.svg');
 							$info['previewAsIcon'] = true;
 						}
 					}
 				}
 				// fix documentation
-				if (isset($info['documentation']) && is_array($info['documentation'])) {
+				if (isset($info['documentation']) && \is_array($info['documentation'])) {
 					foreach ($info['documentation'] as $key => $url) {
 						// If it is not an absolute URL we assume it is a key
 						// i.e. admin-ldap will get converted to go.php?to=admin-ldap
-						if (stripos($url, 'https://') !== 0 && stripos($url, 'http://') !== 0) {
+						if (\stripos($url, 'https://') !== 0 && \stripos($url, 'http://') !== 0) {
 							$url = $urlGenerator->linkToDocs($url);
 						}
 
 						$info['documentation'][$key] = $url;
 					}
 				}
-
-				$info['version'] = OC_App::getAppVersion($app);
 				$appList[] = $info;
 			}
 		}
@@ -897,29 +857,20 @@ class OC_App {
 		return $appList;
 	}
 
-	/**
-	 * Returns the internal app ID or false
-	 * @param string $ocsID
-	 * @return string|false
-	 */
-	public static function getInternalAppIdByOcs($ocsID) {
-		if(is_numeric($ocsID)) {
-			$idArray = \OC::$server->getAppConfig()->getValues(false, 'ocsid');
-			if(array_search($ocsID, $idArray)) {
-				return array_search($ocsID, $idArray);
-			}
-		}
-		return false;
-	}
-
 	public static function shouldUpgrade($app) {
 		$versions = self::getAppVersions();
-		$currentVersion = OC_App::getAppVersion($app);
-		if ($currentVersion && isset($versions[$app])) {
-			$installedVersion = $versions[$app];
-			if (!version_compare($currentVersion, $installedVersion, '=')) {
+		$info = \OC::$server->getAppManager()->getAppInfo($app);
+
+		if ($info && isset($versions[$app])) {
+			if ($info['version'] === $versions[$app]) {
+				return false;
+			}
+
+			if (self::atLeastMinorVersionLevelChanged($info['version'], $versions[$app])) {
 				return true;
 			}
+			// update app version in db
+			\OC::$server->getConfig()->setAppValue($app, 'installed_version', $info['version']);
 		}
 		return false;
 	}
@@ -933,17 +884,17 @@ class OC_App {
 	 * @return string shortened $version1
 	 */
 	private static function adjustVersionParts($version1, $version2) {
-		$version1 = explode('.', $version1);
-		$version2 = explode('.', $version2);
+		$version1 = \explode('.', $version1);
+		$version2 = \explode('.', $version2);
 		// reduce $version1 to match the number of parts in $version2
-		while (count($version1) > count($version2)) {
-			array_pop($version1);
+		while (\count($version1) > \count($version2)) {
+			\array_pop($version1);
 		}
 		// if $version1 does not have enough parts, add some
-		while (count($version1) < count($version2)) {
+		while (\count($version1) < \count($version2)) {
 			$version1[] = '0';
 		}
-		return implode('.', $version1);
+		return \implode('.', $version1);
 	}
 
 	/**
@@ -967,31 +918,30 @@ class OC_App {
 		$requireMax = '';
 		if (isset($appInfo['dependencies']['owncloud']['@attributes']['min-version'])) {
 			$requireMin = $appInfo['dependencies']['owncloud']['@attributes']['min-version'];
-		} else if (isset($appInfo['requiremin'])) {
+		} elseif (isset($appInfo['requiremin'])) {
 			$requireMin = $appInfo['requiremin'];
-		} else if (isset($appInfo['require'])) {
+		} elseif (isset($appInfo['require'])) {
 			$requireMin = $appInfo['require'];
 		}
 
 		if (isset($appInfo['dependencies']['owncloud']['@attributes']['max-version'])) {
 			$requireMax = $appInfo['dependencies']['owncloud']['@attributes']['max-version'];
-		} else if (isset($appInfo['requiremax'])) {
+		} elseif (isset($appInfo['requiremax'])) {
 			$requireMax = $appInfo['requiremax'];
 		}
 
-		if (is_array($ocVersion)) {
-			$ocVersion = implode('.', $ocVersion);
+		if (\is_array($ocVersion)) {
+			$ocVersion = \implode('.', $ocVersion);
 		}
 
 		if (!empty($requireMin)
-			&& version_compare(self::adjustVersionParts($ocVersion, $requireMin), $requireMin, '<')
+			&& \version_compare(self::adjustVersionParts($ocVersion, $requireMin), $requireMin, '<')
 		) {
-
 			return false;
 		}
 
 		if (!empty($requireMax)
-			&& version_compare(self::adjustVersionParts($ocVersion, $requireMax), $requireMax, '>')
+			&& \version_compare(self::adjustVersionParts($ocVersion, $requireMax), $requireMax, '>')
 		) {
 			return false;
 		}
@@ -1005,7 +955,7 @@ class OC_App {
 	public static function getAppVersions() {
 		static $versions;
 
-		if(!$versions) {
+		if (!$versions) {
 			$appConfig = \OC::$server->getAppConfig();
 			$versions = $appConfig->getValues(false, 'installed_version');
 		}
@@ -1019,8 +969,9 @@ class OC_App {
 	 * @return bool
 	 */
 	public static function updateApp($appId) {
+		\OC::$server->getAppManager()->clearAppsCache();
 		$appPath = self::getAppPath($appId);
-		if($appPath === false) {
+		if ($appPath === false) {
 			return false;
 		}
 		$appData = self::getAppInfo($appId);
@@ -1029,26 +980,20 @@ class OC_App {
 			$ms = new \OC\DB\MigrationService($appId, \OC::$server->getDatabaseConnection());
 			$ms->migrate();
 		} else {
-			if (file_exists($appPath . '/appinfo/database.xml')) {
+			if (\file_exists($appPath . '/appinfo/database.xml')) {
 				OC_DB::updateDbFromStructure($appPath . '/appinfo/database.xml');
 			}
 		}
 		self::executeRepairSteps($appId, $appData['repair-steps']['post-migration']);
 		self::setupLiveMigrations($appId, $appData['repair-steps']['live-migration']);
-		self::clearAppCache($appId);
 		// run upgrade code
-		if (file_exists($appPath . '/appinfo/update.php')) {
+		if (\file_exists($appPath . '/appinfo/update.php')) {
 			self::loadApp($appId, false);
 			include $appPath . '/appinfo/update.php';
 		}
 		self::setupBackgroundJobs($appData['background-jobs']);
 
 		//set remote/public handlers
-		if (array_key_exists('ocsid', $appData)) {
-			\OC::$server->getConfig()->setAppValue($appId, 'ocsid', $appData['ocsid']);
-		} elseif(\OC::$server->getConfig()->getAppValue($appId, 'ocsid', null) !== null) {
-			\OC::$server->getConfig()->deleteAppValue($appId, 'ocsid');
-		}
 		foreach ($appData['remote'] as $name => $path) {
 			\OC::$server->getConfig()->setAppValue('core', 'remote_' . $name, $appId . '/' . $path);
 		}
@@ -1058,8 +1003,7 @@ class OC_App {
 
 		self::setAppTypes($appId);
 
-		$version = \OC_App::getAppVersion($appId);
-		\OC::$server->getAppConfig()->setValue($appId, 'installed_version', $version);
+		\OC::$server->getConfig()->setAppValue($appId, 'installed_version', $appData['version']);
 
 		return true;
 	}
@@ -1067,7 +1011,7 @@ class OC_App {
 	/**
 	 * @param string $appId
 	 * @param string[] $steps
-	 * @throws \OC\NeedsUpdateException
+	 * @throws NeedsUpdateException
 	 */
 	public static function executeRepairSteps($appId, array $steps) {
 		if (empty($steps)) {
@@ -1097,6 +1041,7 @@ class OC_App {
 		foreach ($jobs as $job) {
 			$queue->add($job);
 		}
+		// TODO remove jobs that no longer exist in this app version
 	}
 
 	/**
@@ -1145,24 +1090,23 @@ class OC_App {
 		// just modify the description if it is available
 		// otherwise this will create a $data element with an empty 'description'
 		if (isset($data['description'])) {
-			if (is_string($data['description'])) {
+			if (\is_string($data['description'])) {
 				// sometimes the description contains line breaks and they are then also
 				// shown in this way in the app management which isn't wanted as HTML
 				// manages line breaks itself
 
 				// first of all we split on empty lines
-				$paragraphs = preg_split("!\n[[:space:]]*\n!mu", $data['description']);
+				$paragraphs = \preg_split("!\n[[:space:]]*\n!mu", $data['description']);
 
 				$result = [];
 				foreach ($paragraphs as $value) {
 					// replace multiple whitespace (tabs, space, newlines) inside a paragraph
 					// with a single space - also trims whitespace
-					$result[] = trim(preg_replace('![[:space:]]+!mu', ' ', $value));
+					$result[] = \trim(\preg_replace('![[:space:]]+!mu', ' ', $value));
 				}
 
 				// join the single paragraphs with a empty line in between
-				$data['description'] = implode("\n\n", $result);
-
+				$data['description'] = \implode("\n\n", $result);
 			} else {
 				$data['description'] = '';
 			}
@@ -1181,7 +1125,7 @@ class OC_App {
 		$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
 		$missing = $dependencyAnalyzer->analyze($info);
 		if (!empty($missing)) {
-			$missingMsg = join(PHP_EOL, $missing);
+			$missingMsg = \join(PHP_EOL, $missing);
 			throw new \Exception(
 				$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
 					[$info['name'], $missingMsg]
@@ -1191,10 +1135,27 @@ class OC_App {
 	}
 
 	/**
-	 * @param $appId
+	 * @param $currentVersion
+	 * @param $installedVersion
+	 * @return bool
 	 */
-	public static function clearAppCache($appId) {
-		unset(self::$appVersion[$appId]);
-		unset(self::$appInfo[$appId]);
+	public static function atLeastMinorVersionLevelChanged($currentVersion, $installedVersion) {
+		if ($currentVersion === $installedVersion) {
+			return false;
+		}
+
+		$p = new \Composer\Semver\VersionParser();
+		$currentVersion = $p->normalize($currentVersion);
+		$installedVersion = $p->normalize($installedVersion);
+
+		$currentVersion = \explode('.', $currentVersion);
+		$installedVersion = \explode('.', $installedVersion);
+
+		if ($currentVersion[0] === $installedVersion[0] &&
+			$currentVersion[1] === $installedVersion[1]) {
+			return false;
+		}
+
+		return true;
 	}
 }
