@@ -1,8 +1,8 @@
 OC.L10N.register(
     "settings",
     {
-    "Wrong password" : "Falsches Passwort",
-    "The new password can not be the same as the previous one" : "Das neue Passwort kann nicht das gleiche Passwort wie das vorherige sein",
+    "Wrong current password" : "Falsches aktuelles Passwort",
+    "The new password cannot be the same as the previous one" : "Das neue Passwort kann nicht das gleiche sein wie das alte",
     "No user supplied" : "Keinen Benutzer angegeben",
     "Authentication error" : "Authentifizierungsfehler",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bitte geben Sie ein Wiederherstellungspasswort für das Administratorkonto an, da sonst alle Benutzerdaten verloren gehen können.",
@@ -11,32 +11,39 @@ OC.L10N.register(
     "Unable to change password" : "Passwort konnte nicht geändert werden",
     "%s password changed successfully" : "%s Passwort erfolgreich geändert",
     "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL verwendet eine veraltete %s Version (%s). Bitte aktualisieren Sie ihr Betriebssystem, da ansonsten Funktionen, wie z.B. %s, nicht zuverlässig funktionieren werden.",
-    "A problem occurred, please check your log files (Error: %s)" : "Es ist ein Problem aufgetreten, bitte überprüfen Sie Ihre Logdateien (Fehler: %s)",
-    "Migration Completed" : "Migration abgeschlossen",
+    "Invalid url '%s'. Urls should be set up like 'http://www.example.com' or 'https://www.example.com'" : "Die URL ist ungültig '%s'. Eine URL sollte wie beispielsweise 'http://www.example.com' oder 'https://www.example.com' eingerichtet werden.",
     "Group already exists." : "Gruppe existiert bereits.",
     "Unable to add group." : "Gruppe konnte nicht angelegt werden.",
     "Unable to delete group." : "Gruppe konnte nicht gelöscht werden.",
-    "log-level out of allowed range" : "Log-Level außerhalb des erlaubten Bereichs",
     "Saved" : "Gespeichert",
+    "log-level out of allowed range" : "Log-Level außerhalb des erlaubten Bereichs",
+    "Updated log level" : "Loglevel aktualisiert",
+    "Invalid email address" : "Ungültige E-Mail-Adresse",
     "test email settings" : "E-Mail-Einstellungen testen",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Beim Senden der E-Mail ist ein Problem aufgetreten. Bitte überprüfen Sie Ihre Einstellungen. (Fehler: %s)",
     "Email sent" : "E-Mail gesendet",
     "You need to set your user email before being able to send test emails." : "Sie müssen Ihre Benutzer-E-Mail-Adresse einstellen, bevor Sie Test-E-Mails versenden können.",
     "Couldn't change the email address because the user does not exist" : "Die E-Mail Adresse konnte nicht geändert werden, da der Benutzer nicht existiert",
     "Couldn't change the email address because the token is invalid" : "Die E-Mail Adresse konnte nicht geändert werden, da der Token ungültig ist",
+    "Your %s account was created" : "Ihr %s-Konto wurde erstellt",
     "Invalid mail address" : "Ungültige E-Mail-Adresse",
     "A user with that name already exists." : "Ein Benutzer mit diesem Namen existiert bereits.",
     "Unable to create user." : "Benutzer konnte nicht erstellt werden.",
-    "Your %s account was created" : "Ihr %s-Konto wurde erstellt",
+    "The token provided is invalid." : "Der Token ist ungültig",
+    "The token provided had expired." : "Der angegebene Token ist abgelaufen",
+    "Failed to create activation link. Please contact your administrator." : "Erstellen des Aktivierungslinks fehlgeschlagen, bitte kontaktieren Sie Ihren Administrator.",
+    "Can't send email to the user. Contact your administrator." : "Kann E-mail nicht an Benutzer senden. Bitte benachrichtigen Sie ihren System-Administrator",
+    "Failed to set password. Please contact the administrator." : "Passwort erstellen fehlgeschlagen. Bitte kontaktieren Sie ihren Administrator",
+    "Failed to set password. Please contact your administrator." : "Passwort erstellen fehlgeschlagen. Bitte kontaktieren Sie ihren Administrator",
+    "Failed to send email. Please contact your administrator." : "E-mail versand fehlgeschlagen. Bitte kontaktieren Sie ihren Administrator.",
     "Unable to delete user." : "Benutzer konnte nicht gelöscht werden.",
     "Forbidden" : "Verboten",
     "Invalid user" : "Ungültiger Benutzer",
     "Unable to change mail address" : "E-Mail-Adresse konnte nicht geändert werden",
     "Email has been changed successfully." : "E-Mail Adresse wurde erfolgreich geändert.",
-    "An email has been sent to this address for confirmation" : "Eine E-Mail wurde zur Bestätigung an diese Adresse gesendet",
+    "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "Eine E-Mail ist an diese Adresse zur Bestätigung gesendet worden. Bis diese Email bestätigt wurde, wird diese Adresse nicht verwendet.",
     "No email was sent because you already sent one recently. Please try again later." : "Es wurde keine E-Mail versendet, da bereits eine E-Mail versendet wurde. Bitte später noch einmal versuchen.",
     "Your full name has been changed." : "Ihr vollständiger Name ist geändert worden.",
     "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
@@ -45,12 +52,16 @@ OC.L10N.register(
     "%s email address changed successfully" : "%s E-Mail Adresse wurde erfolgreich geändert",
     "Couldn't send email address change notification mail. Please contact your administrator." : "Die Benachrichtigung zur Änderung der E-Mail Adresse konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
     "Unable to enable/disable user." : "Benutzer konnte nicht de-/aktiviert werden.",
+    "Owner language" : "Sprache des Eigentümers",
+    "Create" : "Erstellen",
+    "Change" : "Ändern",
+    "Delete" : "Löschen",
+    "Share" : "Teilen",
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "__language_name__" : "Deutsch (Förmlich: Sie)",
     "Language changed" : "Sprache geändert",
     "Invalid request" : "Ungültige Anforderung",
-    "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der admin-Gruppe löschen",
+    "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der Admin-Gruppe löschen",
     "Unknown user" : "Unbekannter Benutzer",
     "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
     "Official" : "Offiziell",
@@ -81,20 +92,20 @@ OC.L10N.register(
     "App update" : "App aktualisieren",
     "Experimental" : "Experimentell",
     "No apps found for {query}" : "Keine Applikationen für {query} gefunden",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sind Sie sich wirklich sicher, dass Sie »{domain}« als vertrauenswürdige Domain hinzufügen möchten?",
-    "Add trusted domain" : "Vertrauenswürdige Domain hinzufügen",
     "Migration in progress. Please wait until the migration is finished" : "Migration in Arbeit. Bitte warten Sie, bis die Migration beendet ist",
     "Migration started …" : "Migration begonnen…",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte laden Sie ein ASCII-kodiertes PEM-Zertifikat hoch.",
     "Valid until {date}" : "Gültig bis {date}",
-    "Delete" : "Löschen",
     "Disconnect" : "Trennen",
     "Error while loading browser sessions and device tokens" : "Fehler beim Laden der Browser-Sitzungen und Gerätetoken",
+    "Empty app name is not allowed." : "Ein leerer App-Name ist nicht erlaubt.",
     "Error while creating device token" : "Fehler beim Erstellen des Gerätetokens",
     "Error while deleting the token" : "Fehler beim Löschen des Gerätetokens",
+    "Are you sure you want to remove this domain?" : "Sind Sie sicher, dass Sie diese Domain entfernen möchten?",
+    "CORS" : "KERNE",
     "Sending..." : "Wird gesendet…",
     "Failed to change the email address." : "Fehler beim Ändern der E-Mail-Adresse.",
-    "Email changed successfully." : "E-Mail Adresse erfolgreich geändert.",
+    "Email changed successfully for {user}." : "E-Mail erfolgreich für {user} geändert.",
     "An error occurred: {message}" : "Ein Fehler ist aufgetreten: {message}",
     "Select a profile picture" : "Wählen Sie ein Profilbild",
     "Very weak password" : "Sehr schwaches Passwort",
@@ -102,14 +113,19 @@ OC.L10N.register(
     "So-so password" : "Passables Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
+    "Passwords do not match" : "Passwörter stimmen nicht überein",
     "Groups" : "Gruppen",
     "Unable to delete {objName}" : "Löschen von {objName} nicht möglich",
     "Error creating group: {message}" : "Fehler beim Erstellen einer Gruppe: {message}",
     "A valid group name must be provided" : "Ein gültiger Gruppenname muss angegeben werden",
     "deleted {groupName}" : "{groupName} gelöscht",
     "undo" : "rückgängig machen",
-    "never" : "niemals",
+    "You are about to delete a group. This action can't be undone and is permanent. Are you sure that you want to permanently delete {groupName}?" : "Sie sind kurz davor eine Gruppe zu löschen. Diese Aktion kann nicht rückgängig gemacht werden. Sind Sie sich sicher, dass Sie {groupName} dauerhaft löschen wollen?",
+    "Delete group" : "Gruppe löschen",
+    "never" : "Niemals",
     "deleted {userName}" : "{userName} gelöscht",
+    "You are about to delete a user. This action can't be undone and is permanent. All user data, files and shares will be deleted. Are you sure that you want to permanently delete {userName}?" : "Sie sind kurz davor einen Nutzer zu löschen. Diese Aktion kann nicht rückgängig gemacht werden. Alle Nutzerdaten und -dateien, sowie vom Nutzer geteilte Ordner/Dateien werden gelöscht. Sind Sie sich sicher, dass Sie {userName} dauerhaft löschen wollen?",
+    "Delete user" : "Nutzer löschen",
     "add group" : "Gruppe hinzufügen",
     "Invalid quota value \"{val}\"" : "Ungültiger Wert \"{val}\" für das Kontigent",
     "enabled" : "aktiviert",
@@ -124,20 +140,16 @@ OC.L10N.register(
     "A valid email must be provided" : "Es muss eine gültige E-Mail-Adresse angegeben werden",
     "Use the following link to confirm your changes to the email address: {link}" : "Benutzen Sie den folgenden Link, um die Änderung der E-Mail Adresse zu bestätigen: {link}",
     "Email address changed to {mailAddress} successfully." : "E-Mail Adresse wurde erfolgreich auf {mailAddress} geändert.",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass Sie jetzt ein %s-Konto haben.<br><br>Ihr Benutzername: %s<br>Greifen Sie darauf zu: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Noch einen schönen Tag!",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Please set the password by accessing it: <a href=\"%s\">Here</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass Sie jetzt ein %s-Konto haben.<br><br>Ihr Benutzername: %s<br>Erstellen Sie jetzt ein Passwort indem Sie darauf zugreifen: <a href=\"%s\">Hier</a><br><br>",
+    "Cheers!" : "Wir wünschen Ihnen noch einen schönen Tag!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass Sie jetzt ein %s-Konto haben.\n\nIhr Benutzername: %s\nGreifen Sie darauf zu: %s\n\n",
-    "User documentation" : "Dokumentation für Benutzer",
-    "Administrator documentation" : "Dokumentation für Administratoren",
-    "Online documentation" : "Online-Dokumentation",
-    "Forum" : "Forum",
-    "Issue tracker" : "Issue Tracker",
-    "Commercial support" : "Kommerzieller Support",
+    "Language" : "Sprache",
     "Apps Management" : "Verwaltung der Apps",
     "Developer documentation" : "Dokumentation für Entwickler",
     "by %s" : "durch %s",
     "%s-licensed" : "%s-Lizensiert",
     "Documentation:" : "Dokumentation:",
+    "User documentation" : "Dokumentation für Benutzer",
     "Admin documentation" : "Dokumentation für Administratoren",
     "Visit website" : "Webseite besuchen",
     "Report a bug" : "Melden Sie einen technischen Fehler",
@@ -159,7 +171,7 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ist als Webcron-Dienst registriert, der die cron.php alle 15 Minuten per HTTP aufruft.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Benutzen Sie den systemeigenen Cron-Dienst, um die cron.php alle 15 Minuten aufzurufen.",
     "SSL Root Certificates" : "SSL Root Zertifikate",
-    "Common Name" : "Common Name",
+    "Common Name" : "Gemeinsamer Name",
     "Valid until" : "Gültig bis",
     "Issued By" : "Ausgestellt von:",
     "Valid until %s" : "Gültig bis %s",
@@ -182,21 +194,43 @@ OC.L10N.register(
     "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
     "Allow users to share via link" : "Benutzern erlauben, Inhalte über Links zu teilen",
     "Allow public uploads" : "Öffentliches Hochladen erlauben",
-    "Enforce password protection" : "Passwortschutz erzwingen",
+    "Enforce password protection for read-only links" : "Passwort für \"nur lesen\" Links erzwingen",
+    "Enforce password protection for read + write links" : "Passwort für \"lesen+schreiben\" Links erzwingen",
+    "Enforce password protection for read + write + delete links" : "Passwort für \"lesen+schreiben+löschen\" Links erzwingen",
+    "Enforce password protection for upload-only (File Drop) links" : "Passwort für Upload-Links (File Drop) erzwingen",
     "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
-    "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
-    "Allow users to share file via social media" : "Benutzern erlauben, Inhalte über die sozialen Medien zu teilen",
     "Expire after " : "Ablauf nach ",
     "days" : "Tagen",
-    "Enforce expiration date" : "Ablaufdatum erzwingen",
+    "Enforce as maximum expiration date" : "Als spätestes Ablaufdatum erzwingen",
+    "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
+    "Language used for public mail notifications for shared files" : "Sprache, die für öffentliche Mail-Benachrichtigungen für geteilte Daten benutzt wird ",
+    "Allow users to share file via social media" : "Benutzern erlauben, Inhalte über die sozialen Medien zu teilen",
+    "Set default expiration date for user shares" : "Standardmäßiges Ablaufdatum für Benutzerfreigaben festlegen",
+    "Set default expiration date for group shares" : "Standardmäßiges Ablaufdatum für Gruppenfreigaben festlegen",
+    "Set default expiration date for remote shares" : "Standard-Ablaufdatum für Remote-Freigaben festlegen",
+    "Automatically accept new incoming local user shares" : "Neue lokale Benutzerfreigaben automatisch akzeptieren",
     "Allow resharing" : "Weiterverteilen erlauben",
     "Allow sharing with groups" : "Das Teilen mit Gruppen erlauben",
     "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
+    "Restrict users to only share with groups they are member of" : "Benutzer auf das Teilen innerhalb der Gruppen, deren Mitglied sie sind, beschränken",
     "Allow users to send mail notification for shared files to other users" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien an andere Benutzer zu senden",
     "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
     "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
     "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Die Auto-Vervollständigung von Benutzernamen im Teilen-Dialog erlauben. Wenn dies deaktiviert ist, muss der vollständige Benutzername eingegeben werden.",
     "Restrict enumeration to group members" : "Aufzählung auf Gruppenmitglieder beschränken",
+    "Default user and group share permissions" : "Nutzer und Gruppen Standard-Berechtigungen für das Teilen",
+    "Extra field to display in autocomplete results" : "Separates Feld zur Anzeige des Autovervollständigen-Ergebnisses",
+    "None" : "Keine",
+    "User ID" : "Benutzer-ID",
+    "Email address" : "E-Mail-Adresse",
+    "Legal" : "Rechtliches",
+    "Imprint URL:" : "Impressum-URL:",
+    "Imprint URL" : "Impressum-URL",
+    "Privacy Policy URL:" : "Datenschutz-URL:",
+    "Privacy Policy URL" : "Datenschutz-URL",
+    "Enterprise license key" : "Enterprise-Lizenzschlüssel",
+    "Enter a new license:" : "Neue Lizenz eingeben:",
+    "Save" : "Speichern",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatale Probleme, Fehler, Warnungen, Infos, Fehlerdiagnose)",
     "Info, warnings, errors and fatal issues" : "Infos, Warnungen, Fehler und fatale Probleme",
     "Warnings, errors and fatal issues" : "Warnungen, Fehler und fatale Probleme",
@@ -206,13 +240,14 @@ OC.L10N.register(
     "What to log" : "Was geloggt wird",
     "Download logfile (%s)" : "Logdatei (%s) herunterladen",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Die Logdatei ist größer als 100 MB. Es kann etwas Zeit beanspruchen, sie herunterzuladen!",
-    "None" : "Keine",
     "Login" : "Anmelden",
     "Plain" : "Plain",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "Email server" : "E-Mail-Server",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Die Konfigurationsdatei ist schreibgeschützt. Bitte passen Sie Ihre Einstellungen durch manuelle Bearbeitung der Konfigurationsdatei selbst an.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In einem gruppierten Umgebung stellen Sie bitte sicher, dass die config.php-Datei über alle Knoten synchronisiert wird.",
     "This is used for sending out notifications." : "Dies wird für das Senden von Benachrichtigungen verwendet.",
     "Send mode" : "Sendemodus",
     "Encryption" : "Verschlüsselung",
@@ -228,6 +263,10 @@ OC.L10N.register(
     "Store credentials" : "Anmeldeinformationen speichern",
     "Test email settings" : "E-Mail-Einstellungen testen",
     "Send email" : "E-Mail senden",
+    "Manual File Locking" : "Manuelles Sperren von Dateien",
+    "Default timeout for the locks if not specified (in seconds)" : "Standard-Timeout für die Sperre, falls nicht angegeben (in Sekunden)",
+    "Maximum timeout for the locks (in seconds)" : "Maximaler-Timeout für die Sperre (in Sekunden)",
+    "Enable manual file locking on clients" : "Manuelle Dateisperre auf Clients aktivieren",
     "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv (\"PATH\") liefert nur eine leere Antwort zurück.",
     "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Bitte schauen Sie in der <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Installationsdokumentation ↗</a>auf Hinweise zur PHP-Konfiguration, sowie die PHP-Konfiguration ihres Servers, insbesondere dann, wenn Sie PHP-FPM einsetzten.",
@@ -253,7 +292,6 @@ OC.L10N.register(
     "System Status" : "Systemstatus",
     "Tips & tricks" : "Tipps & Tricks",
     "How to do backups" : "Wie man Backups anlegt",
-    "Advanced monitoring" : "Erweitertes Monitoring",
     "Performance tuning" : "Leistungsoptimierung",
     "Improving the config.php" : "Die config.php optimieren",
     "Theming" : "Themes verwenden",
@@ -264,6 +302,11 @@ OC.L10N.register(
     "iOS app" : "iOS-App",
     "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Wenn Sie das Projekt unterstützen möchten,\n<a href=\"https://owncloud.org/contribute\"\ntarget=\"_blank\" rel=\"noreferrer\">beteiligen Sie sich an der Entwicklung</a>\noder\n<a href=\"https://owncloud.org/promote\"\ntarget=\"_blank\" rel=\"noreferrer\">helfen Sie mit, es bekannter zu machen</a>!",
     "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
+    "White-listed Domains" : "Weiße Liste der Domains",
+    "No Domains." : "Keine Domains.",
+    "Domain" : "Domain",
+    "Add Domain" : "Domain hinzufügen",
+    "Add" : "Hinzufügen",
     "Profile picture" : "Profilbild",
     "Upload new" : "Neues hochladen",
     "Select from Files" : "Aus Dateien wählen",
@@ -281,43 +324,52 @@ OC.L10N.register(
     "For password recovery and notifications" : "Für Passwort Wiederherstellung und Benachrichtigungen",
     "No email address set" : "Keine E-Mail-Adresse angegeben",
     "You are member of the following groups:" : "Sie sind Mitglied folgender Gruppen:",
+    "You are not a member of any groups." : "Sie sind kein Mitglied einer Gruppe.",
     "Password" : "Passwort",
     "Unable to change your password" : "Das Passwort konnte nicht geändert werden",
     "Current password" : "Aktuelles Passwort",
     "New password" : "Neues Passwort",
     "Change password" : "Passwort ändern",
-    "Language" : "Sprache",
     "Help translate" : "Helfen Sie bei der Übersetzung",
-    "Unlimited" : "Unbegrenzt",
-    "You are using %s of %s" : "Sie benutzen %s von %s",
+    "You are using %s" : "Sie verwenden %s",
     "You are using %s of %s (%s %%)" : "Sie benutzen %s von %s (%s %%)",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Entwickelt von der {communityopen}ownCloud-Community{linkclose}, der {githubopen}Quellcode{linkclose} ist unter den Bedingungen der {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} lizenziert.",
     "Sessions" : "Sitzungen",
-    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Dies sind die Web-, Desktop und mobilen Clients, mit denen Sie aktuell in Ihrer ownCloud angemeldet sind.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Diese Web-, Desktop- und Mobil-Clients sind aktuell an 1%s angemeldet",
     "Browser" : "Browser",
     "Most recent activity" : "Neueste Aktivität",
-    "App passwords" : "App-Passwörter",
+    "App passwords / tokens" : "App-Passwörter / Token",
     "You've linked these apps." : "Sie haben diese Apps verbunden.",
     "Name" : "Name",
-    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Ein App-Passwort ist ein Passwort, dass einer App oder einem Gerät erlaubt auf Ihren %s-Konto zuzugreifen.",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "App-Passwörter oder Token sind passcodes, die einer App oder einem Gerät Zugriff auf Ihr %s-Konto geben.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Benutzen Sie diese als Sicherheitsmaßnahme, um Ihr richtiges Passwort nur für den Webzugriff zu verwenden.",
     "App name" : "App-Name",
-    "Create new app password" : "Neues App-Passwort erstellen",
+    "Create new app passcode" : "Neuen App-Passcode erstellen",
     "Use the credentials below to configure your app or device." : "Verwenden Sie die folgenden Zugangsdaten um Ihre App oder Ihr Gerät zu konfigurieren.",
     "Username" : "Benutzername",
+    "Password / Token" : "Passwort / Token",
     "Done" : "Erledigt",
     "Version" : "Version",
+    "The activation link has expired. Click the button below to request a new one and complete the registration." : "Der Aktivierungslink ist abgelaufen. Klicken Sie den Knopf unten um einen neuen anzufordern und die Registrierung abzuschliessen. ",
+    "Resend activation link" : "Aktivierungslink erneut versenden.",
+    "New Password" : "Neues Passwort",
+    "Confirm Password" : "Passwort bestätigen",
+    "Please set your password" : "Passwort setzen",
     "Personal" : "Persönlich",
     "Admin" : "Administrator",
-    "Error" : "Fehler",
-    "No panels for this section." : "Keine Tafeln für diese Auswahl",
+    "Currently no settings are available in this category" : "Momentan sind keine Einstellungen in dieser Kategorie verfügbar",
+    "The administrators can enable additional apps which add settings sections here." : "Die Administratoren können weitere Apps aktivieren, welche hier Abschnitte für Einstellungen hinzufügen.",
+    "Activation link was sent to an email address, if one was configured." : "Der Aktivierungs Link wurde an eine E-Mail-Adresse versandt, falls eine angelegt konfiguriert wurde. ",
+    "Settings" : "Einstellungen",
     "Show enabled/disabled option" : "Option Aktiviert/Deaktiviert anzeigen",
     "Show storage location" : "Speicherort anzeigen",
     "Show last log in" : "Letzte Anmeldung anzeigen",
     "Show user backend" : "Benutzer-Backend anzeigen",
-    "Send email to new user" : "E-Mail an neuen Benutzer senden",
+    "Set password for new users" : "Setze Passwort für neue Benutzer",
     "Show email address" : "E-Mail Adresse anzeigen",
+    "Show password field" : "Passwortfeld anzeigen",
+    "Show quota field" : "Kontingent-Feld anzeigen",
     "E-Mail" : "E-Mail",
-    "Create" : "Erstellen",
     "Admin Recovery Password" : "Admin-Passwort-Wiederherstellung",
     "Enter the recovery password in order to recover the users files during password change" : "Geben Sie das Wiederherstellungspasswort ein, um die Benutzerdateien während der Passwortänderung wiederherzustellen",
     "Add Group" : "Gruppe hinzufügen",
@@ -326,6 +378,7 @@ OC.L10N.register(
     "Admins" : "Administratoren",
     "Default Quota" : "Standardkontingent",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Bitte Speicherkontingent eingeben (z.B.: „512 MB“ oder „12 GB“)",
+    "Unlimited" : "Unbegrenzt",
     "Other" : "Andere",
     "Full Name" : "Vollständiger Name",
     "Group Admin for" : "Gruppenadministrator für",
@@ -336,32 +389,6 @@ OC.L10N.register(
     "change full name" : "Vollständigen Namen ändern",
     "set new password" : "Neues Passwort setzen",
     "change email address" : "E-Mail-Adresse ändern",
-    "Default" : "Standard",
-    "Change" : "Ändern",
-    "Share" : "Teilen",
-    "installing and updating apps via the market or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
-    "White-listed Domains" : "Weiße Liste der Domains",
-    "Add Domain" : "Domain hinzufügen",
-    "Empty app name is not allowed." : "Ein leerer App-Name ist nicht erlaubt.",
-    "CORS" : "KERNE",
-    "User ID" : "Benutzer-ID",
-    "Email address" : "E-Mail-Adresse",
-    "Invalid email address" : "Ungültige E-Mail-Adresse",
-    "Extra field to display in autocomplete results" : "Separates Feld zur Anzeige des Autovervollständigen-Ergebnisses",
-    "Restrict users to only share with groups they are member of" : "Benutzer auf das Teilen innerhalb der Gruppen, deren Mitglied sie sind, beschränken",
-    "Default user and group share permissions" : "Nutzer und Gruppen Standard-Berechtigungen für das Teilen",
-    "Enforce password protection for read-only links" : "Passwort-Schutz für \"nur lesen\" Links durchsetzen",
-    "Enforce password protection for read & write links" : "Passwort-Schutz für lesbare und schreibbare Links durchsetzen.",
-    "Enforce password protection for upload-only (File Drop) links" : "Passwort-Schutz für \"nur hochladen\" Links/Dateien durchsetzen.",
-    "No Domains." : "Keine Domains.",
-    "Are you sure you want to remove this domain?" : "Sind Sie sicher, dass Sie diese Domain entfernen möchten?",
-    "Add" : "Hinzufügen",
-    "Domain" : "Domain",
-    "The config file is read only. Please adjust your setup by editing the config file manually." : "Die Konfigurationsdatei ist schreibgeschützt. Bitte passen Sie Ihre Einstellungen durch manuelle Bearbeitung der Konfigurationsdatei selbst an.",
-    "Email changed successfully for {user}." : "E-Mail erfolgreich für {user} geändert.",
-    "You are not a member of any groups." : "Du bist kein Mitglied einer Gruppe.",
-    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In einem gruppierten Umgebung stellen Sie bitte sicher, dass die config.php-Datei über alle Knoten synchronisiert wird.",
-    "You are using %s" : "Sie verwenden %s",
-    "These are the web, desktop and mobile clients currently logged in to your %s." : "Diese Web-, Desktop- und Mobil-Clients sind aktuell an 1%s angemeldet"
+    "Default" : "Standard"
 },
 "nplurals=2; plural=(n != 1);");
