@@ -1,40 +1,45 @@
 OC.L10N.register(
     "settings",
     {
-    "Wrong password" : "Väärä salasana",
-    "The new password can not be the same as the previous one" : "Uusi salasana ei voi sama kuin aiempi salasana",
     "No user supplied" : "Käyttäjää ei määritetty",
     "Authentication error" : "Tunnistautumisvirhe",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Taustaosa ei tue salasanan vaihtoa, mutta käyttäjän salausavain päivitettiin onnistuneesti.",
     "Unable to change password" : "Salasanan vaihto ei onnistunut",
+    "%s password changed successfully" : "%s salasana vaihdettiin onnistuneesti",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL käyttää vanhentunutta %s-versiota (%s). Päivitä käyttöjärjestelmäsi tai ominaisuudet kuten %s eivät toimi luotettavasti.",
-    "A problem occurred, please check your log files (Error: %s)" : "Tapahtui virhe, tarkista lokitiedostot (Virhe: %s)",
-    "Migration Completed" : "Migraatio valmistui",
     "Group already exists." : "Ryhmä on jo olemassa.",
     "Unable to add group." : "Ryhmän lisääminen ei onnistunut.",
     "Unable to delete group." : "Ryhmän poistaminen ei onnistunut.",
-    "log-level out of allowed range" : "lokitaso ei sallittujen rajojen sisäpuolella",
     "Saved" : "Tallennettu",
+    "log-level out of allowed range" : "lokitaso ei sallittujen rajojen sisäpuolella",
     "test email settings" : "testaa sähköpostiasetukset",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
     "Email sent" : "Sähköposti lähetetty",
     "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
+    "Your %s account was created" : "%s-tilisi luotiin",
     "Invalid mail address" : "Virheellinen sähköpostiosoite",
     "A user with that name already exists." : "Käyttäjä samalla nimellä on jo olemassa.",
     "Unable to create user." : "Käyttäjän luominen ei onnistunut.",
-    "Your %s account was created" : "%s-tilisi luotiin",
     "Unable to delete user." : "Käyttäjän poistaminen ei onnistunut.",
     "Forbidden" : "Estetty",
     "Invalid user" : "Virheellinen käyttäjä",
     "Unable to change mail address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
+    "Email has been changed successfully." : "Sähköpostiosoite vaihdettiin onnistuneesti.",
     "Your full name has been changed." : "Koko nimesi on muutettu.",
     "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
+    "%s email address confirm" : "%s sähköpostiosoite vahvistus",
+    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Ei voitu lähettää sähköpostiosoitteen vaihtamisen vahvistusta. Ole hyvä ja ota yhteyttä järjestelmänvalvojaan.",
+    "%s email address changed successfully" : "%s sähköpostiosoite vaihdettu onnistuneesti",
+    "Couldn't send email address change notification mail. Please contact your administrator." : "Ei voitu lähettää sähköpostiosoitteen vaihtamisen ilmoitusta. Ole hyvä ja ota yhteyttä järjestelmänvalvojaan.",
+    "Unable to enable/disable user." : "Ei voitu ottaa käyttöön tai poistaa käytöstä käyttäjää",
+    "Create" : "Luo",
+    "Change" : "Muuta",
+    "Delete" : "Poista",
+    "Share" : "Jaa",
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "__language_name__" : "_kielen_nimi_",
     "Language changed" : "Kieli on vaihdettu",
     "Invalid request" : "Virheellinen pyyntö",
     "Admins can't remove themself from the admin group" : "Ylläpitäjät eivät poistaa omia tunnuksiaan ylläpitäjien ryhmästä",
@@ -68,13 +73,10 @@ OC.L10N.register(
     "App update" : "Sovelluspäivitys",
     "Experimental" : "Kokeellinen",
     "No apps found for {query}" : "Haulla {query} ei löytynyt sovelluksia",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Haluatko varmasti liittää kohteen \"{domain}\" luotetuksi toimialueeksi?",
-    "Add trusted domain" : "Lisää luotettu toimialue",
     "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
     "Migration started …" : "Migraatio käynnistyi…",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
     "Valid until {date}" : "Kelvollinen {date} asti",
-    "Delete" : "Poista",
     "Disconnect" : "Katkaise yhteys",
     "Sending..." : "Lähetetään...",
     "An error occurred: {message}" : "Tapahtui virhe: {message}",
@@ -90,32 +92,32 @@ OC.L10N.register(
     "A valid group name must be provided" : "Anna kelvollinen ryhmän nimi",
     "deleted {groupName}" : "poistettu {groupName}",
     "undo" : "kumoa",
+    "Delete group" : "Poista ryhmä",
     "never" : "ei koskaan",
     "deleted {userName}" : "poistettu {userName}",
     "add group" : "lisää ryhmä",
     "Invalid quota value \"{val}\"" : "Virheellinen kiintiöarvo \"{val}\"",
     "enabled" : "Käytössä",
     "disabled" : "Poissa käytöstä",
+    "User {uid} has been {state}!" : "Käyttäjä {uid} on asetettu {state}!",
+    "no group" : "ei ryhmää",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Salasanan muuttaminen johtaa tietojen häviämiseen, koska tietojen palautusta ei ole käytettävissä tämän käyttäjän kohdalla",
     "Password successfully changed" : "Salasana muutettu onnistuneesti",
     "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
     "Error creating user: {message}" : "Virhe käyttäjää luotaessa: {message}",
     "A valid password must be provided" : "Anna kelvollinen salasana",
     "A valid email must be provided" : "Tarvitaan kelvollinen sähköpostiosoite",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hei<br><br>Sinulla on nyt %s-tili.<br><br>Käyttäjätunnus: %s<br>Aloita käyttö: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Kippis!",
+    "Use the following link to confirm your changes to the email address: {link}" : "Käytä oheistä linkkiä vahvistaaksesi muutoksesi sähköpostiosoitteseen: {link}",
+    "Email address changed to {mailAddress} successfully." : "Uusi sähköpostiosoite {mailAddress} vaihdettiin onnistuneesti.",
+    "Cheers!" : "Kiitos!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hei\n\nSinulla on nyt %s-tili.\n\nKäyttäjätunnuksesi: %s\nAloita käyttö: %s\n\n",
-    "User documentation" : "Käyttäjädokumentaatio",
-    "Administrator documentation" : "Ylläpidon dokumentaatio",
-    "Online documentation" : "Verkkodokumentaatio",
-    "Forum" : "Keskustelupalsta",
-    "Issue tracker" : "Ongelmien seuranta",
-    "Commercial support" : "Kaupallinen tuki",
+    "Language" : "Kieli",
     "Apps Management" : "Sovellushallinta",
     "Developer documentation" : "Kehittäjädokumentaatio",
     "by %s" : "tekijä %s",
     "%s-licensed" : "%s -lisensoitu",
     "Documentation:" : "Ohjeistus:",
+    "User documentation" : "Käyttäjädokumentaatio",
     "Admin documentation" : "Ylläpitäjän ohjeistus",
     "Visit website" : "Käy verkkosivustolla",
     "Report a bug" : "Ilmoita viasta",
@@ -159,13 +161,11 @@ OC.L10N.register(
     "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
     "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
     "Allow public uploads" : "Salli julkiset lähetykset",
-    "Enforce password protection" : "Pakota salasanasuojaus",
     "Set default expiration date" : "Aseta oletusvanhenemispäivä",
-    "Allow users to send mail notification for shared files" : "Salli käyttäjien lähettää sähköposti-ilmoituksia jaetuista tiedostoista",
-    "Allow users to share file via social media" : "Salli käyttäjien jakaa tiedosto sosiaalisessa mediassa",
     "Expire after " : "Vanhenna",
     "days" : "päivän jälkeen",
-    "Enforce expiration date" : "Pakota vanhenemispäivä",
+    "Allow users to send mail notification for shared files" : "Salli käyttäjien lähettää sähköposti-ilmoituksia jaetuista tiedostoista",
+    "Allow users to share file via social media" : "Salli käyttäjien jakaa tiedosto sosiaalisessa mediassa",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
     "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
@@ -173,6 +173,8 @@ OC.L10N.register(
     "Exclude groups from sharing" : "Kiellä ryhmiä jakamasta",
     "These groups will still be able to receive shares, but not to initiate them." : "Nämä ryhmät kykenevät vastaanottamaan jakoja, mutta eivät kuitenkaan itse pysty luoda jakoja.",
     "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Salli käyttäjätunnuksen automaattinen täydentäminen jakamisikkunnassa. Jos tämä asetus on pois käytöstä, tulee käyttäjätunnus kirjoittaa kokonaan itse.",
+    "None" : "Ei mitään",
+    "Save" : "Tallenna",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Kaikki (vakavat ongelmat, virheet, varoitukset, tiedot, vianjäljitys)",
     "Info, warnings, errors and fatal issues" : "Tiedot, varoitukset, virheet ja vakavat ongelmat",
     "Warnings, errors and fatal issues" : "Varoitukset, virheet ja vakavat ongelmat",
@@ -182,7 +184,6 @@ OC.L10N.register(
     "What to log" : "Mitä kerätään lokiin",
     "Download logfile (%s)" : "Lataa lokitiedosto (%s)",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Lokitiedosto on kooltaan yli 100 megatavua. Sen lataaminen saattaa kestää hetken.",
-    "None" : "Ei mitään",
     "Login" : "Kirjaudu",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
@@ -217,7 +218,6 @@ OC.L10N.register(
     "System Status" : "Järjestelmän tila",
     "Tips & tricks" : "Vinkit",
     "How to do backups" : "Kuinka tehdä varmuuskopioita",
-    "Advanced monitoring" : "Edistynyt valvonta",
     "Performance tuning" : "Suorituskyvyn hienosäätö",
     "Improving the config.php" : "Config.php-tiedoston parantaminen",
     "Theming" : "Teemojen käyttö",
@@ -228,6 +228,7 @@ OC.L10N.register(
     "iOS app" : "iOS-sovellus",
     "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Jos haluat tukea projektia,\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">osallistu kehitykseen</a>\n\t\t\ttai\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">levitä sanaa</a>!",
     "Show First Run Wizard again" : "Näytä ensimmäisen käyttökerran avustaja uudelleen",
+    "Add" : "Lisää",
     "Profile picture" : "Profiilikuva",
     "Upload new" : "Lähetä uusi",
     "Select from Files" : "Valitse tiedostosovelluksesta",
@@ -248,36 +249,30 @@ OC.L10N.register(
     "Current password" : "Nykyinen salasana",
     "New password" : "Uusi salasana",
     "Change password" : "Vaihda salasana",
-    "Language" : "Kieli",
     "Help translate" : "Auta kääntämisessä",
-    "Unlimited" : "Rajoittamaton",
-    "You are using %s of %s" : "Käytössäsi on %s/%s",
-    "You are using %s of %s (%s %%)" : "Käytössäsi on %s/%s (%s %%)",
+    "You are using %s" : "Käyttämäsi tila on %s",
+    "You are using %s of %s (%s %%)" : "Käyttämäsi tila on %s/%s (%s %%)",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Kehityksestä on vastannut {communityopen}ownCloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}<abbr title=\"Affero General Public License\">AGPL-lisensoitu</abbr>{linkclose}.",
     "Sessions" : "Istunnot",
-    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Nämä ovat parhaillaan ownCloudiisi kirjautuneet verkko-, työpöytä- ja mobiilisovellukset.",
     "Browser" : "Selain",
     "Most recent activity" : "Viimeisimmät toimet",
-    "App passwords" : "Sovellusten salasanat",
     "You've linked these apps." : "Olet linkittänyt nämä sovellukset.",
     "Name" : "Nimi",
-    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Sovellussalasana on suojakoodi, joka antaa sovellukselle tai laitteelle käyttöoikeuden %s-tiliisi.",
     "App name" : "Sovelluksen nimi",
-    "Create new app password" : "Luo uusi sovellussalasana",
     "Use the credentials below to configure your app or device." : "Käytä alla olevia kirjautumistietoja määrittääksesi sovelluksesi tai laitteen.",
     "Username" : "Käyttäjätunnus",
     "Done" : "Valmis",
     "Version" : "Versio",
+    "New Password" : "Uusi salasana",
     "Personal" : "Henkilökohtainen",
     "Admin" : "Ylläpito",
-    "Error" : "Virhe",
+    "Settings" : "Asetukset",
+    "Show enabled/disabled option" : "Näytä käytössä/ei käytössä vaihtoehto",
     "Show storage location" : "Näytä tallennustilan sijainti",
     "Show last log in" : "Näytä viimeisin sisäänkirjautuminen",
     "Show user backend" : "Näytä käyttäjätaustaosa",
-    "Send email to new user" : "Lähetä sähköpostia uudelle käyttäjälle",
     "Show email address" : "Näytä sähköpostiosoite",
     "E-Mail" : "Sähköposti",
-    "Create" : "Luo",
     "Admin Recovery Password" : "Ylläpitäjän palautussalasana",
     "Enter the recovery password in order to recover the users files during password change" : "Anna palautussalasana, jotta käyttäjien tiedostot on mahdollista palauttaa salasanan muuttamisen yhteydessä",
     "Add Group" : "Lisää ryhmä",
@@ -286,8 +281,10 @@ OC.L10N.register(
     "Admins" : "Ylläpitäjät",
     "Default Quota" : "Oletuskiintiö",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Määritä tallennustilan kiintiö (esim. \"512 MB\" tai \"12 GB\")",
+    "Unlimited" : "Rajoittamaton",
     "Other" : "Muu",
     "Full Name" : "Koko nimi",
+    "Group Admin for" : "Ryhmäylläpitäjä kohteille",
     "Quota" : "Kiintiö",
     "Storage Location" : "Tallennustilan sijainti",
     "User Backend" : "Käyttäjätaustaosa",
@@ -295,9 +292,6 @@ OC.L10N.register(
     "change full name" : "muuta koko nimi",
     "set new password" : "aseta uusi salasana",
     "change email address" : "vaihda sähköpostiosoite",
-    "Default" : "Oletus",
-    "Change" : "Muuta",
-    "Share" : "Jaa",
-    "Add" : "Lisää"
+    "Default" : "Oletus"
 },
 "nplurals=2; plural=(n != 1);");
