@@ -1,8 +1,8 @@
 OC.L10N.register(
     "settings",
     {
-    "Wrong password" : "Mot de passe incorrect",
-    "The new password can not be the same as the previous one" : "Le nouveau mot de passe ne peut pas être le même que l'ancien",
+    "Wrong current password" : "Mot de passe actuel incorrect",
+    "The new password cannot be the same as the previous one" : "Le nouveau mot de passe ne peut pas être le même que l'ancien",
     "No user supplied" : "Aucun utilisateur fourni",
     "Authentication error" : "Erreur d'authentification",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues.",
@@ -11,38 +11,52 @@ OC.L10N.register(
     "Unable to change password" : "Impossible de modifier le mot de passe",
     "%s password changed successfully" : "Le mot de passe %s a été correctement changé",
     "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "installation et mise à jour des applications via le marché ou le Cloud Fédéré Partagé",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilise %s %s, qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %s ne fonctionneront pas correctement.",
-    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
-    "Migration Completed" : "Migration terminée",
+    "Invalid url '%s'. Urls should be set up like 'http://www.example.com' or 'https://www.example.com'" : "Url invalide '%s'. Les Urls doivent être de la forme 'http://www.exemple.com' ou 'https://www.exemple.com'",
     "Group already exists." : "Ce groupe existe déjà.",
     "Unable to add group." : "Impossible d'ajouter le groupe.",
     "Unable to delete group." : "Impossible de supprimer le groupe.",
-    "log-level out of allowed range" : "niveau de journalisation hors borne",
     "Saved" : "Sauvegardé",
+    "log-level out of allowed range" : "niveau de journalisation hors borne",
+    "Invalid email address" : "Adresse mail invalide",
     "test email settings" : "Test des paramètres e-mail",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
     "Email sent" : "E-mail envoyé",
     "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
     "Couldn't change the email address because the user does not exist" : "Le courriel n'a pas pu être mise à jour car l'utilisateur n'existe pas",
     "Couldn't change the email address because the token is invalid" : "Le courriel n'a pas pu être mise à jour car le jeton est invalide",
-    "Invalid mail address" : "Adresse e-mail non valide",
-    "A user with that name already exists." : "Un utilisateur à ce nom existe déjà.",
-    "Unable to create user." : "Impossible de créer l'utilisateur.",
     "Your %s account was created" : "Votre compte %s a été créé",
+    "Invalid mail address" : "Adresse e-mail non valide",
+    "A user with that name already exists." : "Un utilisateur avec ce nom existe déjà.",
+    "Unable to create user." : "Impossible de créer l'utilisateur.",
+    "The token provided is invalid." : "Le jeton fourni n'est pas valide.",
+    "The token provided had expired." : "Le jeton fourni est expiré.",
+    "Failed to create activation link. Please contact your administrator." : "Échec de la création du lien d'activation. Veuillez contacter votre administrateur.",
+    "Can't send email to the user. Contact your administrator." : "Impossible d'envoyer un courrier électronique à l'utilisateur. Contactez votre administrateur.",
+    "Failed to set password. Please contact the administrator." : "Impossible de définir le mot de passe. Veuillez contacter l'administrateur.",
+    "Failed to set password. Please contact your administrator." : "Impossible de définir le mot de passe. Veuillez contacter votre administrateur.",
+    "Failed to send email. Please contact your administrator." : "Impossible de définir le mot de passe. Veuillez contacter l'administrateur.",
     "Unable to delete user." : "Impossible de supprimer l'utilisateur.",
     "Forbidden" : "interdit",
     "Invalid user" : "Utilisateur non valable",
     "Unable to change mail address" : "Impossible de modifier l'adresse e-mail",
     "Email has been changed successfully." : "Le courriel a été correctement modifiée.",
+    "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "Un mail a été envoyé à cette adresse pour confirmation. Jusqu'à ce que l'email soit vérifié, cette adresse ne sera pas configurée.",
+    "No email was sent because you already sent one recently. Please try again later." : "Aucun courriel n'a été envoyé car vous en avez déjà reçu un récemment. Veuillez réessayer ultérieurement",
     "Your full name has been changed." : "Votre nom complet a été modifié.",
     "Unable to change full name" : "Impossible de changer le nom complet",
+    "%s email address confirm" : "Confirmation de l'adresse de courriel %s",
     "Couldn't send email address change confirmation mail. Please contact your administrator." : "Impossible d'envoyer le courriel de confirmation. Veuillez contacter votre administrateur.",
+    "%s email address changed successfully" : "l'adresse de courriel %s a été modifiée avec succès",
+    "Couldn't send email address change notification mail. Please contact your administrator." : "Impossible d'envoyer un courriel de notification de changement d'adresse. Veuillez contacter votre administrateur.",
     "Unable to enable/disable user." : "Impossible d'activer/désactiver l'utilisateur.",
+    "Create" : "Créer",
+    "Change" : "Modification",
+    "Delete" : "Supprimer",
+    "Share" : "Partager",
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "__language_name__" : "Français",
     "Language changed" : "Langue changée",
     "Invalid request" : "Requête non valide",
     "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
@@ -76,20 +90,20 @@ OC.L10N.register(
     "App update" : "Mise à jour",
     "Experimental" : "Expérimentale",
     "No apps found for {query}" : "Aucune application trouvée pour {query}",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter \"{domain}\" comme domaine de confiance ?",
-    "Add trusted domain" : "Ajouter un domaine de confiance",
     "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
     "Migration started …" : "Migration démarrée...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
     "Valid until {date}" : "Valide jusqu'au {date}",
-    "Delete" : "Supprimer",
     "Disconnect" : "Déconnexion",
     "Error while loading browser sessions and device tokens" : "Erreur lors du chargement des jetons de la session du navigateur et de l'appareil",
+    "Empty app name is not allowed." : "Un nom d'application vide n'est pas autorisé.",
     "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
     "Error while deleting the token" : "Erreur lors de la suppression du jeton",
+    "Are you sure you want to remove this domain?" : "Êtes-vous sûr de vouloir supprimer ce domaine ?",
+    "CORS" : "Partage de ressources d'origines croisées",
     "Sending..." : "Envoi en cours...",
     "Failed to change the email address." : "Impossible de modifier le courriel.",
-    "Email changed successfully." : "Courriel modifié avec succès.",
+    "Email changed successfully for {user}." : "L'Email de {utilisateur} à été mis à jour.",
     "An error occurred: {message}" : "Une erreur est survenue : {message}",
     "Select a profile picture" : "Selectionnez une photo de profil ",
     "Very weak password" : "Mot de passe de très faible sécurité",
@@ -97,18 +111,24 @@ OC.L10N.register(
     "So-so password" : "Mot de passe de sécurité tout juste acceptable",
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe de forte sécurité",
+    "Passwords do not match" : "Les mots de passe ne correspondent pas",
     "Groups" : "Groupes",
     "Unable to delete {objName}" : "Impossible de supprimer {objName}",
     "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
     "A valid group name must be provided" : "Vous devez spécifier un nom de groupe valide",
     "deleted {groupName}" : "{groupName} supprimé",
     "undo" : "annuler",
+    "You are about to delete a group. This action can't be undone and is permanent. Are you sure that you want to permanently delete {groupName}?" : "Vous êtes sur le point de supprimer un groupe. Cette action ne peut pas être annulée et est permanente. Êtes-vous sûr de vouloir supprimer définitivement {groupName}? ",
+    "Delete group" : "Effacer le groupe",
     "never" : "jamais",
     "deleted {userName}" : "{userName} supprimé",
+    "You are about to delete a user. This action can't be undone and is permanent. All user data, files and shares will be deleted. Are you sure that you want to permanently delete {userName}?" : "Vous êtes sur le point de supprimer un utilisateur. Cette action ne peut pas être annulée et est permanente. Toutes les données utilisateur, fichiers et partages seront supprimés. Êtes-vous sûr de vouloir supprimer définitivement {userName}?",
+    "Delete user" : "Supprimer l'utilisateur",
     "add group" : "ajouter un groupe",
     "Invalid quota value \"{val}\"" : "Valeur de quota invalide \"{val}\"",
     "enabled" : "activé",
     "disabled" : "désactivé",
+    "User {uid} has been {state}!" : "L'utilisateur {uid} a été {state}!",
     "no group" : "Aucun groupe",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
     "Password successfully changed" : "Mot de passe changé avec succès",
@@ -116,19 +136,18 @@ OC.L10N.register(
     "Error creating user: {message}" : "Erreur a la création d'un utilisateur : {message}",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : <a href=\"%s\">%s</a><br><br>",
+    "Use the following link to confirm your changes to the email address: {link}" : "Utilisez ce lien pour confirmer votre changement d'adresse de courriel : {link} ",
+    "Email address changed to {mailAddress} successfully." : "L'adresse de courriel a été changée avec succès en :  {mailAddress}",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Please set the password by accessing it: <a href=\"%s\">Here</a><br><br>" : "Bonjour,<br><br>Votre compte %s a été créé.<br><br>Votre nom d'utilisateur : %s<br>Veuillez définir un mot de passe en <a href=\"%s\">cliquant ici.</a><br><br>",
     "Cheers!" : "À bientôt !",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : %s<br><br>\n",
-    "User documentation" : "Documentation utilisateur",
-    "Administrator documentation" : "Documentation administrateur",
-    "Online documentation" : "Documentation en ligne",
-    "Forum" : "Forum",
-    "Issue tracker" : "Suivi de problèmes",
-    "Commercial support" : "Support commercial",
+    "Language" : "Langue",
+    "Apps Management" : "Gestion des applications",
     "Developer documentation" : "Documentation pour développeurs",
     "by %s" : "par %s",
     "%s-licensed" : "Sous licence %s",
     "Documentation:" : "Documentation :",
+    "User documentation" : "Documentation utilisateur",
     "Admin documentation" : "Documentation administrateur",
     "Visit website" : "Visiter le site web",
     "Report a bug" : "Signaler un bogue",
@@ -139,6 +158,8 @@ OC.L10N.register(
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
     "Enable only for specific groups" : "Activer uniquement pour certains groupes",
     "Uninstall App" : "Désinstaller l'application",
+    "Show enabled apps" : "Montrer les applications activées",
+    "Show disabled apps" : "Montrer les applications désactivées",
     "Cron" : "Cron",
     "Last cron job execution: %s." : "Dernière tâche cron exécutée : %s.",
     "Last cron job execution: %s. Something seems wrong." : "Dernière tâche cron exécutée : %s. Quelque chose s'est mal passé.",
@@ -171,20 +192,32 @@ OC.L10N.register(
     "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
     "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
     "Allow public uploads" : "Autoriser les téléversements publics",
-    "Enforce password protection" : "Imposer la protection par mot de passe",
+    "Enforce password protection for read-only links" : "Forcer la protection par mot de passe pour les liens en lecture seule",
+    "Enforce password protection for read + write links" : "Forcer la protection par mot de passe pour les liens en écriture et lecture",
     "Set default expiration date" : "Spécifier une date d'expiration par défaut",
-    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
-    "Allow users to share file via social media" : "Autoriser les utilisateurs à partager un fichier via les réseaux sociaux",
     "Expire after " : "Expiration après ",
     "days" : "jours",
-    "Enforce expiration date" : "Imposer la date d'expiration",
+    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
+    "Allow users to share file via social media" : "Autoriser les utilisateurs à partager un fichier via les réseaux sociaux",
     "Allow resharing" : "Autoriser le repartage",
     "Allow sharing with groups" : "Autoriser le partage avec les groupes",
     "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
+    "Restrict users to only share with groups they are member of" : "N'autoriser les utilisateurs qu'à partager avec les groupes dont ils sont membre",
     "Allow users to send mail notification for shared files to other users" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
     "Exclude groups from sharing" : "Empêcher certains groupes de partager",
     "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
     "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée,  les noms complets doivent être indiqués.",
+    "Restrict enumeration to group members" : "Restreindre l'énumération aux membres du groupe",
+    "Default user and group share permissions" : "Autorisations par défaut de partage de groupe et d'utilisateur",
+    "Extra field to display in autocomplete results" : "Champ supplémentaire à afficher dans les résultats de l'Auto-complétion",
+    "None" : "Aucun",
+    "User ID" : "ID utilisateur",
+    "Email address" : "Adresse mail",
+    "Imprint URL:" : "adresse d'Mentions légales : ",
+    "Imprint URL" : "adresse d'Mentions légales",
+    "Privacy Policy URL:" : "adresse de la Politique de confidentialité : ",
+    "Privacy Policy URL" : "adresse de la Politique de confidentialité",
+    "Save" : "Enregistrer",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
     "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
     "Warnings, errors and fatal issues" : "Avertissements, erreurs et erreurs fatales",
@@ -194,13 +227,14 @@ OC.L10N.register(
     "What to log" : "Ce qu'il faut journaliser",
     "Download logfile (%s)" : "Télécharger le fichier journal (%s)",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La taille du fichier journal excède 100 Mo. Le télécharger peut prendre un certain temps!",
-    "None" : "Aucun",
     "Login" : "Login",
     "Plain" : "En clair",
     "NT LAN Manager" : "Gestionnaire du réseau NT",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "Email server" : "Serveur e-mail",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Le fichier de configuration est en lecture seule. Veuillez ajuster votre configuration en éditant manuellement le fichier.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Dans une configuration de grappe, assurez-vous de synchroniser le fichier config.php sur chaque nœud.",
     "This is used for sending out notifications." : "Ceci est utilisé pour l'envoi des notifications.",
     "Send mode" : "Mode d'envoi",
     "Encryption" : "Chiffrement",
@@ -238,9 +272,9 @@ OC.L10N.register(
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
     "All checks passed." : "Tous les tests ont réussi.",
+    "System Status" : "Statut du système",
     "Tips & tricks" : "Trucs et astuces",
     "How to do backups" : "Comment faire des sauvegardes",
-    "Advanced monitoring" : "Surveillance avancée",
     "Performance tuning" : "Ajustement des performances",
     "Improving the config.php" : "Amélioration du config.php ",
     "Theming" : "Personnalisation de l'apparence",
@@ -249,7 +283,13 @@ OC.L10N.register(
     "Desktop client" : "Client de bureau",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
+    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vous souhaitez soutenir le projet\n⇥⇥⇥<a href=\"https://owncloud.org/contribute\"\n\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">rejoignez l'équipe de développement</a>\n\n⇥⇥⇥ou\n\n⇥⇥⇥<a href=\"https://owncloud.org/promote\"\n\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">Faites passer !</a>!",
     "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
+    "White-listed Domains" : "Liste blanche de domaines",
+    "No Domains." : "Pas de domaines.",
+    "Domain" : "Domaine",
+    "Add Domain" : "Ajouter un domaine",
+    "Add" : "Ajouter",
     "Profile picture" : "Photo de profil",
     "Upload new" : "Nouvelle depuis votre ordinateur",
     "Select from Files" : "Sélectionner depuis les Fichiers",
@@ -262,42 +302,56 @@ OC.L10N.register(
     "No display name set" : "Aucun nom d'affichage configuré",
     "Email" : "Adresse e-mail",
     "Your email address" : "Votre adresse e-mail",
+    "Change email" : "Changer l'adresse de courriel",
+    "Set email" : "Définir le courriel",
     "For password recovery and notifications" : "Pour la récupération de mot de passe et les notifications",
     "No email address set" : "Aucune adresse e-mail configurée",
     "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
+    "You are not a member of any groups." : "Vous n'êtes membre d'aucun groupe.",
     "Password" : "Mot de passe",
     "Unable to change your password" : "Impossible de changer votre mot de passe",
     "Current password" : "Mot de passe actuel",
     "New password" : "Nouveau mot de passe",
     "Change password" : "Changer de mot de passe",
-    "Language" : "Langue",
     "Help translate" : "Aidez à traduire",
-    "Unlimited" : "Illimité",
+    "You are using %s" : "Vous utilisez %s",
+    "You are using %s of %s (%s %%)" : "Vous utilisez %s sur %s (%s %%)",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Développé par la {communityopen}communauté ownCloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Sessions" : "Sessions",
-    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Voici les clients web, de bureau et mobiles actuellement connectés à votre ownCloud.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Voivi les clients Web, de bureau et mobiles actuellement connectés à votre %s.",
     "Browser" : "Navigateur",
     "Most recent activity" : "Activité la plus récente",
-    "App passwords" : "Mots de passe d'applications",
+    "App passwords / tokens" : "mots de passe / jetons d'application",
     "You've linked these apps." : "Vous avez lié ces applications.",
     "Name" : "Nom",
-    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Un mot de passe d'une application est un code d'accès qui donne à une application ou à un appareil les droits d'accès à votre compte %s.",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Les mots de passe d'application ou jetons sont des code d'accés qui donne à une application ou à un appareil les droits d'accès à votre compte %s.",
     "App name" : "Nom de l'application",
-    "Create new app password" : "Créer un nouveau mot de passe d'application",
+    "Create new app passcode" : "Créer un nouveau code de sécurité d'application",
     "Use the credentials below to configure your app or device." : "Utilisez les identifiants ci-dessous pour configurer votre application ou votre périphérique.",
     "Username" : "Nom d'utilisateur",
+    "Password / Token" : "mot de passe / jeton",
     "Done" : "Terminé",
     "Version" : "Version",
+    "The activation link has expired. Click the button below to request a new one and complete the registration." : "Le lien d'activation a expiré. Cliquez sur le bouton ci-dessous pour en demander un nouveau et terminer l'enregistrement.",
+    "Resend activation link" : "Renvoyer le lien d'activation",
+    "New Password" : "Nouveau mot de passe",
+    "Confirm Password" : "Confirmer le mot de passe",
+    "Please set your password" : "Veuillez entrer votre mot de passe",
     "Personal" : "Personnel",
     "Admin" : "Administration",
-    "Error" : "Erreur",
+    "Currently no settings are available in this category" : "Actuellement, aucun paramètre n'est disponible dans cette catégorie",
+    "The administrators can enable additional apps which add settings sections here." : "Les administrateurs peuvent activer des applications supplémentaires qui ajoutent des rubriques de paramètres ici.",
+    "Activation link was sent to an email address, if one was configured." : "Le lien d'activation a été envoyé à une adresse électronique, si elle a été configurée.",
+    "Settings" : "Paramètres",
+    "Show enabled/disabled option" : "Afficher l'option Activé/Désactivé",
     "Show storage location" : "Afficher l'emplacement du stockage",
     "Show last log in" : "Montrer la dernière connexion",
     "Show user backend" : "Montrer la source de l'identifiant",
-    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
+    "Set password for new users" : "Définir un mot de passe pour les nouveaux utilisateurs",
     "Show email address" : "Afficher l'adresse e-mail",
-    "E-Mail" : "E-Mail",
-    "Create" : "Créer",
+    "Show password field" : "Montrer le champs mot de passe",
+    "Show quota field" : "Montrer le champs quota",
+    "E-Mail" : "Courriel",
     "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
     "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
     "Add Group" : "Ajouter un groupe",
@@ -306,6 +360,7 @@ OC.L10N.register(
     "Admins" : "Administrateurs",
     "Default Quota" : "Quota par défaut",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
+    "Unlimited" : "Illimité",
     "Other" : "Autre",
     "Full Name" : "Nom complet",
     "Group Admin for" : "Administrateur de groupe pour",
@@ -316,35 +371,6 @@ OC.L10N.register(
     "change full name" : "Modifier le nom complet",
     "set new password" : "Changer le mot de passe",
     "change email address" : "changer l'adresse e-mail",
-    "Default" : "Défaut",
-    "Change" : "Modification",
-    "Share" : "Partager",
-    "installing and updating apps via the market or Federated Cloud Sharing" : "installation et mise à jour des applications via le marché ou le Cloud Fédéré Partagé",
-    "Invalid email address" : "Adresse mail invalide",
-    "System Status" : "Statut du système",
-    "White-listed Domains" : "Liste blanche de domaines",
-    "Domain" : "Domaine",
-    "Add Domain" : "Ajouter un domaine",
-    "Change email" : "Changer l'adresse de courriel",
-    "Set email" : "Définir le courriel",
-    "You are using %s of %s" : "Vous utilisez %s sur %s",
-    "CORS" : "Partage de ressources d'origines croisées",
-    "Apps Management" : "Gestion des applications",
-    "Show enabled apps" : "Montrer les applications activées",
-    "Show disabled apps" : "Monter les applications désactivées",
-    "User ID" : "ID utilisateur",
-    "Email address" : "Adresse mail",
-    "Restrict enumeration to group members" : "Restreindre l'énumération aux membres du groupe",
-    "Restrict users to only share with groups they are member of" : "N'autoriser les utilisateurs qu'à partager avec les groupes dont ils sont membre",
-    "Default user and group share permissions" : "Autorisations par défaut de partage de groupe et d'utilisateur",
-    "You are using %s of %s (%s %%)" : "Vous utilisez %s sur %s (%s %%)",
-    "No Domains." : "Pas de domaines.",
-    "Are you sure you want to remove this domain?" : "Êtes-vous sûr de vouloir supprimer ce domaine ?",
-    "Add" : "Ajouter",
-    "No panels for this section." : "Pas de panneau dans cette section",
-    "Empty app name is not allowed." : "Un nom d'application vide n'est pas autorisé.",
-    "The config file is read only. Please adjust your setup by editing the config file manually." : "Le fichier de configuration est en lecture seule. Veuillez ajuster votre configuration en éditant manuellement le fichier.",
-    "Email changed successfully for {user}." : "L'Email de {utilisateur} à été mis à jour.",
-    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Dans une configuration de grappe, assurez-vous de synchroniser le fichier config.php sur chaque nœud."
+    "Default" : "Défaut"
 },
 "nplurals=2; plural=(n > 1);");
