@@ -1,40 +1,53 @@
 OC.L10N.register(
     "settings",
     {
-    "Wrong password" : "Hibás jelszó",
+    "Wrong current password" : "A jelenlegi jelszót helytelenül adtad meg",
+    "The new password cannot be the same as the previous one" : "Az új jelszó nem lehet ugyanaz, mint az előző",
     "No user supplied" : "Nincs megadva felhasználó",
     "Authentication error" : "Azonosítási hiba",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Adjon meg admin helyreállító jelszót, egyébként valamennyi felhasználói adat törlődik.",
     "Wrong admin recovery password. Please check the password and try again." : "Hibás admin helyreállítási jelszó. Ellenőrizze a jelszót és próbálja újra!",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A háttér-alrendszer nem támogatja a jelszómódosítást, de felhasználó titkosítási kulcsát sikeresen frissítettük.",
     "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
+    "%s password changed successfully" : "%s jelszó sikeresen megváltozott",
     "Couldn't send reset email. Please contact your administrator." : "Visszaállítási e-mail nem küldhető. Kérjük, lépjen kapcsolatba a rendszergazdával.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "alkalmazások telepítése és frissítése az alkalmazás tárból vagy Szövetséges Felhő Megosztásból",
-    "Federated Cloud Sharing" : "Megosztás Egyesített Felhőben",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL elavult %s verziót (%s) használ. Kérjük, frissítse az operációs rendszerét, vagy egyes funkciók (mint például a %s) megbízhatatlanul fognak működni.",
-    "A problem occurred, please check your log files (Error: %s)" : "Probléma történt, kérjük nézd meg a naplófájlokat (Hiba: %s).",
-    "Migration Completed" : "Migráció kész!",
     "Group already exists." : "A csoport már létezik.",
     "Unable to add group." : "Nem lehet létrehozni a csoportot.",
     "Unable to delete group." : "Nem lehet törölni a csoportot.",
-    "log-level out of allowed range" : "A naplózási szint a megengedett terjedelmen kívül van.",
     "Saved" : "Elmentve",
+    "log-level out of allowed range" : "A naplózási szint a megengedett terjedelmen kívül van.",
+    "Invalid email address" : "Érvénytelen email cím",
     "test email settings" : "e-mail beállítások ellenőrzése",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hiba történt az e-mail küldésekor. Kérjük ellenőrizd a beállításokat! (Hiba: %s)",
     "Email sent" : "Az e-mail elküldve!",
     "You need to set your user email before being able to send test emails." : "Előbb meg kell adnia az e-mail címét, mielőtt tesztelni tudná az e-mail küldést.",
+    "Couldn't change the email address because the user does not exist" : "Az email címet men lehet megváltoztatni mert a felhasználó nem létezik",
+    "Couldn't change the email address because the token is invalid" : "Nem sikerült megváltoztatni az e-mail címet, mert a token érvénytelen",
+    "Your %s account was created" : "%s fiók létrehozva",
     "Invalid mail address" : "Érvénytelen e-mail cím",
     "A user with that name already exists." : "Ilyen névvel már létezik felhasználó!",
     "Unable to create user." : "Nem lehet létrehozni a felhasználót.",
-    "Your %s account was created" : "%s fiók létrehozva",
     "Unable to delete user." : "Nem lehet törölni a felhasználót.",
     "Forbidden" : "Tiltott",
     "Invalid user" : "Érvénytelen felhasználó",
     "Unable to change mail address" : "Nem lehet megváltoztatni az e-mail címet",
+    "Email has been changed successfully." : "Az email cím megváltoztatása sikeres volt.",
+    "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "Erre a címre e-mailt küldtek megerősítés céljából. Amíg az e-mailt nem ellenőrizzük, ez a cím nem lesz beállítva.",
+    "No email was sent because you already sent one recently. Please try again later." : "Nem küldtünk e-mailt, mert már nemrégiben küldtél. Kérlek, próbáld újra később.",
     "Your full name has been changed." : "Az Ön teljes nevét módosítottuk.",
     "Unable to change full name" : "Nem sikerült megváltoztatni a teljes nevét",
+    "%s email address confirm" : "%se-mail cím megerősítése",
+    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Nem sikerült elküldeni az e-mail cím módosítási megerősítő üzenetet. Kérjük, lépjen kapcsolatba a rendszergazdájával.",
+    "%s email address changed successfully" : "%s az email cím megváltoztatása sikeres",
+    "Couldn't send email address change notification mail. Please contact your administrator." : "Nem sikerült elküldeni az e-mail cím módosítási értesítést. Kérjük, lépjen kapcsolatba a rendszergazdájával.",
+    "Unable to enable/disable user." : "A felhasználó engedélyezése / tiltása nem lehetséges.",
+    "Create" : "Létrehozás",
+    "Change" : "Változás",
+    "Delete" : "Törlés",
+    "Share" : "Megosztás",
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "__language_name__" : "__language_name__",
     "Language changed" : "A nyelv megváltozott",
     "Invalid request" : "Érvénytelen kérés",
     "Admins can't remove themself from the admin group" : "Adminisztrátorok nem távolíthatják el magukat az admin csoportból.",
@@ -68,14 +81,18 @@ OC.L10N.register(
     "App update" : "Alkalmazás frissítése",
     "Experimental" : "Kísérleti",
     "No apps found for {query}" : "{query} keresésre nincs találat",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Biztos abban, hogy hozzá akarja adni \"{domain}\"-t a megbízható tartományokhoz?",
-    "Add trusted domain" : "Megbízható tartomány hozzáadása",
     "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérjük várj, míg a migráció befejeződik.",
     "Migration started …" : "Migráció elindítva ...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hiba történt! Kérem töltsön fel egy, ASCII karakterekkel kódolt PEM tanusítványt!",
     "Valid until {date}" : "Érvényes: {date}",
-    "Delete" : "Törlés",
+    "Disconnect" : "Szétkapcsol",
+    "Error while loading browser sessions and device tokens" : "Hiba történt a böngésző munkamenetek és eszköztokenek betöltése során",
+    "Empty app name is not allowed." : "Az alkalmazásnév nem lehet üres.",
+    "Error while creating device token" : "Hiba történt az eszköztoken generálása közben",
+    "Error while deleting the token" : "Hiba történt az eszköztoken törlése közben",
     "Sending..." : "Küldés...",
+    "Failed to change the email address." : "Az email cím megváltoztatása sikertelen.",
+    "Email changed successfully for {user}." : "A(z) {user} felhasználó email címe sikeresen megváltozott.",
     "An error occurred: {message}" : "Hiba történt: {message}",
     "Select a profile picture" : "Válasszon profilképet!",
     "Very weak password" : "Nagyon gyenge jelszó",
@@ -89,31 +106,36 @@ OC.L10N.register(
     "A valid group name must be provided" : "Érvényes csoportnevet kell megadni",
     "deleted {groupName}" : "törölve: {groupName}",
     "undo" : "visszavonás",
+    "Delete group" : "Csoport törlése",
     "never" : "soha",
     "deleted {userName}" : "törölve: {userName}",
+    "Delete user" : "Felhasználó törlése",
     "add group" : "csoport hozzáadása",
+    "Invalid quota value \"{val}\"" : "Érvénytelen kvótaérték \"{val}\"",
     "enabled" : "Bekapcsolva",
     "disabled" : "Kikapcsolva",
+    "User {uid} has been {state}!" : "A {uid} felhasználó {state} volt!",
     "no group" : "nincs csoport",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "A jelszó megváltoztatása adatvesztéssel jár, mert lehetséges az adatok visszaállítása ennek a felhasználónak",
+    "Password successfully changed" : "Jelszó sikeresen megváltoztatva",
     "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
     "Error creating user: {message}" : "Hiba történt a felhasználó létrehozásakor: {message}",
     "A valid password must be provided" : "Érvényes jelszót kell megadnia",
     "A valid email must be provided" : "Érvényes e-mail címet kell megadni",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Üdv!<br><br>Értesítünk, hogy van egy %s fiókja.<br><br>Felhasználónév: %s<br>Hozzáférés: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Üdv.",
+    "Use the following link to confirm your changes to the email address: {link}" : "A következő linken erősítse meg az email cím módosítását: {link}",
+    "Email address changed to {mailAddress} successfully." : "Emailcím {mailAddress}-re sikeresen módosítva ",
+    "Cheers!" : "Üdvözlet!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Üdv!\n\nÉrtesítünk, hogy van egy %s fiókja.\n\nFelhasználónév: %s\nHozzáférés: %s\n\n",
-    "User documentation" : "Felhasználói dokumentáció",
-    "Administrator documentation" : "Adminisztrátori dokumentáció",
-    "Online documentation" : "Online dokumentáció",
-    "Forum" : "Fórum",
-    "Issue tracker" : "Hibabejelentések",
-    "Commercial support" : "Kereskedelmi támogatás",
+    "Language" : "Nyelv",
+    "Apps Management" : "Alkalmazások kezelése",
     "Developer documentation" : "Fejlesztői dokumentáció",
     "by %s" : "készítő: %s",
     "%s-licensed" : "%s-licencelt",
     "Documentation:" : "Dokumentációk:",
+    "User documentation" : "Felhasználói dokumentáció",
     "Admin documentation" : "Adminisztrátori dokumentáció",
+    "Visit website" : "Webhely meglátogatása",
+    "Report a bug" : "Hibabejelentés",
     "Show description …" : "Leírás megjelenítése ...",
     "Hide description …" : "Leírás elrejtése ...",
     "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ennek az alkalmazásnak nincs minimális ownCloud verzió megadva. Ez hibát okoz majd az ownCloud 11-es és későbbi verziókban.",
@@ -121,6 +143,8 @@ OC.L10N.register(
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az applikációt nem lehet telepíteni, mert a következő függőségek hiányoznak:",
     "Enable only for specific groups" : "Csak bizonyos csoportok számára tegyük elérhetővé",
     "Uninstall App" : "Alkalmazás eltávolítása",
+    "Show enabled apps" : "Az engedélyezett alkalmazások megjelenítése",
+    "Show disabled apps" : "A nem engedélyezett alkalmazások megjelenítése",
     "Cron" : "Ütemezett feladatok",
     "Last cron job execution: %s." : "Az utolsó cron feladat ekkor futott le: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Az utolsó cron feladat ekkor futott le: %s. Valami nincs rendben.",
@@ -153,12 +177,11 @@ OC.L10N.register(
     "Allow apps to use the Share API" : "Lehetővé teszi, hogy a programmodulok is használhassák a megosztást",
     "Allow users to share via link" : "Engedjük meg az állományok linkekkel történő megosztását",
     "Allow public uploads" : "Nyilvános feltöltés engedélyezése",
-    "Enforce password protection" : "Legyen kötelező a linkek jelszóval való védelme",
+    "Enforce password protection for read-only links" : "Jelszavas védelem kényszerítése a csak olvasható hivatkozásokra.",
     "Set default expiration date" : "Alapértelmezett lejárati idő beállítása",
-    "Allow users to send mail notification for shared files" : "A felhasználók küldhessenek e-mail értesítést a megosztás létrejöttéről",
     "Expire after " : "A lejárat legyen",
     "days" : "nap",
-    "Enforce expiration date" : "A beállított lejárati idő legyen kötelezően érvényes",
+    "Allow users to send mail notification for shared files" : "A felhasználók küldhessenek e-mail értesítést a megosztás létrejöttéről",
     "Allow resharing" : "A megosztás továbbadásának engedélyezése",
     "Allow sharing with groups" : "Megosztás engedélyezése a csoportokkal",
     "Restrict users to only share with users in their groups" : "A csoporttagok csak a saját csoportjukon belül oszthassanak meg anyagokat",
@@ -166,6 +189,8 @@ OC.L10N.register(
     "Exclude groups from sharing" : "Csoportok megosztási jogának tiltása",
     "These groups will still be able to receive shares, but not to initiate them." : "E csoportok tagjaival meg lehet osztani anyagokat, de ők nem hozhatnak létre megosztást.",
     "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Felhasználónév automatikus befejezése engedélyezése a megosztás ablakban. Ha le van tiltva, akkor a teljes felhasználónevet kell beírni.",
+    "None" : "Egyik sem",
+    "Save" : "Mentés",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Minden (végzetes hibák, hibák, figyelmeztetések, információk, hibakeresési üzenetek)",
     "Info, warnings, errors and fatal issues" : "Információk, figyelmeztetések, hibák és végzetes hibák",
     "Warnings, errors and fatal issues" : "Figyelmeztetések, hibák és végzetes hibák",
@@ -173,14 +198,15 @@ OC.L10N.register(
     "Fatal issues only" : "Csak a végzetes hibák",
     "Log" : "Naplózás",
     "What to log" : "Mit naplózzon",
+    "Download logfile (%s)" : "Naplófájl letöltése (%s)",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "A naplófájl 100MB-nál nagyobb. A letöltése hosszabb időt vehet igénybe.",
-    "None" : "Egyik sem",
     "Login" : "Login",
     "Plain" : "Plain",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "Email server" : "E-mail szerver",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "A konfigurációs fájl írásvédett. A beállításokat a fájl kézi módosításával végezd el.",
     "This is used for sending out notifications." : "Ezt használjuk a jelentések kiküldésére.",
     "Send mode" : "Küldési mód",
     "Encryption" : "Titkosítás",
@@ -211,12 +237,13 @@ OC.L10N.register(
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Adatbázisként az SQLite-ot fogjuk használni. Nagyobb telepítések esetén javasoljuk, hogy váltson másik adatbázis háttérkiszolgálóra",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Amikor az asztali klienset használja fálj szinkronizációra, akkor az SQLite használata nem ajánlott.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Más adatbázisról való áttéréshez használja a parancssort: 'occ db:convert-type', vagy keresse fel a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentációt ↗</a>.",
+    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Javasoljuk, hogy engedélyezd az operációs rendszer cron ütemezőjét, mivel a többi megoldás teljesítmény és megbízhatósági problémákat hordoz magában.",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Az ütemezett feladat (cronjob) nem futott le parancssorból. A következő hibák tűntek fel:",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Kérjük, ellenőrizze a <a target=\"_blank\" rel=\"noreferrer\"  href=\"%s\">telepítési dokumentációt ↗</a> és ellenőrizze a <a href=\"#log-section\">naplófájlt</a>, hogy tartalmaz-e bármilyen hibát vagy figyelmeztetést.",
     "All checks passed." : "Minden ellenőrzés sikeres.",
+    "System Status" : "Rendszerállapot",
     "Tips & tricks" : "Tippek és trükkök",
     "How to do backups" : "Hogyan csináljunk biztonsági mentéseket",
-    "Advanced monitoring" : "Haladó monitorozás",
     "Performance tuning" : "Teljesítményi hangolás",
     "Improving the config.php" : "config.php javítása",
     "Theming" : "Témázás",
@@ -226,6 +253,8 @@ OC.L10N.register(
     "Android app" : "Android applikáció",
     "iOS app" : "IOS applikáció",
     "Show First Run Wizard again" : "Nézzük meg újra az első bejelentkezéskori segítséget!",
+    "Domain" : "Domain",
+    "Add" : "Hozzáadás",
     "Profile picture" : "Profilkép",
     "Upload new" : "Új feltöltése",
     "Select from Files" : "Kiválasztás a Fájlkból",
@@ -240,29 +269,33 @@ OC.L10N.register(
     "For password recovery and notifications" : "Jelszó helyreállításhoz és értesítésekhez",
     "No email address set" : "Nincs e-mail cím beállítva",
     "You are member of the following groups:" : "Tagja vagy a következő csoport(ok)nak:",
+    "You are not a member of any groups." : "Egyetlen csoportnak sem vagy tagja.",
     "Password" : "Jelszó",
     "Unable to change your password" : "A jelszó nem változtatható meg",
     "Current password" : "A jelenlegi jelszó",
     "New password" : "Az új jelszó",
     "Change password" : "A jelszó megváltoztatása",
-    "Language" : "Nyelv",
     "Help translate" : "Segítsen a fordításban!",
-    "Unlimited" : "Korlátlan",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "{communityopen}ownCloud közösség{linkclose} fejleszti, a {githubopen}forráskód{linkclose} {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} licenc alatt licencelve.",
+    "Sessions" : "Munkamenetek",
+    "Browser" : "Böngésző",
     "Name" : "Név",
     "Username" : "Felhasználónév",
     "Done" : "Kész",
     "Version" : "Verzió",
+    "Resend activation link" : "Aktiválási link újraküldése",
+    "New Password" : "Új jelszó",
+    "Confirm Password" : "Jelszó megerősítése",
+    "Please set your password" : "Kérjük állítsa be jelszavát",
     "Personal" : "Személyes",
     "Admin" : "Adminsztráció",
-    "Error" : "Hiba",
+    "Settings" : "Beállítások",
+    "Show enabled/disabled option" : "Az engedélyezett / letiltott lehetőség megjelenítése",
     "Show storage location" : "Háttértároló helyének mutatása",
     "Show last log in" : "Utolsó bejelentkezés megjelenítése",
     "Show user backend" : "Felhasználói háttér mutatása",
-    "Send email to new user" : "E-mail küldése az új felhasználónak",
     "Show email address" : "E-mail cím megjelenítése",
     "E-Mail" : "E-mail",
-    "Create" : "Létrehozás",
     "Admin Recovery Password" : "Adminisztrátori jelszó az állományok visszanyerésére",
     "Enter the recovery password in order to recover the users files during password change" : "Adja meg az adatok visszanyeréséhez szükséges jelszót arra az esetre, ha a felhasználók megváltoztatják a jelszavukat",
     "Add Group" : "Csoport létrehozása",
@@ -271,7 +304,8 @@ OC.L10N.register(
     "Admins" : "Adminok",
     "Default Quota" : "Alapértelmezett kvóta",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Kérjük adja meg a tárolási kvótát (pl.  \"512 MB\" vagy \"12 GB\")",
-    "Other" : "Más",
+    "Unlimited" : "Korlátlan",
+    "Other" : "más",
     "Full Name" : "Teljes név",
     "Group Admin for" : "Csoport Adminisztrátor itt",
     "Quota" : "Kvóta",
@@ -281,15 +315,6 @@ OC.L10N.register(
     "change full name" : "a teljes név megváltoztatása",
     "set new password" : "új jelszó beállítása",
     "change email address" : "e-mail cím megváltoztatása",
-    "Default" : "Alapértelmezett",
-    "Change" : "Változás",
-    "Share" : "Megosztás",
-    "Disconnect" : "Szétkapcsol",
-    "Domain" : "Domain",
-    "Add" : "Hozzáadás",
-    "Show enabled apps" : "Az engedéjezett alkalmazások mutatása",
-    "Show disabled apps" : "A nem engedéjezett alkalmazások mutatása",
-    "Invalid email address" : "Érvénytelen email cím",
-    "%s password changed successfully" : "%s jelszó sikeresen megváltozott"
+    "Default" : "Alapértelmezett"
 },
 "nplurals=2; plural=(n != 1);");
