@@ -1,38 +1,48 @@
 OC.L10N.register(
     "settings",
     {
-    "Log" : "Registro",
-    "Language changed" : "Linguage cambiate",
-    "Invalid request" : "Requesta invalide",
+    "Couldn't send reset email. Please contact your administrator." : "Non poteva inviar le message de reinitialisation. Per favor contacta tu administrator.",
     "Saved" : "Salveguardate",
     "Email sent" : "Message de e-posta inviate",
+    "Create" : "Crear",
+    "Delete" : "Deler",
+    "Share" : "Compartir",
+    "Language changed" : "Linguage cambiate",
+    "Invalid request" : "Requesta invalide",
+    "All" : "Omne",
     "Very weak password" : "Contrasigno multo debile",
     "Weak password" : "Contrasigno debile",
     "So-so password" : "Contrasigno passabile",
     "Good password" : "Contrasigno bon",
     "Strong password" : "Contrasigno forte",
-    "Delete" : "Deler",
     "Groups" : "Gruppos",
     "never" : "nunquam",
-    "__language_name__" : "Interlingua",
-    "Security Warning" : "Aviso de securitate",
-    "More" : "Plus",
-    "by" : "per",
     "Cheers!" : "Acclamationes!",
+    "Language" : "Linguage",
+    "days" : "dies",
+    "None" : "Necun",
+    "Save" : "Salveguardar",
+    "Log" : "Registro",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Particularmente quando usar le cliente scriptorio pro synchronisar files, le uso de SQLite es discoragiate.",
     "Get the apps to sync your files" : "Obtene le apps (applicationes) pro synchronizar tu files",
+    "Add" : "Adder",
+    "Profile picture" : "Imagine de profilo",
+    "Cancel" : "Cancellar",
+    "Email" : "E-posta",
+    "Your email address" : "Tu adresse de e-posta",
     "Password" : "Contrasigno",
     "Unable to change your password" : "Non pote cambiar tu contrasigno",
     "Current password" : "Contrasigno currente",
     "New password" : "Nove contrasigno",
     "Change password" : "Cambiar contrasigno",
-    "Email" : "E-posta",
-    "Your email address" : "Tu adresse de e-posta",
-    "Profile picture" : "Imagine de profilo",
-    "Cancel" : "Cancellar",
-    "Language" : "Linguage",
     "Help translate" : "Adjuta a traducer",
+    "Name" : "Nomine",
     "Username" : "Nomine de usator",
-    "Create" : "Crear",
+    "New Password" : "Nove contrasigno",
+    "Personal" : "Personal",
+    "Admin" : "Administration",
+    "Settings" : "Configurationes",
+    "E-Mail" : "E-posta",
     "Group" : "Gruppo",
     "Default Quota" : "Quota predeterminate",
     "Other" : "Altere",
